@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel.h
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.h 8438 2018-03-29 13:05:42Z michael $
+ * \version $Id: channel.h 8916 2019-04-21 22:49:51Z michael $
  */
 
 #ifndef INCLUDED_channel_h
@@ -36,6 +36,13 @@
 #define AddMemberFlag(x, y) ((x)->flags |=  (y))
 #define DelMemberFlag(x, y) ((x)->flags &= ~(y))
 
+enum
+{
+  CAN_SEND_NO    =  0,
+  CAN_SEND_NONOP = -1,
+  CAN_SEND_OPV   = -2
+};
+
 enum
 {
   MSG_FLOOD_NOTICED  = 1 << 0,
@@ -71,16 +78,16 @@ struct Channel
   char topic[TOPICLEN + 1];
   char topic_info[NICKLEN + USERLEN + HOSTLEN + 3];
 
-  uintmax_t creationtime;
-  uintmax_t topic_time;
-  uintmax_t last_knock;  /**< Don't allow knock to flood */
-  uintmax_t last_invite;
-  uintmax_t last_join_time;
-  uintmax_t first_received_message_time; /*!< channel flood control */
+  uintmax_t creationtime;  /**< Real time */
+  uintmax_t topic_time;  /**< Real time */
+  uintmax_t last_knock;  /**< Don't allow knock to flood; monotonic time */
+  uintmax_t last_invite;  /**< Monotonic time */
+  uintmax_t last_join_time;  /**< Monotonic time */
+  uintmax_t first_received_message_time; /*!< Channel flood control; monotonic time */
   unsigned int flags;
   unsigned int received_number_of_privmsgs;
 
-  dlink_list locmembers;  /*!< local members are here too */
+  dlink_list members_local;  /*!< local members are here too */
   dlink_list members;
   dlink_list invites;
   dlink_list banlist;
@@ -96,7 +103,7 @@ struct Channel
 /*! \brief Membership structure */
 struct Membership
 {
-  dlink_node locchannode;  /**< link to chptr->locmembers */
+  dlink_node locchannode;  /**< link to chptr->members_local */
   dlink_node channode;     /**< link to chptr->members    */
   dlink_node usernode;     /**< link to source_p->channel */
   struct Channel *chptr;   /**< Channel pointer */
@@ -113,7 +120,7 @@ struct Ban
   char host[HOSTLEN + 1];
   char who[NICKLEN + USERLEN + HOSTLEN + 3];
   size_t len;
-  uintmax_t when;
+  uintmax_t when;  /**< Time this ban has been set; real time */
   struct irc_ssaddr addr;
   int bits;
   int type;
@@ -126,22 +133,22 @@ struct Invite
   dlink_node chan_node;  /**< link to chptr->invites */
   struct Channel *chptr;  /**< Channel pointer */
   struct Client *client_p;  /**< Client pointer */
-  uintmax_t when;  /**< Time the invite has been created */
+  uintmax_t when;  /**< Time the invite has been created; monotonic time */
 };
 
 
 extern const dlink_list *channel_get_list(void);
-extern int channel_check_name(const char *, const int);
-extern int can_send(struct Channel *, struct Client *, struct Membership *, const char *, int);
-extern int is_banned(const struct Channel *, const struct Client *);
+extern bool channel_check_name(const char *, bool);
+extern int can_send(struct Channel *, struct Client *, struct Membership *, const char *, bool);
+extern bool is_banned(const struct Channel *, const struct Client *);
 extern int has_member_flags(const struct Membership *, const unsigned int);
 
 extern void channel_do_join(struct Client *, char *, char *);
 extern void channel_do_part(struct Client *, char *, const char *);
 extern void remove_ban(struct Ban *, dlink_list *);
-extern void add_user_to_channel(struct Channel *, struct Client *, unsigned int, int);
+extern void add_user_to_channel(struct Channel *, struct Client *, unsigned int, bool);
 extern void remove_user_from_channel(struct Membership *);
-extern void channel_member_names(struct Client *, struct Channel *, int);
+extern void channel_member_names(struct Client *, struct Channel *, bool);
 extern void add_invite(struct Channel *, struct Client *);
 extern void del_invite(struct Invite *);
 extern void clear_invite_list(dlink_list *);
@@ -149,9 +156,9 @@ extern void channel_send_modes(struct Client *, const struct Channel *);
 extern void channel_modes(const struct Channel *, const struct Client *, char *, char *);
 extern void check_spambot_warning(struct Client *, const char *);
 extern void channel_free(struct Channel *);
-extern void channel_set_topic(struct Channel *, const char *, const char *, uintmax_t, int);
+extern void channel_set_topic(struct Channel *, const char *, const char *, uintmax_t, bool);
 
-extern const char *get_member_status(const struct Membership *, const int);
+extern const char *get_member_status(const struct Membership *, bool);
 
 extern struct Channel *channel_make(const char *);
 extern struct Membership *find_channel_link(const struct Client *, const struct Channel *);
