@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.h
  * \brief Includes channel mode related definitions and structures.
- * \version $Id: channel_mode.h 8478 2018-04-03 17:03:30Z michael $
+ * \version $Id: channel_mode.h 8807 2019-01-19 19:47:11Z michael $
  */
 
 #ifndef INCLUDED_channel_mode_h
@@ -38,26 +38,18 @@ enum { MAXMODEPARAMS = 6 };
 
 enum
 {
-  MODE_QUERY = 0,
-  MODE_DEL   = 1,
-  MODE_ADD   = 2
+  MODE_QUERY,
+  MODE_DEL,
+  MODE_ADD
 };
 
 enum
 {
   CHACCESS_NOTONCHAN = -1,
-  CHACCESS_PEON      =  0,
-  CHACCESS_HALFOP    =  1,
-  CHACCESS_CHANOP    =  2,
-  CHACCESS_REMOTE    =  3
-};
-
-/* can_send results */
-enum
-{
-  CAN_SEND_NO    =  0,
-  CAN_SEND_NONOP = -1,
-  CAN_SEND_OPV   = -2
+  CHACCESS_PEON,
+  CHACCESS_HALFOP,
+  CHACCESS_CHANOP,
+  CHACCESS_REMOTE
 };
 
 /* Channel related flags */
@@ -117,10 +109,12 @@ struct ChModeChange
 
 struct chan_mode
 {
-  const unsigned char letter;
-  const unsigned int mode;
-  const unsigned int only_opers;
-  const unsigned int only_servers;
+  unsigned char letter;
+  unsigned int mode;
+  unsigned int flag;
+  bool only_opers;
+  bool only_servers;
+  int required_oplevel;
   void (*func)(struct Client *,
                struct Channel *, int, int *, char **, int *,
                int, int, const char, const struct chan_mode *);
@@ -130,7 +124,7 @@ extern const struct chan_mode *cmode_map[];
 extern const struct chan_mode  cmode_tab[];
 
 extern void channel_mode_init(void);
-extern int add_id(struct Client *, struct Channel *, char *, unsigned int);
+extern bool add_id(struct Client *, struct Channel *, char *, dlink_list *);
 extern void channel_mode_set(struct Client *, struct Channel *,
                              struct Membership *, int, char **);
 extern void clear_ban_cache_list(dlink_list *);
