@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id: client.h 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: client.h 8962 2019-05-11 21:04:34Z michael $
  */
 
 
@@ -129,15 +129,14 @@ enum
   FLAGS_EOB           = 1 << 13,  /**< Server has sent us an EOB */
   FLAGS_HIDDEN        = 1 << 14,  /**< A hidden server. Not shown in /links */
   FLAGS_BLOCKED       = 1 << 15,  /**< Must wait for COMM_SELECT_WRITE */
-  FLAGS_USERHOST      = 1 << 16,  /**< Client is in userhost hash */
-  FLAGS_EXEMPTRESV    = 1 << 17,  /**< Client is exempt from RESV */
-  FLAGS_GOTUSER       = 1 << 18,  /**< If we received a USER command */
-  FLAGS_FINISHED_AUTH = 1 << 19,  /**< Client has been released from auth */
-  FLAGS_FLOOD_NOTICED = 1 << 20,  /**< Notice to opers about this flooder has been sent */
-  FLAGS_SERVICE       = 1 << 21,  /**< Client/server is a network service */
-  FLAGS_SSL           = 1 << 22,  /**< User is connected via TLS/SSL */
-  FLAGS_SQUIT         = 1 << 23,
-  FLAGS_EXEMPTXLINE   = 1 << 24   /**< Client is exempt from x-lines */
+  FLAGS_EXEMPTRESV    = 1 << 16,  /**< Client is exempt from RESV */
+  FLAGS_GOTUSER       = 1 << 17,  /**< If we received a USER command */
+  FLAGS_FINISHED_AUTH = 1 << 18,  /**< Client has been released from auth */
+  FLAGS_FLOOD_NOTICED = 1 << 19,  /**< Notice to opers about this flooder has been sent */
+  FLAGS_SERVICE       = 1 << 20,  /**< Client/server is a network service */
+  FLAGS_SSL           = 1 << 21,  /**< User is connected via TLS/SSL */
+  FLAGS_SQUIT         = 1 << 22,
+  FLAGS_EXEMPTXLINE   = 1 << 23   /**< Client is exempt from x-lines */
 };
 
 #define HasFlag(x, y) ((x)->flags &   (y))
@@ -174,7 +173,8 @@ enum
   UMODE_SSL          = 1 << 23,  /**< User is connected via TLS/SSL */
   UMODE_WEBIRC       = 1 << 24,  /**< User connected via a webirc gateway */
   UMODE_HIDEIDLE     = 1 << 25,  /**< Hides idle and signon time in WHOIS */
-  UMODE_HIDECHANS    = 1 << 26   /**< Hides channel list in WHOIS */
+  UMODE_HIDECHANS    = 1 << 26,  /**< Hides channel list in WHOIS */
+  UMODE_EXPIRATION   = 1 << 27   /**< Receives *LINE expiration notices */
 };
 
 #define HasUMode(x, y) ((x)->umodes &   (y))
@@ -261,7 +261,7 @@ struct Server
 {
   dlink_list server_list;  /**< Servers on this server */
   dlink_list client_list;  /**< Clients on this server */
-  char by[NICKLEN + 1];    /**< Who activated this connection */
+  char by[NICKLEN + 1];  /**< Who activated this connection */
 };
 
 /*! \brief ListTask structure */
@@ -274,10 +274,10 @@ struct ListTask
   unsigned int hash_index;  /**< The hash bucket we are currently in */
   unsigned int users_min;
   unsigned int users_max;
-  unsigned int created_min;
-  unsigned int created_max;
-  unsigned int topicts_min;
-  unsigned int topicts_max;
+  unsigned int created_min;  /**< Real time */
+  unsigned int created_max;  /**< Real time */
+  unsigned int topicts_min;  /**< Real time */
+  unsigned int topicts_max;  /**< Real time */
   char topic[TOPICLEN + 1];
 };
 
@@ -288,31 +288,30 @@ struct ListTask
  */
 struct Connection
 {
-  dlink_node   lclient_node;
+  dlink_node lclient_node;
 
   unsigned int registration;
   unsigned int cap_client;  /**< Client capabilities (from us) */
   unsigned int cap_active;  /**< Active capabilities (to us) */
-  unsigned int       caps;  /**< Capabilities bit-field */
+  unsigned int caps;  /**< Capabilities bit-field */
 
   unsigned int operflags;     /**< IRC Operator privilege flags */
   unsigned int random_ping; /**< Holding a 32bit value used for PING cookies */
 
-  uintmax_t serial;     /**< Used to enforce 1 send per nick */
-
-  uintmax_t    lasttime;   /**< Last time data read from socket */
-  uintmax_t    firsttime;  /**< Time client was created */
-  uintmax_t    since;      /**< Last time we parsed something */
-  uintmax_t    last_join_time;   /**< When this client last joined a channel */
-  uintmax_t    last_leave_time;  /**< When this client last left a channel */
-  int          join_leave_count; /**< Count of JOIN/LEAVE in less than
-                                         MIN_JOIN_LEAVE_TIME seconds */
-  int          oper_warn_count_down; /**< Warn opers of this possible
-                                          spambot every time this gets to 0 */
-  uintmax_t    last_caller_id_time;
-  uintmax_t    first_received_message_time;
-  uintmax_t    last_privmsg;  /**< Last time we got a PRIVMSG */
+  uintmax_t serial;  /**< Used to enforce 1 send per nick */
+  uintmax_t last_data;  /**< Last time data read from socket; monotonic time */
+  uintmax_t last_ping;  /**< Last time data read from socket; currently this is a copy of last_data
+                             which can be modified by check_pings_list; monotonic time */
+  uintmax_t created_real;  /**< Time client was created; real time */
+  uintmax_t created_monotonic;  /**< Time client was created; monotonic time */
+  uintmax_t last_caller_id_time;  /**< Monotonic time */
+  uintmax_t first_received_message_time;  /**< Monotonic time */
+  uintmax_t last_privmsg;  /**< Last time we got a PRIVMSG; monotonic time */
+  uintmax_t last_join_time;  /**< When this client last joined a channel; monotonic time */
+  uintmax_t last_leave_time;  /**< When this client last left a channel; monotonic time */
 
+  unsigned int join_leave_count;  /**< Count of JOIN/LEAVE in less than MIN_JOIN_LEAVE_TIME seconds */
+  unsigned int oper_warn_count_down;  /**< Warn opers of this possible spambot every time this gets to 0 */
   unsigned int received_number_of_privmsgs;
 
   struct ListTask  *list_task;
@@ -322,34 +321,31 @@ struct Connection
 
   struct
   {
-    unsigned int messages;      /**< Statistics: protocol messages sent/received */
-    uintmax_t bytes;             /**< Statistics: total bytes sent/received */
+    unsigned int messages;  /**< Statistics: protocol messages sent/received */
+    uintmax_t bytes;  /**< Statistics: total bytes sent/received */
   } recv, send;
 
   struct
   {
     unsigned int count;  /**< How many AWAY/INVITE/KNOCK/NICK requests client has sent */
-    uintmax_t last_attempt;  /**< Last time the AWAY/INVITE/KNOCK/NICK request was issued */
+    uintmax_t last_attempt;  /**< Last time the AWAY/INVITE/KNOCK/NICK request was issued; monotonic time */
   } away, invite, knock, nick;
 
   struct AuthRequest *auth;
-  struct Listener *listener;   /**< Listener accepted from */
-  dlink_list        acceptlist; /**< Clients I'll allow to talk to me */
-  dlink_list        watches;   /**< Chain of Watch pointer blocks */
-  dlink_list        confs;     /**< Configuration record associated */
-  dlink_list        invited;   /**< Chain of invite pointer blocks */
-  struct irc_ssaddr ip;
-  int               aftype;    /**< Makes life easier for DNS res in IPV6 */
+  struct Listener *listener;  /**< Listener accepted from */
+  dlink_list acceptlist;  /**< Clients I'll allow to talk to me */
+  dlink_list watches;  /**< Chain of Watch pointer blocks */
+  dlink_list confs;  /**< Configuration record associated */
+  dlink_list invited;  /**< Chain of invite pointer blocks */
 
-  fde_t            *fd;
+  fde_t *fd;  /**< Pointer to fdlist.c:fd_table[] */
 
   /* Anti-flood stuff. We track how many messages were parsed and how
    * many we were allowed in the current second, and apply a simple
    * decay to avoid flooding.
    *   -- adrian
    */
-  int allow_read;       /**< How many we're allowed to read in this second */
-  int sent_parsed;      /**< How many messages we've parsed in this second */
+  int sent_parsed;  /**< How many messages we've parsed in this second */
 
   char *password;  /**< Password supplied by the client/server */
 };
@@ -358,31 +354,35 @@ struct Connection
 struct Client
 {
   dlink_node node;
-  dlink_node lnode;             /**< Used for Server->servers/users */
+  dlink_node lnode;  /**< Used for Server->servers/users */
 
   struct Connection *connection;  /**< Connection structure associated with this client */
-  struct Client    *hnext;      /**< For client hash table lookups by name */
-  struct Client    *idhnext;    /**< For SID hash table lookups by sid */
-  struct Server    *serv;       /**< ...defined, if this is a server */
-  struct Client    *servptr;    /**< Points to server this Client is on */
-  struct Client    *from;       /**< == self, if Local Client, *NEVER* NULL! */
+  struct Client *hnext;  /**< For client hash table lookups by name */
+  struct Client *idhnext;  /**< For SID hash table lookups by sid */
+  struct Server *serv;  /**< ...defined, if this is a server */
+  struct Client *servptr;  /**< Points to server this Client is on */
+  struct Client *from;  /**< == self, if Local Client, *NEVER* NULL! */
 
-  uintmax_t         tsinfo;     /**< TS on the nick, SVINFO on server */
+  uintmax_t tsinfo;  /**< Timestamp on this nick; real time */
 
-  unsigned int      flags;      /**< Client flags */
-  unsigned int      umodes;     /**< User modes this client has set */
-  unsigned int      hopcount;   /**< Number of servers to this 0 = local */
-  unsigned int      status;     /**< Client type */
-  unsigned int      handler;    /**< Handler index */
+  unsigned int flags;  /**< Client flags */
+  unsigned int umodes;  /**< User modes this client has set */
+  unsigned int hopcount;  /**< Number of servers to this 0 = local */
+  unsigned int status;  /**< Client type */
+  unsigned int handler;  /**< Handler index */
 
-  dlink_list        whowas_list;
-  dlink_list        channel;   /**< Chain of channel pointer blocks */
-  dlink_list        svstags;   /**< List of ServicesTag items */
+  dlink_list whowas_list;
+  dlink_list channel;  /**< Chain of channel pointer blocks */
+  dlink_list svstags;  /**< List of ServicesTag items */
 
-  char away[AWAYLEN + 1]; /**< Client's AWAY message. Can be set/unset via AWAY command */
-  char name[HOSTLEN + 1]; /**< Unique name for a client nick or host */
-  char id[IDLEN + 1];       /**< Client ID, unique ID per client */
-  char account[ACCOUNTLEN + 1]; /**< Services account */
+  struct irc_ssaddr ip;  /**< Real IP address */
+
+  char *certfp;  /**< SSL certificate fingerprint */
+
+  char away[AWAYLEN + 1];  /**< Client's AWAY message. Can be set/unset via AWAY command */
+  char name[HOSTLEN + 1];  /**< Unique name for a client nick or host */
+  char id[IDLEN + 1];  /**< Client ID, unique ID per client */
+  char account[ACCOUNTLEN + 1];  /**< Services account */
 
   /*
    * client->username is the username from ident or the USER message,
@@ -391,37 +391,35 @@ struct Client
    * tilde depending on the auth{} block. Once a client has registered,
    * this field should be considered read-only.
    */
-  char              username[USERLEN + 1]; /* client's username */
+  char username[USERLEN + 1];  /**< client's username */
 
   /*
    * client->host contains the resolved name or ip address as a string
    * for the user, it may be fiddled with for oper spoofing etc.
    * once it's changed the *real* address goes away.
    */
-  char              host[HOSTLEN + 1];     /* client's hostname */
+  char host[HOSTLEN + 1];  /**< Client's hostname. Can be faked/spoofed */
 
   /*
    * client->realhost contains the resolved name or ip address as a string
    * for the user. Once a client has registered, this field should be
    * considered read-only.
    */
-  char              realhost[HOSTLEN + 1];     /* client's real hostname */
+  char realhost[HOSTLEN + 1];  /**< Client's real hostname */
 
 
   /*
    * client->info for unix clients will normally contain the info from the
    * gcos field in /etc/passwd but anything can go here.
    */
-  char              info[REALLEN + 1]; /* Free form additional client info */
+  char info[REALLEN + 1];  /**< Free form additional client info */
 
   /*
    * client->sockhost contains the ip address gotten from the socket as a
    * string, this field should be considered read-only once the connection
    * has been made. (set in s_bsd.c only)
    */
-  char              sockhost[HOSTIPLEN + 1]; /* This is the host name from the
-                                                socket ip address as string */
-  char             *certfp;  /**< SSL certificate fingerprint */
+  char sockhost[HOSTIPLEN + 1];  /**< This is the host name from the socket ip address as string */
 };
 
 
@@ -434,7 +432,7 @@ extern dlink_list local_server_list;  /* local servers to this server ONLY
 extern dlink_list unknown_list;       /* unknown clients ON this server only        */
 extern dlink_list oper_list;          /* our opers, duplicated in local_client_list */
 
-extern int accept_message(struct Client *, struct Client *);
+extern bool accept_message(struct Client *, struct Client *);
 extern unsigned int client_get_idle_time(const struct Client *, const struct Client *);
 extern struct split_nuh_item *find_accept(const char *, const char *,
                                           const char *, struct Client *,
