@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf.h
  * \brief A header for the configuration functions.
- * \version $Id: conf.h 8478 2018-04-03 17:03:30Z michael $
+ * \version $Id: conf.h 8970 2019-05-18 11:58:17Z michael $
  */
 
 #ifndef INCLUDED_conf_h
@@ -126,20 +126,20 @@ struct MaskItem
   dlink_list         leaf_list;
   dlink_list         hub_list;
   enum maskitem_type type;
-  unsigned int       dns_failed;
-  unsigned int       dns_pending;
+  bool       active;
+  bool       dns_failed;
+  bool       dns_pending;
   unsigned int       flags;
   unsigned int       modes;
   unsigned int       port;
   unsigned int       aftype;
-  unsigned int       active;
   unsigned int       htype;
   unsigned int       ref_count;  /* Number of *LOCAL* clients using this */
   int                bits;
   uintmax_t          until;     /* Hold action until this time (calendar time) */
   uintmax_t          setat;
-  struct irc_ssaddr  bind;  /* ip to bind to for outgoing connect */
-  struct irc_ssaddr  addr;  /* ip to connect to */
+  struct irc_ssaddr  *bind;  /* ip to bind to for outgoing connect */
+  struct irc_ssaddr  *addr;  /* ip to connect to */
   struct ClassItem  *class;  /* Class of connection */
   char              *name;
   char              *user;     /* user part of user@host */
@@ -152,13 +152,6 @@ struct MaskItem
   char              *cipher_list;
 };
 
-struct CidrItem
-{
-  dlink_node node;
-  struct irc_ssaddr mask;
-  unsigned int number_on_this_cidr;
-};
-
 struct conf_parser_context
 {
   unsigned int boot;
@@ -205,9 +198,7 @@ struct config_general_entry
   unsigned int stats_u_oper_only;
   unsigned int short_motd;
   unsigned int no_oper_flood;
-  unsigned int tkline_expire_notices;
   unsigned int opers_bypass_callerid;
-  unsigned int ignore_bogus_ts;
   unsigned int pace_wait;
   unsigned int pace_wait_simple;
   unsigned int oper_only_umodes;
@@ -276,10 +267,6 @@ struct config_serverinfo_entry
   unsigned int default_max_clients;
   unsigned int max_nick_length;
   unsigned int max_topic_length;
-  unsigned int specific_ipv4_vhost;
-  unsigned int specific_ipv6_vhost;
-  struct irc_ssaddr ip;
-  struct irc_ssaddr ip6;
 };
 
 struct config_admin_entry
@@ -294,6 +281,18 @@ struct config_log_entry
   unsigned int use_logging;
 };
 
+struct aline_ctx
+{
+  bool add;
+  bool simple_mask;
+  char *mask;
+  char *user;
+  char *host;
+  char *reason;
+  char *server;
+  uintmax_t duration;
+};
+
 extern dlink_list flatten_links;
 extern dlink_list connect_items;
 extern dlink_list operator_items;
@@ -305,19 +304,18 @@ extern struct config_serverhide_entry ConfigServerHide;
 extern struct config_serverinfo_entry ConfigServerInfo;
 extern struct config_admin_entry ConfigAdminInfo;
 
-extern int valid_wild_card_simple(const char *);
-extern int valid_wild_card(int, ...);
+extern bool valid_wild_card_simple(const char *);
+extern bool valid_wild_card(int, ...);
 
 extern struct MaskItem *conf_make(enum maskitem_type);
-extern void read_conf_files(int);
+extern void read_conf_files(bool);
 extern int conf_attach(struct Client *, struct MaskItem *);
 extern int check_client(struct Client *);
 
 
 extern void conf_detach(struct Client *, enum maskitem_type);
 extern struct MaskItem *find_conf_name(dlink_list *, const char *, enum maskitem_type);
-extern int conf_connect_allowed(struct irc_ssaddr *, int);
-extern const char *oper_privs_as_string(const unsigned int);
+extern int conf_connect_allowed(struct irc_ssaddr *);
 extern void split_nuh(struct split_nuh_item *);
 extern struct MaskItem *operator_find(const struct Client *, const char *);
 extern struct MaskItem *connect_find(const char *, int (*)(const char *, const char *));
@@ -325,16 +323,15 @@ extern void conf_free(struct MaskItem *);
 extern void yyerror(const char *);
 extern void conf_error_report(const char *);
 extern void cleanup_tklines(void *);
-extern void conf_rehash(int);
+extern void conf_rehash(bool);
 extern void lookup_confhost(struct MaskItem *);
 extern void conf_add_class_to_conf(struct MaskItem *, const char *);
 
 extern const char *get_oper_name(const struct Client *);
 
 /* XXX should the parse_aline stuff go into another file ?? */
-extern int parse_aline(const char *, struct Client *, int, char **,
-                       char **, char **, uintmax_t *, char **, char **);
+extern bool parse_aline(const char *, struct Client *, int, char **, struct aline_ctx *);
 
 extern uintmax_t valid_tkline(const char *, const int);
-extern int match_conf_password(const char *, const struct MaskItem *);
+extern bool match_conf_password(const char *, const struct MaskItem *);
 #endif  /* INCLUDED_conf_h */
