@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file
  * \brief Configuration managment for class{} blocks
- * \version $Id: conf_class.h 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: conf_class.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 
@@ -39,17 +39,17 @@ struct ClassItem
 {
   char *name;
   dlink_node node;
-  dlink_list list_ipv4;         /* base of per cidr ipv4 client link list */
-  dlink_list list_ipv6;         /* base of per cidr ipv6 client link list */
+  bool active;
+  void *ip_tree_v6;  /**< Pointer to 'patricia_tree_t' item */
+  void *ip_tree_v4;  /**< Pointer to 'patricia_tree_t' item */
   unsigned int ref_count;
   unsigned int max_sendq;
   unsigned int max_recvq;
   unsigned int con_freq;
   unsigned int ping_freq;
   unsigned int max_total;
-  unsigned int max_local;
-  unsigned int max_global;
-  unsigned int max_perip;
+  unsigned int max_perip_local;
+  unsigned int max_perip_global;
   unsigned int min_idle;
   unsigned int max_idle;
   unsigned int max_channels;
@@ -57,7 +57,6 @@ struct ClassItem
   unsigned int cidr_bitlen_ipv6;
   unsigned int number_per_cidr;
   unsigned int flags;
-  unsigned int active;
 };
 
 /* address of default class conf */
@@ -72,11 +71,10 @@ extern const char *get_client_class(const dlink_list *const);
 extern unsigned int get_client_ping(const dlink_list *const);
 extern unsigned int get_sendq(const dlink_list *const);
 extern unsigned int get_recvq(const dlink_list *const);
-extern struct ClassItem *class_find(const char *, int);
+extern struct ClassItem *class_find(const char *, bool);
 extern void class_mark_for_deletion(void);
 extern void class_delete_marked(void);
-extern void destroy_cidr_class(struct ClassItem *);
-extern int cidr_limit_reached(int, struct irc_ssaddr *, struct ClassItem *);
-extern void remove_from_cidr_check(struct irc_ssaddr *, struct ClassItem *);
-extern void rebuild_cidr_list(struct ClassItem *);
+extern bool class_ip_limit_add(struct ClassItem *, void *, bool);
+extern bool class_ip_limit_remove(struct ClassItem *, void *);
+extern void class_ip_limit_rebuild(struct ClassItem *);
 #endif  /* INCLUDED_conf_class_h */
