@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1996-2009 by Andrew Church <achurch@achurch.org>
- *  Copyright (c) 2012-2018 ircd-hybrid development team
+ *  Copyright (c) 2012-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file conf_db.h
  * \brief Includes file utilities for database handling
- * \version $Id: conf_db.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: conf_db.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_conf_db_h
@@ -36,14 +36,14 @@ struct dbFILE
   char tempname[HYB_PATH_MAX + 1];  /**< Name of the temporary file (for writing) */
 };
 
-extern int read_uint16(uint16_t *, struct dbFILE *);
-extern int write_uint16(uint16_t, struct dbFILE *);
-extern int read_uint32(uint32_t *, struct dbFILE *);
-extern int write_uint32(uint32_t, struct dbFILE *);
-extern int read_uint64(uint64_t *, struct dbFILE *);
-extern int write_uint64(uint64_t, struct dbFILE *);
-extern int read_string(char **, struct dbFILE *);
-extern int write_string(const char *, struct dbFILE *);
+extern bool read_uint16(uint16_t *, struct dbFILE *);
+extern bool write_uint16(uint16_t, struct dbFILE *);
+extern bool read_uint32(uint32_t *, struct dbFILE *);
+extern bool write_uint32(uint32_t, struct dbFILE *);
+extern bool read_uint64(uint64_t *, struct dbFILE *);
+extern bool write_uint64(uint64_t, struct dbFILE *);
+extern bool read_string(char **, struct dbFILE *);
+extern bool write_string(const char *, struct dbFILE *);
 
 extern void load_kline_database(const char *);
 extern void save_kline_database(const char *);
