@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2018 ircd-hybrid development team
+ *  Copyright (c) 1998-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_gecos.h
  * \brief Implements gecos {} block configuration management.
- * \version $Id: conf_gecos.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: conf_gecos.h 8971 2019-05-18 12:52:56Z michael $
  */
 
 #ifndef INCLUDED_conf_gecos_h
@@ -34,11 +34,11 @@ struct GecosItem
   char *reason;
   uintmax_t expire;
   uintmax_t setat;
-  unsigned int in_database;
+  bool in_database;
 };
 
 extern const dlink_list *gecos_get_list(void);
-extern void gecos_delete(struct GecosItem *);
+extern void gecos_delete(struct GecosItem *, bool);
 extern struct GecosItem *gecos_make(void);
 extern struct GecosItem *gecos_find(const char *, int (*)(const char *, const char *));
 extern void gecos_clear(void);
