@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2018 ircd-hybrid development team
+ *  Copyright (c) 2001-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_resv.h
  * \brief A header for the RESV functions.
- * \version $Id: conf_resv.h 8313 2018-02-28 17:45:36Z michael $
+ * \version $Id: conf_resv.h 8971 2019-05-18 12:52:56Z michael $
  */
 
 #ifndef INCLUDED_conf_resv_h
@@ -36,7 +36,7 @@ struct ResvItem
   char *reason;
   uintmax_t expire;
   uintmax_t setat;
-  unsigned int in_database;
+  bool in_database;
 };
 
 struct ResvExemptItem
@@ -52,9 +52,9 @@ struct ResvExemptItem
 
 extern const dlink_list *resv_chan_get_list(void);
 extern const dlink_list *resv_nick_get_list(void);
-extern void resv_delete(struct ResvItem *);
+extern void resv_delete(struct ResvItem *, bool);
 extern struct ResvItem *resv_make(const char *, const char *, const dlink_list *);
-extern int resv_exempt_find(const struct Client *, const struct ResvItem *);
+extern bool resv_exempt_find(const struct Client *, const struct ResvItem *);
 extern struct ResvItem *resv_find(const char *, int (*)(const char *, const char *));
 extern void resv_clear(void);
 extern void resv_expire(void);
