@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file fdlist.h
  * \brief The file descriptor list header.
- * \version $Id: fdlist.h 8378 2018-03-11 14:56:39Z michael $
+ * \version $Id: fdlist.h 8806 2019-01-19 19:32:10Z michael $
  */
 
 #ifndef INCLUDED_fdlist_h
@@ -31,20 +31,7 @@
 #include "tls.h"
 
 
-enum { FD_DESC_SIZE = 128 };  /* HOSTLEN + comment */
-
-enum
-{
-  COMM_OK,
-  COMM_ERR_BIND,
-  COMM_ERR_DNS,
-  COMM_ERR_TIMEOUT,
-  COMM_ERR_CONNECT,
-  COMM_ERROR,
-  COMM_ERR_MAX
-};
-
-struct Client;
+enum { FD_DESC_SIZE = 80 };  /* HOSTLEN + comment */
 
 typedef struct _fde
 {
@@ -56,7 +43,7 @@ typedef struct _fde
   int fd;  /* So we can use the fde_t as a callback ptr */
   int comm_index;  /* where in the poll list we live */
   int evcache;          /* current fd events as set up by the underlying I/O */
-  char desc[FD_DESC_SIZE];
+  char *desc;
 
   void (*read_handler)(struct _fde *, void *);
   void *read_data;
@@ -74,14 +61,13 @@ typedef struct _fde
 
   struct
   {
-    unsigned int open:1;
-    unsigned int is_socket:1;
+    bool open;
+    bool is_socket;
   } flags;
 
   struct
   {
     /* We don't need the host here ? */
-    struct irc_ssaddr S;
     struct irc_ssaddr hostaddr;
 
     void (*callback)(struct _fde *, int, void *);
@@ -98,8 +84,8 @@ extern int highest_fd;
 extern fde_t *fd_table;
 
 extern void fdlist_init(void);
-extern fde_t *fd_open(int, int, const char *);
-extern void fd_close(fde_t *);
+extern fde_t *fd_open(int, bool, const char *);
+extern fde_t *fd_close(fde_t *);
 extern void fd_note(fde_t *, const char *, ...);
 extern void close_standard_fds(void);
 extern void close_fds(void);
