@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hash.h
  * \brief A header for the ircd hashtable code.
- * \version $Id: hash.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: hash.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_hash_h
@@ -34,14 +34,12 @@
 
 struct Client;
 struct Channel;
-struct UserHost;
 
 enum
 {
   HASH_TYPE_ID,
   HASH_TYPE_CLIENT,
-  HASH_TYPE_CHANNEL,
-  HASH_TYPE_USERHOST
+  HASH_TYPE_CHANNEL
 };
 
 extern void hash_init(void);
@@ -51,10 +49,7 @@ extern void hash_add_channel(struct Channel *);
 extern void hash_del_channel(struct Channel *);
 extern void hash_add_id(struct Client *);
 extern void hash_del_id(struct Client *);
-extern void hash_add_userhost(struct UserHost *);
-extern void hash_del_userhost(struct UserHost *);
 
-extern struct UserHost *hash_find_userhost(const char *);
 extern struct Client *hash_find_id(const char *);
 extern struct Client *hash_find_client(const char *);
 extern struct Client *hash_find_server(const char *);
@@ -62,7 +57,7 @@ extern struct Channel *hash_find_channel(const char *);
 extern void *hash_get_bucket(int, unsigned int);
 
 extern void free_list_task(struct Client *);
-extern void safe_list_channels(struct Client *, int);
+extern void safe_list_channels(struct Client *, bool);
 
 extern unsigned int strhash(const char *);
 #endif  /* INCLUDED_hash_h */
