@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2018 ircd-hybrid development team
+ *  Copyright (c) 2001-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hostmask.h
  * \brief A header for the hostmask code.
- * \version $Id: hostmask.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: hostmask.h 8828 2019-02-02 16:49:32Z michael $
  */
 
 #ifndef INCLUDED_hostmask_h
@@ -68,18 +68,16 @@ struct AddressRec
 
 extern dlink_list atable[ATABLE_SIZE];
 extern int parse_netmask(const char *, struct irc_ssaddr *, int *);
-extern int match_ipv6(const struct irc_ssaddr *, const struct irc_ssaddr *, int);
-extern int match_ipv4(const struct irc_ssaddr *, const struct irc_ssaddr *, int);
+extern bool match_ipv6(const struct irc_ssaddr *, const struct irc_ssaddr *, int);
+extern bool match_ipv4(const struct irc_ssaddr *, const struct irc_ssaddr *, int);
 
-extern void mask_addr(struct irc_ssaddr *, int);
 extern struct AddressRec *add_conf_by_address(const unsigned int, struct MaskItem *);
 extern void delete_one_address_conf(const char *, struct MaskItem *);
 extern void clear_out_address_conf(void);
 extern void hostmask_expire_temporary(void);
 
-extern struct MaskItem *find_address_conf(const char *, const char *, const struct irc_ssaddr *,
-                                          int, const char *);
-extern struct MaskItem *find_dline_conf(const struct irc_ssaddr *, int);
+extern struct MaskItem *find_address_conf(const char *, const char *, const struct irc_ssaddr *, const char *);
+extern struct MaskItem *find_dline_conf(const struct irc_ssaddr *);
 extern struct MaskItem *find_conf_by_address(const char *, const struct irc_ssaddr *,
-                                             unsigned int, int, const char *, const char *, int);
+                                             unsigned int, const char *, const char *, int);
 #endif /* INCLUDED_hostmask_h */
