@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file id.h
  * \brief Contains functions pertaining to SID/UID generation.
- * \version $Id: id.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: id.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_id_h
@@ -34,8 +34,8 @@ enum
   TOTALSIDUID = IRC_MAXSID + IRC_MAXUID
 };
 
-extern int valid_sid(const char *);
-extern int valid_uid(const char *);
+extern bool valid_sid(const char *);
+extern bool valid_uid(const char *);
 extern void init_uid(void);
 extern const char *uid_get(void);
 extern void generate_sid(void);
