@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,31 +21,24 @@
 
 /*! \file ipcache.h
  * \brief Routines to count connections from particular IP addresses.
- * \version $Id: ipcache.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: ipcache.h 8928 2019-04-22 18:09:43Z michael $
  */
 
 #ifndef INCLUDED_ipcache_h
 #define INCLUDED_ipcache_h
-#include "ircd_defs.h"
-
-/*
- * Usually, with hash tables, you use a prime number...
- * but in this case I am dealing with ip addresses,
- * not ascii strings.
- */
-enum { IP_HASH_SIZE = 0x1000 };
 
 struct ip_entry
 {
-  dlink_node node;                /**< Doubly linked list node */
-  struct irc_ssaddr ip;           /**< Holds an IPv6 or IPv4 address */
-  unsigned int count;             /**< Number of registered users using this IP */
+  dlink_node node;                /**< List node; linked into ipcache_list */
+  void *trie_pointer;             /**< Pointer to 'patricia_tree_t' item */
+  unsigned int count_local;       /**< Number of local users using this IP */
+  unsigned int count_remote;      /**< Number of remote users using this IP */
   unsigned int connection_count;  /**< Number of connections from this IP in the last throttle_time duration */
-  uintmax_t last_attempt;         /**< The last time someone connected from this IP */
+  uintmax_t last_attempt;         /**< The last time someone connected from this IP; monotonic time */
 };
 
-extern struct ip_entry *ipcache_find_or_add_address(const struct irc_ssaddr *);
-extern void ipcache_remove_address(const struct irc_ssaddr *);
+extern struct ip_entry *ipcache_record_find_or_add(void *);
+extern void ipcache_record_remove(void *, int);
 extern void ipcache_get_stats(unsigned int *const, size_t *const);
 extern void ipcache_init(void);
 #endif
