@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2018 ircd-hybrid development team
+ *  Copyright (c) 1999-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file irc_string.h
  * \brief A header for the ircd string functions.
- * \version $Id: irc_string.h 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: irc_string.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_irc_string_h
@@ -30,7 +30,7 @@
 #include "config.h"
 
 
-extern int has_wildcards(const char *);
+extern bool has_wildcards(const char *);
 extern int match(const char *, const char *);
 
 extern unsigned int token_vector(char *, char, char *[], unsigned int);
