@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.h
  * \brief A header for the ircd startup routines.
- * \version $Id: ircd.h 8313 2018-02-28 17:45:36Z michael $
+ * \version $Id: ircd.h 8927 2019-04-22 11:08:47Z michael $
  */
 
 
@@ -30,18 +30,18 @@
 
 #include "ircd_defs.h"
 #include "config.h"
+#include "event.h"
 
 
 struct SetOptions
 {
+  bool autoconn;      /* autoconn enabled for all servers? */
   unsigned int maxclients;
-  unsigned int autoconn;      /* autoconn enabled for all servers? */
   unsigned int floodcount;  /* Number of messages in 'floodtime' seconds */
   unsigned int floodtime;
   unsigned int joinfloodtime;
   unsigned int joinfloodcount;
-  unsigned int ident_timeout; /* timeout for identd lookups        */
-  int spam_num;
+  unsigned int spam_num;
   unsigned int spam_time;
 };
 
@@ -85,30 +85,17 @@ struct Counter
 
 struct ServerState_t
 {
-  unsigned int foreground;
+  bool foreground;
 };
 
-struct ServerTime
-{
-  uintmax_t tv_sec, tv_usec;
-};
-
-
 extern char **myargv;
-extern const char *infotext[];
-extern const char *serno;
-extern const char *ircd_version;
 extern const char *logFileName;
 extern const char *pidFileName;
-extern unsigned int dorehash;
-extern unsigned int doremotd;
+extern bool dorehash;
+extern bool doremotd;
 extern struct Counter Count;
 extern struct ServerStatistics ServerStats;
 extern struct SetOptions GlobalSetOptions;
 extern struct ServerState_t server_state;
 extern struct event event_write_links_file;
-extern struct ServerTime SystemTime;
-#define CurrentTime SystemTime.tv_sec
-
-extern void set_time(void);
 #endif
