@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2018 ircd-hybrid development team
+ *  Copyright (c) 2001-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd_getopt.h
  * \brief A header for the getopt() command line option calls.
- * \version $Id: ircd_getopt.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: ircd_getopt.h 8863 2019-02-15 21:36:29Z michael $
  */
 
 #ifndef INCLUDED_ircd_getopt_h
@@ -31,7 +31,7 @@ struct lgetopt
 {
   const char *opt; /* name of the argument */
   void *argloc; /* where we store the argument to it (-option argument) */
-  enum { INTEGER, YESNO, STRING, USAGE, ENDEBUG } argtype;
+  enum { INTEGER, BOOLEAN, STRING, USAGE } argtype;
   const char *desc; /* description of the argument, usage for printing help */
 };
 
