@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file listener.h
  * \brief A header for the listener code.
- * \version $Id: listener.h 8338 2018-03-03 22:26:59Z michael $
+ * \version $Id: listener.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_listener_h
@@ -40,10 +40,10 @@ enum
 struct Listener
 {
   dlink_node node;           /**< Doubly linked list node */
+  bool active;               /**< Current state of listener */
   fde_t *fd;                 /**< File descriptor */
   int port;                  /**< Listener IP port */
   int ref_count;             /**< Number of connection references */
-  int active;                /**< Current state of listener */
   struct irc_ssaddr addr;    /**< Holds an IPv6 or IPv4 address */
   char name[HOSTIPLEN + 1];  /**< Holds an IPv6 or IPv4 address in string representation*/
   unsigned int flags;        /**< Listener flags (ssl, hidden, server) */
