@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file log.h
  * \brief A header for the logger functions.
- * \version $Id: log.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: log.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_log_h
@@ -43,8 +43,16 @@ enum log_type
   LOG_TYPE_LAST
 };
 
+struct LogFile
+{
+  char *path;
+  size_t size;
+  FILE *file;
+};
+
 extern void log_set_file(enum log_type, size_t, const char *);
-extern void log_del_all(void);
-extern void log_reopen_all(void);
+extern void log_free(struct LogFile *);
+extern void log_reopen(struct LogFile *);
+extern void log_iterate(void (*func)(struct LogFile *));
 extern void ilog(enum log_type, const char *, ...) AFP(2,3);
-#endif /* INCLUDED_s_log_h */
+#endif  /* INCLUDED_log_h */
