@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file misc.h
  * \brief A header for the miscellaneous functions.
- * \version $Id: misc.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: misc.h 9020 2019-05-27 22:07:41Z michael $
  */
 
 #ifndef INCLUDED_misc_h
@@ -32,6 +32,7 @@ extern const char *date_iso8601(uintmax_t);
 extern const char *date_ctime(uintmax_t);
 extern const char *time_dissect(uintmax_t);
 extern void binary_to_hex(const unsigned char *, char *, unsigned int);
+extern bool address_compare(const void *, const void *, bool);
 
 /* Just blindly define our own MIN/MAX macro */
 #define IRCD_MAX(a, b)  ((a) > (b) ? (a) : (b))
@@ -40,8 +41,8 @@ extern void binary_to_hex(const unsigned char *, char *, unsigned int);
 #define _1MEG     (1024.0f)
 #define _1GIG     (1024.0f*1024.0f)
 #define _1TER     (1024.0f*1024.0f*1024.0f)
-#define _GMKs(x)  (((x) > _1TER) ? "Terabytes" : (((x) > _1GIG) ? "Gigabytes" :\
-                  (((x) > _1MEG) ? "Megabytes" : "Kilobytes")))
+#define _GMKs(x)  (((x) > _1TER) ? "Tebibytes" : (((x) > _1GIG) ? "Gibibytes" :\
+                  (((x) > _1MEG) ? "Mebibytes" : "Kibibytes")))
 #define _GMKv(x)  (((x) > _1TER) ? (float)((x)/_1TER) : (((x) > _1GIG) ? \
                    (float)((x)/_1GIG) : (((x) > _1MEG) ? (float)((x)/_1MEG) : \
                    (float)(x))))
