@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,18 +21,12 @@
 
 /*! \file modules.h
  * \brief A header for the modules functions.
- * \version $Id: modules.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: modules.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_modules_h
 #define INCLUDED_modules_h
 
-enum
-{
-  MODULE_FLAG_CORE     = 1 << 0,
-  MODULE_FLAG_NOUNLOAD = 1 << 1
-};
-
 struct module
 {
   dlink_node node;
@@ -41,7 +35,8 @@ struct module
   void *handle;
   void (*modinit)(void);
   void (*modexit)(void);
-  unsigned int flags;
+  bool is_resident;
+  bool is_core;
 };
 
 struct module_path
@@ -57,10 +52,10 @@ extern void mod_add_path(const char *);
 extern void modules_conf_clear(void);
 
 /* load all modules */
-extern void load_all_modules(int);
+extern void load_all_modules(bool);
 
 /* load core modules */
-extern void load_core_modules(int);
+extern void load_core_modules(bool);
 
 /* Add this module to list of modules to be loaded from conf */
 extern void add_conf_module(const char *);
@@ -68,9 +63,9 @@ extern void add_conf_module(const char *);
 extern void load_conf_modules(void);
 extern void modules_init(void);
 
-extern int unload_one_module(const char *, int);
-extern int modules_valid_suffix(const char *);
-extern int load_one_module(const char *);
-extern int load_a_module(const char *, int);
+extern bool unload_one_module(const char *, bool);
+extern bool modules_valid_suffix(const char *);
+extern bool load_one_module(const char *);
+extern bool load_a_module(const char *, bool);
 extern struct module *findmodule_byname(const char *);
 #endif /* INCLUDED_modules_h */
