@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file parse.h
  * \brief A header for the message parser.
- * \version $Id: parse.h 8478 2018-04-03 17:03:30Z michael $
+ * \version $Id: parse.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_parse_h
@@ -88,12 +88,14 @@ struct Message
   int (*handlers[LAST_HANDLER_TYPE])(struct Client *, int, char *[]);
 };
 
-/*
- * Constants
- */
-#define MFLG_EXTRA 0x00000001U
 #define MAXPARA    15
 
+enum
+{
+  MFLG_EXTRA    = 1 << 0,
+  MFLG_ENDGRACE = 1 << 1
+};
+
 extern void parse(struct Client *, char *, char *);
 extern void mod_add_cmd(struct Message *);
 extern void mod_del_cmd(struct Message *);
