@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,17 +21,11 @@
 
 /*! \file restart.h
  * \brief A header for the restart/die functions.
- * \version $Id: restart.h 8478 2018-04-03 17:03:30Z michael $
+ * \version $Id: restart.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_restart_h
 #define INCLUDED_restart_h
 
-enum
-{
-  SERVER_SHUTDOWN,
-  SERVER_RESTART
-};
-
-extern void server_die(const char *, int);
+extern void server_die(const char *, bool);
 #endif  /* INCLUDED_restart_h */
