@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd.h
  * \brief A header for the network subsystem.
- * \version $Id: s_bsd.h 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: s_bsd.h 8874 2019-02-16 21:53:04Z michael $
  */
 
 #ifndef INCLUDED_s_bsd_h
@@ -29,6 +29,16 @@
 
 #include "fdlist.h"
 
+enum
+{
+  COMM_OK,
+  COMM_ERR_BIND,
+  COMM_ERR_TIMEOUT,
+  COMM_ERR_CONNECT,
+  COMM_ERROR,
+  COMM_ERR_MAX
+};
+
 /* Type of IO */
 enum
 {
@@ -45,17 +55,17 @@ struct Listener;
 extern void add_connection(struct Listener *, struct irc_ssaddr *, int);
 extern void report_error(int, const char *, const char *, int);
 
-extern int comm_get_sockerr(int);
-extern int comm_ignore_errno(int);
+extern int comm_get_sockerr(fde_t *);
+extern bool comm_ignore_errno(int);
 
 extern void comm_settimeout(fde_t *, uintmax_t, void (*)(fde_t *, void *), void *);
 extern void comm_setflush(fde_t *, uintmax_t, void (*)(fde_t *, void *), void *);
 extern void comm_checktimeouts(void *);
-extern void comm_connect_tcp(fde_t *, const char *, unsigned short, struct sockaddr *, int,
-                             void (fde_t *, int, void *), void *, int, uintmax_t);
+extern void comm_connect_tcp(fde_t *, const struct irc_ssaddr *, unsigned short, const struct irc_ssaddr *,
+                             void (fde_t *, int, void *), void *, uintmax_t);
 extern const char *comm_errstr(int);
 extern int comm_socket(int, int, int);
-extern int comm_accept(int, struct irc_ssaddr *);
+extern int comm_accept(fde_t *, struct irc_ssaddr *);
 
 /* These must be defined in the network IO loop code of your choice */
 extern void comm_select_init(void);
