@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.h
  * \brief A header for the message sending functions.
- * \version $Id: send.h 8478 2018-04-03 17:03:30Z michael $
+ * \version $Id: send.h 9001 2019-05-25 23:13:18Z michael $
  */
 
 #ifndef INCLUDED_send_h
@@ -60,14 +60,13 @@ struct Client;
 /* send.c prototypes */
 extern void sendq_unblocked(fde_t *, void *);
 extern void send_queued_write(struct Client *);
-extern void send_queued_all(void);
 extern void sendto_one(struct Client *, const char *, ...) AFP(2,3);
 extern void sendto_one_numeric(struct Client *, const struct Client *, enum irc_numerics, ...);
 extern void sendto_one_notice(struct Client *, const struct Client *, const char *, ...) AFP(3,4);
 extern void sendto_channel_butone(struct Client *, const struct Client *,
                                   struct Channel *, unsigned int,
                                   const char *, ...) AFP(5,6);
-extern void sendto_common_channels_local(struct Client *, int, unsigned int, unsigned int,
+extern void sendto_common_channels_local(struct Client *, bool, unsigned int, unsigned int,
                                          const char *, ...) AFP(5,6);
 extern void sendto_channel_local(const struct Client *, struct Channel *, unsigned int,
                                  unsigned int, unsigned int, const char *, ...)  AFP(6,7);
