@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2015-2018 ircd-hybrid development team
+ *  Copyright (c) 2015-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls.h
  * \brief A header for generic TLS functions
- * \version $Id: tls.h 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: tls.h 8957 2019-05-10 17:07:45Z michael $
  */
 
 #ifndef INCLUDED_tls_h
@@ -37,6 +37,8 @@
 #include "tls_none.h"
 #endif
 
+enum { TLS_HANDSHAKE_TIMEOUT = 5 };  /**< Time in seconds for the TLS handshake to time out */
+
 typedef enum _tls_role
 {
   TLS_ROLE_SERVER,
@@ -51,25 +53,25 @@ typedef enum _tls_handshake_status
   TLS_HANDSHAKE_ERROR
 } tls_handshake_status_t;
 
-extern int tls_is_initialized(void);
+extern bool tls_is_initialized(void);
 extern void tls_init(void);
-extern int tls_new_cred(void);
+extern bool tls_new_cred(void);
 
 extern const char *tls_get_cipher(const tls_data_t *);
 extern const char *tls_get_version(void);
 
-extern int tls_isusing(tls_data_t *);
-extern int tls_new(tls_data_t *, int, tls_role_t);
+extern bool tls_isusing(tls_data_t *);
+extern bool tls_new(tls_data_t *, int, tls_role_t);
 extern void tls_free(tls_data_t *);
 
 extern tls_handshake_status_t tls_handshake(tls_data_t *, tls_role_t, const char **);
-extern int tls_read(tls_data_t *, char *, size_t, int *);
-extern int tls_write(tls_data_t *, const char *, size_t, int *);
+extern ssize_t tls_read(tls_data_t *, char *, size_t, bool *);
+extern ssize_t tls_write(tls_data_t *, const char *, size_t, bool *);
 
 extern void tls_shutdown(tls_data_t *);
 
-extern int tls_set_ciphers(tls_data_t *, const char *);
+extern bool tls_set_ciphers(tls_data_t *, const char *);
 
-extern int tls_verify_cert(tls_data_t *, tls_md_t, char **);
+extern bool tls_verify_cert(tls_data_t *, tls_md_t, char **);
 
 #endif  /* INCLUDED_tls_h */
