@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file user.h
  * \brief A header for the user functions.
- * \version $Id: user.h 8478 2018-04-03 17:03:30Z michael $
+ * \version $Id: user.h 8751 2019-01-01 11:06:50Z michael $
  */
 
 #ifndef INCLUDED_user_h
@@ -44,15 +44,14 @@ extern const struct user_modes *umode_map[];
 extern const struct user_modes  umode_tab[];
 
 extern void user_modes_init(void);
-extern void send_umode(struct Client *, unsigned int,
-                       unsigned int, char *);
+extern void send_umode(struct Client *, bool, unsigned int, char *);
 extern void send_umode_out(struct Client *, unsigned int);
 extern void show_lusers(struct Client *);
 
 extern void register_local_user(struct Client *);
 extern void register_remote_user(struct Client *);
-extern int valid_hostname(const char *);
-extern int valid_username(const char *, const int);
-extern int valid_nickname(const char *, const int);
+extern bool valid_hostname(const char *);
+extern bool valid_username(const char *, bool);
+extern bool valid_nickname(const char *, bool);
 extern void user_set_hostmask(struct Client *, const char *);
 #endif  /* INCLUDED_user_h */
