@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1997 Jukka Santala (Donwulff)
- *  Copyright (c) 2005-2018 ircd-hybrid development team
+ *  Copyright (c) 2005-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file watch.h
  * \brief Header including structures and prototypes for WATCH support
- * \version $Id: watch.h 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: watch.h 8916 2019-04-21 22:49:51Z michael $
  */
 
 #ifndef INCLUDED_watch_h
@@ -34,7 +34,8 @@ struct Watch
 {
   dlink_node node;  /**< List node; linked into watchTable */
   dlink_list watched_by;  /**< List of clients that have this entry on their watch list */
-  uintmax_t lasttime;  /**< Last time the client was seen */
+  uintmax_t lasttime;  /**< Last time the client was seen; real time */
+  unsigned int hash_value; /**< Cached hash value derived from Watch::name */
   char name[NICKLEN + 1];  /**< Name of the client to watch */
 };
 
