@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file whowas.h
  * \brief A header for the whowas functions.
- * \version $Id: whowas.h 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: whowas.h 8948 2019-04-30 22:37:37Z michael $
  */
 
 #ifndef INCLUDED_whowas_h
@@ -36,9 +36,9 @@ struct Whowas
   dlink_node hnode;  /**< List node; linked into whowas_hash */
   dlink_node cnode;  /**< List node; linked into client->whowas_list */
   dlink_node lnode;  /**< List node; linked into whowas_list */
-  unsigned int hashv;  /**< Hash value derived from Whowas::name */
-  unsigned int shide;  /**< Client's server is hidden */
-  uintmax_t logoff;  /**< When the client logged off */
+  unsigned int hash_value;  /**< Hash value derived from Whowas::name */
+  uintmax_t logoff;  /**< When the client logged off; real time */
+  bool server_hidden;  /**< Client's server is hidden */
   char account[ACCOUNTLEN + 1];  /**< Services account */
   char name[NICKLEN + 1];  /**< Client's nick name */
   char username[USERLEN + 1];  /**< Client's user name */
@@ -52,7 +52,7 @@ struct Whowas
 
 extern const dlink_list *whowas_get_hash(unsigned int);
 extern void whowas_trim(void);
-extern void whowas_add_history(struct Client *, const int);
+extern void whowas_add_history(struct Client *, bool);
 extern void whowas_off_history(struct Client *);
 extern struct Client *whowas_get_history(const char *, uintmax_t);
 extern void whowas_count_memory(unsigned int *const, size_t *const);
