@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_bmask.c
  * \brief Includes required functions for processing the BMASK command.
- * \version $Id: m_bmask.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_bmask.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -60,7 +60,7 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
   char banbuf[IRCD_BUFSIZE] = "";
   struct Channel *chptr = NULL;
   char *s, *t, *mbuf, *pbuf;
-  unsigned int mode_type = 0;
+  dlink_list *list = NULL;
   int mlen = 0, tlen = 0;
   int modecount = 0;
   unsigned int flags = 0;
@@ -75,13 +75,13 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
   switch (*parv[3])
   {
     case 'b':
-      mode_type = CHFL_BAN;
+      list = &chptr->banlist;
       break;
     case 'e':
-      mode_type = CHFL_EXCEPTION;
+      list = &chptr->exceptlist;
       break;
     case 'I':
-      mode_type = CHFL_INVEX;
+      list = &chptr->invexlist;
       break;
     default:
       return 0;
@@ -109,7 +109,7 @@ ms_bmask(struct Client *source_p, int parc, char *parv[])
     if (tlen > MODEBUFLEN)
       break;
 
-    if (tlen && *s != ':' && add_id(source_p, chptr, s, mode_type))
+    if (tlen && *s != ':' && add_id(source_p, chptr, s, list) == true)
     {
       /* add_id can modify 's' */
       tlen = strlen(s);
@@ -172,8 +172,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
