@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_die.c
  * \brief Includes required functions for processing the DIE command.
- * \version $Id: m_die.c 8448 2018-03-30 11:40:13Z michael $
+ * \version $Id: m_die.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -72,7 +72,7 @@ mo_die(struct Client *source_p, int parc, char *parv[])
 
   snprintf(buf, sizeof(buf), "received DIE command from %s",
            client_get_name(source_p, HIDE_IP));
-  server_die(buf, SERVER_SHUTDOWN);
+  server_die(buf, false);
   return 0;
 }
 
@@ -101,8 +101,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8448 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
