@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_kick.c
  * \brief Includes required functions for processing the KICK command.
- * \version $Id: m_kick.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: m_kick.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -69,9 +69,6 @@ m_kick(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!IsFloodDone(source_p))
-    flood_endgrace(source_p);
-
   if ((chptr = hash_find_channel(parv[1])) == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, parv[1]);
@@ -184,6 +181,7 @@ static struct Message kick_msgtab =
   .cmd = "KICK",
   .args_min = 3,
   .args_max = MAXPARA,
+  .flags = MFLG_ENDGRACE,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_kick,
   .handlers[SERVER_HANDLER] = ms_kick,
@@ -205,8 +203,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8430 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
