@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_mode.c
  * \brief Includes required functions for processing the MODE command.
- * \version $Id: m_mode.c 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: m_mode.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -56,7 +56,8 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
   const struct user_modes *tab = NULL;
   const unsigned int setmodes = source_p->umodes;
   const struct Client *target_p = NULL;
-  int what = MODE_ADD, badmode = 0;
+  bool badmode = false;
+  int what = MODE_ADD;
 
   if ((target_p = find_person(source_p, parv[1])) == NULL)
   {
@@ -141,7 +142,7 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
         {
           if (MyConnect(source_p) && !HasUMode(source_p, UMODE_OPER) &&
               (ConfigGeneral.oper_only_umodes & tab->flag))
-            badmode = 1;
+            badmode = true;
           else
           {
             if (what == MODE_ADD)
@@ -151,13 +152,13 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
           }
         }
         else if (MyConnect(source_p))
-          badmode = 1;
+          badmode = true;
 
         break;
     }
   }
 
-  if (badmode)
+  if (badmode == true)
     sendto_one_numeric(source_p, &me, ERR_UMODEUNKNOWNFLAG);
 
   if (MyConnect(source_p) && HasUMode(source_p, UMODE_ADMIN) &&
@@ -230,14 +231,8 @@ m_mode(struct Client *source_p, int parc, char *parv[])
   }
 
   if (MyClient(source_p))
-  {
     member = find_channel_link(source_p, chptr);
 
-    if (!IsFloodDone(source_p))
-      if (!((parc == 3) && (parv[2][0] == 'b') && (parv[2][1] == '\0')))
-        flood_endgrace(source_p);
-  }
-
   channel_mode_set(source_p, chptr, member, parc - 2, parv + 2);
   return 0;
 }
@@ -268,8 +263,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8483 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
