@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 8467 2018-04-03 11:21:48Z michael $
+ * \version $Id: m_nick.c 8927 2019-04-22 11:08:47Z michael $
  */
 
 #include "stdinc.h"
@@ -43,6 +43,7 @@
 #include "watch.h"
 #include "misc.h"
 #include "id.h"
+#include "ipcache.h"
 
 
 /* check_clean_nick()
@@ -66,7 +67,7 @@ check_clean_nick(struct Client *source_p, const char *nick)
    * The old code did some wacky stuff here, if the nick is invalid, kill it
    * and don't bother messing at all
    */
-  if (valid_nickname(nick, 0))
+  if (valid_nickname(nick, false) == true)
     return 0;
 
   ++ServerStats.is_kill;
@@ -93,7 +94,7 @@ check_clean_uid(struct Client *source_p, const char *nick, const char *uid)
 {
   assert(IsServer(source_p));
 
-  if (valid_uid(uid) && strncmp(uid, source_p->id, IRC_MAXSID) == 0)
+  if (valid_uid(uid) == true && strncmp(uid, source_p->id, IRC_MAXSID) == 0)
     return 0;
 
   ++ServerStats.is_kill;
@@ -119,7 +120,7 @@ check_clean_user(struct Client *source_p, const char *nick, const char *user)
 {
   assert(IsServer(source_p));
 
-  if (valid_username(user, 0))
+  if (valid_username(user, false) == true)
     return 0;
 
   ++ServerStats.is_kill;
@@ -145,7 +146,7 @@ check_clean_host(struct Client *source_p, const char *nick, const char *host)
 {
   assert(IsServer(source_p));
 
-  if (valid_hostname(host))
+  if (valid_hostname(host) == true)
     return 0;
 
   ++ServerStats.is_kill;
@@ -169,9 +170,9 @@ check_clean_host(struct Client *source_p, const char *nick, const char *host)
 static void
 set_initial_nick(struct Client *source_p, const char *nick)
 {
-  int samenick = irccmp(source_p->name, nick) == 0;
-  if (samenick == 0)
-    source_p->tsinfo = CurrentTime;
+  bool samenick = irccmp(source_p->name, nick) == 0;
+  if (samenick == false)
+    source_p->tsinfo = event_base->time.sec_real;
 
   source_p->connection->registration &= ~REG_NEED_NICK;
 
@@ -202,7 +203,7 @@ change_local_nick(struct Client *source_p, const char *nick)
   assert(source_p->name[0] && !EmptyString(nick));
   assert(MyClient(source_p));
 
-  if ((source_p->connection->nick.last_attempt + ConfigGeneral.max_nick_time) < CurrentTime)
+  if ((source_p->connection->nick.last_attempt + ConfigGeneral.max_nick_time) < event_base->time.sec_monotonic)
     source_p->connection->nick.count = 0;
 
   if (ConfigGeneral.anti_nick_flood && !HasUMode(source_p, UMODE_OPER) &&
@@ -213,13 +214,13 @@ change_local_nick(struct Client *source_p, const char *nick)
     return;
   }
 
-  source_p->connection->nick.last_attempt = CurrentTime;
+  source_p->connection->nick.last_attempt = event_base->time.sec_monotonic;
   source_p->connection->nick.count++;
 
-  int samenick = irccmp(source_p->name, nick) == 0;
-  if (samenick == 0)
+  bool samenick = irccmp(source_p->name, nick) == 0;
+  if (samenick == false)
   {
-    source_p->tsinfo = CurrentTime;
+    source_p->tsinfo = event_base->time.sec_real;
     clear_ban_cache_list(&source_p->channel);
     watch_check_hash(source_p, RPL_LOGOFF);
 
@@ -229,7 +230,7 @@ change_local_nick(struct Client *source_p, const char *nick)
       char modebuf[IRCD_BUFSIZE] = "";
 
       DelUMode(source_p, UMODE_REGISTERED);
-      send_umode(source_p, 1, oldmodes, modebuf);
+      send_umode(source_p, true, oldmodes, modebuf);
     }
   }
 
@@ -241,10 +242,10 @@ change_local_nick(struct Client *source_p, const char *nick)
   sendto_realops_flags(UMODE_NCHANGE, L_ALL, SEND_NOTICE,
                        "Nick change: From %s to %s [%s@%s]",
                        source_p->name, nick, source_p->username, source_p->host);
-  sendto_common_channels_local(source_p, 1, 0, 0, ":%s!%s@%s NICK :%s",
+  sendto_common_channels_local(source_p, true, 0, 0, ":%s!%s@%s NICK :%s",
                                source_p->name, source_p->username,
                                source_p->host, nick);
-  whowas_add_history(source_p, 1);
+  whowas_add_history(source_p, true);
 
   sendto_server(source_p, 0, 0, ":%s NICK %s :%ju",
                 source_p->id, nick, source_p->tsinfo);
@@ -281,23 +282,24 @@ change_remote_nick(struct Client *source_p, char *parv[])
   assert(source_p->name[0]);
 
   /* Client changing their nick */
-  int samenick = irccmp(source_p->name, parv[1]) == 0;
-  if (samenick == 0)
+  bool samenick = irccmp(source_p->name, parv[1]) == 0;
+  if (samenick == false)
   {
     DelUMode(source_p, UMODE_REGISTERED);
     watch_check_hash(source_p, RPL_LOGOFF);
+
     source_p->tsinfo = strtoumax(parv[2], NULL, 10);
-    assert(source_p->tsinfo > 0);
+    assert(source_p->tsinfo);
   }
 
   sendto_realops_flags(UMODE_NCHANGE, L_ALL, SEND_NOTICE,
                        "Nick change: From %s to %s [%s@%s]",
                        source_p->name, parv[1], source_p->username, source_p->host);
-  sendto_common_channels_local(source_p, 1, 0, 0, ":%s!%s@%s NICK :%s",
+  sendto_common_channels_local(source_p, true, 0, 0, ":%s!%s@%s NICK :%s",
                                source_p->name, source_p->username,
                                source_p->host, parv[1]);
 
-  whowas_add_history(source_p, 1);
+  whowas_add_history(source_p, true);
   sendto_server(source_p, 0, 0, ":%s NICK %s :%ju",
                 source_p->id, parv[1], source_p->tsinfo);
 
@@ -306,7 +308,7 @@ change_remote_nick(struct Client *source_p, char *parv[])
   strlcpy(source_p->name, parv[1], sizeof(source_p->name));
   hash_add_client(source_p);
 
-  if (samenick == 0)
+  if (samenick == false)
     watch_check_hash(source_p, RPL_LOGON);
 }
 
@@ -354,6 +356,24 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   strlcpy(client_p->id, parv[8 + does_rhost], sizeof(client_p->id));
   strlcpy(client_p->account, parv[9 + does_rhost], sizeof(client_p->account));
 
+  struct addrinfo hints, *res;
+  memset(&hints, 0, sizeof(hints));
+  hints.ai_family = AF_UNSPEC;
+  hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
+
+  if (getaddrinfo(client_p->sockhost, NULL, &hints, &res) == 0)
+  {
+    memcpy(&client_p->ip, res->ai_addr, res->ai_addrlen);
+    client_p->ip.ss_len = res->ai_addrlen;
+
+    struct ip_entry *ipcache = ipcache_record_find_or_add(&client_p->ip);
+    ++ipcache->count_remote;
+    AddFlag(client_p, FLAGS_IPHASH);
+  }
+
+  if (res)
+    freeaddrinfo(res);
+
   hash_add_client(client_p);
   hash_add_id(client_p);
 
@@ -362,7 +382,7 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   {
     const struct user_modes *tab = umode_map[(unsigned char)*m];
 
-    if (!tab)
+    if (tab == NULL)
       continue;
     if ((tab->flag & UMODE_INVISIBLE) && !HasUMode(client_p, UMODE_INVISIBLE))
       ++Count.invisi;
@@ -409,7 +429,7 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
  *      - parv[10] = services id (account name)
  *      - parv[11] = ircname (gecos)
  */
-static int
+static bool
 perform_uid_introduction_collides(struct Client *source_p, struct Client *target_p,
                                   int parc, char *parv[])
 {
@@ -424,7 +444,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   /* Server introducing new nick */
 
   /* If we don't have a TS, or their TS's are the same, kill both */
-  if (!newts || !target_p->tsinfo || (newts == target_p->tsinfo))
+  if (newts == 0 || target_p->tsinfo == 0 || (newts == target_p->tsinfo))
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(both killed)",
@@ -441,27 +461,26 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
 
     AddFlag(target_p, FLAGS_KILLED);
     exit_client(target_p, "Nick collision (new)");
-    return 0;
+    return false;
   }
 
   /* The timestamps are different */
-  int sameuser = !irccmp(target_p->username, parv[5]) &&
-                 !irccmp(target_p->sockhost, parv[7 + does_rhost]);
+  bool sameuser = irccmp(target_p->username, parv[5]) == 0 &&
+                  irccmp(target_p->sockhost, parv[7 + does_rhost]) == 0;
 
   /*
    * If the users are the same (loaded a client on a different server)
    * and the new users ts is older, or the users are different and the
    * new users ts is newer, ignore the new client and let it do the kill
    */
-  if ((sameuser && newts < target_p->tsinfo) ||
-      (!sameuser && newts > target_p->tsinfo))
+  if ((sameuser == true && newts < target_p->tsinfo) || (sameuser == false && newts > target_p->tsinfo))
   {
     sendto_one(source_p, ":%s KILL %s :%s (Nick collision (new))",
                me.id, uid, me.name);
-    return 0;
+    return false;
   }
 
-  if (sameuser)
+  if (sameuser == true)
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(older killed)",
                          target_p->name, target_p->from->name,
@@ -481,7 +500,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   AddFlag(target_p, FLAGS_KILLED);
   exit_client(target_p, "Nick collision");
 
-  return 1;
+  return true;
 }
 
 /*!
@@ -497,7 +516,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
  *      - parv[1] = nickname
  *      - parv[2] = timestamp
  */
-static int
+static bool
 perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
                              int parc, char *parv[])
 {
@@ -505,10 +524,10 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
 
   assert(IsClient(source_p));
   assert(IsClient(target_p));
-  assert(newts > 0);
+  assert(newts);
 
   /* It's a client changing nick and causing a collide */
-  if (!newts || !target_p->tsinfo || (newts == target_p->tsinfo))
+  if (newts == 0 || target_p->tsinfo == 0 || (newts == target_p->tsinfo))
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                "Nick change collision from %s to %s(%s <- %s)(both killed)",
@@ -527,17 +546,16 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
     AddFlag(target_p, FLAGS_KILLED);
     exit_client(source_p, "Nick collision (old)");
     exit_client(target_p, "Nick collision (new)");
-    return 0;
+    return false;
   }
 
   /* The timestamps are different */
-  int sameuser = irccmp(target_p->username, source_p->username) == 0 &&
-                 irccmp(target_p->sockhost, source_p->sockhost) == 0;
+  bool sameuser = irccmp(target_p->username, source_p->username) == 0 &&
+                  irccmp(target_p->sockhost, source_p->sockhost) == 0;
 
-  if ((sameuser && newts < target_p->tsinfo) ||
-      (!sameuser && newts > target_p->tsinfo))
+  if ((sameuser == true && newts < target_p->tsinfo) || (sameuser == false && newts > target_p->tsinfo))
   {
-    if (sameuser)
+    if (sameuser == true)
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
            "Nick change collision from %s to %s(%s <- %s)(older killed)",
            source_p->name, target_p->name, target_p->from->name,
@@ -554,14 +572,14 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
                   me.id, source_p->id, me.name);
     AddFlag(source_p, FLAGS_KILLED);
 
-    if (sameuser)
+    if (sameuser == true)
       exit_client(source_p, "Nick collision (old)");
     else
       exit_client(source_p, "Nick collision (new)");
-    return 0;
+    return false;
   }
 
-  if (sameuser)
+  if (sameuser == true)
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Nick collision on %s(%s <- %s)(older killed)",
                          target_p->name, target_p->from->name,
@@ -581,7 +599,7 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
   AddFlag(target_p, FLAGS_KILLED);
   exit_client(target_p, "Nick collision");
 
-  return 1;
+  return true;
 }
 
 /*! \brief NICK command handler
@@ -610,7 +628,7 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
   strlcpy(nick, parv[1], IRCD_MIN(sizeof(nick), ConfigServerInfo.max_nick_length + 1));
 
   /* Check the nickname is ok */
-  if (!valid_nickname(nick, 1))
+  if (valid_nickname(nick, true) == false)
   {
     sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, parv[1], "Erroneous Nickname");
     return 0;
@@ -661,15 +679,11 @@ m_nick(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /* Mark end of grace period, to prevent nickflooding */
-  if (!IsFloodDone(source_p))
-    flood_endgrace(source_p);
-
   /* Terminate nick to NICKLEN */
   strlcpy(nick, parv[1], IRCD_MIN(sizeof(nick), ConfigServerInfo.max_nick_length + 1));
 
   /* Check the nickname is ok */
-  if (!valid_nickname(nick, 1))
+  if (valid_nickname(nick, true) == false)
   {
     sendto_one_numeric(source_p, &me, ERR_ERRONEUSNICKNAME, nick, "Erroneous Nickname");
     return 0;
@@ -771,7 +785,7 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
     if (strcmp(target_p->name, parv[1]))
       change_remote_nick(source_p, parv);
   }
-  else if (perform_nick_change_collides(source_p, target_p, parc, parv))
+  else if (perform_nick_change_collides(source_p, target_p, parc, parv) == true)
     change_remote_nick(source_p, parv);
   return 0;
 }
@@ -855,7 +869,7 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
     exit_client(target_p, "Overridden by other sign on");
     uid_from_server(source_p, parc, parv);
   }
-  else if (perform_uid_introduction_collides(source_p, target_p, parc, parv))
+  else if (perform_uid_introduction_collides(source_p, target_p, parc, parv) == true)
     uid_from_server(source_p, parc, parv);
   return 0;
 }
@@ -864,6 +878,7 @@ static struct Message nick_msgtab =
 {
   .cmd = "NICK",
   .args_max = MAXPARA,
+  .flags = MFLG_ENDGRACE,
   .handlers[UNREGISTERED_HANDLER] = mr_nick,
   .handlers[CLIENT_HANDLER] = m_nick,
   .handlers[SERVER_HANDLER] = ms_nick,
@@ -899,8 +914,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8467 $",
+  .version = "$Revision: 8927 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
