@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_part.c
  * \brief Includes required functions for processing the PART command.
- * \version $Id: m_part.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_part.c 8983 2019-05-21 13:18:58Z michael $
  */
 
 #include "stdinc.h"
@@ -55,16 +55,10 @@ static int
 m_part(struct Client *source_p, int parc, char *parv[])
 {
   if (EmptyString(parv[1]))
-  {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "PART");
-    return 0;
-  }
+  else
+    channel_do_part(source_p, parv[1], parv[2]);
 
-  /* Finish the flood grace period... */
-  if (MyClient(source_p) && !IsFloodDone(source_p))
-    flood_endgrace(source_p);
-
-  channel_do_part(source_p, parv[1], parv[2]);
   return 0;
 }
 
@@ -73,6 +67,7 @@ static struct Message part_msgtab =
   .cmd = "PART",
   .args_min = 2,
   .args_max = MAXPARA,
+  .flags = MFLG_ENDGRACE,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_part,
   .handlers[SERVER_HANDLER] = m_part,
@@ -94,8 +89,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8983 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
