@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_quit.c
  * \brief Includes required functions for processing the QUIT command.
- * \version $Id: m_quit.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_quit.c 8918 2019-04-22 09:51:16Z michael $
  */
 
 #include "stdinc.h"
@@ -51,8 +51,8 @@ m_quit(struct Client *source_p, int parc, char *parv[])
   char reason[KICKLEN + 1] = "Quit: ";
 
   if (!EmptyString(parv[1]) && (HasUMode(source_p, UMODE_OPER) ||
-      (source_p->connection->firsttime + ConfigGeneral.anti_spam_exit_message_time)
-      < CurrentTime))
+      (source_p->connection->created_monotonic + ConfigGeneral.anti_spam_exit_message_time)
+      < event_base->time.sec_monotonic))
     strlcpy(reason + 6, parv[1], sizeof(reason) - 6);
 
   exit_client(source_p, reason);
@@ -107,8 +107,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8918 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
