@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_server.c
  * \brief Includes required functions for processing the SERVER/SID command.
- * \version $Id: m_server.c 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: m_server.c 8967 2019-05-18 11:00:34Z michael $
  */
 
 #include "stdinc.h"
@@ -121,7 +121,7 @@ server_send_client(struct Client *client_p, struct Client *target_p)
 
   assert(IsClient(target_p));
 
-  send_umode(target_p, 0, 0, buf);
+  send_umode(target_p, false, 0, buf);
 
   if (buf[0] == '\0')
   {
@@ -178,7 +178,7 @@ server_send_client(struct Client *client_p, struct Client *target_p)
 static void
 server_burst(struct Client *client_p)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
 
   DLINK_FOREACH(node, global_client_list.head)
   {
@@ -233,7 +233,7 @@ server_estab(struct Client *client_p)
   xfree(client_p->connection->password);
   client_p->connection->password = NULL;
 
-  if (!ConfigServerInfo.hub && dlink_list_length(&local_server_list))
+  if (ConfigServerInfo.hub == 0 && dlink_list_length(&local_server_list))
   {
     ++ServerStats.is_ref;
     exit_client(client_p, "I'm a leaf not a hub");
@@ -251,11 +251,11 @@ server_estab(struct Client *client_p)
   }
 
   sendto_one(client_p, ":%s SVINFO %u %u 0 :%ju", me.id, TS_CURRENT, TS_MIN,
-             CurrentTime);
+             event_base->time.sec_real);
 
   client_p->servptr = &me;
 
-  if (HasFlag(client_p, FLAGS_CLOSING))
+  if (IsDead(client_p))
     return;
 
   SetServer(client_p);
@@ -280,7 +280,8 @@ server_estab(struct Client *client_p)
   server_make(client_p);
 
   /* Fixing eob timings.. -gnp */
-  client_p->connection->firsttime = CurrentTime;
+  client_p->connection->created_monotonic = event_base->time.sec_monotonic;
+  client_p->connection->created_real = event_base->time.sec_real;
 
   if (service_find(client_p->name, irccmp))
     AddFlag(client_p, FLAGS_SERVICE);
@@ -392,12 +393,21 @@ server_set_gecos(struct Client *client_p, const char *info)
     strlcpy(client_p->info, "(Unknown Location)", sizeof(client_p->info));
 }
 
+enum
+{
+  SERVER_CHECK_OK                  =  0,
+  SERVER_CHECK_NOCONNECT           = -1,
+  SERVER_CHECK_INVALID_PASSWORD    = -2,
+  SERVER_CHECK_INVALID_HOST        = -3,
+  SERVER_CHECK_INVALID_CERTIFICATE = -4,
+};
+
 static int
 server_check(const char *name, struct Client *client_p)
 {
-  dlink_node *node = NULL;
+  dlink_node *node;
   struct MaskItem *server_conf = NULL;
-  int error = -1;
+  int error = SERVER_CHECK_NOCONNECT;
 
   assert(client_p);
 
@@ -409,19 +419,17 @@ server_check(const char *name, struct Client *client_p)
     if (irccmp(name, conf->name))
       continue;
 
-    error = -3;
+    error = SERVER_CHECK_INVALID_HOST;
 
     if (!irccmp(conf->host, client_p->host) ||
         !irccmp(conf->host, client_p->sockhost))
     {
-      error = -2;
-
-      if (!match_conf_password(client_p->connection->password, conf))
-        return -2;
+      if (match_conf_password(client_p->connection->password, conf) == false)
+        return SERVER_CHECK_INVALID_PASSWORD;
 
       if (!EmptyString(conf->certfp))
         if (EmptyString(client_p->certfp) || strcasecmp(client_p->certfp, conf->certfp))
-          return -4;
+          return SERVER_CHECK_INVALID_CERTIFICATE;
 
       server_conf = conf;
     }
@@ -432,27 +440,7 @@ server_check(const char *name, struct Client *client_p)
 
   conf_attach(client_p, server_conf);
 
-  switch (server_conf->aftype)
-  {
-    case AF_INET6:
-    {
-      const struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)&server_conf->addr;
-
-      if (IN6_IS_ADDR_UNSPECIFIED(&v6->sin6_addr))
-        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(server_conf->addr));
-      break;
-    }
-    case AF_INET:
-    {
-      const struct sockaddr_in *v4 = (struct sockaddr_in *)&server_conf->addr;
-
-      if (v4->sin_addr.s_addr == INADDR_NONE)
-        memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(server_conf->addr));
-      break;
-    }
-  }
-
-  return 0;
+  return SERVER_CHECK_OK;
 }
 
 /* mr_server()
@@ -475,6 +463,8 @@ mr_server(struct Client *source_p, int parc, char *parv[])
   const char *name = parv[1];
   const char *sid = parc == 6 ? parv[3] : source_p->id; /* TBR: compatibility 'mode' */
   struct Client *target_p = NULL;
+  const char *error = NULL;
+  bool warn = true;
 
   if (EmptyString(parv[parc - 1]))
   {
@@ -482,7 +472,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!server_valid_name(name))
+  if (server_valid_name(name) == false)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
           "Unauthorized server connection attempt from %s: Bogus server name "
@@ -494,7 +484,7 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!valid_sid(sid))
+  if (valid_sid(sid) == false)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
@@ -506,66 +496,41 @@ mr_server(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /* Now we just have to call server_check() and everything should
-   * be check for us... -A1kmm.
+  /*
+   * Now we just have to call server_check() and everything should
+   * be checked for us... -A1kmm.
    */
   switch (server_check(name, source_p))
   {
-    case -1:
-      if (ConfigGeneral.warn_no_connect_block)
-      {
-        sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: No entry for "
-           "servername %s", client_get_name(source_p, SHOW_IP), name);
-
-        sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: No entry for "
-           "servername %s", client_get_name(source_p, MASK_IP), name);
-      }
-
-      exit_client(source_p, "No connect {} block.");
-      return 0;
-      /* NOT REACHED */
+    case SERVER_CHECK_NOCONNECT:
+      error = "No connect {} block";
+      warn = ConfigGeneral.warn_no_connect_block != 0;
       break;
-
-    case -2:
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: Bad password "
-           "for server %s", client_get_name(source_p, SHOW_IP), name);
-
-      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: Bad password "
-           "for server %s", client_get_name(source_p, MASK_IP), name);
-
-      exit_client(source_p, "Invalid password.");
-      return 0;
-      /* NOT REACHED */
+    case SERVER_CHECK_INVALID_PASSWORD:
+      error = "Invalid password";
       break;
-
-    case -3:
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: Invalid host "
-           "for server %s", client_get_name(source_p, SHOW_IP), name);
-
-      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: Invalid host "
-           "for server %s", client_get_name(source_p, MASK_IP), name);
-
-      exit_client(source_p, "Invalid host.");
-      return 0;
-    case -4:
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: Invalid certificate fingerprint "
-           "for server %s", client_get_name(source_p, SHOW_IP), name);
-
-      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-           "Unauthorized server connection attempt from %s: Invalid certificate fingerprint "
-           "for server %s", client_get_name(source_p, MASK_IP), name);
-
-      exit_client(source_p, "Invalid certificate fingerprint.");
-      return 0;
-      /* NOT REACHED */
+    case SERVER_CHECK_INVALID_HOST:
+      error = "Invalid host";
       break;
+    case SERVER_CHECK_INVALID_CERTIFICATE:
+      error = "Invalid certificate fingerprint";
+      break;
+  }
+
+  if (error)
+  {
+    if (warn == true)
+    {
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+         "Unauthorized server connection attempt from %s: %s for server %s",
+         client_get_name(source_p, SHOW_IP), error, name);
+      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+         "Unauthorized server connection attempt from %s: %s for server %s",
+         client_get_name(source_p, MASK_IP), error, name);
+    }
+
+    exit_client(source_p, error);
+    return 0;
   }
 
   if ((target_p = hash_find_server(name)))
@@ -661,7 +626,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!server_valid_name(parv[1]))
+  if (server_valid_name(parv[1]) == false)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server name %s",
@@ -673,7 +638,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!valid_sid(parv[3]))
+  if (valid_sid(parv[3]) == false)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                          "Link %s introduced server with bogus server ID %s",
@@ -724,24 +689,24 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
    * leaf. If so, close the link.
    */
   dlink_node *node;
-  unsigned int hlined = 0;
-  unsigned int llined = 0;
+  bool hlined = false;
+  bool llined = false;
   const struct MaskItem *conf = source_p->from->connection->confs.head->data;
 
   DLINK_FOREACH(node, conf->leaf_list.head)
   {
-    if (!match(node->data, parv[1]))
+    if (match(node->data, parv[1]) == 0)
     {
-      llined = 1;
+      llined = true;
       break;
     }
   }
 
   DLINK_FOREACH(node, conf->hub_list.head)
   {
-    if (!match(node->data, parv[1]))
+    if (match(node->data, parv[1]) == 0)
     {
-      hlined = 1;
+      hlined = true;
       break;
     }
   }
@@ -770,7 +735,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
    */
 
   /* Ok, check source_p->from can hub the new server */
-  if (!hlined)
+  if (hlined == false)
   {
     /* OOOPs nope can't HUB */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
@@ -784,7 +749,7 @@ ms_sid(struct Client *source_p, int parc, char *parv[])
   }
 
   /* Check for the new server being leafed behind this HUB */
-  if (llined)
+  if (llined == true)
   {
     /* OOOPs nope can't HUB this leaf */
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
@@ -873,8 +838,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8483 $",
+  .version = "$Revision: 8967 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
