@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_sjoin.c
  * \brief Includes required functions for processing the SJOIN command.
- * \version $Id: m_sjoin.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_sjoin.c 8787 2019-01-16 18:47:10Z michael $
  */
 
 #include "stdinc.h"
@@ -41,14 +41,7 @@
 #include "misc.h"
 
 
-static char modebuf[MODEBUFLEN];
-static char parabuf[MODEBUFLEN];
-static char sendbuf[MODEBUFLEN];
-static const char *para[MAXMODEPARAMS];
-static char *mbuf;
-static int pargs;
-
-static void set_final_mode(struct Mode *, struct Mode *);
+static void set_final_mode(struct Mode *, struct Mode *, char *, char *);
 static void remove_our_modes(struct Channel *, struct Client *);
 static void remove_a_mode(struct Channel *, struct Client *, int, char);
 static void remove_ban_list(struct Channel *, struct Client *, dlink_list *, char);
@@ -76,14 +69,14 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   uintmax_t tstosend;
   struct Mode mode, *oldmode;
   int            args = 0;
-  char           keep_our_modes = 1;
-  char           keep_new_modes = 1;
-  char           have_many_uids = 0;
-  int            lcount;
+  bool           isnew = false;
+  bool           keep_our_modes = true;
+  bool           keep_new_modes = true;
+  bool           have_many_uids = false;
+  unsigned int   lcount;
   char           uid_prefix[CMEMBER_STATUS_FLAGS_LEN + 1];
   char           *up = NULL;
   int            len_uid = 0;
-  int            isnew = 0;
   int            buflen = 0;
   int            slen;
   unsigned       int fl;
@@ -94,11 +87,16 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
   char           *p; /* pointer used making sjbuf */
   const char *servername = (ConfigServerHide.hide_servers || IsHidden(source_p)) ?
                             me.name : source_p->name;
+  const char *para[MAXMODEPARAMS];
+  char sendbuf[MODEBUFLEN] = "";
+  char modebuf[MODEBUFLEN] = "";
+  char parabuf[MODEBUFLEN] = "";
+  unsigned int pargs = 0;
 
   if (!IsServer(source_p))
     return 0;
 
-  if (!channel_check_name(parv[2], 0))
+  if (channel_check_name(parv[2], false) == false)
   {
     sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
                          "*** Too long or invalid channel name from %s(via %s): %s",
@@ -106,8 +104,6 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  modebuf[0] = '\0';
-  mbuf = modebuf;
   pargs = 0;
   newts = strtoumax(parv[1], NULL, 10);
 
@@ -148,40 +144,24 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 
   if ((chptr = hash_find_channel(parv[2])) == NULL)
   {
-    isnew = 1;
+    isnew = true;
     chptr = channel_make(parv[2]);
   }
 
-  parabuf[0] = '\0';
   oldts = chptr->creationtime;
   oldmode = &chptr->mode;
 
-  if (ConfigGeneral.ignore_bogus_ts)
+  if (newts == 0 && isnew == false && oldts)
   {
-    if (newts < 800000000)
-    {
-      sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                           "*** Bogus TS %ju on %s ignored from %s(via %s)",
-                           newts, chptr->name,
-                           source_p->name, source_p->from->name);
-
-      newts = (oldts == 0) ? 0 : 800000000;
-    }
-  }
-  else
-  {
-    if (!newts && !isnew && oldts)
-    {
-      sendto_channel_local(NULL, chptr, 0, 0, 0,
-                           ":%s NOTICE %s :*** Notice -- TS for %s changed from %ju to 0",
-                           me.name, chptr->name, chptr->name, oldts);
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                           "Server %s changing TS on %s from %ju to 0",
-                           source_p->name, chptr->name, oldts);
-    }
+    sendto_channel_local(NULL, chptr, 0, 0, 0,
+                         ":%s NOTICE %s :*** Notice -- TS for %s changed from %ju to 0",
+                         me.name, chptr->name, chptr->name, oldts);
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                         "Server %s changing TS on %s from %ju to 0",
+                         source_p->name, chptr->name, oldts);
   }
 
-  if (isnew)
+  if (isnew == true)
     chptr->creationtime = tstosend = newts;
   else if (newts == 0 || oldts == 0)
     chptr->creationtime = tstosend = 0;
@@ -189,18 +169,18 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     tstosend = oldts;
   else if (newts < oldts)
   {
-    keep_our_modes = 0;
+    keep_our_modes = false;
     chptr->creationtime = tstosend = newts;
   }
   else
   {
-    keep_new_modes = 0;
+    keep_new_modes = false;
     tstosend = oldts;
   }
 
-  if (!keep_new_modes)
+  if (keep_new_modes == false)
     mode = *oldmode;
-  else if (keep_our_modes)
+  else if (keep_our_modes == true)
   {
     mode.mode |= oldmode->mode;
 
@@ -210,33 +190,28 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
       strlcpy(mode.key, oldmode->key, sizeof(mode.key));
   }
 
-  set_final_mode(&mode, oldmode);
+  set_final_mode(&mode, oldmode, modebuf, parabuf);
   chptr->mode = mode;
 
   /* Lost the TS, other side wins, so remove modes on this side */
-  if (!keep_our_modes)
+  if (keep_our_modes == false)
   {
     /* Update channel name to be the correct case */
-    if (!isnew)
+    if (isnew == false)
       strlcpy(chptr->name, parv[2], sizeof(chptr->name));
 
     remove_our_modes(chptr, source_p);
 
-    if (dlink_list_length(&chptr->banlist))
-      remove_ban_list(chptr, source_p, &chptr->banlist, 'b');
+    remove_ban_list(chptr, source_p, &chptr->banlist, 'b');
+    remove_ban_list(chptr, source_p, &chptr->exceptlist, 'e');
+    remove_ban_list(chptr, source_p, &chptr->invexlist, 'I');
 
-    if (dlink_list_length(&chptr->exceptlist))
-      remove_ban_list(chptr, source_p, &chptr->exceptlist, 'e');
-
-    if (dlink_list_length(&chptr->invexlist))
-      remove_ban_list(chptr, source_p, &chptr->invexlist, 'I');
-
-    clear_ban_cache_list(&chptr->locmembers);
+    clear_ban_cache_list(&chptr->members_local);
     clear_invite_list(&chptr->invites);
 
     if (chptr->topic[0])
     {
-      channel_set_topic(chptr, "", "", 0, 0);
+      channel_set_topic(chptr, "", "", 0, false);
       sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :",
                            (IsHidden(source_p) ||
                            ConfigServerHide.hide_servers) ?
@@ -249,7 +224,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
                          oldts, newts);
   }
 
-  if (*modebuf != '\0')
+  if (*modebuf)
   {
     /* This _SHOULD_ be to ALL_MEMBERS
      * It contains only +imnpstlk, etc */
@@ -257,7 +232,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
                          servername, chptr->name, modebuf, parabuf);
   }
 
-  if (*parv[3] != '0' && keep_new_modes)
+  if (*parv[3] != '0' && keep_new_modes == true)
     channel_modes(chptr, source_p, modebuf, parabuf);
   else
   {
@@ -282,10 +257,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  mbuf = modebuf;
-  sendbuf[0] = '\0';
-  pargs = 0;
-
+  char *mbuf = modebuf;
   *mbuf++ = '+';
 
   s = parv[args + 4];
@@ -298,12 +270,12 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 
     while (*p == ' ')
       ++p;
-    have_many_uids = *p;
+    have_many_uids = *p != '\0';
   }
 
   while (*s)
   {
-    int valid_mode = 1;
+    bool valid_mode = true;
     fl = 0;
 
     do
@@ -323,10 +295,10 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
           ++s;
           break;
         default:
-          valid_mode = 0;
+          valid_mode = false;
           break;
       }
-    } while (valid_mode);
+    } while (valid_mode == true);
 
     /*
      * If the client doesn't exist, or if it's fake direction/server, skip.
@@ -340,7 +312,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
     len_uid = strlen(target_p->id);
     up = uid_prefix;
 
-    if (keep_new_modes)
+    if (keep_new_modes == true)
     {
       if (fl & CHFL_CHANOP)
       {
@@ -379,7 +351,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
 
     if (!IsMember(target_p, chptr))
     {
-      add_user_to_channel(chptr, target_p, fl, !have_many_uids);
+      add_user_to_channel(chptr, target_p, fl, have_many_uids == false);
 
       sendto_channel_local(NULL, chptr, 0, CAP_EXTENDED_JOIN, 0, ":%s!%s@%s JOIN %s %s :%s",
                            target_p->name, target_p->username,
@@ -532,7 +504,7 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
    * and leaving us with a channel formed just as the client parts.
    * - Dianora
    */
-  if (!dlink_list_length(&chptr->members) && isnew)
+  if (dlink_list_length(&chptr->members) == 0 && isnew == true)
   {
     channel_free(chptr);
     return 0;
@@ -556,9 +528,8 @@ ms_sjoin(struct Client *source_p, int parc, char *parv[])
  *		  but were not set in oldmode.
  */
 static void
-set_final_mode(struct Mode *mode, struct Mode *oldmode)
+set_final_mode(struct Mode *mode, struct Mode *oldmode, char *mbuf, char *pbuf)
 {
-  char *pbuf = parabuf;
   int len = 0;
 
   *mbuf++ = '-';
@@ -575,7 +546,6 @@ set_final_mode(struct Mode *mode, struct Mode *oldmode)
     *mbuf++ = 'k';
     len = sprintf(pbuf, "%s ", oldmode->key);
     pbuf += len;
-    pargs++;
   }
 
   if (*(mbuf - 1) == '-')
@@ -592,7 +562,6 @@ set_final_mode(struct Mode *mode, struct Mode *oldmode)
     *mbuf++ = 'l';
     len = sprintf(pbuf, "%u ", mode->limit);
     pbuf += len;
-    pargs++;
   }
 
   if (mode->key[0] && strcmp(oldmode->key, mode->key))
@@ -600,7 +569,6 @@ set_final_mode(struct Mode *mode, struct Mode *oldmode)
     *mbuf++ = 'k';
     len = sprintf(pbuf, "%s ", mode->key);
     pbuf += len;
-    pargs++;
   }
 
   if (*(mbuf - 1) == '+')
@@ -640,12 +608,13 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
 {
   dlink_node *node = NULL;
   char lmodebuf[MODEBUFLEN];
+  char sendbuf[MODEBUFLEN];
   char *sp = sendbuf;
   const char *lpara[MAXMODEPARAMS];
   unsigned int count = 0;
   int l = 0;
+  char *mbuf = lmodebuf;
 
-  mbuf = lmodebuf;
   *mbuf++ = '-';
   *sp = '\0';
 
@@ -707,36 +676,39 @@ remove_a_mode(struct Channel *chptr, struct Client *source_p,
  * side effects	- given ban list is removed, modes are sent to local clients
  */
 static void
-remove_ban_list(struct Channel *chptr, struct Client *source_p,
-                dlink_list *list, char c)
+remove_ban_list(struct Channel *chptr, struct Client *source_p, dlink_list *list, char c)
 {
-  char lmodebuf[MODEBUFLEN];
-  char lparabuf[IRCD_BUFSIZE];
-  dlink_node *node = NULL, *node_next = NULL;
-  char *pbuf = NULL;
+  dlink_node *node, *node_next;
+  char modebuf[IRCD_BUFSIZE];
+  char parabuf[IRCD_BUFSIZE];
+  char *mbuf;
+  char *pbuf;
   int count = 0;
-  int cur_len, mlen, plen;
+  int cur_len, mlen;
 
-  pbuf = lparabuf;
-  cur_len = mlen = snprintf(lmodebuf, sizeof(lmodebuf), ":%s MODE %s -",
+  if (dlink_list_length(list) == 0)
+    return;
+
+  cur_len = mlen = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s -",
                             source_p->name, chptr->name);
-  mbuf = lmodebuf + mlen;
+  mbuf = modebuf + mlen;
+  pbuf = parabuf;
 
   DLINK_FOREACH_SAFE(node, node_next, list->head)
   {
     struct Ban *ban = node->data;
-
-    plen = ban->len + 4;  /* another +b and "!@ " */
+    int plen = ban->len + 4;  /* another +b and "!@ " */
 
     if (count >= MAXMODEPARAMS ||
         (cur_len + 1 /* space between */ + (plen - 1)) > IRCD_BUFSIZE - 2)
     {
       /* NUL-terminate and remove trailing space */
       *mbuf = *(pbuf - 1) = '\0';
-      sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", lmodebuf, lparabuf);
+      sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
+
       cur_len = mlen;
-      mbuf = lmodebuf + mlen;
-      pbuf = lparabuf;
+      mbuf = modebuf + mlen;
+      pbuf = parabuf;
       count = 0;
     }
 
@@ -749,7 +721,7 @@ remove_ban_list(struct Channel *chptr, struct Client *source_p,
   }
 
   *mbuf = *(pbuf - 1) = '\0';
-  sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", lmodebuf, lparabuf);
+  sendto_channel_local(NULL, chptr, 0, 0, 0, "%s %s", modebuf, parabuf);
 }
 
 static struct Message sjoin_msgtab =
@@ -778,8 +750,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8787 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
