@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_squit.c
  * \brief Includes required functions for processing the SQUIT command.
- * \version $Id: m_squit.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_squit.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -56,7 +56,6 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
 {
   char comment[REASONLEN + 1] = "";
   struct Client *target_p = NULL;
-  dlink_node *node = NULL;
   const char *server = parv[1];
 
   if (parc < 2 || EmptyString(parv[1]))
@@ -66,13 +65,14 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
   }
 
   /* The following allows wild cards in SQUIT. */
+  dlink_node *node;
   DLINK_FOREACH(node, global_server_list.head)
   {
     struct Client *p = node->data;
 
     if (IsServer(p) || IsMe(p))
     {
-      if (!match(server, p->name))
+      if (match(server, p->name) == 0)
       {
         target_p = p;
         break;
@@ -80,7 +80,7 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  if (!target_p || IsMe(target_p))
+  if (target_p == NULL || IsMe(target_p))
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHSERVER, server);
     return 0;
@@ -98,10 +98,10 @@ mo_squit(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!EmptyString(parv[2]))
-    strlcpy(comment, parv[2], sizeof(comment));
-  else
+  if (EmptyString(parv[2]))
     strlcpy(comment, CONF_NOREASON, sizeof(comment));
+  else
+    strlcpy(comment, parv[2], sizeof(comment));
 
   if (MyConnect(target_p))
   {
@@ -146,7 +146,6 @@ ms_squit(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
   const char *comment = NULL;
-  dlink_node *node = NULL;
 
   if (parc < 2 || EmptyString(parv[1]))
     return 0;
@@ -175,6 +174,7 @@ ms_squit(struct Client *source_p, int parc, char *parv[])
     sendto_one(target_p, ":%s SQUIT %s :%s", source_p->id, me.id, comment);
 
     /* Send to everything but target and source */
+    dlink_node *node;
     DLINK_FOREACH(node, local_server_list.head)
     {
       struct Client *client_p = node->data;
@@ -222,8 +222,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
