@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_tmode.c
  * \brief Includes required functions for processing the TMODE command.
- * \version $Id: m_tmode.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: m_tmode.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -95,8 +95,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8430 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_CORE
+  .is_core = true
 };
