@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_accept.c
  * \brief Includes required functions for processing the ACCEPT command.
- * \version $Id: m_accept.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: m_accept.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -123,7 +123,7 @@ m_accept(struct Client *source_p, int parc, char *parv[])
   char *p = NULL;
   char *mask = collapse(parv[1]);
 
-  if (EmptyString(mask) || !strcmp(mask, "*"))
+  if (EmptyString(mask) || strcmp(mask, "*") == 0)
   {
     list_accepts(source_p);
     return 0;
@@ -210,7 +210,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8430 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
