@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_away.c
  * \brief Includes required functions for processing the AWAY command.
- * \version $Id: m_away.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_away.c 8973 2019-05-18 18:23:27Z michael $
  */
 
 #include "stdinc.h"
@@ -57,7 +57,7 @@ do_away(struct Client *source_p, const char *message)
 
       /* We now send this only if they were away before --is */
       sendto_server(source_p, 0, 0, ":%s AWAY", source_p->id);
-      sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY",
+      sendto_common_channels_local(source_p, true, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY",
                                    source_p->name, source_p->username, source_p->host);
     }
 
@@ -68,7 +68,7 @@ do_away(struct Client *source_p, const char *message)
 
   if (MyConnect(source_p))
   {
-    if ((source_p->connection->away.last_attempt + ConfigGeneral.away_time) < CurrentTime)
+    if ((source_p->connection->away.last_attempt + ConfigGeneral.away_time) < event_base->time.sec_monotonic)
       source_p->connection->away.count = 0;
 
     if (source_p->connection->away.count > ConfigGeneral.away_count)
@@ -77,13 +77,16 @@ do_away(struct Client *source_p, const char *message)
       return;
     }
 
-    source_p->connection->away.last_attempt = CurrentTime;
+    source_p->connection->away.last_attempt = event_base->time.sec_monotonic;
     source_p->connection->away.count++;
     sendto_one_numeric(source_p, &me, RPL_NOWAWAY);
+
+    if (strncmp(source_p->away, message, sizeof(source_p->away) - 1) == 0)
+      return;
   }
 
   strlcpy(source_p->away, message, sizeof(source_p->away));
-  sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY :%s",
+  sendto_common_channels_local(source_p, true, CAP_AWAY_NOTIFY, 0, ":%s!%s@%s AWAY :%s",
                                source_p->name, source_p->username,
                                source_p->host, source_p->away);
   sendto_server(source_p, 0, 0, ":%s AWAY :%s",
@@ -110,33 +113,13 @@ m_away(struct Client *source_p, int parc, char *parv[])
   return 0;
 }
 
-/*! \brief AWAY command handler
- *
- * \param source_p Pointer to allocated Client struct from which the message
- *                 originally comes from.  This can be a local or remote client.
- * \param parc     Integer holding the number of supplied arguments.
- * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
- *                 pointers.
- * \note Valid arguments for this command are:
- *      - parv[0] = command
- *      - parv[1] = away message
- */
-static int
-ms_away(struct Client *source_p, int parc, char *parv[])
-{
-  const char *const message = parv[1];
-
-  do_away(source_p, message);
-  return 0;
-}
-
 static struct Message away_msgtab =
 {
   .cmd = "AWAY",
   .args_max = MAXPARA,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_away,
-  .handlers[SERVER_HANDLER] = ms_away,
+  .handlers[SERVER_HANDLER] = m_away,
   .handlers[ENCAP_HANDLER] = m_ignore,
   .handlers[OPER_HANDLER] = m_away
 };
@@ -157,7 +140,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8973 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
