@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_connect.c
  * \brief Includes required functions for processing the CONNECT command.
- * \version $Id: m_connect.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: m_connect.c 8870 2019-02-16 19:22:19Z michael $
  */
 
 #include "stdinc.h"
@@ -112,11 +112,11 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
    * At this point we should be calling connect_server with a valid
    * connect{} block and a valid port in the connect{} block
    */
-  if (server_connect(conf, source_p))
+  if (server_connect(conf, source_p) == true)
   {
-    if (!ConfigServerHide.hide_server_ips && HasUMode(source_p, UMODE_ADMIN))
+    if (ConfigServerHide.hide_server_ips == 0 && HasUMode(source_p, UMODE_ADMIN))
       sendto_one_notice(source_p, &me, ":*** Connecting to %s[%s].%u",
-                        conf->host, conf->name, conf->port);
+                        conf->name, conf->host, conf->port);
     else
       sendto_one_notice(source_p, &me, ":*** Connecting to %s.%u",
                         conf->name, conf->port);
@@ -199,7 +199,7 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
    * At this point we should be calling connect_server with a valid
    * connect{} block and a valid port in the connect{} block
    */
-  if (server_connect(conf, source_p))
+  if (server_connect(conf, source_p) == true)
     sendto_one_notice(source_p, &me, ":*** Connecting to %s.%u",
                       conf->name, conf->port);
   else
@@ -239,7 +239,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8430 $",
+  .version = "$Revision: 8870 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
