@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_eob.c
  * \brief Includes required functions for processing the EOB command.
- * \version $Id: m_eob.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_eob.c 8918 2019-04-22 09:51:16Z michael $
  */
 
 #include "stdinc.h"
@@ -50,9 +50,8 @@ ms_eob(struct Client *source_p, int parc, char *parv[])
 
   if (MyConnect(source_p))
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "End of burst from %s (%ju seconds)",
-                         source_p->name,
-                         (CurrentTime - source_p->connection->firsttime));
+                         "End of burst from %s (%ju seconds)", source_p->name,
+                         (event_base->time.sec_monotonic - source_p->connection->created_monotonic));
 
   AddFlag(source_p, FLAGS_EOB);
   sendto_server(source_p, 0, 0, ":%s EOB", source_p->id);
@@ -85,7 +84,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8918 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
