@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_hash.c
  * \brief Includes required functions for processing the HASH command.
- * \version $Id: m_hash.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_hash.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -33,7 +33,6 @@
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
-#include "userhost.h"
 
 
 /*! \brief HASH command handler
@@ -56,7 +55,6 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
   const struct Client *cl = NULL;
   const struct Client *icl = NULL;
   const struct Channel *ch = NULL;
-  const struct UserHost *ush = NULL;
 
   for (i = 0; i < HASHSIZE; ++i)
   {
@@ -119,28 +117,6 @@ mo_hash(struct Client *source_p, int parc, char *parv[])
 
   sendto_one_notice(source_p, &me, ":Id: entries: %u buckets: %u "
                     "max chain: %u", count, buckets, max_chain);
-
-  count     = 0;
-  buckets   = 0;
-  max_chain = 0;
-
-  for (i = 0; i < HASHSIZE; ++i)
-  {
-    if ((ush = hash_get_bucket(HASH_TYPE_USERHOST, i)))
-    {
-      unsigned int len = 0;
-
-      ++buckets;
-      for (; ush; ush = ush->next)
-        ++len;
-      if (len > max_chain)
-        max_chain = len;
-      count += len;
-    }
-  }
-
-  sendto_one_notice(source_p, &me, ":UserHost: entries: %u buckets: %u "
-                    "max chain: %u", count, buckets, max_chain);
   return 0;
 }
 
@@ -169,7 +145,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
