@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2018 ircd-hybrid development team
+ *  Copyright (c) 1999-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_help.c
  * \brief Includes required functions for processing the HELP command.
- * \version $Id: m_help.c 8301 2018-02-25 14:44:54Z michael $
+ * \version $Id: m_help.c 8902 2019-04-21 20:41:04Z michael $
  */
 
 #include "stdinc.h"
@@ -126,13 +126,13 @@ m_help(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
-  if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait_simple) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "HELP");
     return 0;
   }
 
-  last_used = CurrentTime;
+  last_used = event_base->time.sec_monotonic;
 
   do_help(source_p, parv[1]);
   return 0;
@@ -181,7 +181,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8301 $",
+  .version = "$Revision: 8902 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
