@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 8313 2018-02-28 17:45:36Z michael $
+ * \version $Id: m_info.c 8962 2019-05-11 21:04:34Z michael $
  */
 
 #include "stdinc.h"
@@ -38,24 +38,22 @@
 #include "tls.h"
 
 
-/* Types for output_type in InfoStruct */
-enum
-{
-  OUTPUT_STRING     = 1 << 0,  /* Output option as %s w/ dereference  */
-  OUTPUT_STRING_PTR = 1 << 1,  /* Output option as %s w/out deference */
-  OUTPUT_DECIMAL    = 1 << 2,  /* Output option as decimal (%d) */
-  OUTPUT_BOOLEAN    = 1 << 3,  /* Output option as "ON" or "OFF" */
-  OUTPUT_BOOLEAN_YN = 1 << 4,  /* Output option as "YES" or "NO" */
-  OUTPUT_BOOLEAN2   = 1 << 5   /* Output option as "YES/NO/MASKED" */
-};
-
 /*
  * jdc -- Structure for our configuration value table
  */
 struct InfoStruct
 {
   const char *name;  /* Displayed variable name */
-  const unsigned int output_type;  /* Type of output. See enum above */
+  enum
+  {
+    OUTPUT_STRING = 1,  /* Output option as %s w/ dereference  */
+    OUTPUT_STRING_PTR,  /* Output option as %s w/out deference */
+    OUTPUT_DECIMAL,  /* Output option as decimal (%d) */
+    OUTPUT_BOOLEAN,  /* Output option as "ON" or "OFF" */
+    OUTPUT_BOOLEAN_YN,  /* Output option as "YES" or "NO" */
+    OUTPUT_BOOLEAN2  /* Output option as "YES/NO/MASKED" */
+  } output_type;  /* Type of output. See enum above */
+
   const void *option;  /* Pointer reference to the value */
   const char *desc;  /* ASCII description of the variable */
 };
@@ -322,12 +320,6 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.kill_chase_time_limit,
     "Nick Change Tracker for KILL"
   },
-  {
-    "ignore_bogus_ts",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigGeneral.ignore_bogus_ts,
-    "Ignore bogus timestamps from other servers"
-  },
   {
     "cycle_on_host_change",
     OUTPUT_BOOLEAN_YN,
@@ -346,12 +338,6 @@ static const struct InfoStruct info_table[] =
     &ConfigServerHide.disable_remote_commands,
     "Prevent users issuing commands on remote servers"
   },
-  {
-    "tkline_expire_notices",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigGeneral.tkline_expire_notices,
-    "Show temporary kline/xline expire notices"
-  },
   {
     "default_floodcount",
     OUTPUT_DECIMAL,
@@ -560,6 +546,70 @@ static const struct InfoStruct info_table[] =
   }
 };
 
+static const char *infotext[] =
+{
+  "ircd-hybrid --",
+  "Based on the original code written by Jarkko Oikarinen",
+  "Copyright (c) 1988-1991 University of Oulu, Computing Center",
+  "Copyright (c) 1997-2019 ircd-hybrid development team",
+  "",
+  "This program is free software; you can redistribute it and/or",
+  "modify it under the terms of the GNU General Public License as",
+  "published by the Free Software Foundation; either version 2, or",
+  "(at your option) any later version.",
+  "",
+  "",
+  "The core team as of this major release:",
+  "",
+  "Dianora, Diane Bruce <db@db.net>",
+  "Michael, Michael Wobst <michael@wobst.fr>",
+  "Rodder, Jon Lusky <lusky@blown.net>",
+  "Wohali, Joan Touzet <joant@ieee.org>",
+  "",
+  "The following people have contributed blood, sweat, and/or code to",
+  "recent releases of ircd-hybrid, in nick alphabetical order:",
+  "",
+  "A1kmm, Andrew Miller <a1kmm@mware.virtualave.net>",
+  "Adam, Adam <Adam@anope.org>",
+  "Adrian Chadd <adrian@creative.net.au>",
+  "adx, Piotr Nizynski <nizynski@sysplex.pl>",
+  "AndroSyn, Aaron Sethman <androsyn@ratbox.org>",
+  "bane, Dragan Dosen <bane@idolnet.org>",
+  "billy-jon, William Bierman III <bill@thebiermans.org>",
+  "bysin, Ben Kittridge <bkittridge@cfl.rr.com>",
+  "cosine, Patrick Alken <wnder@uwns.underworld.net>",
+  "cryogen, Stuart Walsh <stu@ipng.org.uk>",
+  "David-T, David Taylor <davidt@yadt.co.uk>",
+  "Dom, Dominic Hargreaves <dom@earth.li>",
+  "Fawkes, Christoph Ostermeier <fawkes@phat-net.de>",
+  "fgeek, Henri Salo <henri@nerv.fi>",
+  "fl, Lee Hardy <lee@leeh.co.uk>",
+  "Garion, Joost Vunderink <garion@efnet.nl>",
+  "Habeeb, David Supuran <habeeb@cfl.rr.com>",
+  "Hwy101, W. Campbell <wcampbel@botbay.net>",
+  "jmallett, Juli Mallett <jmallett@FreeBSD.org>",
+  "joshk, Joshua Kwan <joshk@triplehelix.org>",
+  "jv, Jakub Vlasek <jv@pilsedu.cz>",
+  "k9, Jeremy Chadwick <ircd@jdc.parodius.com>",
+  "kire, Erik Small <smalle@hawaii.edu>",
+  "knight, Alan LeVee <alan.levee@prometheus-designs.net>",
+  "kre, Dinko Korunic <kreator@fly.srk.fer.hr>",
+  "madmax, Paul Lomax <madmax@efnet.org>",
+  "metalrock, Jack Low <xxjack12xx@gmail.com>",
+  "r0d3nt, Andrew Strutt <andrew.strutt@gmail.com>",
+  "Riedel, Dennis Vink <dennis@drvink.com>",
+  "scuzzy, David Todd <scuzzy@aniverse.net>",
+  "spookey, David Colburn <spookey@spookey.org>",
+  "TimeMr14C, Yusuf Iskenderoglu <uhc0@stud.uni-karlsruhe.de>",
+  "toot, Toby Verrall <to7@antipope.fsnet.co.uk>",
+  "vx0, Mark Miller <mark@oc768.net>",
+  "wiz, Jason Dambrosio <jason@wiz.cx>",
+  "Xride, S\xC3\xB8ren Straarup <xride@x12.dk>",
+  "zb^3, Alfred Perlstein <alfred@freebsd.org>",
+  "",
+  NULL
+};
+
 /* send_birthdate_online_time()
  *
  * inputs	- client pointer to send to
@@ -571,7 +621,7 @@ send_birthdate_online_time(struct Client *source_p)
 {
   sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                      ":On-line since %s",
-                     date(me.connection->firsttime));
+                     date(me.connection->created_real));
 }
 
 /* send_conf_options()
@@ -719,15 +769,15 @@ m_info(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
-  if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "INFO");
     return 0;
   }
 
-  last_used = CurrentTime;
+  last_used = event_base->time.sec_monotonic;
 
-  if (!ConfigServerHide.disable_remote_commands)
+  if (ConfigServerHide.disable_remote_commands == 0)
     if (server_hunt(source_p, ":%s INFO :%s", 1, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
@@ -781,7 +831,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8313 $",
+  .version = "$Revision: 8962 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
