@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_invite.c
  * \brief Includes required functions for processing the INVITE command.
- * \version $Id: m_invite.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: m_invite.c 8902 2019-04-21 20:41:04Z michael $
  */
 
 #include "stdinc.h"
@@ -73,9 +73,6 @@ m_invite(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (IsFloodDone(source_p))
-    flood_endgrace(source_p);
-
   struct Client *target_p;
   if ((target_p = find_person(source_p, parv[1])) == NULL)
   {
@@ -109,7 +106,7 @@ m_invite(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if ((source_p->connection->invite.last_attempt + ConfigChannel.invite_client_time) < CurrentTime)
+  if ((source_p->connection->invite.last_attempt + ConfigChannel.invite_client_time) < event_base->time.sec_monotonic)
     source_p->connection->invite.count = 0;
 
   if (source_p->connection->invite.count > ConfigChannel.invite_client_count)
@@ -118,13 +115,13 @@ m_invite(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if ((chptr->last_invite + ConfigChannel.invite_delay_channel) > CurrentTime)
+  if ((chptr->last_invite + ConfigChannel.invite_delay_channel) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, ERR_TOOMANYINVITE, chptr->name, "channel");
     return 0;
   }
 
-  source_p->connection->invite.last_attempt = CurrentTime;
+  source_p->connection->invite.last_attempt = event_base->time.sec_monotonic;
   source_p->connection->invite.count++;
 
   sendto_one_numeric(source_p, &me, RPL_INVITING, target_p->name, chptr->name);
@@ -132,7 +129,7 @@ m_invite(struct Client *source_p, int parc, char *parv[])
   if (target_p->away[0])
     sendto_one_numeric(source_p, &me, RPL_AWAY, target_p->name, target_p->away);
 
-  chptr->last_invite = CurrentTime;
+  chptr->last_invite = event_base->time.sec_monotonic;
 
   if (MyConnect(target_p))
   {
@@ -195,7 +192,7 @@ ms_invite(struct Client *source_p, int parc, char *parv[])
     if (strtoumax(parv[3], NULL, 10) > chptr->creationtime)
       return 0;
 
-  chptr->last_invite = CurrentTime;
+  chptr->last_invite = event_base->time.sec_monotonic;
 
   if (MyConnect(target_p))
   {
@@ -229,6 +226,7 @@ static struct Message invite_msgtab =
 {
   .cmd = "INVITE",
   .args_max = MAXPARA,
+  .flags = MFLG_ENDGRACE,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_invite,
   .handlers[SERVER_HANDLER] = ms_invite,
@@ -250,7 +248,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8436 $",
+  .version = "$Revision: 8902 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
