@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2018 ircd-hybrid development team
+ *  Copyright (c) 1998-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_knock.c
  * \brief Includes required functions for processing the KNOCK command.
- * \version $Id: m_knock.c 8487 2018-04-04 16:55:58Z michael $
+ * \version $Id: m_knock.c 8918 2019-04-22 09:51:16Z michael $
  */
 
 #include "stdinc.h"
@@ -91,13 +91,13 @@ m_knock(struct Client *source_p, int parc, char *parv[])
     /*
      * Don't allow a knock if the user is banned, or the channel is private.
      */
-    if (PrivateChannel(chptr) || is_banned(chptr, source_p))
+    if (PrivateChannel(chptr) || is_banned(chptr, source_p) == true)
     {
       sendto_one_numeric(source_p, &me, ERR_CANNOTSENDTOCHAN, chptr->name);
       return 0;
     }
 
-    if ((source_p->connection->knock.last_attempt + ConfigChannel.knock_client_time) < CurrentTime)
+    if ((source_p->connection->knock.last_attempt + ConfigChannel.knock_client_time) < event_base->time.sec_monotonic)
       source_p->connection->knock.count = 0;
 
     if (source_p->connection->knock.count > ConfigChannel.knock_client_count)
@@ -106,19 +106,19 @@ m_knock(struct Client *source_p, int parc, char *parv[])
       return 0;
     }
 
-    if ((chptr->last_knock + ConfigChannel.knock_delay_channel) > CurrentTime)
+    if ((chptr->last_knock + ConfigChannel.knock_delay_channel) > event_base->time.sec_monotonic)
     {
       sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, chptr->name, "channel");
       return 0;
     }
 
-    source_p->connection->knock.last_attempt = CurrentTime;
+    source_p->connection->knock.last_attempt = event_base->time.sec_monotonic;
     source_p->connection->knock.count++;
 
     sendto_one_numeric(source_p, &me, RPL_KNOCKDLVR, chptr->name);
   }
 
-  chptr->last_knock = CurrentTime;
+  chptr->last_knock = event_base->time.sec_monotonic;
   sendto_channel_local(NULL, chptr, CHFL_CHANOP | CHFL_HALFOP, 0, 0,
                        ":%s NOTICE %%%s :KNOCK: %s (%s [%s@%s] has asked for an invite)",
                        me.name, chptr->name, chptr->name,
@@ -161,7 +161,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8487 $",
+  .version = "$Revision: 8918 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
