@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_links.c
  * \brief Includes required functions for processing the LINKS command.
- * \version $Id: m_links.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: m_links.c 9018 2019-05-27 22:04:45Z michael $
  */
 
 #include "stdinc.h"
@@ -52,7 +52,7 @@ do_links(struct Client *source_p, int parc, char *parv[])
                        source_p->username, source_p->host,
                        source_p->servptr->name);
 
-  if (HasUMode(source_p, UMODE_OPER) || !ConfigServerHide.flatten_links)
+  if (HasUMode(source_p, UMODE_OPER) || ConfigServerHide.flatten_links == 0)
   {
     const char *mask = (parc > 2 ? parv[2] : parv[1]);
 
@@ -101,11 +101,6 @@ do_links(struct Client *source_p, int parc, char *parv[])
 static int
 mo_links(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc > 2)
-    if (!ConfigServerHide.disable_remote_commands || HasUMode(source_p, UMODE_OPER))
-      if (server_hunt(source_p, ":%s LINKS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
-        return 0;
-
   do_links(source_p, parc, parv);
   return 0;
 }
@@ -130,52 +125,25 @@ m_links(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
-  if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "LINKS");
     return 0;
   }
 
-  last_used = CurrentTime;
-
-  if (!ConfigServerHide.flatten_links)
-    return mo_links(source_p, parc, parv);
+  last_used = event_base->time.sec_monotonic;
 
   do_links(source_p, parc, parv);
   return 0;
 }
 
-/*! \brief LINKS command handler
- *
- * \param source_p Pointer to allocated Client struct from which the message
- *                 originally comes from.  This can be a local or remote client.
- * \param parc     Integer holding the number of supplied arguments.
- * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
- *                 pointers.
- * \note Valid arguments for this command are:
- *      - parv[0] = command
- *      - parv[1] = servername mask
- * or
- *      - parv[0] = command
- *      - parv[1] = server to query
- *      - parv[2] = servername mask
- */
-static int
-ms_links(struct Client *source_p, int parc, char *parv[])
-{
-  if (server_hunt(source_p, ":%s LINKS %s :%s", 1, parc, parv)->ret != HUNTED_ISME)
-    return 0;
-
-  return m_links(source_p, parc, parv);
-}
-
 static struct Message links_msgtab =
 {
   .cmd = "LINKS",
   .args_max = MAXPARA,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_links,
-  .handlers[SERVER_HANDLER] = ms_links,
+  .handlers[SERVER_HANDLER] = m_ignore,
   .handlers[ENCAP_HANDLER] = m_ignore,
   .handlers[OPER_HANDLER] = mo_links
 };
@@ -194,7 +162,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8430 $",
+  .version = "$Revision: 9018 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
