@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_list.c
  * \brief Includes required functions for processing the LIST command.
- * \version $Id: m_list.c 8309 2018-02-28 16:45:52Z michael $
+ * \version $Id: m_list.c 8927 2019-04-22 11:08:47Z michael $
  */
 
 #include "stdinc.h"
@@ -42,7 +42,7 @@
 static void
 do_list(struct Client *source_p, char *arg)
 {
-  int no_masked_channels = 1;
+  bool no_masked_channels = true;
 
   if (source_p->connection->list_task)
   {
@@ -60,9 +60,10 @@ do_list(struct Client *source_p, char *arg)
 
   if (!EmptyString(arg))
   {
-    char *opt, *save = NULL;
     dlink_list *list = NULL;
-    int i = 0, errors = 0;
+    char *opt, *save = NULL;
+    bool error = false;
+    int i = 0;
 
     for (opt = strtok_r(arg,  ",", &save); opt;
          opt = strtok_r(NULL, ",", &save))
@@ -73,13 +74,13 @@ do_list(struct Client *source_p, char *arg)
           if ((i = atoi(opt + 1)) > 0)
             lt->users_max = (unsigned int)i - 1;
           else
-            errors = 1;
+            error = true;
           break;
         case '>':
           if ((i = atoi(opt + 1)) >= 0)
             lt->users_min = (unsigned int)i + 1;
           else
-            errors = 1;
+            error = true;
           break;
         case 'C':
         case 'c':
@@ -87,18 +88,18 @@ do_list(struct Client *source_p, char *arg)
           {
             case '<':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->created_max = (unsigned int)(CurrentTime - 60 * i);
+                lt->created_max = (unsigned int)(event_base->time.sec_real - 60 * i);
               else
-                errors = 1;
+                error = true;
               break;
             case '>':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->created_min = (unsigned int)(CurrentTime - 60 * i);
+                lt->created_min = (unsigned int)(event_base->time.sec_real - 60 * i);
               else
-                errors = 1;
+                error = true;
               break;
             default:
-              errors = 1;
+              error = true;
           }
 
           break;
@@ -109,22 +110,22 @@ do_list(struct Client *source_p, char *arg)
           {
             case '<':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->topicts_min = (unsigned int)(CurrentTime - 60 * i);
+                lt->topicts_min = (unsigned int)(event_base->time.sec_real - 60 * i);
               else
-                errors = 1;
+                error = true;
               break;
             case '>':
               if ((i = atoi(opt + 1)) >= 0)
-                lt->topicts_max = (unsigned int)(CurrentTime - 60 * i);
+                lt->topicts_max = (unsigned int)(event_base->time.sec_real - 60 * i);
               else
-                errors = 1;
+                error = true;
               break;
             case ':':
               if (strlcpy(lt->topic, opt + 1, sizeof(lt->topic)) == 0)
-                errors = 1;
+                error = true;
               break;
             default:
-              errors = 1;
+              error = true;
           }
 
           break;
@@ -141,17 +142,17 @@ do_list(struct Client *source_p, char *arg)
           if (has_wildcards(opt + !!IsChanPrefix(*opt)))
           {
             if (list == &lt->show_mask)
-              no_masked_channels = 0;
+              no_masked_channels = false;
           }
           else if (!IsChanPrefix(*opt))
-            errors = 1;
+            error = true;
 
-          if (!errors)
+          if (error == false)
             dlinkAdd(xstrdup(opt), make_dlink_node(), list);
       }
     }
 
-    if (errors)
+    if (error == true)
     {
       free_list_task(source_p);
       sendto_one_numeric(source_p, &me, ERR_LISTSYNTAX);
@@ -210,7 +211,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8309 $",
+  .version = "$Revision: 8927 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
