@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2018 ircd-hybrid development team
+ *  Copyright (c) 2001-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_map.c
  * \brief Includes required functions for processing the MAP command.
- * \version $Id: m_map.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: m_map.c 8902 2019-04-21 20:41:04Z michael $
  */
 
 #include "stdinc.h"
@@ -151,13 +151,13 @@ m_map(struct Client *source_p, int parc, char *parv[])
   if (ConfigServerHide.flatten_links)
     return m_not_oper(source_p, parc, parv);
 
-  if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "MAP");
     return 0;
   }
 
-  last_used = CurrentTime;
+  last_used = event_base->time.sec_monotonic;
 
   do_map(source_p);
   sendto_one_numeric(source_p, &me, RPL_MAPEND);
@@ -207,7 +207,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8430 $",
+  .version = "$Revision: 8902 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
