@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_module.c
  * \brief Includes required functions for processing the MODULE command.
- * \version $Id: m_module.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_module.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -74,21 +74,21 @@ module_unload(struct Client *source_p, const char *arg)
     return;
   }
 
-  if (modp->flags & MODULE_FLAG_CORE)
+  if (modp->is_core == true)
   {
     sendto_one_notice(source_p, &me, ":Module %s is a core module and may not be unloaded",
                       m_bn);
     return;
   }
 
-  if (modp->flags & MODULE_FLAG_NOUNLOAD)
+  if (modp->is_resident == true)
   {
     sendto_one_notice(source_p, &me, ":Module %s is a resident module and may not be unloaded",
                       m_bn);
     return;
   }
 
-  if (unload_one_module(m_bn, 1) == -1)
+  if (unload_one_module(m_bn, true) == false)
     sendto_one_notice(source_p, &me, ":Module %s is not loaded", m_bn);
 }
 
@@ -104,7 +104,7 @@ module_reload(struct Client *source_p, const char *arg)
   const char *m_bn = NULL;
   struct module *modp = NULL;
 
-  if (!strcmp(arg, "*"))
+  if (strcmp(arg, "*") == 0)
   {
     unsigned int modnum = dlink_list_length(modules_get_list());
     dlink_node *node, *node_next;
@@ -115,8 +115,8 @@ module_reload(struct Client *source_p, const char *arg)
     {
       modp = node->data;
 
-      if (!(modp->flags & MODULE_FLAG_NOUNLOAD))
-        unload_one_module(modp->name, 0);
+      if (modp->is_resident == false)
+        unload_one_module(modp->name, false);
     }
 
     load_all_modules(0);
@@ -137,21 +137,23 @@ module_reload(struct Client *source_p, const char *arg)
     return;
   }
 
-  if (modp->flags & MODULE_FLAG_NOUNLOAD)
+  if (modp->is_resident == true)
   {
     sendto_one_notice(source_p, &me, ":Module %s is a resident module and may not be unloaded",
                       m_bn);
     return;
   }
 
-  if (unload_one_module(m_bn, 1) == -1)
+  /* Cache modp->is_core for later use after the module is unloaded */
+  bool is_core = modp->is_core;
+
+  if (unload_one_module(m_bn, true) == false)
   {
     sendto_one_notice(source_p, &me, ":Module %s is not loaded", m_bn);
     return;
   }
 
-  int check_core = (modp->flags & MODULE_FLAG_CORE) != 0;
-  if (load_one_module(arg) == -1 && check_core)
+  if (load_one_module(arg) == false && is_core == true)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error reloading core "
@@ -180,7 +182,7 @@ module_list(struct Client *source_p, const char *arg)
 
     sendto_one_numeric(source_p, &me, RPL_MODLIST,
                        modp->name, modp->handle,
-                       modp->version, (modp->flags & MODULE_FLAG_CORE) ? "(core)" : "");
+                       modp->version, modp->is_core == true ? "(core)" : "");
   }
 
   sendto_one_numeric(source_p, &me, RPL_ENDOFMODLIST);
@@ -190,16 +192,16 @@ struct ModuleStruct
 {
   const char *const cmd;
   void (*const handler)(struct Client *, const char *);
-  const unsigned int arg_required;
+  bool arg_required;
 };
 
 static const struct ModuleStruct module_cmd_table[] =
 {
-  { "LOAD",   module_load,   1 },
-  { "UNLOAD", module_unload, 1 },
-  { "RELOAD", module_reload, 1 },
-  { "LIST",   module_list,   0 },
-  { NULL,     NULL,          0 }
+  { "LOAD",   module_load,   true  },
+  { "UNLOAD", module_unload, true  },
+  { "RELOAD", module_reload, true  },
+  { "LIST",   module_list,   false },
+  { NULL,     NULL,          false }
 };
 
 /*! \brief MODULE command handler
@@ -237,7 +239,7 @@ mo_module(struct Client *source_p, int parc, char *parv[])
     if (irccmp(tab->cmd, subcmd))
       continue;
 
-    if (tab->arg_required && EmptyString(module))
+    if (tab->arg_required == true && EmptyString(module))
     {
       sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "MODULE");
       return 0;
@@ -279,8 +281,8 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
-  .flags   = MODULE_FLAG_NOUNLOAD
+  .is_resident = true
 };
