@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_motd.c
  * \brief Includes required functions for processing the MOTD command.
- * \version $Id: m_motd.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_motd.c 8902 2019-04-21 20:41:04Z michael $
  */
 
 #include "stdinc.h"
@@ -68,15 +68,15 @@ m_motd(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
-  if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "MOTD");
     return 0;
   }
 
-  last_used = CurrentTime;
+  last_used = event_base->time.sec_monotonic;
 
-  if (!ConfigServerHide.disable_remote_commands)
+  if (ConfigServerHide.disable_remote_commands == 0)
     if (server_hunt(source_p, ":%s MOTD :%s", 1, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
@@ -130,7 +130,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8902 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
