@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_names.c
  * \brief Includes required functions for processing the NAMES command.
- * \version $Id: m_names.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_names.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -57,7 +57,7 @@ m_names(struct Client *source_p, int parc, char *parv[])
   {
     struct Channel *chptr = hash_find_channel(para);
     if (chptr)
-      channel_member_names(source_p, chptr, 1);
+      channel_member_names(source_p, chptr, true);
     else
       sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, para);
   }
@@ -92,7 +92,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
