@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_oper.c
  * \brief Includes required functions for processing the OPER command.
- * \version $Id: m_oper.c 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: m_oper.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -43,12 +43,12 @@
 /*! \brief Blindly opers up given source_p, using conf info.
  *         All checks on passwords have already been done.
  * \param source_p Pointer to given client to oper
+ * \param conf operator {} configuration record
  */
 static void
-oper_up(struct Client *source_p)
+oper_up(struct Client *source_p, const struct MaskItem *conf)
 {
   const unsigned int old = source_p->umodes;
-  const struct MaskItem *const conf = source_p->connection->confs.head->data;
 
   ++Count.oper;
   SetOper(source_p);
@@ -74,7 +74,7 @@ oper_up(struct Client *source_p)
   if (!EmptyString(conf->whois))
   {
     svstag_attach(&source_p->svstags, RPL_WHOISOPERATOR, "+", conf->whois);
-    sendto_server(source_p, 0, 0, ":%s SVSTAG %s %ju %u + :%s",
+    sendto_server(NULL, 0, 0, ":%s SVSTAG %s %ju %u + :%s",
                   me.id, source_p->id, source_p->tsinfo,
                   RPL_WHOISOPERATOR, conf->whois);
   }
@@ -135,10 +135,6 @@ m_oper(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  /* end the grace period */
-  if (!IsFloodDone(source_p))
-    flood_endgrace(source_p);
-
   struct MaskItem *conf;
   if ((conf = operator_find(source_p, opername)) == NULL)
   {
@@ -166,7 +162,7 @@ m_oper(struct Client *source_p, int parc, char *parv[])
     }
   }
 
-  if (match_conf_password(password, conf))
+  if (match_conf_password(password, conf) == true)
   {
     if (conf_attach(source_p, conf))
     {
@@ -175,7 +171,7 @@ m_oper(struct Client *source_p, int parc, char *parv[])
       return 0;
     }
 
-    oper_up(source_p);
+    oper_up(source_p, conf);
   }
   else
   {
@@ -210,6 +206,7 @@ static struct Message oper_msgtab =
   .cmd = "OPER",
   .args_min = 3,
   .args_max = MAXPARA,
+  .flags = MFLG_ENDGRACE,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_oper,
   .handlers[SERVER_HANDLER] = m_ignore,
@@ -231,7 +228,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8483 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
