@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_set.c
  * \brief Includes required functions for processing the SET command.
- * \version $Id: m_set.c 8390 2018-03-17 21:43:52Z michael $
+ * \version $Id: m_set.c 8892 2019-04-21 14:10:43Z michael $
  */
 
 #include "stdinc.h"
@@ -41,44 +41,50 @@
 static void
 quote_autoconn(struct Client *source_p, const char *arg, int newval)
 {
-  if (!EmptyString(arg))
+  if (EmptyString(arg))
   {
-    struct MaskItem *conf = connect_find(arg, irccmp);
-
-    if (conf)
-    {
-      if (newval)
-        SetConfAllowAutoConn(conf);
-      else
-        ClearConfAllowAutoConn(conf);
-
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                           "%s has changed AUTOCONN for %s to %i",
-                           get_oper_name(source_p), conf->name, newval);
-      sendto_one_notice(source_p, &me, ":AUTOCONN for %s is now set to %i",
-                        conf->name, newval);
-    }
-    else
-      sendto_one_notice(source_p, &me, ":Cannot find %s", arg);
-  }
-  else
     sendto_one_notice(source_p, &me, ":Please specify a server name!");
+    return;
+  }
+
+  struct MaskItem *conf = connect_find(arg, irccmp);
+  if (conf == NULL)
+  {
+    sendto_one_notice(source_p, &me, ":Cannot find %s", arg);
+    return;
+  }
+
+  if (newval)
+    SetConfAllowAutoConn(conf);
+  else
+    ClearConfAllowAutoConn(conf);
+
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                       "%s has changed AUTOCONN for %s to %i",
+                       get_oper_name(source_p), conf->name, newval);
+  sendto_one_notice(source_p, &me, ":AUTOCONN for %s is now set to %i",
+                    conf->name, newval);
 }
 
 /* SET AUTOCONNALL */
 static void
 quote_autoconnall(struct Client *source_p, const char *arg, int newval)
 {
+  static const char *const status[] =
+  {
+    "OFF", "ON"
+  };
+
   if (newval >= 0)
   {
-    GlobalSetOptions.autoconn = newval;
+    GlobalSetOptions.autoconn = newval != 0;
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed AUTOCONNALL to %u",
-                         get_oper_name(source_p), GlobalSetOptions.autoconn);
+                         "%s has changed AUTOCONNALL to %s",
+                         get_oper_name(source_p), status[GlobalSetOptions.autoconn == true]);
   }
   else
-    sendto_one_notice(source_p, &me, ":AUTOCONNALL is currently %u",
-                      GlobalSetOptions.autoconn);
+    sendto_one_notice(source_p, &me, ":AUTOCONNALL is currently %s",
+                      status[GlobalSetOptions.autoconn == true]);
 }
 
 /* SET FLOODCOUNT */
@@ -113,28 +119,6 @@ quote_floodtime(struct Client *source_p, const char *arg, int newval)
                       GlobalSetOptions.floodtime);
 }
 
-/* SET IDENTTIMEOUT */
-static void
-quote_identtimeout(struct Client *source_p, const char *arg, int newval)
-{
-  if (!HasUMode(source_p, UMODE_ADMIN))
-  {
-    sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "set");
-    return;
-  }
-
-  if (newval > 0)
-  {
-    GlobalSetOptions.ident_timeout = newval;
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has changed IDENTTIMEOUT to %u",
-                         get_oper_name(source_p), GlobalSetOptions.ident_timeout);
-  }
-  else
-    sendto_one_notice(source_p, &me, ":IDENTTIMEOUT is currently %u",
-                      GlobalSetOptions.ident_timeout);
-}
-
 /* SET MAX */
 static void
 quote_max(struct Client *source_p, const char *arg, int newval)
@@ -148,13 +132,6 @@ quote_max(struct Client *source_p, const char *arg, int newval)
       return;
     }
 
-    if (newval < MAXCLIENTS_MIN)
-    {
-      sendto_one_notice(source_p, &me, ":You cannot set MAXCLIENTS to < %d, restoring to %u",
-                        MAXCLIENTS_MIN, GlobalSetOptions.maxclients);
-      return;
-    }
-
     GlobalSetOptions.maxclients = newval;
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "%s set new MAXCLIENTS to %u (%u current)",
@@ -242,8 +219,8 @@ struct SetStruct
 {
   const char *const name;
   void (*const handler)(struct Client *, const char *, int);
-  const unsigned int wants_char;  /* 1 if it expects (char *, [int]) */
-  const unsigned int wants_int;  /* 1 if it expects ([char *], int) */
+  bool wants_char;  /* 1 if it expects (char *, [int]) */
+  bool wants_int;  /* 1 if it expects ([char *], int) */
   /* eg:  0, 1 == only an int arg
    * eg:  1, 1 == char and int args */
 };
@@ -258,19 +235,18 @@ struct SetStruct
 static const struct SetStruct set_cmd_table[] =
 {
   /* name               function        string arg  int arg */
-  /* -------------------------------------------------------- */
-  { "AUTOCONN",         quote_autoconn,         1,      1 },
-  { "AUTOCONNALL",      quote_autoconnall,      0,      1 },
-  { "FLOODCOUNT",       quote_floodcount,       0,      1 },
-  { "FLOODTIME",        quote_floodtime,        0,      1 },
-  { "IDENTTIMEOUT",     quote_identtimeout,     0,      1 },
-  { "MAX",              quote_max,              0,      1 },
-  { "SPAMNUM",          quote_spamnum,          0,      1 },
-  { "SPAMTIME",         quote_spamtime,         0,      1 },
-  { "JFLOODTIME",       quote_jfloodtime,       0,      1 },
-  { "JFLOODCOUNT",      quote_jfloodcount,      0,      1 },
-  /* -------------------------------------------------------- */
-  { NULL,               NULL,                   0,      0 }
+  /* ------------------------------------------------------ */
+  { "AUTOCONN",         quote_autoconn,     true,   true  },
+  { "AUTOCONNALL",      quote_autoconnall,  false,  true  },
+  { "FLOODCOUNT",       quote_floodcount,   false,  true  },
+  { "FLOODTIME",        quote_floodtime,    false,  true  },
+  { "MAX",              quote_max,          false,  true  },
+  { "SPAMNUM",          quote_spamnum,      false,  true  },
+  { "SPAMTIME",         quote_spamtime,     false,  true  },
+  { "JFLOODTIME",       quote_jfloodtime,   false,  true  },
+  { "JFLOODCOUNT",      quote_jfloodcount,  false,  true  },
+  /* ------------------------------------------------------ */
+  { NULL,               NULL,               false,  false }
 };
 
 /*
@@ -359,9 +335,9 @@ mo_set(struct Client *source_p, int parc, char *parv[])
       {
         if (intarg)
         {
-          if (!irccmp(intarg, "yes") || !irccmp(intarg, "on"))
+          if (irccmp(intarg, "yes") == 0 || irccmp(intarg, "on") == 0)
             newval = 1;
-          else if (!irccmp(intarg, "no") || !irccmp(intarg, "off"))
+          else if (irccmp(intarg, "no") == 0 || irccmp(intarg, "off") == 0)
             newval = 0;
           else
             newval = atoi(intarg);
@@ -419,7 +395,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8390 $",
+  .version = "$Revision: 8892 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
