@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_stats.c
  * \brief Includes required functions for processing the STATS command.
- * \version $Id: m_stats.c 8490 2018-04-04 22:02:18Z michael $
+ * \version $Id: m_stats.c 9037 2019-05-30 12:26:21Z michael $
  */
 
 #include "stdinc.h"
@@ -55,6 +55,60 @@
 #include "ipcache.h"
 
 
+static const char *
+oper_privs_as_string(const unsigned int flags)
+{
+  static const struct oper_flags
+  {
+    unsigned int flag;
+    unsigned char letter;
+  } flag_table[] = {
+    { OPER_FLAG_ADMIN,          'A' },
+    { OPER_FLAG_CLOSE,          'B' },
+    { OPER_FLAG_CONNECT,        'C' },
+    { OPER_FLAG_CONNECT_REMOTE, 'D' },
+    { OPER_FLAG_DIE,            'E' },
+    { OPER_FLAG_DLINE,          'F' },
+    { OPER_FLAG_GLOBOPS,        'G' },
+    { OPER_FLAG_JOIN_RESV,      'H' },
+    { OPER_FLAG_KILL,           'I' },
+    { OPER_FLAG_KILL_REMOTE,    'J' },
+    { OPER_FLAG_KLINE,          'K' },
+    { OPER_FLAG_LOCOPS,         'L' },
+    { OPER_FLAG_MODULE,         'M' },
+    { OPER_FLAG_NICK_RESV,      'N' },
+    { OPER_FLAG_OPME,           'O' },
+    { OPER_FLAG_REHASH,         'P' },
+    { OPER_FLAG_REMOTEBAN,      'Q' },
+    { OPER_FLAG_RESTART,        'R' },
+    { OPER_FLAG_RESV,           'S' },
+    { OPER_FLAG_SET,            'T' },
+    { OPER_FLAG_SQUIT,          'U' },
+    { OPER_FLAG_SQUIT_REMOTE,   'V' },
+    { OPER_FLAG_UNDLINE,        'W' },
+    { OPER_FLAG_UNKLINE,        'X' },
+    { OPER_FLAG_UNRESV,         'Y' },
+    { OPER_FLAG_UNXLINE,        'Z' },
+    { OPER_FLAG_WALLOPS,        'a' },
+    { OPER_FLAG_XLINE,          'b' },
+    { 0, '\0' }
+  };
+
+  static char buf[sizeof(flag_table) / sizeof(flag_table[0])];
+  char *p = buf;
+
+  for (const struct oper_flags *tab = flag_table; tab->flag; ++tab)
+    if (flags & tab->flag)
+      *p++ = tab->letter;
+
+  if (p == buf)
+    *p++ = '0';
+
+  *p = '\0';
+
+  return buf;
+}
+
 static void
 report_shared(struct Client *source_p)
 {
@@ -222,7 +276,7 @@ stats_connect(struct Client *source_p, int parc, char *parv[])
     /*
      * Allow admins to see actual ips unless 'hide_server_ips' is enabled
      */
-    if (!ConfigServerHide.hide_server_ips && HasUMode(source_p, UMODE_ADMIN))
+    if (ConfigServerHide.hide_server_ips == 0 && HasUMode(source_p, UMODE_ADMIN))
       sendto_one_numeric(source_p, &me, RPL_STATSCLINE, 'C', conf->host,
                          buf, conf->name, conf->port, conf->class->name);
     else
@@ -511,7 +565,7 @@ stats_tdeny(struct Client *source_p, int parc, char *parv[])
 
       const struct MaskItem *conf = arec->conf;
       /* Don't report a permanent dline as temporary dline */
-      if (!conf->until)
+      if (conf->until == 0)
         continue;
 
       sendto_one_numeric(source_p, &me, RPL_STATSDLINE, 'd', conf->host, conf->reason);
@@ -566,8 +620,8 @@ stats_events(struct Client *source_p, int parc, char *parv[])
     const struct event *ev = node->data;
 
     sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                       "E :%-30s %-4ji seconds",
-                       ev->name, ev->next - CurrentTime);
+                       "E :%-30s %-4ju seconds",
+                       ev->name, ev->next - event_base->time.sec_monotonic);
   }
 }
 
@@ -578,7 +632,7 @@ stats_fdlist(struct Client *source_p, int parc, char *parv[])
   {
     const fde_t *F = &fd_table[fd];
 
-    if (F->flags.open)
+    if (F->flags.open == true)
       sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
                          "F :fd %-5d desc '%s'", F->fd, F->desc);
   }
@@ -690,15 +744,14 @@ stats_auth(struct Client *source_p, int parc, char *parv[])
 
     if (MyConnect(source_p))
       conf = find_conf_by_address(source_p->host,
-                                  &source_p->connection->ip, CONF_CLIENT,
-                                  source_p->connection->aftype,
+                                  &source_p->ip, CONF_CLIENT,
                                   source_p->username,
                                   source_p->connection->password, 1);
     else
-      conf = find_conf_by_address(source_p->host, NULL, CONF_CLIENT, 0,
+      conf = find_conf_by_address(source_p->host, NULL, CONF_CLIENT,
                                   source_p->username, NULL, 1);
 
-    if (!conf)
+    if (conf == NULL)
       return;
 
     sendto_one_numeric(source_p, &me, RPL_STATSILINE,
@@ -762,18 +815,17 @@ stats_tklines(struct Client *source_p, int parc, char *parv[])
 
     if (MyConnect(source_p))
       conf = find_conf_by_address(source_p->host,
-                                  &source_p->connection->ip, CONF_KLINE,
-                                  source_p->connection->aftype,
+                                  &source_p->ip, CONF_KLINE,
                                   source_p->username, NULL, 1);
     else
-      conf = find_conf_by_address(source_p->host, NULL, CONF_KLINE, 0,
+      conf = find_conf_by_address(source_p->host, NULL, CONF_KLINE,
                                   source_p->username, NULL, 1);
 
-    if (!conf)
+    if (conf == NULL)
       return;
 
     /* Don't report a permanent kline as temporary kline */
-    if (!conf->until)
+    if (conf->until == 0)
       return;
 
     sendto_one_numeric(source_p, &me, RPL_STATSKLINE, 'k',
@@ -798,14 +850,13 @@ stats_klines(struct Client *source_p, int parc, char *parv[])
     /* Search for a kline */
     if (MyConnect(source_p))
       conf = find_conf_by_address(source_p->host,
-                                  &source_p->connection->ip, CONF_KLINE,
-                                  source_p->connection->aftype,
+                                  &source_p->ip, CONF_KLINE,
                                   source_p->username, NULL, 0);
     else
-      conf = find_conf_by_address(source_p->host, NULL, CONF_KLINE, 0,
+      conf = find_conf_by_address(source_p->host, NULL, CONF_KLINE,
                                   source_p->username, NULL, 0);
 
-    if (!conf)
+    if (conf == NULL)
       return;
 
     /* Don't report a temporary kline as permanent kline */
@@ -915,7 +966,7 @@ show_ports(struct Client *source_p)
       *p++ = 's';
     *p = '\0';
 
-    if (HasUMode(source_p, UMODE_ADMIN) && !ConfigServerHide.hide_server_ips)
+    if (HasUMode(source_p, UMODE_ADMIN) && ConfigServerHide.hide_server_ips == 0)
       sendto_one_numeric(source_p, &me, RPL_STATSPLINE, 'P', listener->port,
                          listener->name,
                          listener->ref_count, buf,
@@ -940,9 +991,7 @@ static void
 stats_tstats(struct Client *source_p, int parc, char *parv[])
 {
   dlink_node *node;
-  struct ServerStatistics sp;
-
-  memcpy(&sp, &ServerStats, sizeof(sp));
+  struct ServerStatistics sp = ServerStats;
 
   DLINK_FOREACH(node, local_server_list.head)
   {
@@ -950,7 +999,7 @@ stats_tstats(struct Client *source_p, int parc, char *parv[])
 
     sp.is_sbs += target_p->connection->send.bytes;
     sp.is_sbr += target_p->connection->recv.bytes;
-    sp.is_sti += CurrentTime - target_p->connection->firsttime;
+    sp.is_sti += event_base->time.sec_monotonic - target_p->connection->created_monotonic;
     sp.is_sv++;
   }
 
@@ -960,7 +1009,7 @@ stats_tstats(struct Client *source_p, int parc, char *parv[])
 
     sp.is_cbs += target_p->connection->send.bytes;
     sp.is_cbr += target_p->connection->recv.bytes;
-    sp.is_cti += CurrentTime - target_p->connection->firsttime;
+    sp.is_cti += event_base->time.sec_monotonic - target_p->connection->created_monotonic;
     sp.is_cl++;
   }
 
@@ -1006,8 +1055,8 @@ stats_uptime(struct Client *source_p, int parc, char *parv[])
   else
   {
     sendto_one_numeric(source_p, &me, RPL_STATSUPTIME,
-                       time_dissect(CurrentTime - me.connection->since));
-    if (!ConfigServerHide.disable_remote_commands || HasUMode(source_p, UMODE_OPER))
+                       time_dissect(event_base->time.sec_monotonic - me.connection->created_monotonic));
+    if (ConfigServerHide.disable_remote_commands == 0 || HasUMode(source_p, UMODE_OPER))
        sendto_one_numeric(source_p, &me, RPL_STATSCONN, Count.max_loc_con,
                           Count.max_loc, Count.totalrestartcount);
   }
@@ -1039,7 +1088,7 @@ stats_servers(struct Client *source_p, int parc, char *parv[])
                        "v :%s (%s!%s@%s) Idle: %s",
                        target_p->name,
                        (target_p->serv->by[0] ? target_p->serv->by : "Remote."),
-                       "*", "*", time_dissect(CurrentTime - target_p->connection->lasttime));
+                       "*", "*", time_dissect(event_base->time.sec_monotonic - target_p->connection->last_data));
   }
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
@@ -1092,7 +1141,7 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
     sendB += target_p->connection->send.bytes;
     recvB += target_p->connection->recv.bytes;
 
-    /* ":%s 211 %s %s %u %u %ju %u %ju :%u %u %s" */
+    /* ":%s 211 %s %s %u %u %ju %u %ju :%ju %ju %s" */
     sendto_one_numeric(source_p, &me, RPL_STATSLINKINFO,
                client_get_name(target_p, HasUMode(source_p, UMODE_ADMIN) ? SHOW_IP : MASK_IP),
                dbuf_length(&target_p->connection->buf_sendq),
@@ -1100,8 +1149,8 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
                target_p->connection->send.bytes >> 10,
                target_p->connection->recv.messages,
                target_p->connection->recv.bytes >> 10,
-               (unsigned int)(CurrentTime - target_p->connection->firsttime),
-               (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since) : 0,
+               (event_base->time.sec_monotonic - target_p->connection->created_monotonic),
+               (event_base->time.sec_monotonic - target_p->connection->last_data),
                HasUMode(source_p, UMODE_OPER) ? capab_get(target_p) : "TS");
   }
 
@@ -1115,16 +1164,16 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT, "? :Recv total: %7.2f %s",
                      _GMKv(recvB), _GMKs(recvB));
 
-  uptime = (CurrentTime - me.connection->since);
+  uptime = (event_base->time.sec_monotonic - me.connection->created_monotonic);
 
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "? :Server send: %7.2f %s (%4.1f K/s)",
+                     "? :Server send: %7.2f %s (%4.1f KiB/s)",
                      _GMKv((me.connection->send.bytes >> 10)),
                      _GMKs((me.connection->send.bytes >> 10)),
                      (float)((float)((me.connection->send.bytes) >> 10) /
                      (float)uptime));
   sendto_one_numeric(source_p, &me, RPL_STATSDEBUG | SND_EXPLICIT,
-                     "? :Server recv: %7.2f %s (%4.1f K/s)",
+                     "? :Server recv: %7.2f %s (%4.1f KiB/s)",
                      _GMKv((me.connection->recv.bytes >> 10)),
                      _GMKs((me.connection->recv.bytes >> 10)),
                      (float)((float)((me.connection->recv.bytes) >> 10) /
@@ -1143,16 +1192,16 @@ stats_servlinks(struct Client *source_p, int parc, char *parv[])
  *
  */
 static const char *
-parse_stats_args(struct Client *source_p, int parc, char *parv[], int *doall, int *wilds)
+parse_stats_args(struct Client *source_p, int parc, char *parv[], bool *doall, bool *wilds)
 {
   if (parc > 2)
   {
     const char *name = parv[2];
 
-    if (!irccmp(name, ID_or_name(&me, source_p)))
-      *doall = 2;
-    else if (!match(name, ID_or_name(&me, source_p)))
-      *doall = 1;
+    if (irccmp(name, ID_or_name(&me, source_p)) == 0)
+      *doall = true;
+    else if (match(name, ID_or_name(&me, source_p)) == 0)
+      *doall = true;
 
     *wilds = has_wildcards(name);
 
@@ -1163,7 +1212,7 @@ parse_stats_args(struct Client *source_p, int parc, char *parv[], int *doall, in
 }
 
 static void
-stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
+stats_L_list(struct Client *source_p, const char *name, bool doall, bool wilds,
              dlink_list *list, const char statchar)
 {
   dlink_node *node;
@@ -1199,8 +1248,8 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
                        target_p->connection->send.bytes >> 10,
                        target_p->connection->recv.messages,
                        target_p->connection->recv.bytes >> 10,
-                       (unsigned int)(CurrentTime - target_p->connection->firsttime),
-                       (CurrentTime > target_p->connection->since) ? (unsigned int)(CurrentTime - target_p->connection->since) : 0,
+                       (event_base->time.sec_monotonic - target_p->connection->created_monotonic),
+                       (event_base->time.sec_monotonic - target_p->connection->last_data),
                        IsServer(target_p) ? capab_get(target_p) : "-");
   }
 }
@@ -1215,8 +1264,8 @@ stats_L_list(struct Client *source_p, const char *name, int doall, int wilds,
  * side effects -
  */
 static void
-stats_L(struct Client *source_p, const char *name, int doall,
-        int wilds, const char statchar)
+stats_L(struct Client *source_p, const char *name, bool doall,
+        bool wilds, const char statchar)
 {
   stats_L_list(source_p, name, doall, wilds, &unknown_list, statchar);
   stats_L_list(source_p, name, doall, wilds, &local_client_list, statchar);
@@ -1226,8 +1275,8 @@ stats_L(struct Client *source_p, const char *name, int doall,
 static void
 stats_ltrace(struct Client *source_p, int parc, char *parv[])
 {
-  int doall = 0;
-  int wilds = 0;
+  bool doall = false;
+  bool wilds = false;
   const char *name = NULL;
 
   if ((name = parse_stats_args(source_p, parc, parv, &doall, &wilds)))
@@ -1331,16 +1380,16 @@ m_stats(struct Client *source_p, int parc, char *parv[])
   static uintmax_t last_used = 0;
 
   /* Check the user is actually allowed to do /stats, and isn't flooding */
-  if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "STATS");
     return 0;
   }
 
-  last_used = CurrentTime;
+  last_used = event_base->time.sec_monotonic;
 
   /* Is the stats meant for us? */
-  if (!ConfigServerHide.disable_remote_commands)
+  if (ConfigServerHide.disable_remote_commands == 0)
     if (server_hunt(source_p, ":%s STATS %s :%s", 2, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
@@ -1398,7 +1447,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8490 $",
+  .version = "$Revision: 9037 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
