@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svinfo.c
  * \brief Includes required functions for processing the SVINFO command.
- * \version $Id: m_svinfo.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: m_svinfo.c 8976 2019-05-18 18:44:09Z michael $
  */
 
 #include "stdinc.h"
@@ -77,24 +77,24 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
   }
 
   /*
-   * Since we're here, might as well set CurrentTime while we're at it
+   * Since we're here, might as well set event_base->time.sec_real while we're at it
    */
-  set_time();
+  event_time_set();
 
-  intmax_t theirtime = strtoimax(parv[4], NULL, 10);
-  intmax_t deltat = imaxabs(theirtime - CurrentTime);
+  uintmax_t theirtime = strtoumax(parv[4], NULL, 10);
+  intmax_t deltat = imaxabs(theirtime - event_base->time.sec_real);
 
   if (deltat > ConfigGeneral.ts_max_delta)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-         client_get_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         client_get_name(source_p, SHOW_IP), event_base->time.sec_real, theirtime, deltat);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-         client_get_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         client_get_name(source_p, MASK_IP), event_base->time.sec_real, theirtime, deltat);
     ilog(LOG_TYPE_IRCD,
-         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-         client_get_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+         "Link %s dropped, excessive TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+         client_get_name(source_p, SHOW_IP), event_base->time.sec_real, theirtime, deltat);
 
     exit_client(source_p, "Excessive TS delta");
     return 0;
@@ -103,11 +103,11 @@ ms_svinfo(struct Client *source_p, int parc, char *parv[])
   if (deltat > ConfigGeneral.ts_warn_delta)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
-          "Link %s notable TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-          client_get_name(source_p, SHOW_IP), CurrentTime, theirtime, deltat);
+          "Link %s notable TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+          client_get_name(source_p, SHOW_IP), event_base->time.sec_real, theirtime, deltat);
     sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
-          "Link %s notable TS delta (my TS=%ju, their TS=%ji, delta=%ji)",
-          client_get_name(source_p, MASK_IP), CurrentTime, theirtime, deltat);
+          "Link %s notable TS delta (my TS=%ju, their TS=%ju, delta=%ji)",
+          client_get_name(source_p, MASK_IP), event_base->time.sec_real, theirtime, deltat);
   }
 
   return 0;
@@ -139,7 +139,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8436 $",
+  .version = "$Revision: 8976 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
