@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2016-2018 ircd-hybrid development team
+ *  Copyright (c) 2016-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svshost.c
  * \brief Includes required functions for processing the SVSHOST command.
- * \version $Id: m_svshost.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: m_svshost.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -61,7 +61,7 @@ ms_svshost(struct Client *source_p, int parc, char *parv[])
   if (ts && (ts != target_p->tsinfo))
     return 0;
 
-  if (valid_hostname(parv[3]))
+  if (valid_hostname(parv[3]) == true)
     user_set_hostmask(target_p, parv[3]);
 
   sendto_server(source_p, 0, 0, ":%s SVSHOST %s %ju %s",
@@ -96,7 +96,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8436 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
