@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2018 ircd-hybrid development team
+ *  Copyright (c) 2011-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsmode.c
  * \brief Includes required functions for processing the SVSMODE command.
- * \version $Id: m_svsmode.c 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: m_svsmode.c 8996 2019-05-25 20:53:32Z michael $
  */
 
 #include "stdinc.h"
@@ -92,7 +92,7 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
         if (!EmptyString(extarg))
         {
           strlcpy(target_p->account, extarg, sizeof(target_p->account));
-          sendto_common_channels_local(target_p, 1, CAP_ACCOUNT_NOTIFY, 0, ":%s!%s@%s ACCOUNT %s",
+          sendto_common_channels_local(target_p, true, CAP_ACCOUNT_NOTIFY, 0, ":%s!%s@%s ACCOUNT %s",
                                        target_p->name, target_p->username,
                                        target_p->host, target_p->account);
         }
@@ -170,7 +170,7 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
   {
     char modebuf[IRCD_BUFSIZE] = "";
 
-    send_umode(target_p, 1, setmodes, modebuf);
+    send_umode(target_p, true, setmodes, modebuf);
   }
 
   return 0;
@@ -202,7 +202,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8483 $",
+  .version = "$Revision: 8996 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
