@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2018 ircd-hybrid development team
+ *  Copyright (c) 2011-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsnick.c
  * \brief Includes required functions for processing the SVSNICK command.
- * \version $Id: m_svsnick.c 8338 2018-03-03 22:26:59Z michael $
+ * \version $Id: m_svsnick.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 
@@ -64,7 +64,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
   if (!HasFlag(source_p, FLAGS_SERVICE))
     return 0;
 
-  if (!valid_nickname(new_nick, 1))
+  if (valid_nickname(new_nick, true) == false)
     return 0;
 
   if ((target_p = find_person(source_p, parv[1])) == NULL)
@@ -105,7 +105,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
   {
     if (target_p == exists_p)
     {
-      if (!strcmp(target_p->name, new_nick))
+      if (strcmp(target_p->name, new_nick) == 0)
         return 0;
     }
     else if (IsUnknown(exists_p))
@@ -127,14 +127,14 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
     char modebuf[IRCD_BUFSIZE] = "";
 
     DelUMode(target_p, UMODE_REGISTERED);
-    send_umode(target_p, 1, oldmodes, modebuf);
+    send_umode(target_p, true, oldmodes, modebuf);
   }
 
-  sendto_common_channels_local(target_p, 1, 0, 0, ":%s!%s@%s NICK :%s",
+  sendto_common_channels_local(target_p, true, 0, 0, ":%s!%s@%s NICK :%s",
                                target_p->name, target_p->username,
                                target_p->host, new_nick);
 
-  whowas_add_history(target_p, 1);
+  whowas_add_history(target_p, true);
 
   sendto_server(NULL, 0, 0, ":%s NICK %s :%ju",
                 target_p->id, new_nick, target_p->tsinfo);
@@ -175,7 +175,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8338 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
