@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2015-2018 ircd-hybrid development team
+ *  Copyright (c) 2015-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_svstag.c
  * \brief Includes required functions for processing the SVSTAG command.
- * \version $Id: m_svstag.c 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: m_svstag.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -64,7 +64,7 @@ ms_svstag(struct Client *source_p, int parc, char *parv[])
   if (ts && (ts != target_p->tsinfo))
     return 0;
 
-  if (!strncmp(parv[3], "-", 1))
+  if (strncmp(parv[3], "-", 1) == 0)
   {
     /* TBD: possibly allow to remove certain tags by numeric */
     svstag_clear_list(&target_p->svstags);
@@ -112,7 +112,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8483 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
