@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2002-2018 ircd-hybrid development team
+ *  Copyright (c) 2002-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_tburst.c
  * \brief Includes required functions for processing the TBURST command.
- * \version $Id: m_tburst.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: m_tburst.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -83,35 +83,35 @@ ms_tburst(struct Client *source_p, int parc, char *parv[])
    *        The TS of the remote channel is equal to ours AND
    *        the TS of the remote topic is newer than ours
    */
-  int accept_remote = 0;
+  bool accept_remote = false;
   if (HasFlag(source_p, FLAGS_SERVICE))
-    accept_remote = 1;
+    accept_remote = true;
   else if (remote_channel_ts < chptr->creationtime)
-    accept_remote = 1;
+    accept_remote = true;
   else if (remote_channel_ts == chptr->creationtime)
     if (remote_topic_ts > chptr->topic_time)
-      accept_remote = 1;
+      accept_remote = true;
 
-  if (accept_remote)
+  if (accept_remote == true)
   {
-    int topic_differs = strncmp(chptr->topic, topic, sizeof(chptr->topic) - 1);
-    int hidden_server = (ConfigServerHide.hide_servers || IsHidden(source_p));
+    bool topic_differs = strncmp(chptr->topic, topic, sizeof(chptr->topic) - 1);
+    bool hidden_server = (ConfigServerHide.hide_servers || IsHidden(source_p));
 
-    channel_set_topic(chptr, topic, setby, remote_topic_ts, 0);
+    channel_set_topic(chptr, topic, setby, remote_topic_ts, false);
 
     sendto_server(source_p, CAPAB_TBURST, 0, ":%s TBURST %s %s %s %s :%s",
                   source_p->id, parv[1], parv[2], parv[3], setby, topic);
 
-    if (topic_differs)
+    if (topic_differs == true)
     {
-      if (!IsClient(source_p))
-        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :%s",
-                             hidden_server ? me.name : source_p->name,
-                             chptr->name, chptr->topic);
-      else
+      if (IsClient(source_p))
         sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s!%s@%s TOPIC %s :%s",
                              source_p->name, source_p->username, source_p->host,
                              chptr->name, chptr->topic);
+      else
+        sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s TOPIC %s :%s",
+                             hidden_server ? me.name : source_p->name,
+                             chptr->name, chptr->topic);
     }
   }
 
@@ -146,7 +146,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8436 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
