@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_topic.c
  * \brief Includes required functions for processing the TOPIC command.
- * \version $Id: m_topic.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: m_topic.c 8927 2019-04-22 11:08:47Z michael $
  */
 
 #include "stdinc.h"
@@ -63,9 +63,6 @@ m_topic(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!IsFloodDone(source_p))
-    flood_endgrace(source_p);
-
   if ((chptr = hash_find_channel(parv[1])) == NULL)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHCHANNEL, parv[1]);
@@ -90,7 +87,7 @@ m_topic(struct Client *source_p, int parc, char *parv[])
 
       snprintf(topic_info, sizeof(topic_info), "%s!%s@%s", source_p->name,
                source_p->username, source_p->host);
-      channel_set_topic(chptr, parv[2], topic_info, CurrentTime, 1);
+      channel_set_topic(chptr, parv[2], topic_info, event_base->time.sec_real, true);
 
       sendto_server(source_p, 0, 0, ":%s TOPIC %s :%s",
                     source_p->id, chptr->name,
@@ -160,10 +157,12 @@ ms_topic(struct Client *source_p, int parc, char *parv[])
   if (IsClient(source_p))
     snprintf(topic_info, sizeof(topic_info), "%s!%s@%s", source_p->name,
              source_p->username, source_p->host);
+  else if (IsHidden(source_p) || ConfigServerHide.hide_servers)
+    strlcpy(topic_info, me.name, sizeof(topic_info));
   else
     strlcpy(topic_info, source_p->name, sizeof(topic_info));
 
-  channel_set_topic(chptr, parv[2], topic_info, CurrentTime, 0);
+  channel_set_topic(chptr, parv[2], topic_info, event_base->time.sec_real, false);
 
   sendto_server(source_p, 0, 0, ":%s TOPIC %s :%s",
                 source_p->id, chptr->name,
@@ -189,6 +188,7 @@ static struct Message topic_msgtab =
   .cmd = "TOPIC",
   .args_min = 2,
   .args_max = MAXPARA,
+  .flags = MFLG_ENDGRACE,
   .handlers[UNREGISTERED_HANDLER] = m_unregistered,
   .handlers[CLIENT_HANDLER] = m_topic,
   .handlers[SERVER_HANDLER] = ms_topic,
@@ -210,7 +210,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8430 $",
+  .version = "$Revision: 8927 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
