@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_trace.c
  * \brief Includes required functions for processing the TRACE command.
- * \version $Id: m_trace.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_trace.c 8918 2019-04-22 09:51:16Z michael $
  */
 
 #include "stdinc.h"
@@ -37,6 +37,7 @@
 #include "modules.h"
 #include "conf.h"
 #include "conf_class.h"
+#include "patchlevel.h"
 
 
 static void
@@ -83,18 +84,18 @@ report_this_status(struct Client *source_p, const struct Client *target_p)
     case STAT_UNKNOWN:
       sendto_one_numeric(source_p, &me, RPL_TRACEUNKNOWN, class_name,
                          name, target_p->sockhost,
-                         CurrentTime - target_p->connection->firsttime);
+                         event_base->time.sec_monotonic - target_p->connection->created_monotonic);
       break;
     case STAT_CLIENT:
       if (HasUMode(target_p, UMODE_OPER))
         sendto_one_numeric(source_p, &me, RPL_TRACEOPERATOR, class_name, name,
                            target_p->sockhost,
-                           CurrentTime - target_p->connection->lasttime,
+                           event_base->time.sec_monotonic - target_p->connection->last_data,
                            client_get_idle_time(source_p, target_p));
       else
         sendto_one_numeric(source_p, &me, RPL_TRACEUSER, class_name, name,
                            target_p->sockhost,
-                           CurrentTime - target_p->connection->lasttime,
+                           event_base->time.sec_monotonic - target_p->connection->last_data,
                            client_get_idle_time(source_p, target_p));
       break;
     case STAT_SERVER:
@@ -110,7 +111,7 @@ report_this_status(struct Client *source_p, const struct Client *target_p)
       sendto_one_numeric(source_p, &me, RPL_TRACESERVER, class_name, servers,
                          clients, name, *(target_p->serv->by) ?
                          target_p->serv->by : "*", "*",
-                         me.name, CurrentTime - target_p->connection->lasttime);
+                         me.name, event_base->time.sec_monotonic - target_p->connection->last_data);
       break;
     }
 
@@ -123,7 +124,7 @@ report_this_status(struct Client *source_p, const struct Client *target_p)
 static void
 do_trace(struct Client *source_p, const char *name)
 {
-  int doall = 0;
+  bool doall = false;
   const dlink_node *node;
   const dlink_list *tab[] = { &local_client_list,
                               &local_server_list, &unknown_list, NULL };
@@ -136,11 +137,11 @@ do_trace(struct Client *source_p, const char *name)
                        source_p->host, source_p->servptr->name);
 
   if (EmptyString(name))
-    doall = 1;
-  else if (!match(name, me.name))
-    doall = 1;
-  else if (!MyClient(source_p) && !strcmp(name, me.id))
-    doall = 1;
+    doall = true;
+  else if (match(name, me.name) == 0)
+    doall = true;
+  else if (!MyClient(source_p) && strcmp(name, me.id) == 0)
+    doall = true;
 
   for (const dlink_list **list = tab; *list; ++list)
   {
@@ -148,12 +149,12 @@ do_trace(struct Client *source_p, const char *name)
     {
       const struct Client *target_p = node->data;
 
-      if (doall || match(name, target_p->name) == 0)
+      if (doall == true || match(name, target_p->name) == 0)
         report_this_status(source_p, target_p);
     }
   }
 
-  if (doall)
+  if (doall == true)
   {
     DLINK_FOREACH(node, class_get_list()->head)
     {
@@ -208,7 +209,7 @@ mo_trace(struct Client *source_p, int parc, char *parv[])
   {
     case HUNTED_PASS:
       sendto_one_numeric(source_p, &me, RPL_TRACELINK,
-                         ircd_version, hunt->target_p->name, hunt->target_p->from->name);
+                         PATCHLEVEL, hunt->target_p->name, hunt->target_p->from->name);
       break;
     case HUNTED_ISME:
       do_trace(source_p, parv[1]);
@@ -245,7 +246,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8918 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
