@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unkline.c
  * \brief Includes required functions for processing the UNKLINE command.
- * \version $Id: m_unkline.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_unkline.c 9025 2019-05-29 16:45:09Z michael $
  */
 
 #include "stdinc.h"
@@ -48,54 +48,44 @@
  * Output: returns YES on success, NO if no tkline removed.
  * Side effects: Any matching tklines are removed.
  */
-static int
-kline_remove(const char *user, const char *host)
+static void
+kline_remove(struct Client *source_p, const struct aline_ctx *aline)
 {
   struct irc_ssaddr iphost, *piphost;
   struct MaskItem *conf;
-  int t = 0;
-  int aftype = 0;
-
-  if ((t = parse_netmask(host, &iphost, NULL)) != HM_HOST)
-  {
-    if (t == HM_IPV6)
-      aftype = AF_INET6;
-    else
-      aftype = AF_INET;
 
+  if (parse_netmask(aline->host, &iphost, NULL) != HM_HOST)
     piphost = &iphost;
-  }
   else
     piphost = NULL;
 
-  if ((conf = find_conf_by_address(host, piphost, CONF_KLINE, aftype, user, NULL, 0)))
-  {
-    if (IsConfDatabase(conf))
-    {
-      delete_one_address_conf(host, conf);
-      return 1;
-    }
-  }
-
-  return 0;
-}
-
-static void
-kline_remove_and_notify(struct Client *source_p, const char *user, const char *host)
-{
-  if (kline_remove(user, host))
+  if ((conf = find_conf_by_address(aline->host, piphost, CONF_KLINE, aline->user, NULL, 0)) == NULL)
   {
     if (IsClient(source_p))
-      sendto_one_notice(source_p, &me, ":K-Line for [%s@%s] is removed", user, host);
+      sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found", aline->user, aline->host);
 
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has removed the K-Line for: [%s@%s]",
-                         get_oper_name(source_p), user, host);
-    ilog(LOG_TYPE_KLINE, "%s removed K-Line for [%s@%s]",
-         get_oper_name(source_p), user, host);
+    return;
   }
-  else if (IsClient(source_p))
-    sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found", user, host);
+
+  if (!IsConfDatabase(conf))
+  {
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":The K-Line for [%s@%s] is in the configuration file and must be removed by hand",
+                        conf->user, conf->host);
+    return;
+  }
+
+  if (IsClient(source_p))
+    sendto_one_notice(source_p, &me, ":K-Line for [%s@%s] is removed",
+                      conf->user, conf->host);
+
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                       "%s has removed the K-Line for: [%s@%s]",
+                       get_oper_name(source_p), conf->user, conf->host);
+  ilog(LOG_TYPE_KLINE, "%s removed K-Line for [%s@%s]",
+       get_oper_name(source_p), conf->user, conf->host);
+
+  delete_one_address_conf(aline->host, conf);
 }
 
 /*! \brief UNKLINE command handler
@@ -114,8 +104,7 @@ kline_remove_and_notify(struct Client *source_p, const char *user, const char *h
 static int
 mo_unkline(struct Client *source_p, int parc, char *parv[])
 {
-  char *target_server = NULL;
-  char *user, *host;
+  struct aline_ctx aline = { .add = false, .simple_mask = false };
 
   if (!HasOFlag(source_p, OPER_FLAG_UNKLINE))
   {
@@ -129,25 +118,23 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!parse_aline("UNKLINE", source_p, parc, parv, &user,
-                   &host, NULL, &target_server, NULL))
+  if (parse_aline("UNKLINE", source_p, parc, parv, &aline) == false)
     return 0;
 
-  if (target_server)
+  if (aline.server)
   {
-     sendto_match_servs(source_p, target_server, CAPAB_UNKLN,
-                        "UNKLINE %s %s %s",
-                        target_server, user, host);
+     sendto_match_servs(source_p, aline.server, CAPAB_UNKLN, "UNKLINE %s %s %s",
+                        aline.server, aline.user, aline.host);
 
     /* Allow ON to apply local unkline as well if it matches */
-    if (match(target_server, me.name))
+    if (match(aline.server, me.name))
       return 0;
   }
   else
     cluster_distribute(source_p, "UNKLINE", CAPAB_UNKLN, CLUSTER_UNKLINE,
-                       "%s %s", user, host);
+                       "%s %s", aline.user, aline.host);
 
-  kline_remove_and_notify(source_p, user, host);
+  kline_remove(source_p, &aline);
   return 0;
 }
 
@@ -167,24 +154,28 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
 static int
 ms_unkline(struct Client *source_p, int parc, char *parv[])
 {
-  const char *user, *host;
+  struct aline_ctx aline =
+  {
+    .add = false,
+    .simple_mask = false,
+    .user = parv[2],
+    .host = parv[3],
+    .server = parv[1]
+  };
 
-  if (parc != 4 || EmptyString(parv[3]))
+  if (parc != 4 || EmptyString(parv[parc - 1]))
     return 0;
 
-  sendto_match_servs(source_p, parv[1], CAPAB_UNKLN, "UNKLINE %s %s %s",
-                     parv[1], parv[2], parv[3]);
+  sendto_match_servs(source_p, aline.server, CAPAB_UNKLN, "UNKLINE %s %s %s",
+                     aline.server, aline.user, aline.host);
 
-  user = parv[2];
-  host = parv[3];
-
-  if (match(parv[1], me.name))
+  if (match(aline.server, me.name))
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
       shared_find(SHARED_UNKLINE, source_p->servptr->name,
                   source_p->username, source_p->host))
-    kline_remove_and_notify(source_p, user, host);
+    kline_remove(source_p, &aline);
 
   return 0;
 }
@@ -217,7 +208,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 9025 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
