@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2003-2018 ircd-hybrid development team
+ *  Copyright (c) 2003-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unxline.c
  * \brief Includes required functions for processing the UNXLINE command.
- * \version $Id: m_unxline.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_unxline.c 8985 2019-05-22 16:47:20Z michael $
  */
 
 #include "stdinc.h"
@@ -48,39 +48,37 @@
  * Output:      returns YES on success, NO if no tkline removed.
  * Side effects: Any matching tklines are removed.
  */
-static int
-xline_remove(const char *mask)
+static void
+xline_remove(struct Client *source_p, const struct aline_ctx *aline)
 {
   struct GecosItem *gecos;
 
-  if ((gecos = gecos_find(mask, irccmp)))
-  {
-    if (gecos->in_database)
-    {
-      gecos_delete(gecos);
-      return 1;
-    }
-  }
-
-  return 0;
-}
-
-static void
-xline_remove_and_notify(struct Client *source_p, const char *gecos)
-{
-  if (xline_remove(gecos))
+  if ((gecos = gecos_find(aline->mask, irccmp)) == NULL)
   {
     if (IsClient(source_p))
-      sendto_one_notice(source_p, &me, ":X-Line for [%s] is removed", gecos);
+      sendto_one_notice(source_p, &me, ":No X-Line for %s", aline->mask);
 
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "%s has removed the X-Line for: [%s]",
-                         get_oper_name(source_p), gecos);
-    ilog(LOG_TYPE_XLINE, "%s removed X-Line for [%s]",
-         get_oper_name(source_p), gecos);
+    return;
   }
-  else if (IsClient(source_p))
-    sendto_one_notice(source_p, &me, ":No X-Line for %s", gecos);
+
+  if (gecos->in_database == false)
+  {
+    if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":The X-Line for %s is in the configuration file and must be removed by hand",
+                        gecos->mask);
+    return;
+  }
+
+  if (IsClient(source_p))
+    sendto_one_notice(source_p, &me, ":X-Line for [%s] is removed", gecos->mask);
+
+  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+                       "%s has removed the X-Line for: [%s]",
+                       get_oper_name(source_p), gecos->mask);
+  ilog(LOG_TYPE_RESV, "%s removed X-Line for [%s]",
+       get_oper_name(source_p), gecos->mask);
+
+  gecos_delete(gecos, false);
 }
 
 /*! \brief UNXLINE command handler
@@ -99,8 +97,7 @@ xline_remove_and_notify(struct Client *source_p, const char *gecos)
 static int
 mo_unxline(struct Client *source_p, int parc, char *parv[])
 {
-  char *gecos = NULL;
-  char *target_server = NULL;
+  struct aline_ctx aline = { .add = false, .simple_mask = true };
 
   if (!HasOFlag(source_p, OPER_FLAG_UNXLINE))
   {
@@ -108,23 +105,22 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!parse_aline("UNXLINE", source_p, parc, parv, &gecos,
-                   NULL, NULL, &target_server, NULL))
+  if (parse_aline("UNXLINE", source_p, parc, parv, &aline) == false)
     return 0;
 
-  if (target_server)
+  if (aline.server)
   {
-    sendto_match_servs(source_p, target_server, CAPAB_CLUSTER,
-                       "UNXLINE %s %s", target_server, gecos);
+    sendto_match_servs(source_p, aline.server, CAPAB_CLUSTER, "UNXLINE %s %s",
+                       aline.server, aline.mask);
 
     /* Allow ON to apply local unxline as well if it matches */
-    if (match(target_server, me.name))
+    if (match(aline.server, me.name))
       return 0;
   }
   else
-    cluster_distribute(source_p, "UNXLINE", CAPAB_CLUSTER, CLUSTER_UNXLINE, "%s", gecos);
+    cluster_distribute(source_p, "UNXLINE", CAPAB_CLUSTER, CLUSTER_UNXLINE, "%s", aline.host);
 
-  xline_remove_and_notify(source_p, gecos);
+  xline_remove(source_p, &aline);
   return 0;
 }
 
@@ -143,19 +139,27 @@ mo_unxline(struct Client *source_p, int parc, char *parv[])
 static int
 ms_unxline(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc != 3 || EmptyString(parv[2]))
+  struct aline_ctx aline =
+  {
+    .add = false,
+    .simple_mask = true,
+    .mask = parv[2],
+    .server = parv[1]
+  };
+
+  if (parc != 3 || EmptyString(parv[parc - 1]))
     return 0;
 
-  sendto_match_servs(source_p, parv[1], CAPAB_CLUSTER, "UNXLINE %s %s",
-                     parv[1], parv[2]);
+  sendto_match_servs(source_p, aline.server, CAPAB_CLUSTER, "UNXLINE %s %s",
+                     aline.server, aline.mask);
 
-  if (match(parv[1], me.name))
+  if (match(aline.server, me.name))
     return 0;
 
   if (HasFlag(source_p, FLAGS_SERVICE) ||
       shared_find(SHARED_UNXLINE, source_p->servptr->name,
                   source_p->username, source_p->host))
-    xline_remove_and_notify(source_p, parv[2]);
+    xline_remove(source_p, &aline);
   return 0;
 }
 
@@ -185,7 +189,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8985 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
