@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_version.c
  * \brief Includes required functions for processing the VERSION command.
- * \version $Id: m_version.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_version.c 8902 2019-04-21 20:41:04Z michael $
  */
 
 #include "stdinc.h"
@@ -35,6 +35,8 @@
 #include "parse.h"
 #include "modules.h"
 #include "isupport.h"
+#include "patchlevel.h"
+#include "serno.h"
 
 
 /* Option string. */
@@ -68,19 +70,19 @@ m_version(struct Client *source_p, int parc, char *parv[])
 {
   static uintmax_t last_used = 0;
 
-  if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
+  if ((last_used + ConfigGeneral.pace_wait_simple) > event_base->time.sec_monotonic)
   {
     sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "VERSION");
     return 0;
   }
 
-  last_used = CurrentTime;
+  last_used = event_base->time.sec_monotonic;
 
-  if (!ConfigServerHide.disable_remote_commands)
+  if (ConfigServerHide.disable_remote_commands == 0)
     if (server_hunt(source_p, ":%s VERSION :%s", 1, parc, parv)->ret != HUNTED_ISME)
       return 0;
 
-  sendto_one_numeric(source_p, &me, RPL_VERSION, ircd_version, serno,
+  sendto_one_numeric(source_p, &me, RPL_VERSION, PATCHLEVEL, SERIALNUM,
                      me.name, serveropts);
   isupport_show(source_p);
   return 0;
@@ -103,7 +105,7 @@ ms_version(struct Client *source_p, int parc, char *parv[])
   if (server_hunt(source_p, ":%s VERSION :%s", 1, parc, parv)->ret != HUNTED_ISME)
     return 0;
 
-  sendto_one_numeric(source_p, &me, RPL_VERSION, ircd_version, serno,
+  sendto_one_numeric(source_p, &me, RPL_VERSION, PATCHLEVEL, SERIALNUM,
                      me.name, serveropts);
   isupport_show(source_p);
   return 0;
@@ -134,7 +136,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8902 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
