@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1997 Jukka Santala (Donwulff)
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_watch.c
  * \brief Includes required functions for processing the WATCH command.
- * \version $Id: m_watch.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: m_watch.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -84,8 +84,8 @@ m_watch(struct Client *source_p, int parc, char *parv[])
   if (parc < 2)
     parv[1] = def;
 
-  for (char *s = strtok_r(parv[1], ", ", &p); s;
-             s = strtok_r(NULL,    ", ", &p))
+  for (const char *s = strtok_r(parv[1], ", ", &p); s;
+                   s = strtok_r(NULL,    ", ", &p))
   {
     char *user;
     if ((user = strchr(s, '!')))
@@ -105,7 +105,7 @@ m_watch(struct Client *source_p, int parc, char *parv[])
           continue;
         }
 
-        if (valid_nickname(s + 1, 1))
+        if (valid_nickname(s + 1, true) == true)
           watch_add_to_hash_table(s + 1, source_p);
       }
 
@@ -264,7 +264,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8436 $",
+  .version = "$Revision: 8751 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
