@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2012-2018 ircd-hybrid development team
+ *  Copyright (c) 2012-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_webirc.c
  * \brief Includes required functions for processing the WEBIRC command.
- * \version $Id: m_webirc.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: m_webirc.c 8876 2019-02-16 22:42:06Z michael $
  */
 
 #include "stdinc.h"
@@ -70,8 +70,7 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
 
   conf = find_address_conf(source_p->host,
                            HasFlag(source_p, FLAGS_GOTID) ? source_p->username : "webirc",
-                           &source_p->connection->ip,
-                           source_p->connection->aftype, pass);
+                           &source_p->ip, pass);
   if (!conf || !IsConfClient(conf))
     return 0;
 
@@ -87,7 +86,7 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!match_conf_password(pass, conf))
+  if (match_conf_password(pass, conf) == false)
   {
     sendto_one_notice(source_p, &me, ":WEBIRC password incorrect");
     return 0;
@@ -107,10 +106,8 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
 
   assert(res);
 
-  memcpy(&source_p->connection->ip, res->ai_addr, res->ai_addrlen);
-  source_p->connection->ip.ss_len = res->ai_addrlen;
-  source_p->connection->ip.ss.ss_family = res->ai_family;
-  source_p->connection->aftype = res->ai_family;
+  memcpy(&source_p->ip, res->ai_addr, res->ai_addrlen);
+  source_p->ip.ss_len = res->ai_addrlen;
   freeaddrinfo(res);
 
   strlcpy(source_p->sockhost, addr, sizeof(source_p->sockhost));
@@ -125,8 +122,7 @@ mr_webirc(struct Client *source_p, int parc, char *parv[])
   strlcpy(source_p->realhost, host, sizeof(source_p->realhost));
 
   /* Check dlines now, k-lines will be checked on registration */
-  if ((conf = find_dline_conf(&source_p->connection->ip,
-                               source_p->connection->aftype)))
+  if ((conf = find_dline_conf(&source_p->ip)))
   {
     if (conf->type == CONF_DLINE)
     {
@@ -167,7 +163,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8280 $",
+  .version = "$Revision: 8876 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
