@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_who.c
  * \brief Includes required functions for processing the WHO command.
- * \version $Id: m_who.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: m_who.c 8902 2019-04-21 20:41:04Z michael $
  */
 
 #include "stdinc.h"
@@ -86,36 +86,36 @@ do_who(struct Client *source_p, const struct Client *target_p,
  * \param source_p Pointer to client requesting who
  * \param target_p Pointer to client to do who on
  * \param mask Mask to match
- * \return 1 if mask matches, 0 otherwise
+ * \return true if mask matches, false otherwise
  */
-static int
+static bool
 who_matches(struct Client *source_p, struct Client *target_p, const char *mask)
 {
-  if (!mask)
-    return 1;
+  if (mask == NULL)
+    return true;
 
-  if (!match(mask, target_p->name))
-    return 1;
+  if (match(mask, target_p->name) == 0)
+    return true;
 
-  if (!match(mask, target_p->username))
-    return 1;
+  if (match(mask, target_p->username) == 0)
+    return true;
 
-  if (!match(mask, target_p->host))
-    return 1;
+  if (match(mask, target_p->host) == 0)
+    return true;
 
-  if (!match(mask, target_p->info))
-    return 1;
+  if (match(mask, target_p->info) == 0)
+    return true;
 
   if (HasUMode(source_p, UMODE_OPER))
-    if (!match(mask, target_p->sockhost))
-      return 1;
+    if (match(mask, target_p->sockhost) == 0)
+      return true;
 
   if (HasUMode(source_p, UMODE_OPER) ||
-      (!ConfigServerHide.hide_servers && !IsHidden(target_p->servptr)))
-    if (!match(mask, target_p->servptr->name))
-      return 1;
+      (ConfigServerHide.hide_servers == 0 && !IsHidden(target_p->servptr)))
+    if (match(mask, target_p->servptr->name) == 0)
+      return true;
 
-  return 0;
+  return false;
 }
 
 /* who_common_channel
@@ -131,7 +131,7 @@ who_matches(struct Client *source_p, struct Client *target_p, const char *mask)
  */
 static void
 who_common_channel(struct Client *source_p, struct Channel *chptr, const char *mask,
-                   int server_oper, unsigned int *maxmatches)
+                   bool server_oper, unsigned int *maxmatches)
 {
   dlink_node *node;
 
@@ -142,14 +142,14 @@ who_common_channel(struct Client *source_p, struct Channel *chptr, const char *m
     if (!HasUMode(target_p, UMODE_INVISIBLE) || HasFlag(target_p, FLAGS_MARK))
       continue;
 
-    if (server_oper)
+    if (server_oper == true)
       if (!HasUMode(target_p, UMODE_OPER) ||
           (HasUMode(target_p, UMODE_HIDDEN) && !HasUMode(source_p, UMODE_OPER)))
         continue;
 
     AddFlag(target_p, FLAGS_MARK);
 
-    if (who_matches(source_p, target_p, mask))
+    if (who_matches(source_p, target_p, mask) == true)
     {
       do_who(source_p, target_p, NULL, "");
 
@@ -175,7 +175,7 @@ who_common_channel(struct Client *source_p, struct Channel *chptr, const char *m
  *		  this is slightly expensive on EFnet ...
  */
 static void
-who_global(struct Client *source_p, const char *mask, int server_oper)
+who_global(struct Client *source_p, const char *mask, bool server_oper)
 {
   dlink_node *node;
   unsigned int maxmatches = WHO_MAX_REPLIES;
@@ -183,13 +183,13 @@ who_global(struct Client *source_p, const char *mask, int server_oper)
 
   if (!HasUMode(source_p, UMODE_OPER))
   {
-    if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
+    if ((last_used + ConfigGeneral.pace_wait) > event_base->time.sec_monotonic)
     {
       sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "WHO");
       return;
     }
 
-    last_used = CurrentTime;
+    last_used = event_base->time.sec_monotonic;
   }
 
   /* First, list all matching invisible clients on common channels */
@@ -212,12 +212,12 @@ who_global(struct Client *source_p, const char *mask, int server_oper)
       continue;
     }
 
-    if (server_oper)
+    if (server_oper == true)
       if (!HasUMode(target_p, UMODE_OPER) ||
           (HasUMode(target_p, UMODE_HIDDEN) && !HasUMode(source_p, UMODE_OPER)))
         continue;
 
-    if (who_matches(source_p, target_p, mask))
+    if (who_matches(source_p, target_p, mask) == true)
     {
       do_who(source_p, target_p, NULL, "");
 
@@ -246,7 +246,7 @@ who_global(struct Client *source_p, const char *mask, int server_oper)
  */
 static void
 do_who_on_channel(struct Client *source_p, struct Channel *chptr,
-                  int is_member, int server_oper)
+                  bool is_member, bool server_oper)
 {
   dlink_node *node;
 
@@ -255,9 +255,9 @@ do_who_on_channel(struct Client *source_p, struct Channel *chptr,
     struct Membership *member = node->data;
     struct Client *target_p = member->client_p;
 
-    if (is_member || !HasUMode(target_p, UMODE_INVISIBLE))
+    if (is_member == true || !HasUMode(target_p, UMODE_INVISIBLE))
     {
-      if (server_oper)
+      if (server_oper == true)
         if (!HasUMode(target_p, UMODE_OPER) ||
             (HasUMode(target_p, UMODE_HIDDEN) && !HasUMode(source_p, UMODE_OPER)))
           continue;
@@ -285,7 +285,7 @@ m_who(struct Client *source_p, int parc, char *parv[])
   struct Client *target_p = NULL;
   struct Channel *chptr = NULL;
   char *mask = parv[1];
-  const int server_oper = parc > 2 && *parv[2] == 'o';  /* Show OPERS only */
+  const bool server_oper = parc > 2 && *parv[2] == 'o';  /* Show OPERS only */
 
   /* See if mask is there, collapse it or return if not there */
   if (EmptyString(mask))
@@ -305,9 +305,9 @@ m_who(struct Client *source_p, int parc, char *parv[])
     if ((chptr = hash_find_channel(mask)))
     {
       if (HasUMode(source_p, UMODE_ADMIN) || IsMember(source_p, chptr))
-        do_who_on_channel(source_p, chptr, 1, server_oper);
+        do_who_on_channel(source_p, chptr, true, server_oper);
       else if (!SecretChannel(chptr))
-        do_who_on_channel(source_p, chptr, 0, server_oper);
+        do_who_on_channel(source_p, chptr, false, server_oper);
     }
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFWHO, mask);
@@ -316,7 +316,7 @@ m_who(struct Client *source_p, int parc, char *parv[])
 
   /* '/who nick' */
   if ((target_p = find_person(source_p, mask)) &&
-      (!server_oper || HasUMode(target_p, UMODE_OPER)))
+      (server_oper == false || HasUMode(target_p, UMODE_OPER)))
   {
     DLINK_FOREACH(node, target_p->channel.head)
     {
@@ -336,12 +336,12 @@ m_who(struct Client *source_p, int parc, char *parv[])
   }
 
   /* '/who *' */
-  if (!strcmp(mask, "*"))
+  if (strcmp(mask, "*") == 0)
   {
     if ((node = source_p->channel.head))
     {
       chptr = ((struct Membership *)node->data)->chptr;
-      do_who_on_channel(source_p, chptr, 1, server_oper);
+      do_who_on_channel(source_p, chptr, true, server_oper);
     }
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFWHO, "*");
@@ -349,7 +349,7 @@ m_who(struct Client *source_p, int parc, char *parv[])
   }
 
   /* '/who 0' */
-  if (!strcmp(mask, "0"))
+  if (strcmp(mask, "0") == 0)
     who_global(source_p, NULL, server_oper);
   else
     who_global(source_p, mask, server_oper);
@@ -384,7 +384,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8436 $",
+  .version = "$Revision: 8902 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
