@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whois.c
  * \brief Includes required functions for processing the WHOIS command.
- * \version $Id: m_whois.c 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: m_whois.c 8918 2019-04-22 09:51:16Z michael $
  */
 
 #include "stdinc.h"
@@ -101,7 +101,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
         t = buf + mlen;
       }
 
-      tlen = sprintf(t, "%s%s%s ", show == 2 ? "~" : "", get_member_status(member, 1),
+      tlen = sprintf(t, "%s%s%s ", show == 2 ? "~" : "", get_member_status(member, true),
                      member->chptr->name);
       t += tlen;
       cur_len += tlen;
@@ -137,7 +137,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
 
   if (HasUMode(target_p, UMODE_CALLERID | UMODE_SOFTCALLERID))
   {
-    const int callerid = !!HasUMode(target_p, UMODE_CALLERID);
+    bool callerid = HasUMode(target_p, UMODE_CALLERID) != 0;
 
     sendto_one_numeric(source_p, &me, RPL_TARGUMODEG, target_p->name,
                        callerid ? "+g" : "+G",
@@ -152,7 +152,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
       if (target_p->svstags.head)
         svstag = target_p->svstags.head->data;
 
-      if (!svstag || svstag->numeric != RPL_WHOISOPERATOR)
+      if (svstag == NULL || svstag->numeric != RPL_WHOISOPERATOR)
       {
         const char *text;
         if (HasFlag(target_p, FLAGS_SERVICE))
@@ -205,7 +205,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
     sendto_one_numeric(source_p, &me, RPL_WHOISSECURE, target_p->name);
 
   if (!EmptyString(target_p->certfp))
-    if (HasUMode(source_p, UMODE_OPER) || target_p == source_p)
+    if (HasUMode(source_p, UMODE_OPER) || source_p == target_p)
       sendto_one_numeric(source_p, &me, RPL_WHOISCERTFP, target_p->name, target_p->certfp);
 
   if (MyConnect(target_p))
@@ -213,7 +213,7 @@ whois_person(struct Client *source_p, struct Client *target_p)
         source_p == target_p)
       sendto_one_numeric(source_p, &me, RPL_WHOISIDLE, target_p->name,
                          client_get_idle_time(source_p, target_p),
-                         target_p->connection->firsttime);
+                         target_p->connection->created_real);
 
   if (HasUMode(target_p, UMODE_SPY) && source_p != target_p)
     sendto_one_notice(target_p, &me, ":*** Notice -- %s (%s@%s) [%s] is doing a /whois on you",
@@ -267,13 +267,13 @@ m_whois(struct Client *source_p, int parc, char *parv[])
   if (parc > 2 && !EmptyString(parv[2]))
   {
     /* seeing as this is going across servers, we should limit it */
-    if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
+    if ((last_used + ConfigGeneral.pace_wait_simple) > event_base->time.sec_monotonic)
     {
       sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "WHOIS");
       return 0;
     }
 
-    last_used = CurrentTime;
+    last_used = event_base->time.sec_monotonic;
 
     /*
      * if we have serverhide enabled, they can either ask the clients
@@ -351,7 +351,7 @@ module_exit(void)
 
 struct module module_entry =
 {
-  .version = "$Revision: 8483 $",
+  .version = "$Revision: 8918 $",
   .modinit = module_init,
   .modexit = module_exit,
 };
