@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file auth.c
  * \brief Implementation of DNS and ident lookups.
- * \version $Id: auth.c 8469 2018-04-03 12:05:14Z michael $
+ * \version $Id: auth.c 8940 2019-04-27 23:45:33Z michael $
  */
 
 /*
@@ -51,6 +51,7 @@
 #include "log.h"
 #include "send.h"
 #include "memory.h"
+#include "misc.h"
 
 
 enum
@@ -81,7 +82,6 @@ static const char *const HeaderMessages[] =
 
 #define auth_sendheader(c, i) sendto_one_notice((c), &me, "%s", HeaderMessages[(i)])
 
-static dlink_list auth_list;
 
 
 /*! \brief Allocate a new auth request.
@@ -95,21 +95,17 @@ auth_make(struct Client *client)
 
   auth->client = client;
   auth->client->connection->auth = auth;
-  auth->timeout = CurrentTime + CONNECTTIMEOUT;
 
   return auth;
 }
 
-/*! \brief Unlink auth request from auth_list and free memory
+/*! \brief Free memory
  * \param auth The allocated auth request to cleanup.
  */
 static void
 auth_free(struct AuthRequest *auth)
 {
-  assert(dlinkFind(&auth_list, auth));
-  dlinkDelete(&auth->node, &auth_list);
-  assert(dlinkFind(&auth_list, auth) == NULL);
-
+  auth->client = NULL;
   xfree(auth);
 }
 
@@ -122,7 +118,10 @@ auth_release_client(struct AuthRequest *auth)
 {
   struct Client *client = auth->client;
 
-  if (IsDoingAuth(auth) || IsDNSPending(auth))
+  assert(client);
+  assert(client->connection);
+
+  if (auth->ident_pending == true || auth->dns_pending == true)
     return;
 
   auth_free(auth);
@@ -133,12 +132,13 @@ auth_release_client(struct AuthRequest *auth)
    * us. This is what read_packet() does.
    *     -- adrian
    */
-  client->connection->allow_read = MAX_FLOOD;
-  comm_setflush(client->connection->fd, 1000, flood_recalc, client);
+  comm_setflush(client->connection->fd, 1, flood_recalc, client);
+
+  client->connection->last_ping = event_base->time.sec_monotonic;
+  client->connection->last_data = event_base->time.sec_monotonic;
+  client->connection->created_real = event_base->time.sec_real;
+  client->connection->created_monotonic = event_base->time.sec_monotonic;
 
-  client->connection->since     = CurrentTime;
-  client->connection->lasttime  = CurrentTime;
-  client->connection->firsttime = CurrentTime;
   AddFlag(client, FLAGS_FINISHED_AUTH);
 
   strlcpy(client->realhost, client->host, sizeof(client->realhost));
@@ -150,7 +150,7 @@ auth_release_client(struct AuthRequest *auth)
  * \param hostname The string to verify
  * \return 1 if it is valid, 0 if it isn't
  */
-static int
+static bool
 auth_verify_hostname(const char *hostname)
 {
   const char *p = hostname;
@@ -158,13 +158,13 @@ auth_verify_hostname(const char *hostname)
   assert(p);
 
   if (EmptyString(p) || *p == '.' || *p == ':')
-    return 0;
+    return false;
 
   for (; *p; ++p)
     if (!IsHostChar(*p))
-      return 0;
+      return false;
 
-  return 1;
+  return true;
 }
 
 /*! \brief Handle a complete DNS lookup. Send the client on its way to a connection
@@ -179,46 +179,23 @@ auth_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, s
 {
   struct AuthRequest *const auth = vptr;
 
-  ClearDNSPending(auth);
+  assert(auth->client);
+  assert(auth->client->connection);
 
-  if (EmptyString(name))
+  auth->dns_pending = false;
+
+  if (namelength == 0)
     auth_sendheader(auth->client, REPORT_FAIL_DNS);
+  else if (address_compare(addr, &auth->client->ip, false) == false)
+    auth_sendheader(auth->client, REPORT_IP_MISMATCH);
+  else if (namelength > HOSTLEN)
+    auth_sendheader(auth->client, REPORT_HOST_TOOLONG);
+  else if (auth_verify_hostname(name) == false)
+    auth_sendheader(auth->client, REPORT_HOST_INVALID);
   else
   {
-    if (auth->client->connection->ip.ss.ss_family == AF_INET6)
-    {
-      const struct sockaddr_in6 *const v6 = (const struct sockaddr_in6 *)&auth->client->connection->ip;
-      const struct sockaddr_in6 *const v6dns = (const struct sockaddr_in6 *)addr;
-
-      if (memcmp(&v6->sin6_addr, &v6dns->sin6_addr, sizeof(struct in6_addr)))
-      {
-        auth_sendheader(auth->client, REPORT_IP_MISMATCH);
-        auth_release_client(auth);
-        return;
-      }
-    }
-    else
-    {
-      const struct sockaddr_in *const v4 = (const struct sockaddr_in *)&auth->client->connection->ip;
-      const struct sockaddr_in *const v4dns = (const struct sockaddr_in *)addr;
-
-      if (v4->sin_addr.s_addr != v4dns->sin_addr.s_addr)
-      {
-        auth_sendheader(auth->client, REPORT_IP_MISMATCH);
-        auth_release_client(auth);
-        return;
-      }
-    }
-
-    if (namelength > HOSTLEN)
-      auth_sendheader(auth->client, REPORT_HOST_TOOLONG);
-    else if (!auth_verify_hostname(name))
-      auth_sendheader(auth->client, REPORT_HOST_INVALID);
-    else
-    {
-      strlcpy(auth->client->host, name, sizeof(auth->client->host));
-      auth_sendheader(auth->client, REPORT_FIN_DNS);
-    }
+    strlcpy(auth->client->host, name, sizeof(auth->client->host));
+    auth_sendheader(auth->client, REPORT_FIN_DNS);
   }
 
   auth_release_client(auth);
@@ -230,12 +207,16 @@ auth_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, s
 static void
 auth_error(struct AuthRequest *auth)
 {
+  assert(auth);
+  assert(auth->fd);
+  assert(auth->client);
+  assert(auth->client->connection);
+
   ++ServerStats.is_abad;
 
   fd_close(auth->fd);
   auth->fd = NULL;
-
-  ClearAuth(auth);
+  auth->ident_pending = false;
 
   auth_sendheader(auth->client, REPORT_FAIL_ID);
 
@@ -304,7 +285,7 @@ auth_check_ident_reply(char *const reply)
    * form - e.g., something that could be used as an argument to "finger"
    * or as a mail address.
    */
-  if (!strncmp(token, "OTHER", 5))
+  if (strncmp(token, "OTHER", 5) == 0)
     return NULL;
 
   /*
@@ -347,8 +328,10 @@ auth_read_reply(fde_t *F, void *data)
   char buf[RFC1413_BUFSIZ + 1];
 
   assert(auth->fd == F);
+  assert(auth->client);
+  assert(auth->client->connection);
 
-  if ((len = recv(auth->fd->fd, buf, RFC1413_BUFSIZ, 0)) > 0)
+  if (F->read_handler == NULL && (len = recv(auth->fd->fd, buf, sizeof(buf) - 1, 0)) > 0)
   {
     buf[len] = '\0';
     username = auth_check_ident_reply(buf);
@@ -356,8 +339,7 @@ auth_read_reply(fde_t *F, void *data)
 
   fd_close(auth->fd);
   auth->fd = NULL;
-
-  ClearAuth(auth);
+  auth->ident_pending = false;
 
   if (EmptyString(username))
   {
@@ -399,14 +381,16 @@ auth_connect_callback(fde_t *F, int error, void *data)
   uint16_t uport, tport;
   struct sockaddr_in6 *v6;
 
+  assert(auth->fd == F);
+  assert(auth->client);
+  assert(auth->client->connection);
+
   if (error != COMM_OK)
   {
     auth_error(auth);
     return;
   }
 
-  assert(auth->fd == F);
-
   if (getsockname(auth->client->connection->fd->fd, (struct sockaddr *)&us, &ulen) ||
       getpeername(auth->client->connection->fd->fd, (struct sockaddr *)&them, &tlen))
   {
@@ -429,7 +413,7 @@ auth_connect_callback(fde_t *F, int error, void *data)
     return;
   }
 
-  comm_setselect(F, COMM_SELECT_READ, auth_read_reply, auth, 0);
+  comm_setselect(F, COMM_SELECT_READ, auth_read_reply, auth, 4);
 }
 
 /*! \brief Flag the client to show an attempt to contact the ident server on
@@ -445,8 +429,11 @@ auth_start_query(struct AuthRequest *auth)
   socklen_t locallen = sizeof(struct irc_ssaddr);
   struct sockaddr_in6 *v6;
 
+  assert(auth->client);
+  assert(auth->client->connection);
+
   /* Open a socket of the same type as the client socket */
-  int fd = comm_socket(auth->client->connection->ip.ss.ss_family, SOCK_STREAM, 0);
+  int fd = comm_socket(auth->client->ip.ss.ss_family, SOCK_STREAM, 0);
   if (fd == -1)
   {
     report_error(L_ALL, "creating auth stream socket %s:%s",
@@ -455,9 +442,9 @@ auth_start_query(struct AuthRequest *auth)
     return;
   }
 
-  auth->fd = fd_open(fd, 1, "ident");
+  auth->fd = fd_open(fd, true, "ident");
+  auth->ident_pending = true;
 
-  SetDoingAuth(auth);
   auth_sendheader(auth->client, REPORT_DO_ID);
 
   /*
@@ -470,12 +457,9 @@ auth_start_query(struct AuthRequest *auth)
   remove_ipv6_mapping(&localaddr);
   v6 = (struct sockaddr_in6 *)&localaddr;
   v6->sin6_port = htons(0);
-  localaddr.ss_port = htons(0);
 
-  comm_connect_tcp(auth->fd, auth->client->sockhost, RFC1413_PORT,
-      (struct sockaddr *)&localaddr, localaddr.ss_len, auth_connect_callback,
-      auth, auth->client->connection->ip.ss.ss_family,
-      GlobalSetOptions.ident_timeout);
+  comm_connect_tcp(auth->fd, &auth->client->ip, RFC1413_PORT, &localaddr,
+                   auth_connect_callback, auth, 4);
 }
 
 /*
@@ -490,16 +474,17 @@ auth_start(struct Client *client_p)
 {
   struct AuthRequest *auth = auth_make(client_p);
 
-  dlinkAddTail(auth, &auth->node, &auth_list);
+  assert(client_p);
+  assert(client_p->connection);
 
   auth_sendheader(client_p, REPORT_DO_DNS);
 
-  SetDNSPending(auth);
+  auth->dns_pending = true;
 
   if (ConfigGeneral.disable_auth == 0)
     auth_start_query(auth);
 
-  gethost_byaddr(auth_dns_callback, auth, &client_p->connection->ip);
+  gethost_byaddr(auth_dns_callback, auth, &client_p->ip);
 }
 
 /*
@@ -508,76 +493,19 @@ auth_start(struct Client *client_p)
 void
 auth_delete(struct AuthRequest *auth)
 {
-  if (IsDoingAuth(auth))
+  assert(auth->client);
+  assert(auth->client->connection);
+
+  if (auth->fd)
   {
     fd_close(auth->fd);
     auth->fd = NULL;
-
-    ClearAuth(auth);
   }
 
-  if (IsDNSPending(auth))
-  {
-    delete_resolver_queries(auth);
-    ClearDNSPending(auth);
-  }
+  auth->ident_pending = false;
+
+  delete_resolver_queries(auth);
+  auth->dns_pending = false;
 
   auth_free(auth);
 }
-
-/*
- * auth_timeout_queries - timeout resolver and identd requests
- * allow clients through if requests failed
- */
-static void
-auth_timeout_queries(void *notused)
-{
-  dlink_node *node, *node_next;
-
-  DLINK_FOREACH_SAFE(node, node_next, auth_list.head)
-  {
-    struct AuthRequest *auth = node->data;
-
-    if (auth->timeout > CurrentTime)
-      break;
-
-    if (IsDoingAuth(auth))
-    {
-      ++ServerStats.is_abad;
-
-      fd_close(auth->fd);
-      auth->fd = NULL;
-
-      ClearAuth(auth);
-
-      auth_sendheader(auth->client, REPORT_FAIL_ID);
-    }
-
-    if (IsDNSPending(auth))
-    {
-      delete_resolver_queries(auth);
-      ClearDNSPending(auth);
-
-      auth_sendheader(auth->client, REPORT_FAIL_DNS);
-    }
-
-    auth_release_client(auth);
-  }
-}
-
-/* auth_init
- *
- * Initialise the auth code
- */
-void
-auth_init(void)
-{
-  static struct event timeout_auth_queries =
-  {
-    .name = "auth_timeout_queries",
-    .handler = auth_timeout_queries,
-    .when = 1
-  };
-
-  event_add(&timeout_auth_queries, NULL);
-}
