@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel.c
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.c 8446 2018-03-30 11:36:06Z michael $
+ * \version $Id: channel.c 8927 2019-04-22 11:08:47Z michael $
  */
 
 #include "stdinc.h"
@@ -65,16 +65,16 @@ channel_get_list(void)
  */
 void
 add_user_to_channel(struct Channel *chptr, struct Client *client_p,
-                    unsigned int flags, int flood_ctrl)
+                    unsigned int flags, bool flood_ctrl)
 {
   assert(IsClient(client_p));
 
   if (GlobalSetOptions.joinfloodtime)
   {
-    if (flood_ctrl)
+    if (flood_ctrl == true)
       ++chptr->number_joined;
 
-    chptr->number_joined -= (CurrentTime - chptr->last_join_time) *
+    chptr->number_joined -= (event_base->time.sec_monotonic - chptr->last_join_time) *
       (((float)GlobalSetOptions.joinfloodcount) /
        (float)GlobalSetOptions.joinfloodtime);
 
@@ -97,7 +97,7 @@ add_user_to_channel(struct Channel *chptr, struct Client *client_p,
       }
     }
 
-    chptr->last_join_time = CurrentTime;
+    chptr->last_join_time = event_base->time.sec_monotonic;
   }
 
   struct Membership *member = xcalloc(sizeof(*member));
@@ -108,7 +108,7 @@ add_user_to_channel(struct Channel *chptr, struct Client *client_p,
   dlinkAdd(member, &member->channode, &chptr->members);
 
   if (MyConnect(client_p))
-    dlinkAdd(member, &member->locchannode, &chptr->locmembers);
+    dlinkAdd(member, &member->locchannode, &chptr->members_local);
 
   dlinkAdd(member, &member->usernode, &client_p->channel);
 }
@@ -126,7 +126,7 @@ remove_user_from_channel(struct Membership *member)
   dlinkDelete(&member->channode, &chptr->members);
 
   if (MyConnect(client_p))
-    dlinkDelete(&member->locchannode, &chptr->locmembers);
+    dlinkDelete(&member->locchannode, &chptr->members_local);
 
   dlinkDelete(&member->usernode, &client_p->channel);
 
@@ -271,27 +271,27 @@ channel_send_modes(struct Client *client_p, const struct Channel *chptr)
  * \param local Indicates whether it's a local or remote creation
  * \return 0 if invalid, 1 otherwise
  */
-int
-channel_check_name(const char *name, const int local)
+bool
+channel_check_name(const char *name, bool local)
 {
   const char *p = name;
 
   assert(!EmptyString(p));
 
   if (!IsChanPrefix(*p))
-    return 0;
+    return false;
 
-  if (!local || !ConfigChannel.disable_fake_channels)
+  if (local == false || ConfigChannel.disable_fake_channels == 0)
   {
     while (*++p)
       if (!IsChanChar(*p))
-        return 0;
+        return false;
   }
   else
   {
     while (*++p)
       if (!IsVisibleChanChar(*p))
-        return 0;
+        return false;
   }
 
   return p - name <= CHANNELLEN;
@@ -331,9 +331,10 @@ channel_make(const char *name)
   assert(!EmptyString(name));
 
   struct Channel *chptr = xcalloc(sizeof(*chptr));
+  chptr->hnextch = chptr;
   /* Doesn't hurt to set it here */
-  chptr->creationtime = CurrentTime;
-  chptr->last_join_time = CurrentTime;
+  chptr->creationtime = event_base->time.sec_real;
+  chptr->last_join_time = event_base->time.sec_monotonic;
 
   /* Cache channel name length to avoid repetitive strlen() calls. */
   chptr->name_len = strlcpy(chptr->name, name, sizeof(chptr->name));
@@ -362,6 +363,35 @@ channel_free(struct Channel *chptr)
   dlinkDelete(&chptr->node, &channel_list);
   hash_del_channel(chptr);
 
+  assert(chptr->hnextch == chptr);
+
+  assert(chptr->node.prev == NULL);
+  assert(chptr->node.next == NULL);
+
+  assert(dlink_list_length(&chptr->members_local) == 0);
+  assert(chptr->members_local.head == NULL);
+  assert(chptr->members_local.tail == NULL);
+
+  assert(dlink_list_length(&chptr->members) == 0);
+  assert(chptr->members.head == NULL);
+  assert(chptr->members.tail == NULL);
+
+  assert(dlink_list_length(&chptr->invites) == 0);
+  assert(chptr->invites.head == NULL);
+  assert(chptr->invites.tail == NULL);
+
+  assert(dlink_list_length(&chptr->banlist) == 0);
+  assert(chptr->banlist.head == NULL);
+  assert(chptr->banlist.tail == NULL);
+
+  assert(dlink_list_length(&chptr->exceptlist) == 0);
+  assert(chptr->exceptlist.head == NULL);
+  assert(chptr->exceptlist.tail == NULL);
+
+  assert(dlink_list_length(&chptr->invexlist) == 0);
+  assert(chptr->invexlist.head == NULL);
+  assert(chptr->invexlist.tail == NULL);
+
   xfree(chptr);
 }
 
@@ -386,19 +416,19 @@ channel_pub_or_secret(const struct Channel *chptr)
  *                 (don't want it with /names with no params)
  */
 void
-channel_member_names(struct Client *client_p, struct Channel *chptr, int show_eon)
+channel_member_names(struct Client *client_p, struct Channel *chptr, bool show_eon)
 {
   dlink_node *node;
   char buf[IRCD_BUFSIZE + 1] = "";
   char *t = NULL, *start = NULL;
   int tlen = 0;
-  const int is_member = IsMember(client_p, chptr);
-  const int multi_prefix = HasCap(client_p, CAP_MULTI_PREFIX) != 0;
-  const int uhnames = HasCap(client_p, CAP_UHNAMES) != 0;
+  bool is_member = IsMember(client_p, chptr);
+  bool multi_prefix = HasCap(client_p, CAP_MULTI_PREFIX) != 0;
+  bool uhnames = HasCap(client_p, CAP_UHNAMES) != 0;
 
   assert(IsClient(client_p));
 
-  if (PubChannel(chptr) || is_member)
+  if (PubChannel(chptr) || is_member == true)
   {
     t = buf + snprintf(buf, sizeof(buf), numeric_form(RPL_NAMREPLY),
                        me.name, client_p->name,
@@ -409,16 +439,16 @@ channel_member_names(struct Client *client_p, struct Channel *chptr, int show_eo
     {
       const struct Membership *member = node->data;
 
-      if (HasUMode(member->client_p, UMODE_INVISIBLE) && !is_member)
+      if (HasUMode(member->client_p, UMODE_INVISIBLE) && is_member == false)
         continue;
 
-      if (uhnames)
+      if (uhnames == true)
         tlen = strlen(member->client_p->name) + strlen(member->client_p->username) +
                strlen(member->client_p->host) + 3;  /* +3 for ! + @ + space */
       else
         tlen = strlen(member->client_p->name) + 1;  /* +1 for space */
 
-      if (multi_prefix)
+      if (multi_prefix == true)
       {
         if (member->flags & CHFL_CHANOP)
           ++tlen;
@@ -440,7 +470,7 @@ channel_member_names(struct Client *client_p, struct Channel *chptr, int show_eo
         t = start;
       }
 
-      if (uhnames)
+      if (uhnames == true)
         t += sprintf(t, "%s%s!%s@%s ", get_member_status(member, multi_prefix),
                      member->client_p->name, member->client_p->username,
                      member->client_p->host);
@@ -456,7 +486,7 @@ channel_member_names(struct Client *client_p, struct Channel *chptr, int show_eo
     }
   }
 
-  if (show_eon)
+  if (show_eon == true)
     sendto_one_numeric(client_p, &me, RPL_ENDOFNAMES, chptr->name);
 }
 
@@ -477,7 +507,7 @@ find_invite(struct Channel *chptr, struct Client *client_p)
     struct Invite *invite = node->data;
 
     if (ConfigChannel.invite_expire_time &&
-        ConfigChannel.invite_expire_time + invite->when < CurrentTime)
+        ConfigChannel.invite_expire_time + invite->when < event_base->time.sec_monotonic)
       del_invite(invite);
     else if (invite->chptr == chptr && invite->client_p == client_p)
       return invite;
@@ -500,7 +530,7 @@ add_invite(struct Channel *chptr, struct Client *client_p)
   invite = xcalloc(sizeof(*invite));
   invite->client_p = client_p;
   invite->chptr = chptr;
-  invite->when = CurrentTime;
+  invite->when = event_base->time.sec_monotonic;
 
   /* Delete last link in chain if the list is max length */
   while (dlink_list_length(&client_p->connection->invited) && 
@@ -550,21 +580,21 @@ clear_invite_list(dlink_list *list)
  * (like in client_get_name)
  */
 const char *
-get_member_status(const struct Membership *member, const int combine)
+get_member_status(const struct Membership *member, bool combine)
 {
   static char buffer[CMEMBER_STATUS_FLAGS_LEN + 1];  /* +1 for \0 */
   char *p = buffer;
 
   if (member->flags & CHFL_CHANOP)
   {
-    if (!combine)
+    if (combine == false)
       return "@";
     *p++ = '@';
   }
 
   if (member->flags & CHFL_HALFOP)
   {
-    if (!combine)
+    if (combine == false)
       return "%";
     *p++ = '%';
   }
@@ -581,7 +611,7 @@ get_member_status(const struct Membership *member, const int combine)
  * \param list     Pointer to ban list to search
  * \return 1 if ban found for given n!u\@h mask, 0 otherwise
  */
-static int
+static bool
 find_bmask(const struct Client *client_p, const dlink_list *list)
 {
   dlink_node *node;
@@ -590,23 +620,23 @@ find_bmask(const struct Client *client_p, const dlink_list *list)
   {
     const struct Ban *ban = node->data;
 
-    if (!match(ban->name, client_p->name) && !match(ban->user, client_p->username))
+    if (match(ban->name, client_p->name) == 0 && match(ban->user, client_p->username) == 0)
     {
       switch (ban->type)
       {
         case HM_HOST:
-          if (!match(ban->host, client_p->host) || !match(ban->host, client_p->sockhost))
-            return 1;
+          if (match(ban->host, client_p->host) == 0 || match(ban->host, client_p->sockhost) == 0)
+            return true;
           break;
         case HM_IPV4:
-          if (client_p->connection->aftype == AF_INET)
-            if (match_ipv4(&client_p->connection->ip, &ban->addr, ban->bits))
-              return 1;
+          if (client_p->ip.ss.ss_family == AF_INET)
+            if (match_ipv4(&client_p->ip, &ban->addr, ban->bits))
+              return true;
           break;
         case HM_IPV6:
-          if (client_p->connection->aftype == AF_INET6)
-            if (match_ipv6(&client_p->connection->ip, &ban->addr, ban->bits))
-              return 1;
+          if (client_p->ip.ss.ss_family == AF_INET6)
+            if (match_ipv6(&client_p->ip, &ban->addr, ban->bits))
+              return true;
           break;
         default:
           assert(0);
@@ -614,7 +644,7 @@ find_bmask(const struct Client *client_p, const dlink_list *list)
     }
   }
 
-  return 0;
+  return false;
 }
 
 /*!
@@ -622,14 +652,12 @@ find_bmask(const struct Client *client_p, const dlink_list *list)
  * \param client_p Pointer to client to check access fo
  * \return 0 if not banned, 1 otherwise
  */
-int
+bool
 is_banned(const struct Channel *chptr, const struct Client *client_p)
 {
-  if (find_bmask(client_p, &chptr->banlist))
-    if (!find_bmask(client_p, &chptr->exceptlist))
-      return 1;
-
-  return 0;
+  if (find_bmask(client_p, &chptr->banlist) == true)
+    return find_bmask(client_p, &chptr->exceptlist) == false;
+  return false;
 }
 
 /*! Tests if a client can join a certain channel
@@ -652,18 +680,18 @@ can_join(struct Client *client_p, struct Channel *chptr, const char *key)
     return ERR_OPERONLYCHAN;
 
   if (HasCMode(chptr, MODE_INVITEONLY))
-    if (!find_invite(chptr, client_p))
-      if (!find_bmask(client_p, &chptr->invexlist))
+    if (find_invite(chptr, client_p) == NULL)
+      if (find_bmask(client_p, &chptr->invexlist) == false)
         return ERR_INVITEONLYCHAN;
 
-  if (chptr->mode.key[0] && (!key || strcmp(chptr->mode.key, key)))
+  if (chptr->mode.key[0] && (key == NULL || strcmp(chptr->mode.key, key)))
     return ERR_BADCHANNELKEY;
 
   if (chptr->mode.limit && dlink_list_length(&chptr->members) >=
       chptr->mode.limit)
     return ERR_CHANNELISFULL;
 
-  if (is_banned(chptr, client_p))
+  if (is_banned(chptr, client_p) == true)
     return ERR_BANNEDFROMCHAN;
 
   return 0;
@@ -704,12 +732,10 @@ find_channel_link(const struct Client *client_p, const struct Channel *chptr)
  * \param message The actual message string the client wants to send
  * \return 1 if the message does contain any control codes, 0 otherwise
  */
-static int
+static bool
 msg_has_ctrls(const char *message)
 {
-  const unsigned char *p = (const unsigned char *)message;
-
-  for (; *p; ++p)
+  for (const char *p = message; *p; ++p)
   {
     if (*p > 31 || *p == 1)
       continue;  /* No control code or CTCP */
@@ -725,10 +751,10 @@ msg_has_ctrls(const char *message)
       }
     }
 
-    return 1;  /* Control code */
+    return true;  /* Control code */
   }
 
-  return 0;  /* No control code found */
+  return false;  /* No control code found */
 }
 
 /*! Tests if a client can send to a channel
@@ -742,7 +768,7 @@ msg_has_ctrls(const char *message)
  */
 int
 can_send(struct Channel *chptr, struct Client *client_p,
-         struct Membership *member, const char *message, int notice)
+         struct Membership *member, const char *message, bool notice)
 {
   const struct ResvItem *resv = NULL;
 
@@ -751,10 +777,10 @@ can_send(struct Channel *chptr, struct Client *client_p,
 
   if (MyConnect(client_p) && !HasFlag(client_p, FLAGS_EXEMPTRESV))
     if (!(HasUMode(client_p, UMODE_OPER) && HasOFlag(client_p, OPER_FLAG_JOIN_RESV)))
-      if ((resv = resv_find(chptr->name, match)) && !resv_exempt_find(client_p, resv))
+      if ((resv = resv_find(chptr->name, match)) && resv_exempt_find(client_p, resv) == false)
         return ERR_CANNOTSENDTOCHAN;
 
-  if (HasCMode(chptr, MODE_NOCTRL) && msg_has_ctrls(message))
+  if (HasCMode(chptr, MODE_NOCTRL) && msg_has_ctrls(message) == true)
     return ERR_NOCTRLSONCHAN;
 
   if (HasCMode(chptr, MODE_NOCTCP))
@@ -765,7 +791,7 @@ can_send(struct Channel *chptr, struct Client *client_p,
     if (member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE))
       return CAN_SEND_OPV;
 
-  if (!member && HasCMode(chptr, MODE_NOPRIVMSGS))
+  if (member == NULL && HasCMode(chptr, MODE_NOPRIVMSGS))
     return ERR_CANNOTSENDTOCHAN;
 
   if (HasCMode(chptr, MODE_MODERATED))
@@ -774,7 +800,7 @@ can_send(struct Channel *chptr, struct Client *client_p,
   if (HasCMode(chptr, MODE_MODREG) && !HasUMode(client_p, UMODE_REGISTERED))
     return ERR_NEEDREGGEDNICK;
 
-  if (HasCMode(chptr, MODE_NONOTICE) && notice)
+  if (HasCMode(chptr, MODE_NONOTICE) && notice == true)
     return ERR_CANNOTSENDTOCHAN;
 
   /* Cache can send if banned */
@@ -787,7 +813,7 @@ can_send(struct Channel *chptr, struct Client *client_p,
 
       if (!(member->flags & CHFL_BAN_CHECKED))
       {
-        if (is_banned(chptr, client_p))
+        if (is_banned(chptr, client_p) == true)
         {
           member->flags |= (CHFL_BAN_CHECKED | CHFL_BAN_SILENCED);
           return ERR_CANNOTSENDTOCHAN;
@@ -796,7 +822,7 @@ can_send(struct Channel *chptr, struct Client *client_p,
         member->flags |= CHFL_BAN_CHECKED;
       }
     }
-    else if (is_banned(chptr, client_p))
+    else if (is_banned(chptr, client_p) == true)
       return ERR_CANNOTSENDTOCHAN;
   }
 
@@ -815,10 +841,8 @@ check_spambot_warning(struct Client *client_p, const char *name)
   if (GlobalSetOptions.spam_num &&
       (client_p->connection->join_leave_count >= GlobalSetOptions.spam_num))
   {
-    if (client_p->connection->oper_warn_count_down > 0)
-      client_p->connection->oper_warn_count_down--;
-    else
-      client_p->connection->oper_warn_count_down = 0;
+    if (client_p->connection->oper_warn_count_down)
+      --client_p->connection->oper_warn_count_down;
 
     if (client_p->connection->oper_warn_count_down == 0)
     {
@@ -838,10 +862,10 @@ check_spambot_warning(struct Client *client_p, const char *name)
   }
   else
   {
-    int t_delta = CurrentTime - client_p->connection->last_leave_time;
+    unsigned int t_delta = event_base->time.sec_monotonic - client_p->connection->last_leave_time;
     if (t_delta > JOIN_LEAVE_COUNT_EXPIRE_TIME)
     {
-      int decrement_count = (t_delta / JOIN_LEAVE_COUNT_EXPIRE_TIME);
+      unsigned int decrement_count = (t_delta / JOIN_LEAVE_COUNT_EXPIRE_TIME);
       if (decrement_count > client_p->connection->join_leave_count)
         client_p->connection->join_leave_count = 0;
       else
@@ -849,15 +873,14 @@ check_spambot_warning(struct Client *client_p, const char *name)
     }
     else
     {
-      if ((CurrentTime - (client_p->connection->last_join_time)) <
-          GlobalSetOptions.spam_time)
-        client_p->connection->join_leave_count++;  /* It's a possible spambot */
+      if ((event_base->time.sec_monotonic - client_p->connection->last_join_time) < GlobalSetOptions.spam_time)
+        ++client_p->connection->join_leave_count;  /* It's a possible spambot */
     }
 
     if (name)
-      client_p->connection->last_join_time = CurrentTime;
+      client_p->connection->last_join_time = event_base->time.sec_monotonic;
     else
-      client_p->connection->last_leave_time = CurrentTime;
+      client_p->connection->last_leave_time = event_base->time.sec_monotonic;
   }
 }
 
@@ -870,9 +893,9 @@ check_spambot_warning(struct Client *client_p, const char *name)
  */
 void
 channel_set_topic(struct Channel *chptr, const char *topic,
-                  const char *topic_info, uintmax_t topicts, int local)
+                  const char *topic_info, uintmax_t topicts, bool local)
 {
-  if (local)
+  if (local == true)
     strlcpy(chptr->topic, topic, IRCD_MIN(sizeof(chptr->topic), ConfigServerInfo.max_topic_length + 1));
   else
     strlcpy(chptr->topic, topic, sizeof(chptr->topic));
@@ -889,7 +912,7 @@ channel_do_join(struct Client *client_p, char *chan_list, char *key_list)
   const struct ClassItem *const class = class_get_ptr(&client_p->connection->confs);
   unsigned int flags = 0;
 
-  assert(IsClient(client_p));
+  assert(MyClient(client_p));
 
   for (const char *name = strtok_r(chan_list, ",", &p); name;
                    name = strtok_r(NULL,      ",", &p))
@@ -904,7 +927,7 @@ channel_do_join(struct Client *client_p, char *chan_list, char *key_list)
     if (key && *key == '\0')
       key = NULL;
 
-    if (channel_check_name(name, 1) == 0)
+    if (channel_check_name(name, true) == false)
     {
       sendto_one_numeric(client_p, &me, ERR_BADCHANNAME, name);
       continue;
@@ -912,7 +935,7 @@ channel_do_join(struct Client *client_p, char *chan_list, char *key_list)
 
     if (!HasFlag(client_p, FLAGS_EXEMPTRESV) &&
         !(HasUMode(client_p, UMODE_OPER) && HasOFlag(client_p, OPER_FLAG_JOIN_RESV)) &&
-        ((resv = resv_find(name, match)) && !resv_exempt_find(client_p, resv)))
+        ((resv = resv_find(name, match)) && resv_exempt_find(client_p, resv) == false))
     {
       sendto_one_numeric(client_p, &me, ERR_CHANBANREASON, name, resv->reason);
       sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
@@ -960,18 +983,18 @@ channel_do_join(struct Client *client_p, char *chan_list, char *key_list)
     if (!HasUMode(client_p, UMODE_OPER))
       check_spambot_warning(client_p, chptr->name);
 
-    add_user_to_channel(chptr, client_p, flags, 1);
+    add_user_to_channel(chptr, client_p, flags, true);
 
     /*
      * Set timestamp if appropriate, and propagate
      */
     if (flags == CHFL_CHANOP)
     {
-      chptr->creationtime = CurrentTime;
+      chptr->creationtime = event_base->time.sec_real;
       AddCMode(chptr, MODE_TOPICLIMIT);
       AddCMode(chptr, MODE_NOPRIVMSGS);
 
-      sendto_server(client_p, 0, 0, ":%s SJOIN %ju %s +nt :@%s",
+      sendto_server(NULL, 0, 0, ":%s SJOIN %ju %s +nt :@%s",
                     me.id, chptr->creationtime,
                     chptr->name, client_p->id);
 
@@ -986,16 +1009,10 @@ channel_do_join(struct Client *client_p, char *chan_list, char *key_list)
                            client_p->host, chptr->name);
       sendto_channel_local(NULL, chptr, 0, 0, 0, ":%s MODE %s +nt",
                            me.name, chptr->name);
-
-      if (client_p->away[0])
-        sendto_channel_local(client_p, chptr, 0, CAP_AWAY_NOTIFY, 0,
-                             ":%s!%s@%s AWAY :%s",
-                             client_p->name, client_p->username,
-                             client_p->host, client_p->away);
     }
     else
     {
-      sendto_server(client_p, 0, 0, ":%s JOIN %ju %s +",
+      sendto_server(NULL, 0, 0, ":%s JOIN %ju %s +",
                     client_p->id, chptr->creationtime,
                     chptr->name);
 
@@ -1005,14 +1022,14 @@ channel_do_join(struct Client *client_p, char *chan_list, char *key_list)
       sendto_channel_local(NULL, chptr, 0, 0, CAP_EXTENDED_JOIN, ":%s!%s@%s JOIN :%s",
                            client_p->name, client_p->username,
                            client_p->host, chptr->name);
-
-      if (client_p->away[0])
-        sendto_channel_local(client_p, chptr, 0, CAP_AWAY_NOTIFY, 0,
-                             ":%s!%s@%s AWAY :%s",
-                             client_p->name, client_p->username,
-                             client_p->host, client_p->away);
     }
 
+    if (client_p->away[0])
+      sendto_channel_local(client_p, chptr, 0, CAP_AWAY_NOTIFY, 0,
+                           ":%s!%s@%s AWAY :%s",
+                           client_p->name, client_p->username,
+                           client_p->host, client_p->away);
+
     struct Invite *invite;
     if ((invite = find_invite(chptr, client_p)))
       del_invite(invite);
@@ -1024,9 +1041,9 @@ channel_do_join(struct Client *client_p, char *chan_list, char *key_list)
                          chptr->topic_info, chptr->topic_time);
     }
 
-    channel_member_names(client_p, chptr, 1);
+    channel_member_names(client_p, chptr, true);
 
-    client_p->connection->last_join_time = CurrentTime;
+    client_p->connection->last_join_time = event_base->time.sec_monotonic;
   }
 }
 
@@ -1061,9 +1078,9 @@ channel_part_one_client(struct Client *client_p, const char *name, const char *r
    * only allow /part reasons in -m chans
    */
   if (*reason && (!MyConnect(client_p) ||
-      ((client_p->connection->firsttime +
-        ConfigGeneral.anti_spam_exit_message_time) < CurrentTime &&
-       can_send(chptr, client_p, member, reason, 0) < 0)))
+      ((client_p->connection->created_monotonic +
+        ConfigGeneral.anti_spam_exit_message_time) < event_base->time.sec_monotonic &&
+       can_send(chptr, client_p, member, reason, false) < 0)))
   {
     sendto_server(client_p, 0, 0, ":%s PART %s :%s",
                   client_p->id, chptr->name, reason);
