@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.c
  * \brief Controls modes on channels.
- * \version $Id: channel_mode.c 8467 2018-04-03 11:21:48Z michael $
+ * \version $Id: channel_mode.c 8927 2019-04-22 11:08:47Z michael $
  */
 
 #include "stdinc.h"
@@ -84,10 +84,9 @@ check_string(char *s)
  *   -is 8/9/00
  */
 
-int
-add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int type)
+bool
+add_id(struct Client *client_p, struct Channel *chptr, char *banid, dlink_list *list)
 {
-  dlink_list *list;
   dlink_node *node;
   char name[NICKLEN + 1] = "";
   char user[USERLEN + 1] = "";
@@ -105,7 +104,7 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
                                                         ConfigChannel.max_bans))
     {
       sendto_one_numeric(client_p, &me, ERR_BANLISTFULL, chptr->name, banid);
-      return 0;
+      return false;
     }
 
     collapse(banid);
@@ -128,35 +127,20 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
    */
   size_t len = snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
 
-  switch (type)
-  {
-    case CHFL_BAN:
-      list = &chptr->banlist;
-      clear_ban_cache_list(&chptr->locmembers);
-      break;
-    case CHFL_EXCEPTION:
-      list = &chptr->exceptlist;
-      clear_ban_cache_list(&chptr->locmembers);
-      break;
-    case CHFL_INVEX:
-      list = &chptr->invexlist;
-      break;
-    default:
-      list = NULL;  /* Let it crash */
-  }
-
   DLINK_FOREACH(node, list->head)
   {
     const struct Ban *ban = node->data;
 
-    if (!irccmp(ban->name, name) &&
-        !irccmp(ban->user, user) &&
-        !irccmp(ban->host, host))
-      return 0;
+    if (irccmp(ban->name, name) == 0 &&
+        irccmp(ban->user, user) == 0 &&
+        irccmp(ban->host, host) == 0)
+      return false;
   }
 
+  clear_ban_cache_list(&chptr->members_local);
+
   struct Ban *ban = xcalloc(sizeof(*ban));
-  ban->when = CurrentTime;
+  ban->when = event_base->time.sec_real;
   ban->len = len - 2;  /* -2 for ! + @ */
   ban->type = parse_netmask(host, &ban->addr, &ban->bits);
   strlcpy(ban->name, name, sizeof(ban->name));
@@ -173,7 +157,7 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
 
   dlinkAdd(ban, &ban->node, list);
 
-  return 1;
+  return true;
 }
 
 /*
@@ -183,10 +167,9 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
  * output	- 0 for failure, 1 for success
  * side effects	-
  */
-static int
-del_id(struct Channel *chptr, char *banid, unsigned int type)
+static bool
+del_id(struct Channel *chptr, char *banid, dlink_list *list)
 {
-  dlink_list *list;
   dlink_node *node;
   char name[NICKLEN + 1] = "";
   char user[USERLEN + 1] = "";
@@ -212,37 +195,21 @@ del_id(struct Channel *chptr, char *banid, unsigned int type)
    */
   snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
 
-  switch (type)
-  {
-    case CHFL_BAN:
-      list = &chptr->banlist;
-      clear_ban_cache_list(&chptr->locmembers);
-      break;
-    case CHFL_EXCEPTION:
-      list = &chptr->exceptlist;
-      clear_ban_cache_list(&chptr->locmembers);
-      break;
-    case CHFL_INVEX:
-      list = &chptr->invexlist;
-      break;
-    default:
-      list = NULL;  /* Let it crash */
-  }
-
   DLINK_FOREACH(node, list->head)
   {
     struct Ban *ban = node->data;
 
-    if (!irccmp(name, ban->name) &&
-        !irccmp(user, ban->user) &&
-        !irccmp(host, ban->host))
+    if (irccmp(name, ban->name) == 0 &&
+        irccmp(user, ban->user) == 0 &&
+        irccmp(host, ban->host) == 0)
     {
+      clear_ban_cache_list(&chptr->members_local);
       remove_ban(ban, list);
-      return 1;
+      return true;
     }
   }
 
-  return 0;
+  return false;
 }
 
 /* channel_modes()
@@ -384,7 +351,7 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     }
   }
 
-  if (alev < CHACCESS_HALFOP)
+  if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
@@ -424,33 +391,61 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 }
 
 static void
-chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
-        int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
+chm_mask(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+         int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
+  dlink_list *list;
+  enum irc_numerics rpl_list = 0, rpl_endlist = 0;
+  int errtype = 0;
+
+  switch (mode->flag)
+  {
+    case CHFL_BAN:
+      errtype = SM_ERR_RPL_B;
+      list = &chptr->banlist;
+      rpl_list = RPL_BANLIST;
+      rpl_endlist = RPL_ENDOFBANLIST;
+      break;
+    case CHFL_EXCEPTION:
+      errtype = SM_ERR_RPL_E;
+      list = &chptr->exceptlist;
+      rpl_list = RPL_EXCEPTLIST;
+      rpl_endlist = RPL_ENDOFEXCEPTLIST;
+      break;
+    case CHFL_INVEX:
+      errtype = SM_ERR_RPL_I;
+      list = &chptr->invexlist;
+      rpl_list = RPL_INVEXLIST;
+      rpl_endlist = RPL_ENDOFINVEXLIST;
+      break;
+    default:
+      list = NULL;  /* Let it crash */
+  }
+
   if (dir == MODE_QUERY || parc <= *parn)
   {
     dlink_node *node;
 
-    if (*errors & SM_ERR_RPL_B)
+    if (*errors & errtype)
       return;
 
-    *errors |= SM_ERR_RPL_B;
+    *errors |= errtype;
 
-    DLINK_FOREACH(node, chptr->banlist.head)
+    DLINK_FOREACH(node, list->head)
     {
       const struct Ban *ban = node->data;
 
-      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= CHACCESS_HALFOP)
-        sendto_one_numeric(source_p, &me, RPL_BANLIST, chptr->name,
+      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= mode->required_oplevel)
+        sendto_one_numeric(source_p, &me, rpl_list, chptr->name,
                            ban->name, ban->user, ban->host,
                            ban->who, ban->when);
     }
 
-    sendto_one_numeric(source_p, &me, RPL_ENDOFBANLIST, chptr->name);
+    sendto_one_numeric(source_p, &me, rpl_endlist, chptr->name);
     return;
   }
 
-  if (alev < CHACCESS_HALFOP)
+  if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
@@ -473,12 +468,12 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn, cha
 
   if (dir == MODE_ADD)  /* setting + */
   {
-    if (add_id(source_p, chptr, mask, CHFL_BAN) == 0)
+    if (add_id(source_p, chptr, mask, list) == false)
       return;
   }
   else if (dir == MODE_DEL)  /* setting - */
   {
-    if (del_id(chptr, mask, CHFL_BAN) == 0)
+    if (del_id(chptr, mask, list) == false)
       return;
   }
 
@@ -493,151 +488,13 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn, cha
 }
 
 static void
-chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
-           int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
-{
-  if (dir == MODE_QUERY || parc <= *parn)
-  {
-    dlink_node *node;
-
-    if (*errors & SM_ERR_RPL_E)
-      return;
-
-    *errors |= SM_ERR_RPL_E;
-
-    DLINK_FOREACH(node, chptr->exceptlist.head)
-    {
-      const struct Ban *ban = node->data;
-
-      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= CHACCESS_HALFOP)
-        sendto_one_numeric(source_p, &me, RPL_EXCEPTLIST, chptr->name,
-                           ban->name, ban->user, ban->host,
-                           ban->who, ban->when);
-    }
-
-    sendto_one_numeric(source_p, &me, RPL_ENDOFEXCEPTLIST, chptr->name);
-    return;
-  }
-
-  if (alev < CHACCESS_HALFOP)
-  {
-    if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
-                         alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
-
-    *errors |= SM_ERR_NOOPS;
-    return;
-  }
-
-  if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
-    return;
-
-  char *const mask = nuh_mask[*parn];
-  strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
-  ++(*parn);
-
-  if (*mask == ':' || (!MyConnect(source_p) && strchr(mask, ' ')))
-    return;
-
-  if (dir == MODE_ADD)  /* setting + */
-  {
-    if (add_id(source_p, chptr, mask, CHFL_EXCEPTION) == 0)
-      return;
-  }
-  else if (dir == MODE_DEL)  /* setting - */
-  {
-    if (del_id(chptr, mask, CHFL_EXCEPTION) == 0)
-      return;
-  }
-
-  mode_changes[mode_count].letter = mode->letter;
-  mode_changes[mode_count].arg = mask;  /* At this point 'mask' is no longer than NICKLEN + USERLEN + HOSTLEN + 3 */
-  mode_changes[mode_count].id = NULL;
-  if (HasCMode(chptr, MODE_HIDEBMASKS))
-    mode_changes[mode_count].flags = CHFL_CHANOP | CHFL_HALFOP;
-  else
-    mode_changes[mode_count].flags = 0;
-  mode_changes[mode_count++].dir = dir;
-}
-
-static void
-chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
-          int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
-{
-  if (dir == MODE_QUERY || parc <= *parn)
-  {
-    dlink_node *node;
-
-    if (*errors & SM_ERR_RPL_I)
-      return;
-
-    *errors |= SM_ERR_RPL_I;
-
-    DLINK_FOREACH(node, chptr->invexlist.head)
-    {
-      const struct Ban *ban = node->data;
-
-      if (!HasCMode(chptr, MODE_HIDEBMASKS) || alev >= CHACCESS_HALFOP)
-        sendto_one_numeric(source_p, &me, RPL_INVEXLIST, chptr->name,
-                           ban->name, ban->user, ban->host,
-                           ban->who, ban->when);
-    }
-
-    sendto_one_numeric(source_p, &me, RPL_ENDOFINVEXLIST, chptr->name);
-    return;
-  }
-
-  if (alev < CHACCESS_HALFOP)
-  {
-    if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
-                         alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
-
-    *errors |= SM_ERR_NOOPS;
-    return;
-  }
-
-  if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
-    return;
-
-  char *const mask = nuh_mask[*parn];
-  strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
-  ++(*parn);
-
-  if (*mask == ':' || (!MyConnect(source_p) && strchr(mask, ' ')))
-    return;
-
-  if (dir == MODE_ADD)  /* setting + */
-  {
-    if (add_id(source_p, chptr, mask, CHFL_INVEX) == 0)
-      return;
-  }
-  else if (dir == MODE_DEL)  /* setting - */
-  {
-    if (del_id(chptr, mask, CHFL_INVEX) == 0)
-      return;
-  }
-
-  mode_changes[mode_count].letter = mode->letter;
-  mode_changes[mode_count].arg = mask;  /* At this point 'mask' is no longer than NICKLEN + USERLEN + HOSTLEN + 3 */
-  mode_changes[mode_count].id = NULL;
-  if (HasCMode(chptr, MODE_HIDEBMASKS))
-    mode_changes[mode_count].flags = CHFL_CHANOP | CHFL_HALFOP;
-  else
-    mode_changes[mode_count].flags = 0;
-  mode_changes[mode_count++].dir = dir;
-}
-
-static void
-chm_voice(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
-          int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
+chm_flag(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
+         int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
   struct Client *target_p;
   struct Membership *member;
 
-  if (alev < CHACCESS_HALFOP)
+  if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
@@ -668,133 +525,17 @@ chm_voice(struct Client *source_p, struct Channel *chptr, int parc, int *parn, c
 
   if (dir == MODE_ADD)  /* setting + */
   {
-    if (has_member_flags(member, CHFL_VOICE))
+    if (has_member_flags(member, mode->flag))
       return;  /* No redundant mode changes */
 
-    AddMemberFlag(member, CHFL_VOICE);
+    AddMemberFlag(member, mode->flag);
   }
   else if (dir == MODE_DEL)  /* setting - */
   {
-    if (has_member_flags(member, CHFL_VOICE) == 0)
+    if (has_member_flags(member, mode->flag) == 0)
       return;  /* No redundant mode changes */
 
-    DelMemberFlag(member, CHFL_VOICE);
-  }
-
-  mode_changes[mode_count].letter = mode->letter;
-  mode_changes[mode_count].arg = target_p->name;
-  mode_changes[mode_count].id = target_p->id;
-  mode_changes[mode_count].flags = 0;
-  mode_changes[mode_count++].dir = dir;
-}
-
-static void
-chm_hop(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
-        int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
-{
-  struct Client *target_p;
-  struct Membership *member;
-
-  if (alev < CHACCESS_CHANOP)
-  {
-    if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
-                         alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
-
-    *errors |= SM_ERR_NOOPS;
-    return;
-  }
-
-  if (dir == MODE_QUERY || parc <= *parn)
-    return;
-
-  if ((target_p = find_chasing(source_p, parv[(*parn)++])) == NULL)
-    return;  /* find_chasing sends ERR_NOSUCHNICK */
-
-  if ((member = find_channel_link(target_p, chptr)) == NULL)
-  {
-    if (!(*errors & SM_ERR_NOTONCHANNEL))
-      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->name);
-
-    *errors |= SM_ERR_NOTONCHANNEL;
-    return;
-  }
-
-  if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
-    return;
-
-  if (dir == MODE_ADD)  /* setting + */
-  {
-    if (has_member_flags(member, CHFL_HALFOP))
-      return;  /* No redundant mode changes */
-
-    AddMemberFlag(member, CHFL_HALFOP);
-  }
-  else if (dir == MODE_DEL)  /* setting - */
-  {
-    if (has_member_flags(member, CHFL_HALFOP) == 0)
-      return;  /* No redundant mode changes */
-
-    DelMemberFlag(member, CHFL_HALFOP);
-  }
-
-  mode_changes[mode_count].letter = mode->letter;
-  mode_changes[mode_count].arg = target_p->name;
-  mode_changes[mode_count].id = target_p->id;
-  mode_changes[mode_count].flags = 0;
-  mode_changes[mode_count++].dir = dir;
-}
-
-static void
-chm_op(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
-       int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
-{
-  struct Client *target_p;
-  struct Membership *member;
-
-  if (alev < CHACCESS_CHANOP)
-  {
-    if (!(*errors & SM_ERR_NOOPS))
-      sendto_one_numeric(source_p, &me,
-                         alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->name);
-
-    *errors |= SM_ERR_NOOPS;
-    return;
-  }
-
-  if (dir == MODE_QUERY || parc <= *parn)
-    return;
-
-  if ((target_p = find_chasing(source_p, parv[(*parn)++])) == NULL)
-    return;  /* find_chasing sends ERR_NOSUCHNICK */
-
-  if ((member = find_channel_link(target_p, chptr)) == NULL)
-  {
-    if (!(*errors & SM_ERR_NOTONCHANNEL))
-      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->name);
-
-    *errors |= SM_ERR_NOTONCHANNEL;
-    return;
-  }
-
-  if (MyClient(source_p) && (++mode_limit > MAXMODEPARAMS))
-    return;
-
-  if (dir == MODE_ADD)  /* setting + */
-  {
-    if (has_member_flags(member, CHFL_CHANOP))
-      return;  /* No redundant mode changes */
-
-    AddMemberFlag(member, CHFL_CHANOP);
-  }
-  else if (dir == MODE_DEL)  /* setting - */
-  {
-    if (has_member_flags(member, CHFL_CHANOP) == 0)
-      return;  /* No redundant mode changes */
-
-    DelMemberFlag(member, CHFL_CHANOP);
+    DelMemberFlag(member, mode->flag);
   }
 
   mode_changes[mode_count].letter = mode->letter;
@@ -808,7 +549,7 @@ static void
 chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
           int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
-  if (alev < CHACCESS_HALFOP)
+  if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
@@ -863,7 +604,7 @@ static void
 chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn, char **parv,
         int *errors, int alev, int dir, const char c, const struct chan_mode *mode)
 {
-  if (alev < CHACCESS_HALFOP)
+  if (alev < mode->required_oplevel)
   {
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
@@ -931,7 +672,7 @@ get_channel_access(const struct Client *source_p,
   if (!MyClient(source_p))
     return CHACCESS_REMOTE;
 
-  if (!member)
+  if (member == NULL)
     return CHACCESS_NOTONCHAN;
 
   /* Just to be sure.. */
@@ -1119,31 +860,31 @@ send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
 const struct chan_mode *cmode_map[256];
 const struct chan_mode  cmode_tab[] =
 {
-  { .letter = 'b', .func = chm_ban },
-  { .letter = 'c', .mode = MODE_NOCTRL, .func = chm_simple },
-  { .letter = 'e', .func = chm_except },
-  { .letter = 'h', .func = chm_hop },
-  { .letter = 'i', .mode = MODE_INVITEONLY, .func = chm_simple },
-  { .letter = 'k', .func = chm_key },
-  { .letter = 'l', .func = chm_limit },
-  { .letter = 'm', .mode = MODE_MODERATED, .func = chm_simple },
-  { .letter = 'n', .mode = MODE_NOPRIVMSGS, .func = chm_simple },
-  { .letter = 'o', .func = chm_op },
-  { .letter = 'p', .mode = MODE_PRIVATE, .func = chm_simple },
-  { .letter = 'r', .mode = MODE_REGISTERED, .only_servers = 1, .func = chm_simple },
-  { .letter = 's', .mode = MODE_SECRET, .func = chm_simple },
-  { .letter = 't', .mode = MODE_TOPICLIMIT, .func = chm_simple },
-  { .letter = 'u', .mode = MODE_HIDEBMASKS, .func = chm_simple },
-  { .letter = 'v', .func = chm_voice },
-  { .letter = 'C', .mode = MODE_NOCTCP, .func = chm_simple },
-  { .letter = 'I', .func = chm_invex },
-  { .letter = 'L', .mode = MODE_EXTLIMIT, .only_opers = 1, .func = chm_simple },
-  { .letter = 'M', .mode = MODE_MODREG, .func = chm_simple },
-  { .letter = 'N', .mode = MODE_NONICKCHANGE, .func = chm_simple },
-  { .letter = 'O', .mode = MODE_OPERONLY, .only_opers = 1, .func = chm_simple },
-  { .letter = 'R', .mode = MODE_REGONLY, .func = chm_simple },
-  { .letter = 'S', .mode = MODE_SSLONLY, .func = chm_simple },
-  { .letter = 'T', .mode = MODE_NONOTICE, .func = chm_simple },
+  { .letter = 'b', .flag = CHFL_BAN, .required_oplevel = CHACCESS_HALFOP, .func = chm_mask },
+  { .letter = 'c', .mode = MODE_NOCTRL, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'e', .flag = CHFL_EXCEPTION, .required_oplevel = CHACCESS_HALFOP, .func = chm_mask },
+  { .letter = 'h', .flag = CHFL_HALFOP, .required_oplevel = CHACCESS_CHANOP, .func = chm_flag },
+  { .letter = 'i', .mode = MODE_INVITEONLY, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'k', .func = chm_key, .required_oplevel = CHACCESS_HALFOP },
+  { .letter = 'l', .func = chm_limit, .required_oplevel = CHACCESS_HALFOP },
+  { .letter = 'm', .mode = MODE_MODERATED, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'n', .mode = MODE_NOPRIVMSGS, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'o', .flag = CHFL_CHANOP, .required_oplevel = CHACCESS_CHANOP, .func = chm_flag },
+  { .letter = 'p', .mode = MODE_PRIVATE, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'r', .mode = MODE_REGISTERED, .required_oplevel = CHACCESS_REMOTE, .only_servers = true, .func = chm_simple },
+  { .letter = 's', .mode = MODE_SECRET, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 't', .mode = MODE_TOPICLIMIT, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'u', .mode = MODE_HIDEBMASKS, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'v', .flag = CHFL_VOICE, .required_oplevel = CHACCESS_HALFOP, .func = chm_flag },
+  { .letter = 'C', .mode = MODE_NOCTCP, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'I', .flag = CHFL_INVEX, .required_oplevel = CHACCESS_HALFOP, .func = chm_mask },
+  { .letter = 'L', .mode = MODE_EXTLIMIT, .required_oplevel = CHACCESS_HALFOP, .only_opers = true, .func = chm_simple },
+  { .letter = 'M', .mode = MODE_MODREG, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'N', .mode = MODE_NONICKCHANGE, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'O', .mode = MODE_OPERONLY, .required_oplevel = CHACCESS_HALFOP, .only_opers = true, .func = chm_simple },
+  { .letter = 'R', .mode = MODE_REGONLY, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'S', .mode = MODE_SSLONLY, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
+  { .letter = 'T', .mode = MODE_NONOTICE, .required_oplevel = CHACCESS_HALFOP, .func = chm_simple },
   { .letter = '\0', .mode = 0 }
 };
 
