@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.c
  * \brief Controls clients.
- * \version $Id: client.c 8483 2018-04-04 15:07:19Z michael $
+ * \version $Id: client.c 8989 2019-05-25 20:15:14Z michael $
  */
 
 #include "stdinc.h"
@@ -46,7 +46,6 @@
 #include "memory.h"
 #include "hostmask.h"
 #include "listener.h"
-#include "userhost.h"
 #include "watch.h"
 #include "rng_mt.h"
 #include "parse.h"
@@ -91,9 +90,10 @@ client_make(struct Client *from)
   {
     client_p->from = client_p;  /* 'from' of local client is self! */
     client_p->connection = xcalloc(sizeof(*client_p->connection));
-    client_p->connection->since = CurrentTime;
-    client_p->connection->lasttime = CurrentTime;
-    client_p->connection->firsttime = CurrentTime;
+    client_p->connection->last_data = event_base->time.sec_monotonic;
+    client_p->connection->last_ping = event_base->time.sec_monotonic;
+    client_p->connection->created_real = event_base->time.sec_real;
+    client_p->connection->created_monotonic = event_base->time.sec_monotonic;
     client_p->connection->registration = REG_INIT;
 
     /* as good a place as any... */
@@ -204,22 +204,18 @@ static void
 check_pings_list(dlink_list *list)
 {
   char buf[32] = "";  /* 32 = sizeof("Ping timeout: 999999999 seconds") */
-  unsigned int ping = 0;      /* ping time value from client */
   dlink_node *node, *node_next;
 
   DLINK_FOREACH_SAFE(node, node_next, list->head)
   {
     struct Client *client_p = node->data;
+    assert(IsClient(client_p) || IsServer(client_p));
 
     if (IsDead(client_p))
       continue;  /* Ignore it, it's been exited already */
 
-    if (IsClient(client_p) || IsServer(client_p))
-      ping = get_client_ping(&client_p->connection->confs);
-    else
-      ping = CONNECTTIMEOUT;
-
-    if (ping < CurrentTime - client_p->connection->lasttime)
+    unsigned int ping = get_client_ping(&client_p->connection->confs);
+    if (ping < event_base->time.sec_monotonic - client_p->connection->last_ping)
     {
       if (!HasFlag(client_p, FLAGS_PINGSENT))
       {
@@ -229,18 +225,18 @@ check_pings_list(dlink_list *list)
          * it is still alive.
          */
         AddFlag(client_p, FLAGS_PINGSENT);
-        client_p->connection->lasttime = CurrentTime - ping;
+        client_p->connection->last_ping = event_base->time.sec_monotonic - ping;
         sendto_one(client_p, "PING :%s", ID_or_name(&me, client_p));
       }
       else
       {
-        if (CurrentTime - client_p->connection->lasttime >= 2 * ping)
+        if (event_base->time.sec_monotonic - client_p->connection->last_ping >= 2 * ping)
         {
           /*
            * If the client/server hasn't talked to us in 2*ping seconds
            * and it has a ping time, then close its connection.
            */
-          if (IsServer(client_p) || IsHandshake(client_p))
+          if (IsServer(client_p))
           {
             sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
                                  "No response from %s, closing link",
@@ -252,8 +248,8 @@ check_pings_list(dlink_list *list)
                  client_get_name(client_p, SHOW_IP));
           }
 
-          snprintf(buf, sizeof(buf), "Ping timeout: %ji seconds",
-                   (CurrentTime - client_p->connection->lasttime));
+          snprintf(buf, sizeof(buf), "Ping timeout: %ju seconds",
+                   (event_base->time.sec_monotonic - client_p->connection->last_ping));
           exit_client(client_p, buf);
         }
       }
@@ -275,12 +271,31 @@ check_unknowns_list(void)
   DLINK_FOREACH_SAFE(node, node_next, unknown_list.head)
   {
     struct Client *client_p = node->data;
+    bool exit = false;
 
     /*
      * Check UNKNOWN connections - if they have been in this state
      * for > 30s, close them.
      */
-    if (HasFlag(client_p, FLAGS_FINISHED_AUTH) && (CurrentTime - client_p->connection->firsttime) > 30)
+    if ((event_base->time.sec_monotonic - client_p->connection->created_monotonic) <= 30)
+      continue;
+
+    if (IsHandshake(client_p))
+    {
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE,
+                           "No response from %s during handshake, closing link",
+                           client_get_name(client_p, SHOW_IP));
+      sendto_realops_flags(UMODE_SERVNOTICE, L_OPER, SEND_NOTICE,
+                           "No response from %s during handshake, closing link",
+                           client_get_name(client_p, MASK_IP));
+      ilog(LOG_TYPE_IRCD, "No response from %s during handshake, closing link",
+           client_get_name(client_p, SHOW_IP));
+      exit = true;
+    }
+    else if (HasFlag(client_p, FLAGS_FINISHED_AUTH))
+      exit = true;
+
+    if (exit == true)
       exit_client(client_p, "Registration timed out");
   }
 }
@@ -339,16 +354,14 @@ check_conf_klines(void)
     if (IsDead(client_p))
       continue;
 
-    if ((ptr = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
-                                    client_p->connection->aftype, NULL, NULL, 1)))
+    if ((ptr = find_conf_by_address(NULL, &client_p->ip, CONF_DLINE, NULL, NULL, 1)))
     {
       const struct MaskItem *conf = ptr;
       conf_try_ban(client_p, CLIENT_BAN_DLINE, conf->reason);
       continue;  /* and go examine next Client */
     }
 
-    if ((ptr = find_conf_by_address(client_p->host, &client_p->connection->ip,
-                                    CONF_KLINE, client_p->connection->aftype,
+    if ((ptr = find_conf_by_address(client_p->host, &client_p->ip, CONF_KLINE,
                                     client_p->username, NULL, 1)))
     {
       const struct MaskItem *conf = ptr;
@@ -369,8 +382,11 @@ check_conf_klines(void)
   {
     struct Client *client_p = node->data;
 
-    if ((ptr = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
-                                    client_p->connection->aftype, NULL, NULL, 1)))
+    /* If a client is already being exited */
+    if (IsDead(client_p))
+      continue;
+
+    if ((ptr = find_conf_by_address(NULL, &client_p->ip, CONF_DLINE, NULL, NULL, 1)))
     {
       const struct MaskItem *conf = ptr;
       conf_try_ban(client_p, CLIENT_BAN_DLINE, conf->reason);
@@ -406,8 +422,7 @@ conf_try_ban(struct Client *client_p, int type, const char *reason)
       ban_type = 'K';
       break;
     case CLIENT_BAN_DLINE:
-      if (find_conf_by_address(NULL, &client_p->connection->ip, CONF_EXEMPT,
-                               client_p->connection->aftype, NULL, NULL, 1))
+      if (find_conf_by_address(NULL, &client_p->ip, CONF_EXEMPT, NULL, NULL, 1))
         return;
       ban_type = 'D';
       break;
@@ -475,7 +490,7 @@ find_chasing(struct Client *source_p, const char *name)
     return NULL;
 
   target_p = whowas_get_history(name, ConfigGeneral.kill_chase_time_limit);
-  if (!target_p)
+  if (target_p == NULL)
     sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, name);
 
   return target_p;
@@ -488,16 +503,6 @@ find_chasing(struct Client *source_p, const char *name)
  *      return the "socket host" name of the client, if that
  *        differs from the advertised name (other than case).
  *        But, this can be used to any client structure.
- *
- * NOTE 1:
- *        Watch out the allocation of "buf", if either source_p->name
- *        or source_p->sockhost gets changed into pointers instead of
- *        directly allocated within the structure...
- *
- * NOTE 2:
- *        Function return either a pointer to the structure (source_p) or
- *        to internal buffer (buf). *NEVER* use the returned pointer
- *        to modify what it points!!!
  */
 const char *
 client_get_name(const struct Client *client_p, enum addr_mask_type type)
@@ -509,7 +514,7 @@ client_get_name(const struct Client *client_p, enum addr_mask_type type)
 
   if (IsServer(client_p) || IsConnecting(client_p) || IsHandshake(client_p))
   {
-    if (!irccmp(client_p->name, client_p->host))
+    if (irccmp(client_p->name, client_p->host) == 0)
       return client_p->name;
     else if (ConfigServerHide.hide_server_ips)
       type = MASK_IP;
@@ -524,7 +529,7 @@ client_get_name(const struct Client *client_p, enum addr_mask_type type)
                client_p->username, client_p->sockhost);
       break;
     case MASK_IP:
-      if (client_p->connection->aftype == AF_INET)
+      if (client_p->ip.ss.ss_family == AF_INET)
         snprintf(buf, sizeof(buf), "%s[%s@255.255.255.255]",
                  client_p->name, client_p->username);
       else
@@ -580,7 +585,7 @@ client_close_connection(struct Client *client_p)
     ++ServerStats.is_cl;
     ServerStats.is_cbs += client_p->connection->send.bytes;
     ServerStats.is_cbr += client_p->connection->recv.bytes;
-    ServerStats.is_cti += CurrentTime - client_p->connection->firsttime;
+    ServerStats.is_cti += event_base->time.sec_monotonic - client_p->connection->created_monotonic;
   }
   else if (IsServer(client_p))
   {
@@ -589,20 +594,18 @@ client_close_connection(struct Client *client_p)
     ++ServerStats.is_sv;
     ServerStats.is_sbs += client_p->connection->send.bytes;
     ServerStats.is_sbr += client_p->connection->recv.bytes;
-    ServerStats.is_sti += CurrentTime - client_p->connection->firsttime;
+    ServerStats.is_sti += event_base->time.sec_monotonic - client_p->connection->created_monotonic;
 
     DLINK_FOREACH(node, connect_items.head)
     {
       struct MaskItem *conf = node->data;
 
-      if (irccmp(conf->name, client_p->name))
-        continue;
-
       /*
        * Reset next-connect cycle of all connect{} blocks that match
        * this servername.
        */
-      conf->until = CurrentTime + conf->class->con_freq;
+      if (irccmp(conf->name, client_p->name) == 0)
+        conf->until = event_base->time.sec_monotonic + conf->class->con_freq;
     }
   }
   else
@@ -656,7 +659,7 @@ exit_one_client(struct Client *source_p, const char *comment)
      * that the client can show the "**signoff" message).
      * (Note: The notice is to the local clients *only*)
      */
-    sendto_common_channels_local(source_p, 0, 0, 0, ":%s!%s@%s QUIT :%s",
+    sendto_common_channels_local(source_p, false, 0, 0, ":%s!%s@%s QUIT :%s",
                                  source_p->name, source_p->username,
                                  source_p->host, comment);
 
@@ -665,7 +668,7 @@ exit_one_client(struct Client *source_p, const char *comment)
 
     svstag_clear_list(&source_p->svstags);
 
-    whowas_add_history(source_p, 0);
+    whowas_add_history(source_p, false);
     whowas_off_history(source_p);
 
     watch_check_hash(source_p, RPL_LOGOFF);
@@ -687,8 +690,11 @@ exit_one_client(struct Client *source_p, const char *comment)
   if (source_p->name[0])
     hash_del_client(source_p);
 
-  if (HasFlag(source_p, FLAGS_USERHOST))
-    userhost_del(source_p->sockhost, !MyConnect(source_p));
+  if (HasFlag(source_p, FLAGS_IPHASH))
+  {
+    DelFlag(source_p, FLAGS_IPHASH);
+    ipcache_record_remove(&source_p->ip, MyConnect(source_p));
+  }
 
   /* Check to see if the client isn't already on the dead list */
   assert(dlinkFind(&dead_list, source_p) == NULL);
@@ -744,6 +750,8 @@ exit_client(struct Client *source_p, const char *comment)
 
   if (MyConnect(source_p))
   {
+    assert(source_p == source_p->from);
+
     /*
      * DO NOT REMOVE. exit_client can be called twice after a failed read/write.
      */
@@ -752,12 +760,6 @@ exit_client(struct Client *source_p, const char *comment)
 
     AddFlag(source_p, FLAGS_CLOSING);
 
-    if (HasFlag(source_p, FLAGS_IPHASH))
-    {
-      DelFlag(source_p, FLAGS_IPHASH);
-      ipcache_remove_address(&source_p->connection->ip);
-    }
-
     if (source_p->connection->auth)
     {
       auth_delete(source_p->connection->auth);
@@ -788,8 +790,8 @@ exit_client(struct Client *source_p, const char *comment)
                            source_p->sockhost, comment);
 
       ilog(LOG_TYPE_USER, "%s (%ju): %s!%s@%s %s %s %ju/%ju :%s",
-           date_ctime(source_p->connection->firsttime),
-           CurrentTime - source_p->connection->firsttime,
+           date_ctime(source_p->connection->created_real),
+           event_base->time.sec_monotonic - source_p->connection->created_monotonic,
            source_p->name, source_p->username, source_p->host,
            source_p->sockhost, source_p->account,
            source_p->connection->send.bytes >> 10,
@@ -799,6 +801,10 @@ exit_client(struct Client *source_p, const char *comment)
     {
       assert(dlinkFind(&local_server_list, source_p));
       dlinkDelete(&source_p->connection->lclient_node, &local_server_list);
+
+      if (!HasFlag(source_p, FLAGS_SQUIT))
+        /* For them, we are exiting the network */
+        sendto_one(source_p, ":%s SQUIT %s :%s", me.id, me.id, comment);
     }
     else
     {
@@ -806,21 +812,7 @@ exit_client(struct Client *source_p, const char *comment)
       dlinkDelete(&source_p->connection->lclient_node, &unknown_list);
     }
 
-    if (!IsDead(source_p))
-    {
-      if (IsServer(source_p))
-      {
-        if (!HasFlag(source_p, FLAGS_SQUIT))
-        {
-          /* For them, we are exiting the network */
-          sendto_one(source_p, ":%s SQUIT %s :%s",
-                     me.id, me.id, comment);
-        }
-      }
-
-      sendto_one(source_p, "ERROR :Closing Link: %s (%s)",
-                 source_p->host, comment);
-    }
+    sendto_one(source_p, "ERROR :Closing Link: %s (%s)", source_p->host, comment);
 
     client_close_connection(source_p);
   }
@@ -858,11 +850,11 @@ exit_client(struct Client *source_p, const char *comment)
     {
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "%s was connected for %s. %ju/%ju sendK/recvK.",
-                           source_p->name, time_dissect(CurrentTime - source_p->connection->firsttime),
+                           source_p->name, time_dissect(event_base->time.sec_monotonic - source_p->connection->created_monotonic),
                            source_p->connection->send.bytes >> 10,
                            source_p->connection->recv.bytes >> 10);
       ilog(LOG_TYPE_IRCD, "%s was connected for %s. %ju/%ju sendK/recvK.",
-           source_p->name, time_dissect(CurrentTime - source_p->connection->firsttime),
+           source_p->name, time_dissect(event_base->time.sec_monotonic - source_p->connection->created_monotonic),
            source_p->connection->send.bytes >> 10,
            source_p->connection->recv.bytes >> 10);
     }
@@ -876,6 +868,7 @@ exit_client(struct Client *source_p, const char *comment)
   assert(dlinkFind(&local_server_list, source_p) == NULL);
   assert(dlinkFind(&oper_list, source_p) == NULL);
   assert(dlinkFind(&listing_client_list, source_p) == NULL);
+  assert(dlinkFind(&abort_list, source_p) == NULL);
 
   exit_one_client(source_p, comment);
 }
@@ -922,7 +915,7 @@ dead_link_on_read(struct Client *client_p, int error)
   dbuf_clear(&client_p->connection->buf_recvq);
   dbuf_clear(&client_p->connection->buf_sendq);
 
-  current_error = comm_get_sockerr(client_p->connection->fd->fd);
+  current_error = comm_get_sockerr(client_p->connection->fd);
 
   if (IsServer(client_p) || IsHandshake(client_p))
   {
@@ -951,7 +944,7 @@ dead_link_on_read(struct Client *client_p, int error)
 
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "%s was connected for %s",
-                         client_p->name, time_dissect(CurrentTime - client_p->connection->firsttime));
+                         client_p->name, time_dissect(event_base->time.sec_monotonic - client_p->connection->created_monotonic));
   }
 
   if (error == 0)
@@ -1027,9 +1020,9 @@ find_accept(const char *nick, const char *user,
   {
     struct split_nuh_item *accept_p = node->data;
 
-    if (!compare(accept_p->nickptr, nick) &&
-        !compare(accept_p->userptr, user) &&
-        !compare(accept_p->hostptr, host))
+    if (compare(accept_p->nickptr, nick) == 0 &&
+        compare(accept_p->userptr, user) == 0 &&
+        compare(accept_p->hostptr, host) == 0)
       return accept_p;
   }
 
@@ -1043,7 +1036,7 @@ find_accept(const char *nick, const char *user,
  * output       - 1 if accept this message 0 if not
  * side effects - See if source is on target's allow list
  */
-int
+bool
 accept_message(struct Client *source,
                struct Client *target)
 {
@@ -1051,18 +1044,18 @@ accept_message(struct Client *source,
 
   if (HasFlag(source, FLAGS_SERVICE) ||
       (HasUMode(source, UMODE_OPER) && ConfigGeneral.opers_bypass_callerid))
-    return 1;
+    return true;
 
   if (source == target || find_accept(source->name, source->username,
                                       source->host, target, match))
-    return 1;
+    return true;
 
   if (!HasUMode(target, UMODE_CALLERID) && HasUMode(target, UMODE_SOFTCALLERID))
     DLINK_FOREACH(node, target->channel.head)
       if (IsMember(source, ((struct Membership *)node->data)->chptr))
-        return 1;
+        return true;
 
-  return 0;
+  return false;
 }
 
 /* del_all_accepts()
@@ -1088,11 +1081,11 @@ client_get_idle_time(const struct Client *source_p,
   const struct ClassItem *const class = class_get_ptr(&target_p->connection->confs);
 
   if (!(class->flags & CLASS_FLAGS_FAKE_IDLE) || target_p == source_p)
-    return CurrentTime - target_p->connection->last_privmsg;
+    return event_base->time.sec_monotonic - target_p->connection->last_privmsg;
 
   if (HasUMode(source_p, UMODE_OPER) &&
       !(class->flags & CLASS_FLAGS_HIDE_IDLE_FROM_OPERS))
-    return CurrentTime - target_p->connection->last_privmsg;
+    return event_base->time.sec_monotonic - target_p->connection->last_privmsg;
 
   const unsigned int min_idle = class->min_idle;
   const unsigned int max_idle = class->max_idle;
@@ -1103,7 +1096,7 @@ client_get_idle_time(const struct Client *source_p,
   if (class->flags & CLASS_FLAGS_RANDOM_IDLE)
     idle = genrand_int32();
   else
-    idle = CurrentTime - target_p->connection->last_privmsg;
+    idle = event_base->time.sec_monotonic - target_p->connection->last_privmsg;
 
   if (max_idle)
     idle %= max_idle;
