@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2015-2018 ircd-hybrid development team
+ *  Copyright (c) 2015-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client_svstag.c
  * \brief Controls SVSTAGS.
- * \version $Id: client_svstag.c 8486 2018-04-04 15:13:05Z michael $
+ * \version $Id: client_svstag.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -68,7 +68,7 @@ svstag_attach(dlink_list *list, unsigned int numeric,
   svstag->numeric = numeric;
   svstag->tag = xstrdup(tag);
 
-  for (const char *m = umodes + 1; *m; ++m)
+  for (const char *m = umodes + 1  /* + 1 to skip the '+' */; *m; ++m)
     if ((tab = umode_map[(unsigned char)*m]))
       svstag->umodes |= tab->flag;
 
