@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf.c
  * \brief Configuration file functions.
- * \version $Id: conf.c 8467 2018-04-03 11:21:48Z michael $
+ * \version $Id: conf.c 8970 2019-05-18 11:58:17Z michael $
  */
 
 #include "stdinc.h"
@@ -51,7 +51,6 @@
 #include "send.h"
 #include "memory.h"
 #include "res.h"
-#include "userhost.h"
 #include "user.h"
 #include "channel_mode.h"
 #include "misc.h"
@@ -96,12 +95,12 @@ conf_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, s
 {
   struct MaskItem *const conf = vptr;
 
-  conf->dns_pending = 0;
+  conf->dns_pending = false;
 
   if (addr)
-    memcpy(&conf->addr, addr, sizeof(conf->addr));
+    memcpy(conf->addr, addr, sizeof(*conf->addr));
   else
-    conf->dns_failed = 1;
+    conf->dns_failed = true;
 }
 
 /* conf_dns_lookup()
@@ -113,10 +112,10 @@ conf_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, s
 static void
 conf_dns_lookup(struct MaskItem *conf)
 {
-  if (conf->dns_pending)
+  if (conf->dns_pending == true)
     return;
 
-  conf->dns_pending = 1;
+  conf->dns_pending = true;
 
   if (conf->aftype == AF_INET)
     gethost_byname_type(conf_dns_callback, conf, conf->host, T_A);
@@ -153,7 +152,7 @@ conf_make(enum maskitem_type type)
   dlink_list *list = NULL;
 
   conf->type   = type;
-  conf->active = 1;
+  conf->active = true;
   conf->aftype = AF_INET;
 
   if ((list = map_to_list(type)))
@@ -172,7 +171,7 @@ conf_free(struct MaskItem *conf)
 
   xfree(conf->name);
 
-  if (conf->dns_pending)
+  if (conf->dns_pending == true)
     delete_resolver_queries(conf);
   if (conf->passwd)
     memset(conf->passwd, 0, strlen(conf->passwd));
@@ -188,6 +187,8 @@ conf_free(struct MaskItem *conf)
   xfree(conf->whois);
   xfree(conf->user);
   xfree(conf->host);
+  xfree(conf->addr);
+  xfree(conf->bind);
   xfree(conf->cipher_list);
 
   DLINK_FOREACH_SAFE(node, node_next, conf->hub_list.head)
@@ -218,30 +219,21 @@ static int
 attach_iline(struct Client *client_p, struct MaskItem *conf)
 {
   const struct ClassItem *const class = conf->class;
-  struct ip_entry *ip_found;
-  int a_limit_reached = 0;
-  unsigned int local = 0, global = 0;
+  bool a_limit_reached = false;
 
-  ip_found = ipcache_find_or_add_address(&client_p->connection->ip);
-  ip_found->count++;
+  struct ip_entry *ipcache = ipcache_record_find_or_add(&client_p->ip);
+  ++ipcache->count_local;
   AddFlag(client_p, FLAGS_IPHASH);
 
-  userhost_count(client_p->sockhost, &global, &local);
-
-  /* XXX blah. go down checking the various silly limits
-   * setting a_limit_reached if any limit is reached.
-   * - Dianora
-   */
   if (class->max_total && class->ref_count >= class->max_total)
-    a_limit_reached = 1;
-  else if (class->max_perip && ip_found->count > class->max_perip)
-    a_limit_reached = 1;
-  else if (class->max_local && local >= class->max_local) /* XXX: redundant */
-    a_limit_reached = 1;
-  else if (class->max_global && global >= class->max_global)
-    a_limit_reached = 1;
+    a_limit_reached = true;
+  else if (class->max_perip_local && ipcache->count_local > class->max_perip_local)
+    a_limit_reached = true;
+  else if (class->max_perip_global &&
+           (ipcache->count_local + ipcache->count_remote) > class->max_perip_global)
+    a_limit_reached = true;
 
-  if (a_limit_reached)
+  if (a_limit_reached == true)
   {
     if (!IsConfExemptLimits(conf))
       return TOO_MANY;   /* Already at maximum allowed */
@@ -262,55 +254,49 @@ attach_iline(struct Client *client_p, struct MaskItem *conf)
 static int
 verify_access(struct Client *client_p)
 {
-  struct MaskItem *conf = NULL;
+  struct MaskItem *conf;
 
   if (HasFlag(client_p, FLAGS_GOTID))
-  {
-    conf = find_address_conf(client_p->host, client_p->username,
-                             &client_p->connection->ip,
-                             client_p->connection->aftype,
+    conf = find_address_conf(client_p->host, client_p->username, &client_p->ip,
                              client_p->connection->password);
-  }
   else
   {
     char non_ident[USERLEN + 1] = "~";
 
     strlcpy(non_ident + 1, client_p->username, sizeof(non_ident) - 1);
-    conf = find_address_conf(client_p->host, non_ident,
-                             &client_p->connection->ip,
-                             client_p->connection->aftype,
+    conf = find_address_conf(client_p->host, non_ident, &client_p->ip,
                              client_p->connection->password);
   }
 
-  if (!conf)
+  if (conf == NULL)
     return NOT_AUTHORIZED;
 
   assert(IsConfClient(conf) || IsConfKill(conf));
 
-  if (IsConfClient(conf))
+  if (IsConfKill(conf))
   {
-    if (IsConfRedir(conf))
-    {
-      sendto_one_numeric(client_p, &me, RPL_REDIR,
-                         conf->name ? conf->name : "",
-                         conf->port);
-      return NOT_AUTHORIZED;
-    }
-
-    if (IsConfDoSpoofIp(conf))
-    {
-      if (IsConfSpoofNotice(conf))
-        sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE, "%s spoofing: %s as %s",
-                             client_p->name, client_p->host, conf->name);
-
-      strlcpy(client_p->host, conf->name, sizeof(client_p->host));
-    }
-
-    return attach_iline(client_p, conf);
+    sendto_one_notice(client_p, &me, ":*** Banned: %s", conf->reason);
+    return BANNED_CLIENT;
   }
 
-  sendto_one_notice(client_p, &me, ":*** Banned: %s", conf->reason);
-  return BANNED_CLIENT;
+  if (IsConfRedir(conf))
+  {
+    sendto_one_numeric(client_p, &me, RPL_REDIR,
+                       conf->name ? conf->name : "",
+                       conf->port);
+    return NOT_AUTHORIZED;
+  }
+
+  if (IsConfDoSpoofIp(conf))
+  {
+    if (IsConfSpoofNotice(conf))
+      sendto_realops_flags(UMODE_SERVNOTICE, L_ADMIN, SEND_NOTICE, "%s spoofing: %s as %s",
+                           client_p->name, client_p->host, conf->name);
+
+    strlcpy(client_p->host, conf->name, sizeof(client_p->host));
+  }
+
+  return attach_iline(client_p, conf);
 }
 
 /* check_client()
@@ -414,15 +400,15 @@ conf_detach(struct Client *client_p, enum maskitem_type type)
     free_dlink_node(node);
 
     if (conf->type == CONF_CLIENT)
-      remove_from_cidr_check(&client_p->connection->ip, conf->class);
+      class_ip_limit_remove(conf->class, &client_p->ip);
 
-    if (--conf->class->ref_count == 0 && conf->class->active == 0)
+    if (--conf->class->ref_count == 0 && conf->class->active == false)
     {
       class_free(conf->class);
       conf->class = NULL;
     }
 
-    if (--conf->ref_count == 0 && conf->active == 0)
+    if (--conf->ref_count == 0 && conf->active == false)
       conf_free(conf);
   }
 }
@@ -440,8 +426,7 @@ conf_attach(struct Client *client_p, struct MaskItem *conf)
     return 1;
 
   if (conf->type == CONF_CLIENT)
-    if (cidr_limit_reached(IsConfExemptLimits(conf),
-                           &client_p->connection->ip, conf->class))
+    if (class_ip_limit_add(conf->class, &client_p->ip, IsConfExemptLimits(conf)) == true)
       return TOO_MANY;    /* Already at maximum allowed */
 
   conf->class->ref_count++;
@@ -533,14 +518,14 @@ operator_find(const struct Client *who, const char *name)
                 return conf;
             break;
           case HM_IPV4:
-            if (who->connection->aftype == AF_INET)
-              if (match_ipv4(&who->connection->ip, &conf->addr, conf->bits))
+            if (who->ip.ss.ss_family == AF_INET)
+              if (match_ipv4(&who->ip, conf->addr, conf->bits))
                 if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
                   return conf;
             break;
           case HM_IPV6:
-            if (who->connection->aftype == AF_INET6)
-              if (match_ipv6(&who->connection->ip, &conf->addr, conf->bits))
+            if (who->ip.ss.ss_family == AF_INET6)
+              if (match_ipv6(&who->ip, conf->addr, conf->bits))
                 if (!conf->class->max_total || conf->class->ref_count < conf->class->max_total)
                   return conf;
             break;
@@ -573,18 +558,12 @@ set_default_conf(void)
 
   ConfigServerInfo.network_name = xstrdup(NETWORK_NAME_DEFAULT);
   ConfigServerInfo.network_desc = xstrdup(NETWORK_DESC_DEFAULT);
-
-  memset(&ConfigServerInfo.ip, 0, sizeof(ConfigServerInfo.ip));
-  ConfigServerInfo.specific_ipv4_vhost = 0;
-  memset(&ConfigServerInfo.ip6, 0, sizeof(ConfigServerInfo.ip6));
-  ConfigServerInfo.specific_ipv6_vhost = 0;
-
   ConfigServerInfo.default_max_clients = MAXCLIENTS_MAX;
   ConfigServerInfo.max_nick_length = 9;
   ConfigServerInfo.max_topic_length = 80;
   ConfigServerInfo.hub = 0;
 
-  log_del_all();
+  log_iterate(log_free);
 
   ConfigLog.use_logging = 1;
 
@@ -622,8 +601,6 @@ set_default_conf(void)
   ConfigGeneral.kline_min_cidr = 16;
   ConfigGeneral.kline_min_cidr6 = 48;
   ConfigGeneral.invisible_on_connect = 1;
-  ConfigGeneral.tkline_expire_notices = 1;
-  ConfigGeneral.ignore_bogus_ts = 0;
   ConfigGeneral.disable_auth = 0;
   ConfigGeneral.kill_chase_time_limit = 90;
   ConfigGeneral.default_floodcount = 8;
@@ -705,9 +682,9 @@ read_conf(FILE *file)
  * called as a result of the server receiving a HUP signal.
  */
 void
-conf_rehash(int sig)
+conf_rehash(bool sig)
 {
-  if (sig)
+  if (sig == true)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Got signal SIGHUP, reloading configuration file(s)");
@@ -718,7 +695,7 @@ conf_rehash(int sig)
 
   /* don't close listeners until we know we can go ahead with the rehash */
 
-  read_conf_files(0);
+  read_conf_files(false);
 
   load_conf_modules();
   check_conf_klines();
@@ -754,9 +731,8 @@ lookup_confhost(struct MaskItem *conf)
 
   assert(res);
 
-  memcpy(&conf->addr, res->ai_addr, res->ai_addrlen);
-  conf->addr.ss_len = res->ai_addrlen;
-  conf->addr.ss.ss_family = res->ai_family;
+  memcpy(conf->addr, res->ai_addr, res->ai_addrlen);
+  conf->addr->ss_len = res->ai_addrlen;
 
   freeaddrinfo(res);
 }
@@ -769,10 +745,10 @@ lookup_confhost(struct MaskItem *conf)
  * side effects	- none
  */
 int
-conf_connect_allowed(struct irc_ssaddr *addr, int aftype)
+conf_connect_allowed(struct irc_ssaddr *addr)
 {
   struct ip_entry *ip_found = NULL;
-  const struct MaskItem *conf = find_dline_conf(addr, aftype);
+  const struct MaskItem *conf = find_dline_conf(addr);
 
   if (conf)
   {
@@ -782,9 +758,9 @@ conf_connect_allowed(struct irc_ssaddr *addr, int aftype)
     return BANNED_CLIENT;
   }
 
-  ip_found = ipcache_find_or_add_address(addr);
+  ip_found = ipcache_record_find_or_add(addr);
 
-  if ((CurrentTime - ip_found->last_attempt) < ConfigGeneral.throttle_time)
+  if ((event_base->time.sec_monotonic - ip_found->last_attempt) < ConfigGeneral.throttle_time)
   {
     if (ip_found->connection_count >= ConfigGeneral.throttle_count)
       return TOO_FAST;
@@ -794,7 +770,7 @@ conf_connect_allowed(struct irc_ssaddr *addr, int aftype)
   else
     ip_found->connection_count = 1;
 
-  ip_found->last_attempt = CurrentTime;
+  ip_found->last_attempt = event_base->time.sec_monotonic;
   return 0;
 }
 
@@ -813,66 +789,6 @@ cleanup_tklines(void *unused)
   resv_expire();
 }
 
-/* oper_privs_as_string()
- *
- * inputs        - pointer to client_p
- * output        - pointer to static string showing oper privs
- * side effects  - return as string, the oper privs as derived from port
- */
-static const struct oper_flags
-{
-  const unsigned int flag;
-  const unsigned char c;
-} flag_table[] = {
-  { OPER_FLAG_ADMIN,          'A' },
-  { OPER_FLAG_CLOSE,          'B' },
-  { OPER_FLAG_CONNECT,        'C' },
-  { OPER_FLAG_CONNECT_REMOTE, 'D' },
-  { OPER_FLAG_DIE,            'E' },
-  { OPER_FLAG_DLINE,          'F' },
-  { OPER_FLAG_GLOBOPS,        'G' },
-  { OPER_FLAG_JOIN_RESV,      'H' },
-  { OPER_FLAG_KILL,           'I' },
-  { OPER_FLAG_KILL_REMOTE,    'J' },
-  { OPER_FLAG_KLINE,          'K' },
-  { OPER_FLAG_LOCOPS,         'L' },
-  { OPER_FLAG_MODULE,         'M' },
-  { OPER_FLAG_NICK_RESV,      'N' },
-  { OPER_FLAG_OPME,           'O' },
-  { OPER_FLAG_REHASH,         'P' },
-  { OPER_FLAG_REMOTEBAN,      'Q' },
-  { OPER_FLAG_RESTART,        'R' },
-  { OPER_FLAG_RESV,           'S' },
-  { OPER_FLAG_SET,            'T' },
-  { OPER_FLAG_SQUIT,          'U' },
-  { OPER_FLAG_SQUIT_REMOTE,   'V' },
-  { OPER_FLAG_UNDLINE,        'W' },
-  { OPER_FLAG_UNKLINE,        'X' },
-  { OPER_FLAG_UNRESV,         'Y' },
-  { OPER_FLAG_UNXLINE,        'Z' },
-  { OPER_FLAG_WALLOPS,        'a' },
-  { OPER_FLAG_XLINE,          'b' },
-  { 0, '\0' }
-};
-
-const char *
-oper_privs_as_string(const unsigned int flags)
-{
-  static char buf[sizeof(flag_table) / sizeof(flag_table[0])];
-  char *p = buf;
-
-  for (const struct oper_flags *tab = flag_table; tab->flag; ++tab)
-    if (flags & tab->flag)
-      *p++ = tab->c;
-
-  if (p == buf)
-    *p++ = '0';
-
-  *p = '\0';
-
-  return buf;
-}
-
 /*
  * Input: A client to find the active operator {} name for.
  * Output: The nick!user@host{oper} of the oper.
@@ -941,7 +857,7 @@ clear_out_old_conf(void)
     {
       struct MaskItem *conf = node->data;
 
-      conf->active = 0;
+      conf->active = false;
       dlinkDelete(&conf->node, *iterator);
 
       if (!conf->ref_count)
@@ -1012,11 +928,11 @@ clear_out_old_conf(void)
 }
 
 static void
-conf_handle_tls(int cold)
+conf_handle_tls(bool cold)
 {
-  if (!tls_new_cred())
+  if (tls_new_cred() == false)
   {
-    if (cold)
+    if (cold == true)
     {
       ilog(LOG_TYPE_IRCD, "Error while initializing TLS");
       exit(EXIT_FAILURE);
@@ -1037,7 +953,7 @@ conf_handle_tls(int cold)
  * side effects - read all conf files needed, ircd.conf kline.conf etc.
  */
 void
-read_conf_files(int cold)
+read_conf_files(bool cold)
 {
   const char *filename = NULL;
   char chanmodes[IRCD_BUFSIZE] = "";
@@ -1056,7 +972,7 @@ read_conf_files(int cold)
 
   if ((conf_parser_ctx.conf_file = fopen(filename, "r")) == NULL)
   {
-    if (cold)
+    if (cold == true)
     {
       ilog(LOG_TYPE_IRCD, "Unable to read configuration file '%s': %s",
            filename, strerror(errno));
@@ -1071,13 +987,13 @@ read_conf_files(int cold)
     }
   }
 
-  if (!cold)
+  if (cold == false)
     clear_out_old_conf();
 
   read_conf(conf_parser_ctx.conf_file);
   fclose(conf_parser_ctx.conf_file);
 
-  log_reopen_all();
+  log_iterate(log_reopen);
   conf_handle_tls(cold);
 
   isupport_add("NICKLEN", NULL, ConfigServerInfo.max_nick_length);
@@ -1106,7 +1022,7 @@ read_conf_files(int cold)
 void
 conf_add_class_to_conf(struct MaskItem *conf, const char *name)
 {
-  if (EmptyString(name) || (conf->class = class_find(name, 1)) == NULL)
+  if (EmptyString(name) || (conf->class = class_find(name, true)) == NULL)
   {
     conf->class = class_default;
 
@@ -1190,7 +1106,7 @@ valid_tkline(const char *data, const int minutes)
    * If the incoming time is in seconds convert it to minutes for the purpose
    * of this calculation
    */
-  if (!minutes)
+  if (minutes == 0)
     result = result / 60;
 
   if (result > MAX_TDKLINE_TIME)
@@ -1207,7 +1123,7 @@ valid_tkline(const char *data, const int minutes)
  * outputs      - 1 if valid, else 0
  * side effects - none
  */
-int
+bool
 valid_wild_card_simple(const char *data)
 {
   const unsigned char *p = (const unsigned char *)data;
@@ -1220,18 +1136,18 @@ valid_wild_card_simple(const char *data)
     {
       ++p;
       if (++nonwild >= ConfigGeneral.min_nonwildcard_simple)
-        return 1;
+        return true;
     }
     else if (!IsMWildChar(tmpch))
     {
       if (++nonwild >= ConfigGeneral.min_nonwildcard_simple)
-        return 1;
+        return true;
     }
     else
       ++wild;
   }
 
-  return !wild;
+  return wild == 0;
 }
 
 /* valid_wild_card()
@@ -1242,7 +1158,7 @@ valid_wild_card_simple(const char *data)
  * output       - 0 if not valid, 1 if valid
  * side effects - NOTICE is given to source_p if warn is 1
  */
-int
+bool
 valid_wild_card(int count, ...)
 {
   unsigned char tmpch = '\0';
@@ -1280,93 +1196,14 @@ valid_wild_card(int count, ...)
         if (++nonwild >= ConfigGeneral.min_nonwildcard)
         {
           va_end(args);
-          return 1;
+          return true;
         }
       }
     }
   }
 
   va_end(args);
-  return 0;
-}
-
-/* find_user_host()
- *
- * inputs       - pointer to client placing kline
- *              - pointer to user_host_or_nick
- *              - pointer to user buffer
- *              - pointer to host buffer
- * output       - 0 if not ok to kline, 1 to kline i.e. if valid user host
- * side effects -
- */
-static int
-find_user_host(struct Client *source_p, char *user_host_or_nick,
-               char *luser, char *lhost)
-{
-  struct Client *target_p = NULL;
-  char *hostp = NULL;
-
-  if (lhost == NULL)
-  {
-    strlcpy(luser, user_host_or_nick, USERLEN*4 + 1);
-    return 1;
-  }
-
-  if ((hostp = strchr(user_host_or_nick, '@')) || *user_host_or_nick == '*')
-  {
-    /* Explicit user@host mask given */
-    if (hostp)                            /* I'm a little user@host */
-    {
-      *(hostp++) = '\0';                       /* short and squat */
-
-      if (*user_host_or_nick)
-        strlcpy(luser, user_host_or_nick, USERLEN*4 + 1); /* here is my user */
-      else
-        strcpy(luser, "*");
-
-      if (*hostp)
-        strlcpy(lhost, hostp, HOSTLEN + 1);    /* here is my host */
-      else
-        strcpy(lhost, "*");
-    }
-    else
-    {
-      luser[0] = '*';             /* no @ found, assume its *@somehost */
-      luser[1] = '\0';
-      strlcpy(lhost, user_host_or_nick, HOSTLEN*4 + 1);
-    }
-
-    return 1;
-  }
-  else
-  {
-    /* Try to find user@host mask from nick */
-    /* Okay to use source_p as the first param, because source_p == client_p */
-    if ((target_p =
-        find_chasing(source_p, user_host_or_nick)) == NULL)
-      return 0;  /* find_chasing sends ERR_NOSUCHNICK */
-
-    if (HasFlag(target_p, FLAGS_EXEMPTKLINE))
-    {
-      if (IsClient(source_p))
-        sendto_one_notice(source_p, &me, ":%s is E-lined", target_p->name);
-      return 0;
-    }
-
-    /*
-     * Turn the "user" bit into "*user", blow away '~'
-     * if found in original user name (non-idented)
-     */
-    strlcpy(luser, target_p->username, USERLEN*4 + 1);
-
-    if (target_p->username[0] == '~')
-      luser[0] = '*';
-
-    strlcpy(lhost, target_p->sockhost, HOSTLEN*4 + 1);
-    return 1;
-  }
-
-  return 0;
+  return false;
 }
 
 /* XXX should this go into a separate file ? -Dianora */
@@ -1399,98 +1236,93 @@ find_user_host(struct Client *source_p, char *user_host_or_nick,
  *
  * - Dianora
  */
-int
-parse_aline(const char *cmd, struct Client *source_p,
-            int parc, char **parv,
-            char **up_p, char **h_p, uintmax_t *tkline_time,
-            char **target_server, char **reason)
+bool
+parse_aline(const char *cmd, struct Client *source_p, int parc, char **parv, struct aline_ctx *aline)
 {
-  uintmax_t found_tkline_time=0;
   static char default_reason[] = CONF_NOREASON;
-  static char user[USERLEN*4+1];
-  static char host[HOSTLEN*4+1];
+  static char user[USERLEN * 2 + 1];
+  static char host[HOSTLEN * 2 + 1];
 
-  parv++;
-  parc--;
+  ++parv;
+  --parc;
 
-  found_tkline_time = valid_tkline(*parv, TK_MINUTES);
-
-  if (found_tkline_time)
+  if (aline->add == true && (aline->duration = valid_tkline(*parv, TK_MINUTES)))
   {
-    parv++;
-    parc--;
-
-    if (tkline_time)
-      *tkline_time = found_tkline_time;
-    else
-    {
-      sendto_one_notice(source_p, &me, ":temp_line not supported by %s", cmd);
-      return 0;
-    }
+    ++parv;
+    --parc;
   }
 
   if (parc == 0)
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, cmd);
-    return 0;
+    return false;
   }
 
-  if (h_p == NULL)
-    *up_p = *parv;
+  if (aline->simple_mask == true)
+  {
+    aline->mask = *parv;
+    aline->user = NULL;
+    aline->host = NULL;
+  }
   else
   {
-    if (find_user_host(source_p, *parv, user, host) == 0)
-      return 0;
+    struct split_nuh_item nuh;
 
-    *up_p = user;
-    *h_p = host;
+    nuh.nuhmask  = *parv;
+    nuh.nickptr  = NULL;
+    nuh.userptr  = user;
+    nuh.hostptr  = host;
+
+    nuh.nicksize = 0;
+    nuh.usersize = sizeof(user);
+    nuh.hostsize = sizeof(host);
+
+    split_nuh(&nuh);
+
+    aline->mask = NULL;
+    aline->user = user;
+    aline->host = host;
   }
 
-  parc--;
-  parv++;
+  ++parv;
+  --parc;
 
   if (parc)
   {
     if (irccmp(*parv, "ON") == 0)
     {
-      parc--;
-      parv++;
+      ++parv;
+      --parc;
 
       if (!HasOFlag(source_p, OPER_FLAG_REMOTEBAN))
       {
         sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "remoteban");
-        return 0;
+        return false;
       }
 
       if (parc == 0 || EmptyString(*parv))
       {
         sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, cmd);
-        return 0;
+        return false;
       }
 
-      *target_server = *parv;
-      parc--;
-      parv++;
+      aline->server = *parv;
+      ++parv;
+      --parc;
     }
     else
-    {
-      /* Make sure target_server *is* NULL if no ON server found
-       * caller probably NULL'd it first, but no harm to do it again -db
-       */
-      if (target_server)
-        *target_server = NULL;
-    }
+      aline->server = NULL;
   }
 
-  if (reason)
+  if (aline->add == true)
   {
-    if (parc && !EmptyString(*parv))
-      *reason = *parv;
+    if (parc == 0 || EmptyString(*parv))
+      aline->reason = default_reason;
     else
-      *reason = default_reason;
+      aline->reason = *parv;
   }
 
-  return 1;
+  return true;
 }
 
 /* match_conf_password()
@@ -1500,20 +1332,20 @@ parse_aline(const char *cmd, struct Client *source_p,
  * output       - 1 or 0 if match
  * side effects - none
  */
-int
+bool
 match_conf_password(const char *password, const struct MaskItem *conf)
 {
   const char *encr = NULL;
 
   if (EmptyString(password) || EmptyString(conf->passwd))
-    return 0;
+    return false;
 
   if (conf->flags & CONF_FLAGS_ENCRYPTED)
     encr = crypt(password, conf->passwd);
   else
     encr = password;
 
-  return encr && !strcmp(encr, conf->passwd);
+  return encr && strcmp(encr, conf->passwd) == 0;
 }
 
 /*
@@ -1598,7 +1430,7 @@ split_nuh(struct split_nuh_item *const iptr)
     else
     {
       /* No @ found */
-      if (!iptr->nickptr || strpbrk(iptr->nuhmask, ".:"))
+      if (iptr->nickptr == NULL || strpbrk(iptr->nuhmask, ".:"))
         strlcpy(iptr->hostptr, iptr->nuhmask, iptr->hostsize);
       else
         strlcpy(iptr->nickptr, iptr->nuhmask, iptr->nicksize);
