@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (C) 1996-2009 by Andrew Church <achurch@achurch.org>
- *  Copyright (c) 2012-2018 ircd-hybrid development team
+ *  Copyright (c) 2012-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file conf_db.c
  * \brief Includes file utilities for database handling
- * \version $Id: conf_db.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: conf_db.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 
@@ -50,7 +50,7 @@ get_file_version(struct dbFILE *f)
 {
   uint32_t version = 0;
 
-  if (read_uint32(&version, f) == -1)
+  if (read_uint32(&version, f) == false)
   {
     ilog(LOG_TYPE_IRCD, "Error reading version number on %s: %s",
          f->filename, strerror(errno));
@@ -70,19 +70,19 @@ get_file_version(struct dbFILE *f)
 /*! \brief Write the current version number to the file.
  * \param f dbFile Struct Member
  * \param version Database version
- * \return 0 on error, 1 on success.
+ * \return false on error, true on success.
  */
 static int
 write_file_version(struct dbFILE *f, uint32_t version)
 {
-  if (write_uint32(version, f) == -1)
+  if (write_uint32(version, f) == false)
   {
     ilog(LOG_TYPE_IRCD, "Error writing version number on %s",
          f->filename);
-    return 0;
+    return false;
   }
 
-  return 1;
+  return true;
 }
 
 /*! \brief Open the database for reading
@@ -93,14 +93,13 @@ static struct dbFILE *
 open_db_read(const char *filename)
 {
   struct dbFILE *f = xcalloc(sizeof(*f));
-  FILE *fp = NULL;
 
   strlcpy(f->filename, filename, sizeof(f->filename));
 
   f->mode = 'r';
-  fp = fopen(f->filename, "rb");
+  f->fp = fopen(f->filename, "rb");
 
-  if (!fp)
+  if (f->fp == NULL)
   {
     int errno_save = errno;
 
@@ -112,7 +111,6 @@ open_db_read(const char *filename)
     return NULL;
   }
 
-  f->fp = fp;
   return f;
 }
 
@@ -125,7 +123,6 @@ static struct dbFILE *
 open_db_write(const char *filename, uint32_t version)
 {
   struct dbFILE *f = xcalloc(sizeof(*f));
-  int fd = 0;
 
   strlcpy(f->filename, filename, sizeof(f->filename));
 
@@ -134,7 +131,7 @@ open_db_write(const char *filename, uint32_t version)
 
   snprintf(f->tempname, sizeof(f->tempname), "%s.new", filename);
 
-  if (f->tempname[0] == '\0' || !strcmp(f->tempname, filename))
+  if (f->tempname[0] == '\0' || strcmp(f->tempname, filename) == 0)
   {
     ilog(LOG_TYPE_IRCD, "Opening database file %s for write: Filename too long",
          filename);
@@ -146,19 +143,25 @@ open_db_write(const char *filename, uint32_t version)
   remove(f->tempname);
 
   /* Use open() to avoid people sneaking a new file in under us */
-  fd = open(f->tempname, O_WRONLY | O_CREAT | O_EXCL, 0666);
+  /*
+   * TBD: replace with C11 fopen "x" mode
+   */
+  int fd = open(f->tempname, O_WRONLY | O_CREAT | O_EXCL, 0666);
   if (fd >= 0)
     f->fp = fdopen(fd, "wb");
 
-  if (!f->fp || !write_file_version(f, version))
+  if (f->fp == NULL || write_file_version(f, version) == false)
   {
     int errno_save = errno;
-    static int walloped = 0;
+    static bool walloped = false;
 
-    if (!walloped++)
+    if (walloped == false)
+    {
+      walloped = true;
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "Cannot create temporary database file %s",
                            f->tempname);
+    }
 
     errno = errno_save;
     ilog(LOG_TYPE_IRCD, "Cannot create temporary database file %s",
@@ -233,24 +236,22 @@ restore_db(struct dbFILE *f)
  * fails.
  *
  * \param dbFile struct
- * \return -1 on error, 0 on success.
+ * \return false on error, true on success.
  */
-static int
+static bool
 close_db(struct dbFILE *f)
 {
-  int res;
-
-  if (!f->fp)
+  if (f->fp == NULL)
   {
     errno = EINVAL;
-    return -1;
+    return false;
   }
 
-  res = fclose(f->fp);
+  int res = fclose(f->fp);
   f->fp = NULL;
 
-  if (res != 0)
-    return -1;
+  if (res)
+    return false;
 
   if (f->mode == 'w' && f->tempname[0] && strcmp(f->tempname, f->filename))
   {
@@ -269,7 +270,7 @@ close_db(struct dbFILE *f)
   }
 
   xfree(f);
-  return 0;
+  return true;
 }
 
 /*
@@ -285,44 +286,44 @@ close_db(struct dbFILE *f)
  *
  * \param ret 16bit integer to read
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 read_uint16(uint16_t *ret, struct dbFILE *f)
 {
   int c1 = fgetc(f->fp);
   int c2 = fgetc(f->fp);
 
   if (c1 == EOF || c2 == EOF)
-    return -1;
+    return false;
 
   *ret = c1 << 8 | c2;
-  return 0;
+  return true;
 }
 
 /*! \brief Write a unsigned 16bit integer
  *
  * \param val 16bit integer to write
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 write_uint16(uint16_t val, struct dbFILE *f)
 {
   if (fputc((val >> 8) & 0xFF, f->fp) == EOF ||
-      fputc(val        & 0xFF, f->fp) == EOF)
-    return -1;
+      fputc((val)      & 0xFF, f->fp) == EOF)
+    return false;
 
-  return 0;
+  return true;
 }
 
 /*! \brief Read a unsigned 32bit integer
  *
  * \param ret unsigned 32bit integer to read
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 read_uint32(uint32_t *ret, struct dbFILE *f)
 {
   int c1 = fgetc(f->fp);
@@ -331,10 +332,10 @@ read_uint32(uint32_t *ret, struct dbFILE *f)
   int c4 = fgetc(f->fp);
 
   if (c1 == EOF || c2 == EOF || c3 == EOF || c4 == EOF)
-    return -1;
+    return false;
 
   *ret = c1 << 24 | c2 << 16 | c3 << 8 | c4;
-  return 0;
+  return true;
 }
 
 
@@ -342,29 +343,29 @@ read_uint32(uint32_t *ret, struct dbFILE *f)
  *
  * \param val unsigned 32bit integer to write
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 write_uint32(uint32_t val, struct dbFILE *f)
 {
   if (fputc((val >> 24) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >> 16) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >>  8) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val)       & 0xFF, f->fp) == EOF)
-    return -1;
-  return 0;
+    return false;
+  return true;
 }
 
 /*! \brief Read a unsigned 64bit integer
  *
  * \param ret unsigned 64bit integer to read
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 read_uint64(uint64_t *ret, struct dbFILE *f)
 {
   int64_t c1 = fgetc(f->fp);
@@ -378,11 +379,11 @@ read_uint64(uint64_t *ret, struct dbFILE *f)
 
   if (c1 == EOF || c2 == EOF || c3 == EOF || c4 == EOF ||
       c5 == EOF || c6 == EOF || c7 == EOF || c8 == EOF)
-    return -1;
+    return false;
 
   *ret = c1 << 56 | c2 << 48 | c3 << 40 | c4 << 32 |
          c5 << 24 | c6 << 16 | c7 <<  8 | c8;
-  return 0;
+  return true;
 }
 
 
@@ -390,104 +391,99 @@ read_uint64(uint64_t *ret, struct dbFILE *f)
  *
  * \param val unsigned 64bit integer to write
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 write_uint64(uint64_t val, struct dbFILE *f)
 {
   if (fputc((val >> 56) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >> 48) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >> 40) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >> 32) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >> 24) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >> 16) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val >>  8) & 0xFF, f->fp) == EOF)
-    return -1;
+    return false;
   if (fputc((val)       & 0xFF, f->fp) == EOF)
-    return -1;
-  return 0;
+    return false;
+  return true;
 }
 
 /*! \brief Read String
  *
  * \param ret string
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 read_string(char **ret, struct dbFILE *f)
 {
-  char *s = NULL;
   uint32_t len = 0;
 
-  if (read_uint32(&len, f) < 0)
-    return -1;
+  if (read_uint32(&len, f) == false)
+    return false;
 
   if (len == 0)
   {
     *ret = NULL;
-    return 0;
+    return true;
   }
 
-  s = xcalloc(len);
-
+  char *s = xcalloc(len);
   if (len != fread(s, 1, len, f->fp))
   {
     xfree(s);
-    return -1;
+    return false;
   }
 
   *ret = s;
-  return 0;
+  return true;
 }
 
 /*! \brief Write String
  *
  * \param s string
  * \param dbFile struct
- * \return -1 on error, 0 otherwise.
+ * \return false on error, true otherwise.
  */
-int
+bool
 write_string(const char *s, struct dbFILE *f)
 {
-  uint32_t len = 0;
-
-  if (!s)
+  if (s == NULL)
     return write_uint32(0, f);
 
-  len = strlen(s);
-
+  uint32_t len = strlen(s);
   if (len > 4294967294)
     len = 4294967294;
-  if (write_uint32(len + 1, f) < 0)
-    return -1;
+  if (write_uint32(len + 1, f) == false)
+    return false;
   if (len > 0 && fwrite(s, 1, len, f->fp) != len)
-    return -1;
+    return false;
   if (fputc(0, f->fp) == EOF)
-    return -1;
+    return false;
 
-  return 0;
+  return true;
 }
 
 #define SAFE_READ(x) do {                             \
-    if ((x) < 0) {                                    \
+    if ((x) == false) {                               \
         break;                                        \
     }                                                 \
-} while (0)
+} while (false)
 
 #define SAFE_WRITE(x,db) do {                         \
-    if ((x) < 0) {                                    \
+    if ((x) == false) {                               \
         restore_db(f);                                \
         ilog(LOG_TYPE_IRCD, "Write error on %s", db); \
         return;                                       \
     }                                                 \
-} while (0)
+} while (false)
 
 void
 save_kline_database(const char *filename)
@@ -497,7 +493,7 @@ save_kline_database(const char *filename)
   struct dbFILE *f = NULL;
   dlink_node *ptr = NULL;
 
-  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "w", KLINE_DB_VERSION)) == NULL)
     return;
 
   for (i = 0; i < ATABLE_SIZE; ++i)
@@ -546,7 +542,7 @@ load_kline_database(const char *filename)
   uint64_t field_4 = 0;
   uint64_t field_5 = 0;
 
-  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "r", KLINE_DB_VERSION)) == NULL)
     return;
 
   if (get_file_version(f) < 1)
@@ -587,7 +583,7 @@ save_dline_database(const char *filename)
   struct dbFILE *f = NULL;
   dlink_node *ptr = NULL;
 
-  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "w", KLINE_DB_VERSION)) == NULL)
     return;
 
   for (i = 0; i < ATABLE_SIZE; ++i)
@@ -634,7 +630,7 @@ load_dline_database(const char *filename)
   uint64_t field_3 = 0;
   uint64_t field_4 = 0;
 
-  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "r", KLINE_DB_VERSION)) == NULL)
     return;
 
   if (get_file_version(f) < 1)
@@ -673,14 +669,14 @@ save_resv_database(const char *filename)
   dlink_node *node = NULL;
   const struct ResvItem *resv = NULL;
 
-  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "w", KLINE_DB_VERSION)) == NULL)
     return;
 
   DLINK_FOREACH(node, resv_chan_get_list()->head)
   {
     resv = node->data;
 
-    if (resv->in_database)
+    if (resv->in_database == true)
       ++records;
   }
 
@@ -688,7 +684,7 @@ save_resv_database(const char *filename)
   {
     resv = node->data;
 
-    if (resv->in_database)
+    if (resv->in_database == true)
       ++records;
   }
 
@@ -698,7 +694,7 @@ save_resv_database(const char *filename)
   {
     resv = node->data;
 
-    if (!resv->in_database)
+    if (resv->in_database == false)
       continue;
 
     SAFE_WRITE(write_string(resv->mask, f), filename);
@@ -711,7 +707,7 @@ save_resv_database(const char *filename)
   {
     resv = node->data;
 
-    if (!resv->in_database)
+    if (resv->in_database == false)
       continue;
 
     SAFE_WRITE(write_string(resv->mask, f), filename);
@@ -734,7 +730,7 @@ load_resv_database(const char *filename)
   char *reason = NULL;
   struct ResvItem *resv = NULL;
 
-  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "r", KLINE_DB_VERSION)) == NULL)
     return;
 
   if (get_file_version(f) < 1)
@@ -752,12 +748,10 @@ load_resv_database(const char *filename)
     SAFE_READ(read_uint64(&tmp64_setat, f));
     SAFE_READ(read_uint64(&tmp64_hold, f));
 
-    if ((resv = resv_make(name, reason, NULL)) == NULL)
-      continue;
-
+    resv = resv_make(name, reason, NULL);
     resv->setat = tmp64_setat;
     resv->expire = tmp64_hold;
-    resv->in_database = 1;
+    resv->in_database = true;
 
     xfree(name);
     xfree(reason);
@@ -774,14 +768,14 @@ save_xline_database(const char *filename)
   dlink_node *ptr = NULL;
   struct GecosItem *gecos = NULL;
 
-  if (!(f = open_db(filename, "w", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "w", KLINE_DB_VERSION)) == NULL)
     return;
 
   DLINK_FOREACH(ptr, gecos_get_list()->head)
   {
     gecos = ptr->data;
 
-    if (gecos->in_database)
+    if (gecos->in_database == true)
       ++records;
   }
 
@@ -791,7 +785,7 @@ save_xline_database(const char *filename)
   {
     gecos = ptr->data;
 
-    if (!gecos->in_database)
+    if (gecos->in_database == false)
       continue;
 
     SAFE_WRITE(write_string(gecos->mask, f), filename);
@@ -814,7 +808,7 @@ load_xline_database(const char *filename)
   char *reason = NULL;
   struct GecosItem *gecos = NULL;
 
-  if (!(f = open_db(filename, "r", KLINE_DB_VERSION)))
+  if ((f = open_db(filename, "r", KLINE_DB_VERSION)) == NULL)
     return;
 
   if (get_file_version(f) < 1)
@@ -833,7 +827,7 @@ load_xline_database(const char *filename)
     SAFE_READ(read_uint64(&tmp64_hold, f));
 
     gecos = gecos_make();
-    gecos->in_database = 1;
+    gecos->in_database = true;
     gecos->mask = name;
     gecos->reason = reason;
     gecos->setat = tmp64_setat;
