@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2018 ircd-hybrid development team
+ *  Copyright (c) 1998-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_gecos.c
  * \brief Implements gecos {} block configuration management.
- * \version $Id: conf_gecos.c 8472 2018-04-03 12:54:41Z michael $
+ * \version $Id: conf_gecos.c 8971 2019-05-18 12:52:56Z michael $
  */
 
 #include "stdinc.h"
@@ -52,14 +52,18 @@ gecos_clear(void)
   {
     struct GecosItem *gecos = node->data;
 
-    if (gecos->in_database == 0)
-      gecos_delete(gecos);
+    if (gecos->in_database == false)
+      gecos_delete(gecos, false);
   }
 }
 
 void
-gecos_delete(struct GecosItem *gecos)
+gecos_delete(struct GecosItem *gecos, bool expired)
 {
+  if (expired == true)
+    sendto_realops_flags(UMODE_EXPIRATION, L_ALL, SEND_NOTICE, "Temporary X-line for [%s] expired",
+                         gecos->mask);
+
   dlinkDelete(&gecos->node, &gecos_list);
   xfree(gecos->mask);
   xfree(gecos->reason);
@@ -78,13 +82,16 @@ gecos_make(void)
 struct GecosItem *
 gecos_find(const char *name, int (*compare)(const char *, const char *))
 {
-  dlink_node *node;
+  dlink_node *node, *node_next;
 
-  DLINK_FOREACH(node, gecos_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, gecos_list.head)
   {
     struct GecosItem *gecos = node->data;
 
-    if (!compare(gecos->mask, name))
+    if (gecos->expire &&
+        (gecos->expire <= event_base->time.sec_real))
+      gecos_delete(gecos, true);
+    else if (compare(gecos->mask, name) == 0)
       return gecos;
   }
 
@@ -100,12 +107,8 @@ gecos_expire(void)
   {
     struct GecosItem *gecos = node->data;
 
-    if (gecos->expire == 0 || gecos->expire > CurrentTime)
-      continue;
-
-    if (ConfigGeneral.tkline_expire_notices)
-      sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "Temporary X-line for [%s] expired",
-                           gecos->mask);
-    gecos_delete(gecos);
+    if (gecos->expire &&
+        (gecos->expire <= event_base->time.sec_real))
+      gecos_delete(gecos, true);
   }
 }
