@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -30,6 +31,9 @@
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 #ifndef YY_YY_CONF_PARSER_H_INCLUDED
 # define YY_YY_CONF_PARSER_H_INCLUDED
 /* Debug traces.  */
@@ -84,24 +88,24 @@ extern int yydebug;
     ENCRYPTED = 294,
     EXCEED_LIMIT = 295,
     EXEMPT = 296,
-    FAILED_OPER_NOTICE = 297,
-    FLATTEN_LINKS = 298,
-    FLATTEN_LINKS_DELAY = 299,
-    FLATTEN_LINKS_FILE = 300,
-    GECOS = 301,
-    GENERAL = 302,
-    HIDDEN = 303,
-    HIDDEN_NAME = 304,
-    HIDE_CHANS = 305,
-    HIDE_IDLE = 306,
-    HIDE_IDLE_FROM_OPERS = 307,
-    HIDE_SERVER_IPS = 308,
-    HIDE_SERVERS = 309,
-    HIDE_SERVICES = 310,
-    HOST = 311,
-    HUB = 312,
-    HUB_MASK = 313,
-    IGNORE_BOGUS_TS = 314,
+    EXPIRATION = 297,
+    FAILED_OPER_NOTICE = 298,
+    FLATTEN_LINKS = 299,
+    FLATTEN_LINKS_DELAY = 300,
+    FLATTEN_LINKS_FILE = 301,
+    GECOS = 302,
+    GENERAL = 303,
+    HIDDEN = 304,
+    HIDDEN_NAME = 305,
+    HIDE_CHANS = 306,
+    HIDE_IDLE = 307,
+    HIDE_IDLE_FROM_OPERS = 308,
+    HIDE_SERVER_IPS = 309,
+    HIDE_SERVERS = 310,
+    HIDE_SERVICES = 311,
+    HOST = 312,
+    HUB = 313,
+    HUB_MASK = 314,
     INVISIBLE_ON_CONNECT = 315,
     INVITE_CLIENT_COUNT = 316,
     INVITE_CLIENT_TIME = 317,
@@ -128,85 +132,85 @@ extern int yydebug;
     MAX_BANS = 338,
     MAX_BANS_LARGE = 339,
     MAX_CHANNELS = 340,
-    MAX_GLOBAL = 341,
-    MAX_IDLE = 342,
-    MAX_INVITES = 343,
-    MAX_LOCAL = 344,
-    MAX_NICK_CHANGES = 345,
-    MAX_NICK_LENGTH = 346,
-    MAX_NICK_TIME = 347,
-    MAX_NUMBER = 348,
-    MAX_TARGETS = 349,
-    MAX_TOPIC_LENGTH = 350,
-    MAX_WATCH = 351,
-    MIN_IDLE = 352,
-    MIN_NONWILDCARD = 353,
-    MIN_NONWILDCARD_SIMPLE = 354,
-    MODULE = 355,
-    MODULES = 356,
-    MOTD = 357,
-    NAME = 358,
-    NEED_IDENT = 359,
-    NEED_PASSWORD = 360,
-    NETWORK_DESC = 361,
-    NETWORK_NAME = 362,
-    NICK = 363,
-    NO_OPER_FLOOD = 364,
-    NO_TILDE = 365,
-    NUMBER = 366,
-    NUMBER_PER_CIDR = 367,
-    NUMBER_PER_IP = 368,
-    OPER_ONLY_UMODES = 369,
-    OPER_UMODES = 370,
-    OPERATOR = 371,
-    OPERS_BYPASS_CALLERID = 372,
-    PACE_WAIT = 373,
-    PACE_WAIT_SIMPLE = 374,
-    PASSWORD = 375,
-    PATH = 376,
-    PING_COOKIE = 377,
-    PING_TIME = 378,
-    PORT = 379,
-    QSTRING = 380,
-    RANDOM_IDLE = 381,
-    REASON = 382,
-    REDIRPORT = 383,
-    REDIRSERV = 384,
-    REHASH = 385,
-    REMOTE = 386,
-    REMOTEBAN = 387,
-    RESV = 388,
-    RESV_EXEMPT = 389,
-    RSA_PRIVATE_KEY_FILE = 390,
-    SECONDS = 391,
-    MINUTES = 392,
-    HOURS = 393,
-    DAYS = 394,
-    WEEKS = 395,
-    MONTHS = 396,
-    YEARS = 397,
-    SEND_PASSWORD = 398,
-    SENDQ = 399,
-    SERVERHIDE = 400,
-    SERVERINFO = 401,
-    SHORT_MOTD = 402,
-    SPOOF = 403,
-    SPOOF_NOTICE = 404,
-    SQUIT = 405,
-    SSL_CERTIFICATE_FILE = 406,
-    SSL_CERTIFICATE_FINGERPRINT = 407,
-    SSL_CONNECTION_REQUIRED = 408,
-    SSL_DH_ELLIPTIC_CURVE = 409,
-    SSL_DH_PARAM_FILE = 410,
-    SSL_MESSAGE_DIGEST_ALGORITHM = 411,
-    STATS_E_DISABLED = 412,
-    STATS_I_OPER_ONLY = 413,
-    STATS_K_OPER_ONLY = 414,
-    STATS_M_OPER_ONLY = 415,
-    STATS_O_OPER_ONLY = 416,
-    STATS_P_OPER_ONLY = 417,
-    STATS_U_OPER_ONLY = 418,
-    T_ALL = 419,
+    MAX_IDLE = 341,
+    MAX_INVITES = 342,
+    MAX_NICK_CHANGES = 343,
+    MAX_NICK_LENGTH = 344,
+    MAX_NICK_TIME = 345,
+    MAX_NUMBER = 346,
+    MAX_TARGETS = 347,
+    MAX_TOPIC_LENGTH = 348,
+    MAX_WATCH = 349,
+    MIN_IDLE = 350,
+    MIN_NONWILDCARD = 351,
+    MIN_NONWILDCARD_SIMPLE = 352,
+    MODULE = 353,
+    MODULES = 354,
+    MOTD = 355,
+    NAME = 356,
+    NEED_IDENT = 357,
+    NEED_PASSWORD = 358,
+    NETWORK_DESC = 359,
+    NETWORK_NAME = 360,
+    NICK = 361,
+    NO_OPER_FLOOD = 362,
+    NO_TILDE = 363,
+    NUMBER = 364,
+    NUMBER_PER_CIDR = 365,
+    NUMBER_PER_IP_GLOBAL = 366,
+    NUMBER_PER_IP_LOCAL = 367,
+    OPER_ONLY_UMODES = 368,
+    OPER_UMODES = 369,
+    OPERATOR = 370,
+    OPERS_BYPASS_CALLERID = 371,
+    PACE_WAIT = 372,
+    PACE_WAIT_SIMPLE = 373,
+    PASSWORD = 374,
+    PATH = 375,
+    PING_COOKIE = 376,
+    PING_TIME = 377,
+    PORT = 378,
+    QSTRING = 379,
+    RANDOM_IDLE = 380,
+    REASON = 381,
+    REDIRPORT = 382,
+    REDIRSERV = 383,
+    REHASH = 384,
+    REMOTE = 385,
+    REMOTEBAN = 386,
+    RESV = 387,
+    RESV_EXEMPT = 388,
+    RSA_PRIVATE_KEY_FILE = 389,
+    SECONDS = 390,
+    MINUTES = 391,
+    HOURS = 392,
+    DAYS = 393,
+    WEEKS = 394,
+    MONTHS = 395,
+    YEARS = 396,
+    SEND_PASSWORD = 397,
+    SENDQ = 398,
+    SERVERHIDE = 399,
+    SERVERINFO = 400,
+    SHORT_MOTD = 401,
+    SPOOF = 402,
+    SPOOF_NOTICE = 403,
+    SQUIT = 404,
+    SSL_CERTIFICATE_FILE = 405,
+    SSL_CERTIFICATE_FINGERPRINT = 406,
+    SSL_CONNECTION_REQUIRED = 407,
+    SSL_DH_ELLIPTIC_CURVE = 408,
+    SSL_DH_PARAM_FILE = 409,
+    SSL_MESSAGE_DIGEST_ALGORITHM = 410,
+    STATS_E_DISABLED = 411,
+    STATS_I_OPER_ONLY = 412,
+    STATS_K_OPER_ONLY = 413,
+    STATS_M_OPER_ONLY = 414,
+    STATS_O_OPER_ONLY = 415,
+    STATS_P_OPER_ONLY = 416,
+    STATS_U_OPER_ONLY = 417,
+    T_ALL = 418,
+    T_BIND = 419,
     T_BOTS = 420,
     T_CALLERID = 421,
     T_CCONN = 422,
@@ -257,22 +261,21 @@ extern int yydebug;
     TBOOL = 467,
     THROTTLE_COUNT = 468,
     THROTTLE_TIME = 469,
-    TKLINE_EXPIRE_NOTICES = 470,
-    TMASKED = 471,
-    TS_MAX_DELTA = 472,
-    TS_WARN_DELTA = 473,
-    TWODOTS = 474,
-    TYPE = 475,
-    UNKLINE = 476,
-    USE_LOGGING = 477,
-    USER = 478,
-    VHOST = 479,
-    VHOST6 = 480,
-    WARN_NO_CONNECT_BLOCK = 481,
-    WHOIS = 482,
-    WHOWAS_HISTORY_LENGTH = 483,
-    XLINE = 484,
-    XLINE_EXEMPT = 485
+    TMASKED = 470,
+    TS_MAX_DELTA = 471,
+    TS_WARN_DELTA = 472,
+    TWODOTS = 473,
+    TYPE = 474,
+    UNKLINE = 475,
+    USE_LOGGING = 476,
+    USER = 477,
+    VHOST = 478,
+    VHOST6 = 479,
+    WARN_NO_CONNECT_BLOCK = 480,
+    WHOIS = 481,
+    WHOWAS_HISTORY_LENGTH = 482,
+    XLINE = 483,
+    XLINE_EXEMPT = 484
   };
 #endif
 /* Tokens.  */
@@ -315,24 +318,24 @@ extern int yydebug;
 #define ENCRYPTED 294
 #define EXCEED_LIMIT 295
 #define EXEMPT 296
-#define FAILED_OPER_NOTICE 297
-#define FLATTEN_LINKS 298
-#define FLATTEN_LINKS_DELAY 299
-#define FLATTEN_LINKS_FILE 300
-#define GECOS 301
-#define GENERAL 302
-#define HIDDEN 303
-#define HIDDEN_NAME 304
-#define HIDE_CHANS 305
-#define HIDE_IDLE 306
-#define HIDE_IDLE_FROM_OPERS 307
-#define HIDE_SERVER_IPS 308
-#define HIDE_SERVERS 309
-#define HIDE_SERVICES 310
-#define HOST 311
-#define HUB 312
-#define HUB_MASK 313
-#define IGNORE_BOGUS_TS 314
+#define EXPIRATION 297
+#define FAILED_OPER_NOTICE 298
+#define FLATTEN_LINKS 299
+#define FLATTEN_LINKS_DELAY 300
+#define FLATTEN_LINKS_FILE 301
+#define GECOS 302
+#define GENERAL 303
+#define HIDDEN 304
+#define HIDDEN_NAME 305
+#define HIDE_CHANS 306
+#define HIDE_IDLE 307
+#define HIDE_IDLE_FROM_OPERS 308
+#define HIDE_SERVER_IPS 309
+#define HIDE_SERVERS 310
+#define HIDE_SERVICES 311
+#define HOST 312
+#define HUB 313
+#define HUB_MASK 314
 #define INVISIBLE_ON_CONNECT 315
 #define INVITE_CLIENT_COUNT 316
 #define INVITE_CLIENT_TIME 317
@@ -359,85 +362,85 @@ extern int yydebug;
 #define MAX_BANS 338
 #define MAX_BANS_LARGE 339
 #define MAX_CHANNELS 340
-#define MAX_GLOBAL 341
-#define MAX_IDLE 342
-#define MAX_INVITES 343
-#define MAX_LOCAL 344
-#define MAX_NICK_CHANGES 345
-#define MAX_NICK_LENGTH 346
-#define MAX_NICK_TIME 347
-#define MAX_NUMBER 348
-#define MAX_TARGETS 349
-#define MAX_TOPIC_LENGTH 350
-#define MAX_WATCH 351
-#define MIN_IDLE 352
-#define MIN_NONWILDCARD 353
-#define MIN_NONWILDCARD_SIMPLE 354
-#define MODULE 355
-#define MODULES 356
-#define MOTD 357
-#define NAME 358
-#define NEED_IDENT 359
-#define NEED_PASSWORD 360
-#define NETWORK_DESC 361
-#define NETWORK_NAME 362
-#define NICK 363
-#define NO_OPER_FLOOD 364
-#define NO_TILDE 365
-#define NUMBER 366
-#define NUMBER_PER_CIDR 367
-#define NUMBER_PER_IP 368
-#define OPER_ONLY_UMODES 369
-#define OPER_UMODES 370
-#define OPERATOR 371
-#define OPERS_BYPASS_CALLERID 372
-#define PACE_WAIT 373
-#define PACE_WAIT_SIMPLE 374
-#define PASSWORD 375
-#define PATH 376
-#define PING_COOKIE 377
-#define PING_TIME 378
-#define PORT 379
-#define QSTRING 380
-#define RANDOM_IDLE 381
-#define REASON 382
-#define REDIRPORT 383
-#define REDIRSERV 384
-#define REHASH 385
-#define REMOTE 386
-#define REMOTEBAN 387
-#define RESV 388
-#define RESV_EXEMPT 389
-#define RSA_PRIVATE_KEY_FILE 390
-#define SECONDS 391
-#define MINUTES 392
-#define HOURS 393
-#define DAYS 394
-#define WEEKS 395
-#define MONTHS 396
-#define YEARS 397
-#define SEND_PASSWORD 398
-#define SENDQ 399
-#define SERVERHIDE 400
-#define SERVERINFO 401
-#define SHORT_MOTD 402
-#define SPOOF 403
-#define SPOOF_NOTICE 404
-#define SQUIT 405
-#define SSL_CERTIFICATE_FILE 406
-#define SSL_CERTIFICATE_FINGERPRINT 407
-#define SSL_CONNECTION_REQUIRED 408
-#define SSL_DH_ELLIPTIC_CURVE 409
-#define SSL_DH_PARAM_FILE 410
-#define SSL_MESSAGE_DIGEST_ALGORITHM 411
-#define STATS_E_DISABLED 412
-#define STATS_I_OPER_ONLY 413
-#define STATS_K_OPER_ONLY 414
-#define STATS_M_OPER_ONLY 415
-#define STATS_O_OPER_ONLY 416
-#define STATS_P_OPER_ONLY 417
-#define STATS_U_OPER_ONLY 418
-#define T_ALL 419
+#define MAX_IDLE 341
+#define MAX_INVITES 342
+#define MAX_NICK_CHANGES 343
+#define MAX_NICK_LENGTH 344
+#define MAX_NICK_TIME 345
+#define MAX_NUMBER 346
+#define MAX_TARGETS 347
+#define MAX_TOPIC_LENGTH 348
+#define MAX_WATCH 349
+#define MIN_IDLE 350
+#define MIN_NONWILDCARD 351
+#define MIN_NONWILDCARD_SIMPLE 352
+#define MODULE 353
+#define MODULES 354
+#define MOTD 355
+#define NAME 356
+#define NEED_IDENT 357
+#define NEED_PASSWORD 358
+#define NETWORK_DESC 359
+#define NETWORK_NAME 360
+#define NICK 361
+#define NO_OPER_FLOOD 362
+#define NO_TILDE 363
+#define NUMBER 364
+#define NUMBER_PER_CIDR 365
+#define NUMBER_PER_IP_GLOBAL 366
+#define NUMBER_PER_IP_LOCAL 367
+#define OPER_ONLY_UMODES 368
+#define OPER_UMODES 369
+#define OPERATOR 370
+#define OPERS_BYPASS_CALLERID 371
+#define PACE_WAIT 372
+#define PACE_WAIT_SIMPLE 373
+#define PASSWORD 374
+#define PATH 375
+#define PING_COOKIE 376
+#define PING_TIME 377
+#define PORT 378
+#define QSTRING 379
+#define RANDOM_IDLE 380
+#define REASON 381
+#define REDIRPORT 382
+#define REDIRSERV 383
+#define REHASH 384
+#define REMOTE 385
+#define REMOTEBAN 386
+#define RESV 387
+#define RESV_EXEMPT 388
+#define RSA_PRIVATE_KEY_FILE 389
+#define SECONDS 390
+#define MINUTES 391
+#define HOURS 392
+#define DAYS 393
+#define WEEKS 394
+#define MONTHS 395
+#define YEARS 396
+#define SEND_PASSWORD 397
+#define SENDQ 398
+#define SERVERHIDE 399
+#define SERVERINFO 400
+#define SHORT_MOTD 401
+#define SPOOF 402
+#define SPOOF_NOTICE 403
+#define SQUIT 404
+#define SSL_CERTIFICATE_FILE 405
+#define SSL_CERTIFICATE_FINGERPRINT 406
+#define SSL_CONNECTION_REQUIRED 407
+#define SSL_DH_ELLIPTIC_CURVE 408
+#define SSL_DH_PARAM_FILE 409
+#define SSL_MESSAGE_DIGEST_ALGORITHM 410
+#define STATS_E_DISABLED 411
+#define STATS_I_OPER_ONLY 412
+#define STATS_K_OPER_ONLY 413
+#define STATS_M_OPER_ONLY 414
+#define STATS_O_OPER_ONLY 415
+#define STATS_P_OPER_ONLY 416
+#define STATS_U_OPER_ONLY 417
+#define T_ALL 418
+#define T_BIND 419
 #define T_BOTS 420
 #define T_CALLERID 421
 #define T_CCONN 422
@@ -488,34 +491,33 @@ extern int yydebug;
 #define TBOOL 467
 #define THROTTLE_COUNT 468
 #define THROTTLE_TIME 469
-#define TKLINE_EXPIRE_NOTICES 470
-#define TMASKED 471
-#define TS_MAX_DELTA 472
-#define TS_WARN_DELTA 473
-#define TWODOTS 474
-#define TYPE 475
-#define UNKLINE 476
-#define USE_LOGGING 477
-#define USER 478
-#define VHOST 479
-#define VHOST6 480
-#define WARN_NO_CONNECT_BLOCK 481
-#define WHOIS 482
-#define WHOWAS_HISTORY_LENGTH 483
-#define XLINE 484
-#define XLINE_EXEMPT 485
+#define TMASKED 470
+#define TS_MAX_DELTA 471
+#define TS_WARN_DELTA 472
+#define TWODOTS 473
+#define TYPE 474
+#define UNKLINE 475
+#define USE_LOGGING 476
+#define USER 477
+#define VHOST 478
+#define VHOST6 479
+#define WARN_NO_CONNECT_BLOCK 480
+#define WHOIS 481
+#define WHOWAS_HISTORY_LENGTH 482
+#define XLINE 483
+#define XLINE_EXEMPT 484
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 
 union YYSTYPE
 {
-#line 142 "conf_parser.y" /* yacc.c:1909  */
+#line 141 "conf_parser.y" /* yacc.c:1921  */
 
   int number;
   char *string;
 
-#line 519 "conf_parser.h" /* yacc.c:1909  */
+#line 521 "conf_parser.h" /* yacc.c:1921  */
 };
 
 typedef union YYSTYPE YYSTYPE;
