@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_shared.c
  * \brief Implements shared {} block configuration management.
- * \version $Id: conf_shared.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: conf_shared.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -75,9 +75,9 @@ shared_find(unsigned int type, const char *server,
     const struct SharedItem *shared = node->data;
 
     if (shared->type & type)
-      if (!match(shared->server, server))
-        if (!match(shared->user, user) &&
-            !match(shared->host, host))
+      if (match(shared->server, server) == 0)
+        if (match(shared->user, user) == 0 &&
+            match(shared->host, host) == 0)
           return shared;
   }
 
