@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file event.c
  * \brief Timer based event execution
- * \version $Id: event.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: event.c 8912 2019-04-21 21:42:53Z michael $
  */
 
 #include "stdinc.h"
@@ -29,8 +29,12 @@
 #include "ircd.h"
 #include "event.h"
 #include "rng_mt.h"
+#include "log.h"
 
 
+struct event_base ebase;
+struct event_base *event_base = &ebase;
+
 static dlink_list event_list;
 
 const dlink_list *
@@ -47,8 +51,8 @@ event_add(struct event *ev, void *data)
   event_delete(ev);
 
   ev->data = data;
-  ev->next = CurrentTime + ev->when;
-  ev->active = 1;
+  ev->next = event_base->time.sec_monotonic + ev->when;
+  ev->active = true;
 
   DLINK_FOREACH(node, event_list.head)
   {
@@ -80,11 +84,11 @@ event_addish(struct event *ev, void *data)
 void
 event_delete(struct event *ev)
 {
-  if (ev->active == 0)
+  if (ev->active == false)
     return;
 
   dlinkDelete(&ev->node, &event_list);
-  ev->active = 0;
+  ev->active = false;
 }
 
 void
@@ -92,41 +96,45 @@ event_run(void)
 {
   static uintmax_t last = 0;
 
-  if (last == CurrentTime)
+  if (last == event_base->time.sec_monotonic)
     return;
-  last = CurrentTime;
+  last = event_base->time.sec_monotonic;
 
   unsigned int len = dlink_list_length(&event_list);
   while (len-- && dlink_list_length(&event_list))
   {
     struct event *ev = event_list.head->data;
 
-    if (ev->next > CurrentTime)
+    if (ev->next > event_base->time.sec_monotonic)
       break;
 
     event_delete(ev);
 
     ev->handler(ev->data);
 
-    if (ev->oneshot == 0)
+    if (ev->oneshot == false)
       event_add(ev, ev->data);
   }
 }
 
-/*
- * void event_set_back_events(uintmax_t by)
- * Input: Time to set back events by.
- * Output: None.
- * Side-effects: Sets back all events by "by" seconds.
- */
 void
-event_set_back_events(uintmax_t by)
+event_time_set(void)
 {
-  dlink_node *node;
+  struct timespec newtime;
 
-  DLINK_FOREACH(node, event_list.head)
-  {
-    struct event *ev = node->data;
-    ev->next -= by;
-  }
+  if (clock_gettime(CLOCK_REALTIME, &newtime))
+    exit(EXIT_FAILURE);
+  else if (event_base->time.sec_real > (uintmax_t)newtime.tv_sec)
+    ilog(LOG_TYPE_IRCD, "System clock is running backwards - (%ju < %ju)",
+         (uintmax_t)newtime.tv_sec, event_base->time.sec_real);
+  event_base->time.sec_real = newtime.tv_sec;
+
+#ifdef CLOCK_MONOTONIC_RAW
+  if (clock_gettime(CLOCK_MONOTONIC_RAW, &newtime) == 0)
+#else
+  if (clock_gettime(CLOCK_MONOTONIC, &newtime) == 0)
+#endif
+    event_base->time.sec_monotonic = newtime.tv_sec;
+  else
+    exit(EXIT_FAILURE);
 }
