@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file fdlist.c
  * \brief Maintains a list of file descriptors.
- * \version $Id: fdlist.c 8378 2018-03-11 14:56:39Z michael $
+ * \version $Id: fdlist.c 8874 2019-02-16 21:53:04Z michael $
  */
 
 #include "stdinc.h"
@@ -30,34 +30,27 @@
 #include "s_bsd.h"   /* comm_setselect */
 #include "memory.h"
 #include "misc.h"
-#include "res.h"
 
 
 fde_t *fd_table;
 int number_fd = LEAKED_FDS;
 int hard_fdlimit = 0;
-int highest_fd;
+int highest_fd = -1;
 
 
 void
 fdlist_init(void)
 {
-  struct rlimit limit;
-
-  if (!getrlimit(RLIMIT_NOFILE, &limit))
-  {
-    limit.rlim_cur = limit.rlim_max;
-    setrlimit(RLIMIT_NOFILE, &limit);
-  }
-
-  /* allow MAXCLIENTS_MIN clients even at the cost of MAX_BUFFER and
-   * some not really LEAKED_FDS */
-  hard_fdlimit = IRCD_MAX(getdtablesize(), LEAKED_FDS + MAX_BUFFER + MAXCLIENTS_MIN);
-  fd_table = xcalloc(sizeof(fde_t) * hard_fdlimit);
+  /*
+   * Allow MAXCLIENTS_MIN clients even at the cost of MAX_BUFFER and
+   * some not really LEAKED_FDS
+   */
+  hard_fdlimit = IRCD_MAX(hard_fdlimit, LEAKED_FDS + MAX_BUFFER + MAXCLIENTS_MIN);
+  fd_table = xcalloc(sizeof(*fd_table) * hard_fdlimit);
 }
 
 static void
-fdlist_update_highest_fd(int fd, int opening)
+fdlist_update_highest_fd(int fd, bool opening)
 {
   if (fd < highest_fd)
     return;
@@ -69,7 +62,7 @@ fdlist_update_highest_fd(int fd, int opening)
     /*
      * assert() that we are not closing a FD bigger than our known highest FD.
      */
-    assert(opening);
+    assert(opening == true);
     highest_fd = fd;
     return;
   }
@@ -78,21 +71,21 @@ fdlist_update_highest_fd(int fd, int opening)
   /*
    * assert() that we are closing the highest FD; we can't be re-opening it.
    */
-  assert(!opening);
+  assert(opening == false);
 
-  while (highest_fd >= 0 && fd_table[highest_fd].flags.open == 0)
+  while (highest_fd >= 0 && fd_table[highest_fd].flags.open == false)
     --highest_fd;
 }
 
 /* Called to open a given filedescriptor */
 fde_t *
-fd_open(int fd, int is_socket, const char *desc)
+fd_open(int fd, bool is_socket, const char *desc)
 {
   fde_t *F = &fd_table[fd];
 
   assert(fd >= 0);
   assert(F->fd == 0);
-  assert(F->flags.open == 0);
+  assert(F->flags.open == false);
 
   /*
    * Note: normally we'd have to clear the other flags, but currently F
@@ -100,41 +93,42 @@ fd_open(int fd, int is_socket, const char *desc)
    */
   F->fd = fd;
   F->comm_index = -1;
-  F->flags.open = 1;
+  F->flags.open = true;
   F->flags.is_socket = is_socket;
 
   if (desc)
-    strlcpy(F->desc, desc, sizeof(F->desc));
+    F->desc = xstrndup(desc, FD_DESC_SIZE);
 
+  fdlist_update_highest_fd(F->fd, true);
   ++number_fd;
-  fdlist_update_highest_fd(fd, 1);
 
   return F;
 }
 
 /* Called to close a given filedescriptor */
-void
+fde_t *
 fd_close(fde_t *F)
 {
-  const int fd = F->fd;
-
   assert(F->fd >= 0);
-  assert(F->flags.open);
+  assert(F->flags.open == true);
 
-  if (F->flags.is_socket)
+  if (F->flags.is_socket == true)
     comm_setselect(F, COMM_SELECT_WRITE | COMM_SELECT_READ, NULL, NULL, 0);
 
-  delete_resolver_queries(F);
-
   if (tls_isusing(&F->ssl))
     tls_free(&F->ssl);
 
+  xfree(F->desc);
   /* Unlike squid, we're actually closing the FD here! -- adrian */
   close(F->fd);
-  memset(F, 0, sizeof(*F));  /* Must set F->flags.open == 0 before fdlist_update_highest_fd() */
+  F->flags.open = false;  /* Must set F->flags.open == false before fdlist_update_highest_fd() */
 
+  fdlist_update_highest_fd(F->fd, false);
   --number_fd;
-  fdlist_update_highest_fd(fd, 0);
+
+  memset(F, 0, sizeof(*F));
+
+  return F;
 }
 
 /*
@@ -146,16 +140,23 @@ fd_close(fde_t *F)
 void
 fd_note(fde_t *F, const char *format, ...)
 {
-  va_list args;
-
   if (format)
   {
+    char buf[FD_DESC_SIZE + 1];
+    va_list args;
+
     va_start(args, format);
-    vsnprintf(F->desc, sizeof(F->desc), format, args);
+    vsnprintf(buf, sizeof(buf), format, args);
     va_end(args);
+
+    xfree(F->desc);
+    F->desc = xstrdup(buf);
   }
   else
-    F->desc[0] = '\0';
+  {
+    xfree(F->desc);
+    F->desc = NULL;
+  }
 }
 
 /* Make sure stdio descriptors (0-2) and profiler descriptor (3)
