@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2018 ircd-hybrid development team
+ *  Copyright (c) 2001-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file getopt.c
  * \brief Uses getopt to fetch the command line options.
- * \version $Id: getopt.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: getopt.c 8863 2019-02-15 21:36:29Z michael $
  */
 
 #include "stdinc.h"
@@ -39,7 +39,7 @@ usage(const char *name, const struct lgetopt *opts)
 
   for (; opts->opt; ++opts)
     fprintf(stderr, "\t%c%-10s %-20s%s\n", OPTCHAR, opts->opt,
-            (opts->argtype == YESNO || opts->argtype == USAGE) ? "" :
+            (opts->argtype == BOOLEAN || opts->argtype == USAGE) ? "" :
             opts->argtype == INTEGER ? "<number>" : "<string>",
             opts->desc);
 
@@ -52,9 +52,9 @@ parseargs(int *argc, char ***argv, struct lgetopt *opts)
   const char *progname = (*argv)[0];
 
   /* Loop through each argument */
-  while (1)
+  while (true)
   {
-    int found = 0;
+    bool found = false;
     const char *opt = NULL;
 
     (*argc)--;
@@ -68,15 +68,15 @@ parseargs(int *argc, char ***argv, struct lgetopt *opts)
     /* Search through our argument list, and see if it matches */
     for (unsigned int i = 0; opts[i].opt; ++i)
     {
-      if (!strcmp(opts[i].opt, opt))
+      if (strcmp(opts[i].opt, opt) == 0)
       {
         /* Found our argument */
-        found = 1;
+        found = true;
 
         switch (opts[i].argtype)
         {
-          case YESNO:
-            *((int *)opts[i].argloc) = 1;
+          case BOOLEAN:
+            *((bool *)opts[i].argloc) = true;
             break;
 
           case INTEGER:
@@ -117,7 +117,7 @@ parseargs(int *argc, char ***argv, struct lgetopt *opts)
       }
     }
 
-    if (!found)
+    if (found == false)
     {
       fprintf(stderr, "Error: unknown argument '%c%s'\n",
               OPTCHAR, opt);
