@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hash.c
  * \brief Hash table management.
- * \version $Id: hash.c 8388 2018-03-16 20:23:06Z michael $
+ * \version $Id: hash.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -33,7 +33,6 @@
 #include "hash.h"
 #include "id.h"
 #include "rng_mt.h"
-#include "userhost.h"
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
@@ -52,7 +51,6 @@ static unsigned int hashf_xor_key;
 static struct Client *idTable[HASHSIZE];
 static struct Client *clientTable[HASHSIZE];
 static struct Channel *channelTable[HASHSIZE];
-static struct UserHost *userhostTable[HASHSIZE];
 
 
 /* hash_init()
@@ -143,15 +141,6 @@ hash_add_channel(struct Channel *chptr)
   channelTable[hashv] = chptr;
 }
 
-void
-hash_add_userhost(struct UserHost *userhost)
-{
-  const unsigned int hashv = strhash(userhost->host);
-
-  userhost->next = userhostTable[hashv];
-  userhostTable[hashv] = userhost;
-}
-
 void
 hash_add_id(struct Client *client_p)
 {
@@ -223,37 +212,6 @@ hash_del_client(struct Client *client_p)
   }
 }
 
-/* hash_del_userhost()
- *
- * inputs       - pointer to userhost
- * output       - NONE
- * side effects - Removes a userhost from the hash linked list
- */
-void
-hash_del_userhost(struct UserHost *userhost)
-{
-  const unsigned int hashv = strhash(userhost->host);
-  struct UserHost *tmp = userhostTable[hashv];
-
-  if (tmp)
-  {
-    if (tmp == userhost)
-    {
-      userhostTable[hashv] = userhost->next;
-      userhost->next = userhost;
-    }
-    else
-    {
-      while (tmp->next != userhost)
-        if ((tmp = tmp->next) == NULL)
-          return;
-
-      tmp->next = tmp->next->next;
-      userhost->next = userhost;
-    }
-  }
-}
-
 /* hash_del_channel()
  *
  * inputs       - pointer to client
@@ -419,34 +377,6 @@ hash_find_channel(const char *name)
   return chptr;
 }
 
-struct UserHost *
-hash_find_userhost(const char *host)
-{
-  const unsigned int hashv = strhash(host);
-  struct UserHost *userhost;
-
-  if ((userhost = userhostTable[hashv]))
-  {
-    if (irccmp(host, userhost->host))
-    {
-      struct UserHost *prev;
-
-      while (prev = userhost, (userhost = userhost->next))
-      {
-        if (!irccmp(host, userhost->host))
-        {
-          prev->next = userhost->next;
-          userhost->next = userhostTable[hashv];
-          userhostTable[hashv] = userhost;
-          break;
-        }
-      }
-    }
-  }
-
-  return userhost;
-}
-
 /* hash_get_bucket(int type, unsigned int hashv)
  *
  * inputs       - hash value (must be between 0 and HASHSIZE - 1)
@@ -476,9 +406,6 @@ hash_get_bucket(int type, unsigned int hashv)
     case HASH_TYPE_CLIENT:
       return clientTable[hashv];
       break;
-    case HASH_TYPE_USERHOST:
-      return userhostTable[hashv];
-      break;
     default:
       assert(0);
   }
@@ -508,13 +435,13 @@ hash_get_bucket(int type, unsigned int hashv)
  *
  * Sendq limit is fairly conservative at 1/2 (In original anyway)
  */
-static int
+static bool
 exceeding_sendq(const struct Client *to)
 {
   if (dbuf_length(&to->connection->buf_sendq) > (get_sendq(&to->connection->confs) / 2))
-    return 1;
+    return true;
   else
-    return 0;
+    return false;
 }
 
 void
@@ -551,20 +478,20 @@ free_list_task(struct Client *source_p)
  *                0 otherwise
  * side effects -
  */
-static int
+static bool
 list_allow_channel(const char *name, const struct ListTask *lt)
 {
   dlink_node *node;
 
   DLINK_FOREACH(node, lt->show_mask.head)
     if (match(node->data, name) != 0)
-      return 0;
+      return false;
 
   DLINK_FOREACH(node, lt->hide_mask.head)
     if (match(node->data, name) == 0)
-      return 0;
+      return false;
 
-  return 1;
+  return true;
 }
 
 /* list_one_channel()
@@ -600,7 +527,7 @@ list_one_channel(struct Client *source_p, struct Channel *chptr)
   if (lt->topic[0] && match(lt->topic, chptr->topic))
     return;
 
-  if (!list_allow_channel(chptr->name, lt))
+  if (list_allow_channel(chptr->name, lt) == false)
     return;
 
   channel_modes(chptr, source_p, modebuf, parabuf);
@@ -627,16 +554,16 @@ list_one_channel(struct Client *source_p, struct Channel *chptr)
  * - Dianora
  */
 void
-safe_list_channels(struct Client *source_p, int only_unmasked_channels)
+safe_list_channels(struct Client *source_p, bool only_unmasked_channels)
 {
   struct ListTask *const lt = source_p->connection->list_task;
   struct Channel *chptr = NULL;
 
-  if (!only_unmasked_channels)
+  if (only_unmasked_channels == false)
   {
     for (unsigned int i = lt->hash_index; i < HASHSIZE; ++i)
     {
-      if (exceeding_sendq(source_p))
+      if (exceeding_sendq(source_p) == true)
       {
         lt->hash_index = i;
         return;  /* Still more to do */
