@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2018 ircd-hybrid development team
+ *  Copyright (c) 2001-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hostmask.c
  * \brief Code to efficiently find IP & hostmask based configs.
- * \version $Id: hostmask.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: hostmask.c 9045 2019-05-31 09:59:45Z michael $
  */
 
 #include "stdinc.h"
@@ -42,7 +42,7 @@
                          ch = ch - 'A' + 10; \
                        else if (ch >= 'a' && ch <= 'f') \
                          ch = ch - 'a' + 10; \
-                       } while (0);
+                       } while (false);
 
 /* Hashtable stuff...now external as it's used in m_stats.c */
 dlink_list atable[ATABLE_SIZE];
@@ -66,7 +66,7 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   int finsert = -1;
   int bits = 128;
   int deficit = 0;
-  short dc[8];
+  uint16_t dc[8];
   struct sockaddr_in6 *const v6 = (struct sockaddr_in6 *)addr;
 
   for (const char *p = text; (c = *p); ++p)
@@ -110,13 +110,12 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
     {
       char *after;
 
-      d[dp] = d[dp] >> 4 * nyble;
-      ++dp;
       bits = strtoul(p + 1, &after, 10);
 
-      if (bits < 0 || *after)
+      if (bits < 0 || bits > 128 || *after)
         return HM_HOST;
-      if (bits > dp * 4 && !(finsert >= 0 && bits <= 128))
+      /* 16 bits for each hextet, plus 4 for each parsed nyble */
+      if (bits > dp * 16 + (4 - nyble) * 4 && !(finsert >= 0))
         return HM_HOST;
       break;
     }
@@ -159,7 +158,7 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 
     for (dp = 0; dp < 8; ++dp)
       /* The cast is a kludge to make netbsd work. */
-      ((unsigned short *)&v6->sin6_addr)[dp] = htons(dc[dp]);
+      ((uint16_t *)&v6->sin6_addr)[dp] = htons(dc[dp]);
   }
 
   if (b)
@@ -178,7 +177,7 @@ static int
 try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
 {
   const char *digits[4];
-  unsigned char addb[4];
+  uint8_t addb[4];
   int n = 0, bits = 0;
   char c;
   struct sockaddr_in *const v4 = (struct sockaddr_in *)addr;
@@ -241,7 +240,10 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   {
     v4->sin_family = AF_INET;
     v4->sin_addr.s_addr =
-      htonl(addb[0] << 24 | addb[1] << 16 | addb[2] << 8 | addb[3]);
+      htonl((unsigned int)addb[0] << 24 |
+            (unsigned int)addb[1] << 16 |
+            (unsigned int)addb[2] <<  8 |
+            (unsigned int)addb[3]);
   }
 
   if (b)
@@ -276,7 +278,7 @@ parse_netmask(const char *text, struct irc_ssaddr *addr, int *b)
  * Output: if match, -1 else 0
  * Side effects: None
  */
-int
+bool
 match_ipv6(const struct irc_ssaddr *addr, const struct irc_ssaddr *mask, int bits)
 {
   int i, m, n = bits / 8;
@@ -285,14 +287,14 @@ match_ipv6(const struct irc_ssaddr *addr, const struct irc_ssaddr *mask, int bit
 
   for (i = 0; i < n; ++i)
     if (v6->sin6_addr.s6_addr[i] != v6mask->sin6_addr.s6_addr[i])
-      return 0;
+      return false;
 
   if ((m = bits % 8) == 0)
-    return -1;
+    return true;
   if ((v6->sin6_addr.s6_addr[n] & ~((1 << (8 - m)) - 1)) ==
       v6mask->sin6_addr.s6_addr[n])
-    return -1;
-  return 0;
+    return true;
+  return false;
 }
 
 /* int match_ipv4(struct irc_ssaddr *, struct irc_ssaddr *, int)
@@ -300,55 +302,16 @@ match_ipv6(const struct irc_ssaddr *addr, const struct irc_ssaddr *mask, int bit
  * Output: if match, -1 else 0
  * Side Effects: None
  */
-int
+bool
 match_ipv4(const struct irc_ssaddr *addr, const struct irc_ssaddr *mask, int bits)
 {
   const struct sockaddr_in *const v4 = (const struct sockaddr_in *)addr;
   const struct sockaddr_in *const v4mask = (const struct sockaddr_in *)mask;
 
-  if ((ntohl(v4->sin_addr.s_addr) & ~((1 << (32 - bits)) - 1)) !=
+  if ((ntohl(v4->sin_addr.s_addr) & ~((1 << (32 - bits)) - 1)) ==
       ntohl(v4mask->sin_addr.s_addr))
-    return 0;
-  return -1;
-}
-
-/*
- * mask_addr
- *
- * inputs       - pointer to the ip to mask
- *              - bitlen
- * output       - NONE
- * side effects -
- */
-void
-mask_addr(struct irc_ssaddr *ip, int bits)
-{
-  int mask;
-  struct sockaddr_in6 *v6_base_ip;
-  int i, m, n;
-  struct sockaddr_in *v4_base_ip;
-
-  if (ip->ss.ss_family == AF_INET)
-  {
-    uint32_t tmp = 0;
-    v4_base_ip = (struct sockaddr_in *)ip;
-
-    mask = ~((1 << (32 - bits)) - 1);
-    tmp = ntohl(v4_base_ip->sin_addr.s_addr);
-    v4_base_ip->sin_addr.s_addr = htonl(tmp & mask);
-  }
-  else
-  {
-    n = bits / 8;
-    m = bits % 8;
-    v6_base_ip = (struct sockaddr_in6 *)ip;
-
-    mask = ~((1 << (8 - m)) - 1);
-    v6_base_ip->sin6_addr.s6_addr[n] = v6_base_ip->sin6_addr.s6_addr[n] & mask;
-
-    for (i = n + 1; i < 16; i++)
-      v6_base_ip->sin6_addr.s6_addr[i] = 0;
-  }
+    return true;
+  return false;
 }
 
 /* unsigned long hash_ipv4(struct irc_ssaddr*)
@@ -447,7 +410,7 @@ get_mask_hash(const char *text)
  */
 struct MaskItem *
 find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned int type,
-                     int fam, const char *username, const char *password, int do_match)
+                     const char *username, const char *password, int do_match)
 {
   unsigned int hprecv = 0;
   dlink_node *node;
@@ -458,7 +421,7 @@ find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned i
   if (addr)
   {
     /* Check for IPV6 matches... */
-    if (fam == AF_INET6)
+    if (addr->ss.ss_family == AF_INET6)
     {
       for (int b = 128; b >= 0; b -= 16)
       {
@@ -481,7 +444,7 @@ find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned i
         }
       }
     }
-    else if (fam == AF_INET)
+    else if (addr->ss.ss_family == AF_INET)
     {
       for (int b = 32; b >= 0; b -= 8)
       {
@@ -510,7 +473,7 @@ find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned i
   {
     const char *p = name;
 
-    while (1)
+    while (true)
     {
         DLINK_FOREACH(node, atable[hash_text(p)].head)
         {
@@ -561,13 +524,12 @@ find_conf_by_address(const char *name, const struct irc_ssaddr *addr, unsigned i
  * Side-effects: None
  */
 struct MaskItem *
-find_address_conf(const char *host, const char *user, const struct irc_ssaddr *ip,
-                  int aftype, const char *password)
+find_address_conf(const char *host, const char *user, const struct irc_ssaddr *addr, const char *password)
 {
   struct MaskItem *authcnf = NULL, *killcnf = NULL;
 
   /* Find the best auth{} block... If none, return NULL -A1kmm */
-  if ((authcnf = find_conf_by_address(host, ip, CONF_CLIENT, aftype, user, password, 1)) == NULL)
+  if ((authcnf = find_conf_by_address(host, addr, CONF_CLIENT, user, password, 1)) == NULL)
     return NULL;
 
   /* If they are exempt from K-lines, return the best auth{} block. -A1kmm */
@@ -575,7 +537,7 @@ find_address_conf(const char *host, const char *user, const struct irc_ssaddr *i
     return authcnf;
 
   /* Find the best K-line... -A1kmm */
-  killcnf = find_conf_by_address(host, ip, CONF_KLINE, aftype, user, NULL, 1);
+  killcnf = find_conf_by_address(host, addr, CONF_KLINE, user, NULL, 1);
 
   /*
    * If they are K-lined, return the K-line. Otherwise, return the
@@ -594,15 +556,15 @@ find_address_conf(const char *host, const char *user, const struct irc_ssaddr *i
  * Side effects: None.
  */
 struct MaskItem *
-find_dline_conf(const struct irc_ssaddr *addr, int aftype)
+find_dline_conf(const struct irc_ssaddr *addr)
 {
   struct MaskItem *eline;
 
-  eline = find_conf_by_address(NULL, addr, CONF_EXEMPT, aftype, NULL, NULL, 1);
+  eline = find_conf_by_address(NULL, addr, CONF_EXEMPT, NULL, NULL, 1);
   if (eline)
     return eline;
 
-  return find_conf_by_address(NULL, addr, CONF_DLINE, aftype, NULL, NULL, 1);
+  return find_conf_by_address(NULL, addr, CONF_DLINE, NULL, NULL, 1);
 }
 
 /* void add_conf_by_address(int, struct MaskItem *aconf)
@@ -722,7 +684,7 @@ clear_out_address_conf(void)
         continue;
 
       dlinkDelete(&arec->node, &atable[i]);
-      arec->conf->active = 0;
+      arec->conf->active = false;
 
       if (arec->conf->ref_count == 0)
         conf_free(arec->conf);
@@ -736,9 +698,6 @@ hostmask_send_expiration(const struct AddressRec *const arec)
 {
   char ban_type = '?';
 
-  if (!ConfigGeneral.tkline_expire_notices)
-    return;
-
   switch (arec->type)
   {
     case CONF_KLINE:
@@ -750,7 +709,7 @@ hostmask_send_expiration(const struct AddressRec *const arec)
     default: break;
   }
 
-  sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
+  sendto_realops_flags(UMODE_EXPIRATION, L_ALL, SEND_NOTICE,
                        "Temporary %c-line for [%s@%s] expired", ban_type,
                        (arec->conf->user) ? arec->conf->user : "*",
                        (arec->conf->host) ? arec->conf->host : "*");
@@ -767,7 +726,7 @@ hostmask_expire_temporary(void)
     {
       struct AddressRec *arec = node->data;
 
-      if (arec->conf->until == 0 || arec->conf->until > CurrentTime)
+      if (arec->conf->until == 0 || arec->conf->until > event_base->time.sec_real)
         continue;
 
       switch (arec->type)
