@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file id.c
  * \brief Contains functions pertaining to SID/UID generation.
- * \version $Id: id.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: id.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -31,31 +31,31 @@
 
 static char new_uid[TOTALSIDUID + 1];  /* Allow for \0 */
 
-int
+bool
 valid_sid(const char *sid)
 {
   if (strlen(sid) == IRC_MAXSID)
     if (IsDigit(*sid))
       if (IsAlNum(*(sid + 1)) && IsAlNum(*(sid + 2)))
-        return 1;
+        return true;
 
-  return 0;
+  return false;
 }
 
-int
+bool
 valid_uid(const char *uid)
 {
   if (strlen(uid) != TOTALSIDUID)
-    return 0;
+    return false;
 
   if (!IsDigit(*uid))
-    return 0;
+    return false;
 
   for (unsigned int i = 1; i < TOTALSIDUID; ++i)
     if (!IsAlNum(*(uid + i)))
-      return 0;
+      return false;
 
-  return 1;
+  return true;
 }
 
 /*
