@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file irc_string.c
  * \brief IRC string functions.
- * \version $Id: irc_string.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: irc_string.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "config.h"
@@ -29,7 +29,7 @@
 #include "irc_string.h"
 
 
-int
+bool
 has_wildcards(const char *str)
 {
   const unsigned char *p = (const unsigned char *)str;
@@ -39,13 +39,13 @@ has_wildcards(const char *str)
     if (*p == '\\')
     {
       if (*++p == '\0')
-        return 0;
+        return false;
     }
     else if (IsMWildChar(*p))
-      return 1;
+      return true;
   }
 
-  return 0;
+  return false;
 }
 
 const char *
