@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.c
  * \brief Starts up and runs the ircd.
- * \version $Id: ircd.c 8425 2018-03-25 17:45:13Z michael $
+ * \version $Id: ircd.c 8981 2019-05-19 10:54:54Z michael $
  */
 
 #include "stdinc.h"
@@ -44,7 +44,6 @@
 #include "res.h"
 #include "restart.h"
 #include "rng_mt.h"
-#include "auth.h"
 #include "s_bsd.h"
 #include "log.h"
 #include "server.h"
@@ -57,13 +56,14 @@
 #include "conf_class.h"
 #include "ipcache.h"
 #include "isupport.h"
+#include "patchlevel.h"
+#include "serno.h"
 
 
 struct SetOptions GlobalSetOptions;  /* /quote set variables */
 struct Counter Count;
 struct ServerState_t server_state;
 struct ServerStatistics ServerStats;
-struct ServerTime SystemTime;
 struct Connection meConnection;  /* That's also part of me */
 struct Client me = { .connection = &meConnection };  /* That's me */
 
@@ -71,10 +71,10 @@ char **myargv;
 const char *logFileName = LPATH;
 const char *pidFileName = PPATH;
 
-unsigned int dorehash;
-unsigned int doremotd;
+bool dorehash;
+bool doremotd;
 
-static int printVersion;
+static bool printVersion;
 
 static struct lgetopt myopts[] =
 {
@@ -93,9 +93,9 @@ static struct lgetopt myopts[] =
   { "pidfile",    &pidFileName,
    STRING, "File to use for process ID" },
   { "foreground", &server_state.foreground,
-   YESNO, "Run in foreground (don't detach)" },
+   BOOLEAN, "Run in foreground (don't detach)" },
   { "version",    &printVersion,
-   YESNO, "Print version and exit" },
+   BOOLEAN, "Print version and exit" },
   { "help", NULL, USAGE, "Print this text" },
   { NULL, NULL, STRING, NULL },
 };
@@ -111,7 +111,7 @@ static struct event event_try_connections =
 {
   .name = "try_connections",
   .handler = try_connections,
-  .when = STARTUP_CONNECTIONS_TIME
+  .when = 5
 };
 
 static struct event event_comm_checktimeouts =
@@ -135,44 +135,16 @@ struct event event_write_links_file =
 };
 
 
-void
-set_time(void)
-{
-  struct timeval newtime = { .tv_sec = 0, .tv_usec = 0 };
-
-  if (gettimeofday(&newtime, NULL) == -1)
-  {
-    char buf[IRCD_BUFSIZE];
-
-    snprintf(buf, sizeof(buf), "Clock failure, TS can be corrupted: %s",
-             strerror(errno));
-    server_die(buf, SERVER_SHUTDOWN);
-  }
-
-  if ((uintmax_t)newtime.tv_sec < CurrentTime)
-  {
-    ilog(LOG_TYPE_IRCD, "System clock is running backwards - (%ju < %ju)",
-         (uintmax_t)newtime.tv_sec, CurrentTime);
-    sendto_realops_flags(UMODE_DEBUG, L_ALL, SEND_NOTICE,
-                         "System clock is running backwards - (%ju < %ju)",
-                         (uintmax_t)newtime.tv_sec, CurrentTime);
-    event_set_back_events(CurrentTime - (uintmax_t)newtime.tv_sec);
-  }
-
-  SystemTime.tv_sec = newtime.tv_sec;
-  SystemTime.tv_usec = newtime.tv_usec;
-}
-
 static void
 io_loop(void)
 {
-  while (1)
+  while (true)
   {
     if (listing_client_list.head)
     {
       dlink_node *node = NULL, *node_next = NULL;
       DLINK_FOREACH_SAFE(node, node_next, listing_client_list.head)
-        safe_list_channels(node->data, 0);
+        safe_list_channels(node->data, false);
     }
 
     /* Run pending events */
@@ -183,18 +155,18 @@ io_loop(void)
     free_exited_clients();
 
     /* Check to see whether we have to rehash the configuration. */
-    if (dorehash)
+    if (dorehash == true)
     {
-      conf_rehash(1);
-      dorehash = 0;
+      conf_rehash(true);
+      dorehash = false;
     }
 
-    if (doremotd)
+    if (doremotd == true)
     {
       motd_recache();
       sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                            "Got signal SIGUSR1, reloading motd file(s)");
-      doremotd = 0;
+      doremotd = false;
     }
   }
 }
@@ -209,14 +181,13 @@ static void
 initialize_global_set_options(void)
 {
   GlobalSetOptions.maxclients = ConfigServerInfo.default_max_clients;
-  GlobalSetOptions.autoconn = 1;
+  GlobalSetOptions.autoconn = true;
   GlobalSetOptions.spam_time = MIN_JOIN_LEAVE_TIME;
   GlobalSetOptions.spam_num = MAX_JOIN_LEAVE_COUNT;
   GlobalSetOptions.floodcount = ConfigGeneral.default_floodcount;
   GlobalSetOptions.floodtime = ConfigGeneral.default_floodtime;
   GlobalSetOptions.joinfloodcount = ConfigChannel.default_join_flood_count;
   GlobalSetOptions.joinfloodtime = ConfigChannel.default_join_flood_time;
-  GlobalSetOptions.ident_timeout = IDENT_TIMEOUT;
 }
 
 /* write_pidfile()
@@ -264,14 +235,14 @@ check_pidfile(const char *filename)
 
   if ((fb = fopen(filename, "r")))
   {
-    if (!fgets(buf, 20, fb))
+    if (fgets(buf, 20, fb) == NULL)
       ilog(LOG_TYPE_IRCD, "Error reading from pid file %s: %s",
            filename, strerror(errno));
     else
     {
       pid_t pid = atoi(buf);
 
-      if (!kill(pid, 0))
+      if (kill(pid, 0) == 0)
       {
         /* log(L_ERROR, "Server is already running"); */
         printf("ircd: daemon is already running\n");
@@ -299,20 +270,46 @@ setup_corefile(void)
   struct rlimit rlim; /* resource limits */
 
   /* Set corefilesize to maximum */
-  if (!getrlimit(RLIMIT_CORE, &rlim))
+  if (getrlimit(RLIMIT_CORE, &rlim) == 0)
   {
     rlim.rlim_cur = rlim.rlim_max;
     setrlimit(RLIMIT_CORE, &rlim);
   }
 }
 
+static void
+setup_fdlimit(void)
+{
+  struct rlimit rlim; /* resource limits */
+
+  if (getrlimit(RLIMIT_NOFILE, &rlim))
+  {
+    fprintf(stderr, "getrlimit: couldn't get maximum number of file descriptors: %s\n",
+            strerror(errno));
+    exit(EXIT_FAILURE);
+  }
+
+  if (rlim.rlim_max > 0xFFFF)
+    rlim.rlim_max = 0xFFFF;
+  rlim.rlim_cur = rlim.rlim_max;
+
+  if (setrlimit(RLIMIT_NOFILE, &rlim) == 0)
+    hard_fdlimit = rlim.rlim_cur;
+  else
+  {
+    fprintf(stderr, "setrlimit: couldn't set maximum number of file descriptors: %s\n",
+            strerror(errno));
+    exit(EXIT_FAILURE);
+  }
+}
+
 /*
  * print_startup - print startup information
  */
 static void
 print_startup(int pid)
 {
-  printf("ircd: version %s(%s)\n", ircd_version, serno);
+  printf("ircd: version %s(%s)\n", PATCHLEVEL, SERIALNUM);
   printf("ircd: pid %d\n", pid);
   printf("ircd: running in %s mode from %s\n", !server_state.foreground ? "background"
          : "foreground", ConfigGeneral.dpath);
@@ -341,7 +338,7 @@ int
 main(int argc, char *argv[])
 {
   /* Check to see if the user is running us as root, which is a nono */
-  if (!geteuid())
+  if (geteuid() == 0)
   {
     fprintf(stderr, "ERROR: This server won't run as root/superuser\n");
     return -1;
@@ -350,11 +347,15 @@ main(int argc, char *argv[])
   /* Setup corefile size immediately after boot -kre */
   setup_corefile();
 
+  setup_fdlimit();
+
   /* Save server boot time right away, so getrusage works correctly */
-  set_time();
+  event_time_set();
 
   /* It's not random, but it ought to be a little harder to guess */
-  init_genrand(SystemTime.tv_sec ^ (SystemTime.tv_usec | (getpid() << 20)));
+  uint32_t seed = (uint32_t)(event_base->time.sec_real ^
+                             (event_base->time.sec_monotonic | (getpid() << 16)));
+  init_genrand(seed);
 
   ConfigGeneral.dpath      = DPATH;
   ConfigGeneral.spath      = SPATH;
@@ -370,9 +371,9 @@ main(int argc, char *argv[])
 
   parseargs(&argc, &argv, myopts);
 
-  if (printVersion)
+  if (printVersion == true)
   {
-    printf("ircd: version %s(%s)\n", ircd_version, serno);
+    printf("ircd: version %s(%s)\n", PATCHLEVEL, SERIALNUM);
     exit(EXIT_SUCCESS);
   }
 
@@ -382,7 +383,7 @@ main(int argc, char *argv[])
     exit(EXIT_FAILURE);
   }
 
-  if (!server_state.foreground)
+  if (server_state.foreground == false)
   {
     make_daemon();
     close_standard_fds(); /* this needs to be before comm_select_init()! */
@@ -407,10 +408,9 @@ main(int argc, char *argv[])
   ipcache_init();
   client_init();
   class_init();
-  auth_init();          /* Initialise the auth code */
   resolver_init();      /* Needs to be setup before the io loop */
   modules_init();
-  read_conf_files(1);   /* cold start init conf files */
+  read_conf_files(true);   /* cold start init conf files */
   capab_init();  /* Set up default_server_capabs */
   initialize_global_set_options();  /* Has to be called after read_conf_files() */
   channel_mode_init();
@@ -447,9 +447,8 @@ main(int argc, char *argv[])
 
   me.from = &me;
   me.servptr = &me;
-  me.connection->lasttime = CurrentTime;
-  me.connection->since = CurrentTime;
-  me.connection->firsttime = CurrentTime;
+  me.connection->created_real = event_base->time.sec_real;
+  me.connection->created_monotonic = event_base->time.sec_monotonic;
 
   SetMe(&me);
   server_make(&me);
@@ -464,9 +463,9 @@ main(int argc, char *argv[])
   load_xline_database(ConfigGeneral.xlinefile);
   load_resv_database(ConfigGeneral.resvfile);
 
-  load_all_modules(1);
+  load_all_modules(true);
   load_conf_modules();
-  load_core_modules(1);
+  load_core_modules(true);
 
   write_pidfile(pidFileName);
 
@@ -481,13 +480,13 @@ main(int argc, char *argv[])
 
   event_addish(&event_save_all_databases, NULL);
 
-  if (ConfigServerHide.flatten_links_delay && event_write_links_file.active == 0)
+  if (ConfigServerHide.flatten_links_delay && event_write_links_file.active == false)
   {
     event_write_links_file.when = ConfigServerHide.flatten_links_delay;
     event_add(&event_write_links_file, NULL);
   }
 
-  ilog(LOG_TYPE_IRCD, "Server ready. Running version: %s(%s)", ircd_version, serno);
+  ilog(LOG_TYPE_IRCD, "Server ready. Running version: %s(%s)", PATCHLEVEL, SERIALNUM);
   io_loop();
 
   return 0;
