@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd_signal.c
  * \brief responsible for ircd's signal handling.
- * \version $Id: ircd_signal.c 8411 2018-03-21 17:19:52Z michael $
+ * \version $Id: ircd_signal.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -36,7 +36,7 @@
 static void
 sigterm_handler(int sig)
 {
-  server_die("received signal SIGTERM", SERVER_SHUTDOWN);
+  server_die("received signal SIGTERM", false);
 }
 
 /*
@@ -45,7 +45,7 @@ sigterm_handler(int sig)
 static void
 sighup_handler(int sig)
 {
-  dorehash = 1;
+  dorehash = true;
 }
 
 /*
@@ -54,7 +54,7 @@ sighup_handler(int sig)
 static void
 sigusr1_handler(int sig)
 {
-  doremotd = 1;
+  doremotd = true;
 }
 
 /*
@@ -80,7 +80,7 @@ sigchld_handler(int sig)
 static void
 sigint_handler(int sig)
 {
-  server_die("received signal SIGINT", server_state.foreground ? SERVER_SHUTDOWN : SERVER_RESTART);
+  server_die("received signal SIGINT", server_state.foreground ? false : true);
 }
 
 /*
