@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2018 ircd-hybrid development team
+ *  Copyright (c) 1999-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file listener.c
  * \brief Implementation for handling listening sockets.
- * \version $Id: listener.c 8348 2018-03-04 13:23:49Z michael $
+ * \version $Id: listener.c 9013 2019-05-27 17:45:00Z michael $
  */
 
 #include "stdinc.h"
@@ -55,7 +55,7 @@ listener_make(const int port, const struct irc_ssaddr *addr)
   struct Listener *listener = xcalloc(sizeof(*listener));
 
   listener->port = port;
-  memcpy(&listener->addr, addr, sizeof(listener->addr));
+  listener->addr = *addr;
 
   return listener;
 }
@@ -112,7 +112,7 @@ listener_accept_connection(fde_t *F, void *data)
    * point, just assume that connections cannot
    * be accepted until some old is closed first.
    */
-  while ((fd = comm_accept(listener->fd->fd, &addr)) != -1)
+  while ((fd = comm_accept(listener->fd, &addr)) != -1)
   {
     /*
      * check for connection limit
@@ -134,7 +134,7 @@ listener_accept_connection(fde_t *F, void *data)
      * Do an initial check we aren't connecting too fast or with too many
      * from this IP...
      */
-    if ((pe = conf_connect_allowed(&addr, addr.ss.ss_family)))
+    if ((pe = conf_connect_allowed(&addr)))
     {
       ++ServerStats.is_ref;
 
@@ -181,13 +181,9 @@ listener_accept_connection(fde_t *F, void *data)
 static int
 inetport(struct Listener *listener)
 {
-  struct irc_ssaddr lsin;
   socklen_t opt = 1;
 
-  memset(&lsin, 0, sizeof(lsin));
-  memcpy(&lsin, &listener->addr, sizeof(lsin));
-
-  getnameinfo((const struct sockaddr *)&lsin, lsin.ss_len, listener->name,
+  getnameinfo((const struct sockaddr *)&listener->addr, listener->addr.ss_len, listener->name,
               sizeof(listener->name), NULL, 0, NI_NUMERICHOST);
 
   /*
@@ -213,9 +209,7 @@ inetport(struct Listener *listener)
    * Bind a port to listen for new connections if port is non-null,
    * else assume it is already open and try get something from it.
    */
-  lsin.ss_port = htons(listener->port);
-
-  if (bind(fd, (struct sockaddr *)&lsin, lsin.ss_len))
+  if (bind(fd, (const struct sockaddr *)&listener->addr, listener->addr.ss_len))
   {
     report_error(L_ALL, "binding listener socket %s:%s",
                  listener_get_name(listener), errno);
@@ -231,7 +225,7 @@ inetport(struct Listener *listener)
     return 0;
   }
 
-  listener->fd = fd_open(fd, 1, "Listener socket");
+  listener->fd = fd_open(fd, true, "Listener socket");
 
   /* Listen completion events are READ events .. */
 
@@ -351,7 +345,6 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
   assert(res);
 
   memcpy((struct sockaddr*)&vaddr, res->ai_addr, res->ai_addrlen);
-  vaddr.ss_port = port;
   vaddr.ss_len = res->ai_addrlen;
   freeaddrinfo(res);
 #ifdef MAKES_NO_SENSE
@@ -374,7 +367,6 @@ listener_add(int port, const char *vhost_ip, unsigned int flags)
     assert(res);
 
     memcpy((struct sockaddr*)&vaddr, res->ai_addr, res->ai_addrlen);
-    vaddr.ss_port = port;
     vaddr.ss_len = res->ai_addrlen;
     freeaddrinfo(res);
   }
