@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file match.c
  * \brief Functions to match/compare strings.
- * \version $Id: match.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: match.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -44,7 +44,7 @@ match(const char *mask, const char *name)
   const char *m_tmp = mask, *n_tmp = name;
   unsigned int star = 0;
 
-  while (1)
+  while (true)
   {
     switch (*m)
     {
