@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file memory.c
  * \brief Memory utilities.
- * \version $Id: memory.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: memory.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -100,10 +100,12 @@ xstrndup(const char *s, size_t len)
 void
 outofmemory(void)
 {
-  static int was_here = 0;
+  static bool was_here = false;
 
-  if (was_here++)
+  if (was_here == false)
+    was_here = true;
+  else
     abort();
 
-  server_die("out of memory", SERVER_RESTART);
+  server_die("out of memory", true);
 }
