@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 2000 Kevin L. Mitchell <klmitch@mit.edu>
- *  Copyright (c) 2013-2018 ircd-hybrid development team
+ *  Copyright (c) 2013-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file motd.c
  * \brief Message-of-the-day manipulation implementation.
- * \version $Id: motd.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: motd.c 8751 2019-01-01 11:06:50Z michael $
  */
 
 #include "stdinc.h"
@@ -61,7 +61,7 @@ motd_create(const char *mask, const char *path)
 
   if (EmptyString(mask))
     motd->type = MOTD_UNIVERSAL;
-  else if (class_find(mask, 1))
+  else if (class_find(mask, true))
     motd->type = MOTD_CLASS;
   else
   {
@@ -115,7 +115,7 @@ motd_cache(struct Motd *motd)
   {
     struct MotdCache *cache = node->data;
 
-    if (!strcmp(cache->path, motd->path) && cache->maxcount == motd->maxcount)
+    if (strcmp(cache->path, motd->path) == 0 && cache->maxcount == motd->maxcount)
     {
       cache->ref++;  /* Increase reference count */
       motd->cache = cache;  /* Remember cache */
@@ -238,22 +238,22 @@ motd_lookup(const struct Client *client_p)
       case MOTD_CLASS:
       {
         const struct ClassItem *class = class_get_ptr(&client_p->connection->confs);
-        if (!match(motd->mask, class->name))
+        if (match(motd->mask, class->name) == 0)
           return motd;
         break;
       }
       case MOTD_HOSTMASK:
-        if (!match(motd->mask, client_p->host) || !match(motd->mask, client_p->sockhost))
+        if (match(motd->mask, client_p->host) == 0 || match(motd->mask, client_p->sockhost) == 0)
           return motd;
         break;
       case MOTD_IPMASKV4:
-        if (client_p->connection->aftype == AF_INET)
-          if (match_ipv4(&client_p->connection->ip, &motd->address, motd->addrbits))
+        if (client_p->ip.ss.ss_family == AF_INET)
+          if (match_ipv4(&client_p->ip, &motd->address, motd->addrbits))
             return motd;
         break;
       case MOTD_IPMASKV6:
-        if (client_p->connection->aftype == AF_INET6)
-          if (match_ipv6(&client_p->connection->ip, &motd->address, motd->addrbits))
+        if (client_p->ip.ss.ss_family == AF_INET6)
+          if (match_ipv6(&client_p->ip, &motd->address, motd->addrbits))
             return motd;
         break;
       default: break;
@@ -271,7 +271,7 @@ motd_lookup(const struct Client *client_p)
 static void
 motd_forward(struct Client *client_p, const struct MotdCache *cache)
 {
-  if (!cache)  /* No motd to send */
+  if (cache == NULL)  /* No motd to send */
   {
     sendto_one_numeric(client_p, &me, ERR_NOMOTD);
     return;
@@ -308,7 +308,7 @@ motd_signon(struct Client *client_p)
 {
   const struct MotdCache *cache = motd_cache(motd_lookup(client_p));
 
-  if (!ConfigGeneral.short_motd || !cache)
+  if (ConfigGeneral.short_motd == 0 || cache == NULL)
     motd_forward(client_p, cache);
   else
   {
