@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file packet.c
  * \brief Packet handlers.
- * \version $Id: packet.c 8413 2018-03-22 18:09:06Z michael $
+ * \version $Id: packet.c 8957 2019-05-10 17:07:45Z michael $
  */
 
 #include "stdinc.h"
@@ -78,10 +78,10 @@ client_dopacket(struct Client *client_p, char *buffer, unsigned int length)
  * output       - length of <buffer>
  * side effects - one line is copied and removed from the dbuf
  */
-static unsigned int
+static size_t
 extract_one_line(struct dbuf_queue *qptr, char *buffer)
 {
-  unsigned int line_bytes = 0, eol_bytes = 0;
+  size_t line_bytes = 0, eol_bytes = 0;
   dlink_node *node;
 
   DLINK_FOREACH(node, qptr->blocks.head)
@@ -136,13 +136,11 @@ out:
 static void
 parse_client_queued(struct Client *client_p)
 {
-  unsigned int dolen = 0;
-
   if (IsUnknown(client_p))
   {
     unsigned int i = 0;
 
-    while (1)
+    while (true)
     {
       if (IsDefunct(client_p))
         return;
@@ -151,8 +149,7 @@ parse_client_queued(struct Client *client_p)
       if (i >= MAX_FLOOD)
         break;
 
-      dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf);
-
+      size_t dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf);
       if (dolen == 0)
         break;
 
@@ -170,12 +167,13 @@ parse_client_queued(struct Client *client_p)
 
   if (IsServer(client_p) || IsConnecting(client_p) || IsHandshake(client_p))
   {
-    while (1)
+    while (true)
     {
       if (IsDefunct(client_p))
         return;
 
-      if ((dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf)) == 0)
+      size_t dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf);
+      if (dolen == 0)
         break;
 
       client_dopacket(client_p, readBuf, dolen);
@@ -183,19 +181,19 @@ parse_client_queued(struct Client *client_p)
   }
   else if (IsClient(client_p))
   {
-    unsigned int checkflood = 1;
+    bool checkflood = true;
 
     if (ConfigGeneral.no_oper_flood && HasUMode(client_p, UMODE_OPER))
-      checkflood = 0;
+      checkflood = false;
     else if (HasFlag(client_p, FLAGS_CANFLOOD))
-      checkflood = 0;
+      checkflood = false;
 
     /*
      * Handle flood protection here - if we exceed our flood limit on messages
      * in this loop, we simply drop out of the loop prematurely.
      *   -- adrian
      */
-    while (1)
+    while (true)
     {
       if (IsDefunct(client_p))
         break;
@@ -214,12 +212,11 @@ parse_client_queued(struct Client *client_p)
        * as sent_parsed will always hover around the allow_read limit
        * and no 'bursts' will be permitted.
        */
-      if (checkflood)
-        if (client_p->connection->sent_parsed >= client_p->connection->allow_read)
+      if (checkflood == true)
+        if (client_p->connection->sent_parsed >= (IsFloodDone(client_p) ? MAX_FLOOD : MAX_FLOOD_BURST))
           break;
 
-      dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf);
-
+      size_t dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf);
       if (dolen == 0)
         break;
 
@@ -236,10 +233,10 @@ parse_client_queued(struct Client *client_p)
 void
 flood_endgrace(struct Client *client_p)
 {
-  AddFlag(client_p, FLAGS_FLOODDONE);
+  if (IsFloodDone(client_p))
+    return;  /* Grace period has already ended */
 
-  /* Drop their flood limit back down */
-  client_p->connection->allow_read = MAX_FLOOD;
+  AddFlag(client_p, FLAGS_FLOODDONE);
 
   /*
    * sent_parsed could be way over MAX_FLOOD but under MAX_FLOOD_BURST,
@@ -277,7 +274,7 @@ flood_recalc(fde_t *F, void *data)
   if (!IsDead(client_p))
   {
     /* and finally, reset the flood check */
-    comm_setflush(F, 1000, flood_recalc, client_p);
+    comm_setflush(F, 1, flood_recalc, client_p);
   }
 }
 
@@ -288,8 +285,7 @@ void
 read_packet(fde_t *F, void *data)
 {
   struct Client *const client_p = data;
-  int length = 0;
-  int want_write = 0;
+  ssize_t length = 0;
 
   assert(client_p);
   assert(client_p->connection);
@@ -304,13 +300,14 @@ read_packet(fde_t *F, void *data)
    * I personally think it makes the code too hairy to make sane.
    *     -- adrian
    */
-  do
+  while (true)
   {
     if (tls_isusing(&F->ssl))
     {
+      bool want_write = false;
       length = tls_read(&F->ssl, readBuf, sizeof(readBuf), &want_write);
 
-      if (want_write)
+      if (want_write == true)
         comm_setselect(F, COMM_SELECT_WRITE, sendq_unblocked, client_p, 0);
     }
     else
@@ -319,23 +316,20 @@ read_packet(fde_t *F, void *data)
     if (length <= 0)
     {
       /*
-       * If true, then we can recover from this error. Just jump out of
-       * the loop and re-register a new io-request.
+       * If true, then we can recover from this error. Stop here and register for
+       * another COMM_SELECT_READ io-request.
        */
-      if (length < 0 && comm_ignore_errno(errno))
-        break;
-
-      dead_link_on_read(client_p, length);
+      if (length < 0 && comm_ignore_errno(errno) == true)
+        comm_setselect(F, COMM_SELECT_READ, read_packet, client_p, 0);
+      else
+        dead_link_on_read(client_p, length);
       return;
     }
 
     dbuf_put(&client_p->connection->buf_recvq, readBuf, length);
 
-    if (client_p->connection->lasttime < CurrentTime)
-      client_p->connection->lasttime = CurrentTime;
-
-    if (client_p->connection->lasttime > client_p->connection->since)
-      client_p->connection->since = CurrentTime;
+    client_p->connection->last_ping = event_base->time.sec_monotonic;
+    client_p->connection->last_data = event_base->time.sec_monotonic;
 
     DelFlag(client_p, FLAGS_PINGSENT);
 
@@ -353,8 +347,5 @@ read_packet(fde_t *F, void *data)
       exit_client(client_p, "Excess Flood");
       return;
     }
-  } while (length == sizeof(readBuf) || tls_isusing(&F->ssl));
-
-  /* If we get here, we need to register for another COMM_SELECT_READ */
-  comm_setselect(F, COMM_SELECT_READ, read_packet, client_p, 0);
+  }
 }
