@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file parse.c
  * \brief The message parser.
- * \version $Id: parse.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: parse.c 9031 2019-05-29 20:46:10Z michael $
  */
 
 #include "stdinc.h"
@@ -39,6 +39,7 @@
 #include "memory.h"
 #include "user.h"
 #include "server.h"
+#include "packet.h"
 
 
 /*
@@ -176,7 +177,7 @@ parse_handle_numeric(unsigned int numeric, struct Client *source_p, int parc, ch
   else
     target_p = find_person(source_p, parv[1]);
 
-  if ((!target_p || target_p->from == source_p->from) && !chptr)
+  if ((target_p == NULL || target_p->from == source_p->from) && chptr == NULL)
     return;
 
   /*
@@ -221,9 +222,11 @@ parse_handle_command(struct Message *message, struct Client *source_p,
 {
   if (IsServer(source_p->from))
     ++message->rcount;
-
   ++message->count;
 
+  if (MyClient(source_p) && (message->flags & MFLG_ENDGRACE))
+    flood_endgrace(source_p);
+
   /* Check right amount of parameters is passed... --is */
   if (i < message->args_min)
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, message->cmd);
@@ -248,7 +251,7 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
   unsigned int parc = 0;
   unsigned int paramcount;
 
-  if (IsDefunct(client_p))
+  if (IsDead(client_p))
     return;
 
   assert(client_p->connection);
@@ -393,7 +396,7 @@ parse(struct Client *client_p, char *pbuffer, char *bufend)
     if (paramcount > MAXPARA)
       paramcount = MAXPARA;
 
-    while (1)
+    while (true)
     {
        while (*s == ' ')
          *s++ = '\0';
