@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file res.c
  * \brief ircd resolver functions
- * \version $Id: res.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: res.c 9006 2019-05-26 14:54:03Z michael $
  */
 
 /*
@@ -116,7 +116,7 @@ make_request(dns_callback_fnc callback, void *ctx)
 {
   struct reslist *request = xcalloc(sizeof(*request));
 
-  request->sentat = CurrentTime;
+  request->sentat = event_base->time.sec_monotonic;
   request->retries = 2;
   request->timeout = 4;  /* Start at 4 and exponential inc. */
   request->callback = callback;
@@ -137,43 +137,14 @@ make_request(dns_callback_fnc callback, void *ctx)
  *      paul vixie, 29may94
  *      revised for ircd, cryogen(stu) may03
  */
-static int
+static bool
 res_ourserver(const struct irc_ssaddr *inp)
 {
-  const struct sockaddr_in6 *v6in = (const struct sockaddr_in6 *)inp;
-  const struct sockaddr_in *v4in = (const struct sockaddr_in *)inp;
-
   for (unsigned int i = 0; i < irc_nscount; ++i)
-  {
-    const struct irc_ssaddr *srv = &irc_nsaddr_list[i];
-    const struct sockaddr_in6 *v6 = (const struct sockaddr_in6 *)srv;
-    const struct sockaddr_in *v4 = (const struct sockaddr_in *)srv;
+    if (address_compare(inp, &irc_nsaddr_list[i], true) == true)
+      return true;
 
-    /*
-     * Could probably just memcmp(srv, inp, srv.ss_len) here
-     * but we'll air on the side of caution - stu
-     */
-    switch (srv->ss.ss_family)
-    {
-      case AF_INET6:
-        if (srv->ss.ss_family == inp->ss.ss_family)
-          if (v6->sin6_port == v6in->sin6_port)
-            if (!memcmp(&v6->sin6_addr.s6_addr, &v6in->sin6_addr.s6_addr,
-                        sizeof(struct in6_addr)))
-              return 1;
-        break;
-      case AF_INET:
-        if (srv->ss.ss_family == inp->ss.ss_family)
-          if (v4->sin_port == v4in->sin_port)
-            if (v4->sin_addr.s_addr == v4in->sin_addr.s_addr)
-              return 1;
-        break;
-      default:
-        break;
-    }
-  }
-
-  return 0;
+  return false;
 }
 
 /*
@@ -185,13 +156,13 @@ start_resolver(void)
 {
   irc_res_init();
 
-  if (!ResolverFileDescriptor)
+  if (ResolverFileDescriptor == NULL)
   {
     int fd = comm_socket(irc_nsaddr_list[0].ss.ss_family, SOCK_DGRAM, 0);
     if (fd == -1)
       return;
 
-    ResolverFileDescriptor = fd_open(fd, 1, "UDP resolver socket");
+    ResolverFileDescriptor = fd_open(fd, true, "UDP resolver socket");
 
     /* At the moment, the resolver FD data is global .. */
     comm_setselect(ResolverFileDescriptor, COMM_SELECT_READ, res_readreply, NULL, 0);
@@ -316,7 +287,7 @@ do_query_name(dns_callback_fnc callback, void *ctx, const char *name,
 
   strlcpy(host_name, name, sizeof(host_name));
 
-  if (!request)
+  if (request == NULL)
   {
     request = make_request(callback, ctx);
     request->type = type;
@@ -372,11 +343,11 @@ do_query_number(dns_callback_fnc callback, void *ctx,
              (unsigned int)(cp[0] & 0xf), (unsigned int)(cp[0] >> 4));
   }
 
-  if (!request)
+  if (request == NULL)
   {
     request = make_request(callback, ctx);
     request->type = T_PTR;
-    memcpy(&request->addr, addr, sizeof(struct irc_ssaddr));
+    request->addr = *addr;
   }
 
   query_name(ipbuf, C_IN, T_PTR, request);
@@ -422,7 +393,7 @@ resend_query(struct reslist *request)
 /*
  * proc_answer - process name server reply
  */
-static int
+static bool
 proc_answer(struct reslist *request, HEADER *header, unsigned char *buf, unsigned char *eob)
 {
   char hostbuf[RFC1035_MAX_DOMAIN_LENGTH + 100]; /* working buffer */
@@ -451,7 +422,7 @@ proc_answer(struct reslist *request, HEADER *header, unsigned char *buf, unsigne
     n = irc_dn_expand(buf, eob, current, hostbuf, sizeof(hostbuf));
 
     if (n < 0  /* Broken message */ || n == 0  /* No more answers left */)
-      return 0;
+      return false;
 
     hostbuf[RFC1035_MAX_DOMAIN_LENGTH] = '\0';
 
@@ -479,45 +450,45 @@ proc_answer(struct reslist *request, HEADER *header, unsigned char *buf, unsigne
     {
       case T_A:
         if (request->type != T_A)
-          return 0;
+          return false;
 
         /*
          * Check for invalid rd_length or too many addresses
          */
         if (rd_length != sizeof(struct in_addr))
-          return 0;
+          return false;
 
         request->addr.ss_len = sizeof(struct sockaddr_in);
         v4 = (struct sockaddr_in *)&request->addr;
         v4->sin_family = AF_INET;
         memcpy(&v4->sin_addr, current, sizeof(struct in_addr));
-        return 1;
+        return true;
         break;
 
       case T_AAAA:
         if (request->type != T_AAAA)
-          return 0;
+          return false;
 
         if (rd_length != sizeof(struct in6_addr))
-          return 0;
+          return false;
 
         request->addr.ss_len = sizeof(struct sockaddr_in6);
         v6 = (struct sockaddr_in6 *)&request->addr;
         v6->sin6_family = AF_INET6;
         memcpy(&v6->sin6_addr, current, sizeof(struct in6_addr));
-        return 1;
+        return true;
         break;
 
       case T_PTR:
         if (request->type != T_PTR)
-          return 0;
+          return false;
 
         n = irc_dn_expand(buf, eob, current, hostbuf, sizeof(hostbuf));
         if (n < 0  /* Broken message */ || n == 0  /* No more answers left */)
-          return 0;
+          return false;
 
         request->namelength = strlcpy(request->name, hostbuf, sizeof(request->name));
-        return 1;
+        return true;
         break;
 
       case T_CNAME:
@@ -525,12 +496,12 @@ proc_answer(struct reslist *request, HEADER *header, unsigned char *buf, unsigne
         break;
 
       default:
-        return 0;
+        return false;
         break;
     }
   }
 
-  return 0;
+  return false;
 }
 
 /*
@@ -540,7 +511,6 @@ static void
 res_readreply(fde_t *F, void *data)
 {
   unsigned char buf[sizeof(HEADER) + MAXPACKET];
-  struct reslist *request = NULL;
   ssize_t rc = 0;
   socklen_t len = sizeof(struct irc_ssaddr);
   struct irc_ssaddr lsin;
@@ -553,7 +523,7 @@ res_readreply(fde_t *F, void *data)
     /*
      * Check against possibly fake replies
      */
-    if (res_ourserver(&lsin) == 0)
+    if (res_ourserver(&lsin) == false)
       continue;
 
     /*
@@ -569,6 +539,7 @@ res_readreply(fde_t *F, void *data)
      * Response for an id which we have already received an answer for
      * just ignore this response.
      */
+    struct reslist *request;
     if ((request = find_id(header->id)) == NULL)
       continue;
 
@@ -588,7 +559,7 @@ res_readreply(fde_t *F, void *data)
      * We only give it one shot. If it fails, just leave the client
      * unresolved.
      */
-    if (proc_answer(request, header, buf, buf + rc) == 0)
+    if (proc_answer(request, header, buf, buf + rc) == false)
     {
       (*request->callback)(request->callback_ctx, NULL, NULL, 0);
       rem_request(request);
@@ -648,7 +619,7 @@ timeout_query_list(void)
     struct reslist *request = node->data;
     uintmax_t timeout = request->sentat + request->timeout;
 
-    if (CurrentTime >= timeout)
+    if (event_base->time.sec_monotonic >= timeout)
     {
       if (--request->retries <= 0)
       {
@@ -658,7 +629,7 @@ timeout_query_list(void)
       }
       else
       {
-        request->sentat = CurrentTime;
+        request->sentat = event_base->time.sec_monotonic;
         request->timeout += request->timeout;
         resend_query(request);
       }
@@ -668,7 +639,7 @@ timeout_query_list(void)
       next_time = timeout;
   }
 
-  return (next_time > CurrentTime) ? next_time : (CurrentTime + AR_TTL);
+  return (next_time > event_base->time.sec_monotonic) ? next_time : (event_base->time.sec_monotonic + AR_TTL);
 }
 
 /*
