@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file restart.c
  * \brief Functions to allow the ircd to restart.
- * \version $Id: restart.c 8338 2018-03-03 22:26:59Z michael $
+ * \version $Id: restart.c 9001 2019-05-25 23:13:18Z michael $
  */
 
 #include "stdinc.h"
@@ -38,21 +38,26 @@
 
 
 void
-server_die(const char *message, int action)
+server_die(const char *message, bool restart)
 {
   char buffer[IRCD_BUFSIZE] = "";
-  dlink_node *node = NULL;
-  static int was_here = 0;
+  dlink_node *node;
 
-  if (action == SERVER_RESTART && was_here++)
-    abort();
+  if (restart == true)
+  {
+    static bool was_here = false;
+    if (was_here == false)
+      was_here = true;
+    else
+      abort(); 
+  } 
 
   if (EmptyString(message))
     snprintf(buffer, sizeof(buffer), "Server %s",
-             action == SERVER_RESTART ? "Restarting" : "Terminating");
+             restart ? "Restarting" : "Terminating");
   else
     snprintf(buffer, sizeof(buffer), "Server %s: %s",
-             action == SERVER_RESTART ? "Restarting" : "Terminating", message);
+             restart ? "Restarting" : "Terminating", message);
 
   DLINK_FOREACH(node, local_client_list.head)
     sendto_one_notice(node->data, &me, ":%s", buffer);
@@ -63,12 +68,11 @@ server_die(const char *message, int action)
 
   save_all_databases(NULL);
 
-  send_queued_all();
   close_fds();
 
   unlink(pidFileName);
 
-  if (action == SERVER_RESTART)
+  if (restart == true)
   {
     execv(SPATH, myargv);
     exit(EXIT_FAILURE);
