@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd.c
  * \brief Network functions.
- * \version $Id: s_bsd.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: s_bsd.c 9044 2019-05-31 09:51:38Z michael $
  */
 
 #include "stdinc.h"
@@ -53,7 +53,6 @@ static const char *const comm_err_str[] =
 {
   [COMM_OK] = "Comm OK",
   [COMM_ERR_BIND] = "Error during bind()",
-  [COMM_ERR_DNS] = "Error during DNS lookup",
   [COMM_ERR_TIMEOUT] = "connect timeout",
   [COMM_ERR_CONNECT] = "Error during connect()",
   [COMM_ERROR] = "Comm Error"
@@ -61,7 +60,6 @@ static const char *const comm_err_str[] =
 
 static void comm_connect_callback(fde_t *, int);
 static void comm_connect_timeout(fde_t *, void *);
-static void comm_connect_dns_callback(void *, const struct irc_ssaddr *, const char *, size_t);
 static void comm_connect_tryconnect(fde_t *, void *);
 
 
@@ -72,18 +70,22 @@ static void comm_connect_tryconnect(fde_t *, void *);
  * gamble anyway.
  */
 int
-comm_get_sockerr(int fd)
+comm_get_sockerr(fde_t *F)
 {
   int errtmp = errno;
 #ifdef SO_ERROR
   int err = 0;
   socklen_t len = sizeof(err);
 
-  if (fd > -1 && !getsockopt(fd, SOL_SOCKET, SO_ERROR, &err, &len))
+  assert(F);
+  assert(F->flags.open == true);
+
+  if (getsockopt(F->fd, SOL_SOCKET, SO_ERROR, &err, &len) == 0)
   {
     if (err)
       errtmp = err;
   }
+
   errno = errtmp;
 #endif
   return errtmp;
@@ -154,7 +156,7 @@ ssl_handshake(fde_t *F, void *data)
   tls_handshake_status_t ret = tls_handshake(&F->ssl, TLS_ROLE_SERVER, NULL);
   if (ret != TLS_HANDSHAKE_DONE)
   {
-    if ((CurrentTime - client_p->connection->firsttime) > CONNECTTIMEOUT)
+    if ((event_base->time.sec_monotonic - client_p->connection->created_monotonic) > TLS_HANDSHAKE_TIMEOUT)
     {
       exit_client(client_p, "Timeout during TLS handshake");
       return;
@@ -163,12 +165,10 @@ ssl_handshake(fde_t *F, void *data)
     switch (ret)
     {
       case TLS_HANDSHAKE_WANT_WRITE:
-        comm_setselect(client_p->connection->fd, COMM_SELECT_WRITE,
-                       ssl_handshake, client_p, CONNECTTIMEOUT);
+        comm_setselect(F, COMM_SELECT_WRITE, ssl_handshake, client_p, TLS_HANDSHAKE_TIMEOUT);
         return;
       case TLS_HANDSHAKE_WANT_READ:
-        comm_setselect(client_p->connection->fd, COMM_SELECT_READ,
-                       ssl_handshake, client_p, CONNECTTIMEOUT);
+        comm_setselect(F, COMM_SELECT_READ, ssl_handshake, client_p, TLS_HANDSHAKE_TIMEOUT);
         return;
       default:
         exit_client(client_p, "Error during TLS handshake");
@@ -178,7 +178,7 @@ ssl_handshake(fde_t *F, void *data)
 
   comm_settimeout(F, 0, NULL, NULL);
 
-  if (!tls_verify_cert(&F->ssl, ConfigServerInfo.message_digest_algorithm, &client_p->certfp))
+  if (tls_verify_cert(&F->ssl, ConfigServerInfo.message_digest_algorithm, &client_p->certfp) == false)
     ilog(LOG_TYPE_IRCD, "Client %s!%s@%s gave bad TLS client certificate",
          client_p->name, client_p->username, client_p->host);
 
@@ -197,19 +197,18 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
 {
   struct Client *client_p = client_make(NULL);
 
-  client_p->connection->fd = fd_open(fd, 1, (listener->flags & LISTENER_SSL) ?
+  client_p->connection->fd = fd_open(fd, true, (listener->flags & LISTENER_SSL) ?
                                      "Incoming SSL connection" : "Incoming connection");
 
   /*
    * copy address to 'sockhost' as a string, copy it to host too
    * so we have something valid to put into error messages...
    */
-  memcpy(&client_p->connection->ip, irn, sizeof(client_p->connection->ip));
+  client_p->ip = *irn;
 
-  getnameinfo((const struct sockaddr *)&client_p->connection->ip,
-              client_p->connection->ip.ss_len, client_p->sockhost,
+  getnameinfo((const struct sockaddr *)&client_p->ip,
+              client_p->ip.ss_len, client_p->sockhost,
               sizeof(client_p->sockhost), NULL, 0, NI_NUMERICHOST);
-  client_p->connection->aftype = client_p->connection->ip.ss.ss_family;
 
   if (client_p->sockhost[0] == ':')
   {
@@ -224,7 +223,7 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
 
   if (listener->flags & LISTENER_SSL)
   {
-    if (!tls_new(&client_p->connection->fd->ssl, fd, TLS_ROLE_SERVER))
+    if (tls_new(&client_p->connection->fd->ssl, fd, TLS_ROLE_SERVER) == false)
     {
       SetDead(client_p);
       exit_client(client_p, "TLS context initialization failed");
@@ -244,7 +243,7 @@ add_connection(struct Listener *listener, struct irc_ssaddr *irn, int fd)
  * generally useful for non-blocking network IO related errnos.
  *     -- adrian
  */
-int
+bool
 comm_ignore_errno(int ierrno)
 {
   switch (ierrno)
@@ -259,9 +258,9 @@ comm_ignore_errno(int ierrno)
 #ifdef ERESTART
     case ERESTART:
 #endif
-        return 1;
+      return true;
     default:
-        return 0;
+      return false;
   }
 }
 
@@ -273,9 +272,10 @@ comm_ignore_errno(int ierrno)
 void
 comm_settimeout(fde_t *F, uintmax_t timeout, void (*callback)(fde_t *, void *), void *cbdata)
 {
-  assert(F->flags.open);
+  assert(F);
+  assert(F->flags.open == true);
 
-  F->timeout = CurrentTime + (timeout / 1000);
+  F->timeout = event_base->time.sec_monotonic + timeout;
   F->timeout_handler = callback;
   F->timeout_data = cbdata;
 }
@@ -295,9 +295,10 @@ comm_settimeout(fde_t *F, uintmax_t timeout, void (*callback)(fde_t *, void *),
 void
 comm_setflush(fde_t *F, uintmax_t timeout, void (*callback)(fde_t *, void *), void *cbdata)
 {
-  assert(F->flags.open);
+  assert(F);
+  assert(F->flags.open == true);
 
-  F->flush_timeout = CurrentTime + (timeout / 1000);
+  F->flush_timeout = event_base->time.sec_monotonic + timeout;
   F->flush_handler = callback;
   F->flush_data = cbdata;
 }
@@ -319,12 +320,12 @@ comm_checktimeouts(void *unused)
   {
     fde_t *F = &fd_table[fd];
 
-    if (F->flags.open == 0)
+    if (F->flags.open == false)
       continue;
 
     /* check flush functions */
     if (F->flush_handler && F->flush_timeout > 0 &&
-        F->flush_timeout < CurrentTime)
+        F->flush_timeout < event_base->time.sec_monotonic)
     {
       hdl = F->flush_handler;
       data = F->flush_data;
@@ -335,7 +336,7 @@ comm_checktimeouts(void *unused)
 
     /* check timeouts */
     if (F->timeout_handler && F->timeout > 0 &&
-        F->timeout < CurrentTime)
+        F->timeout < event_base->time.sec_monotonic)
     {
       /* Call timeout handler */
       hdl = F->timeout_handler;
@@ -361,20 +362,17 @@ comm_checktimeouts(void *unused)
  *               may be called now, or it may be called later.
  */
 void
-comm_connect_tcp(fde_t *F, const char *host, unsigned short port, struct sockaddr *clocal,
-                 int socklen, void (*callback)(fde_t *, int, void *), void *data,
-                 int aftype, uintmax_t timeout)
+comm_connect_tcp(fde_t *F, const struct irc_ssaddr *caddr, unsigned short port, const struct irc_ssaddr *baddr,
+                 void (*callback)(fde_t *, int, void *), void *data, uintmax_t timeout)
 {
-  struct addrinfo hints, *res;
-  char portname[PORTNAMELEN + 1];
-
   assert(callback);
+
+  F->connect.hostaddr = *caddr;
+  /* The cast is hacky, but safe - port offset is same on v4 and v6 */
+  ((struct sockaddr_in *)&F->connect.hostaddr)->sin_port = htons(port);
   F->connect.callback = callback;
   F->connect.data = data;
 
-  F->connect.hostaddr.ss.ss_family = aftype;
-  F->connect.hostaddr.ss_port = htons(port);
-
   /* Note that we're using a passed sockaddr here. This is because
    * generally you'll be bind()ing to a sockaddr grabbed from
    * getsockname(), so this makes things easier.
@@ -382,48 +380,15 @@ comm_connect_tcp(fde_t *F, const char *host, unsigned short port, struct sockadd
    * virtual host IP, for completeness.
    *   -- adrian
    */
-  if (clocal && bind(F->fd, clocal, socklen) < 0)
+  if (baddr && bind(F->fd, (const struct sockaddr *)baddr, baddr->ss_len) < 0)
   {
     /* Failure, call the callback with COMM_ERR_BIND */
     comm_connect_callback(F, COMM_ERR_BIND);
     return;  /* ... and quit */
   }
 
-  memset(&hints, 0, sizeof(hints));
-
-  hints.ai_family = AF_UNSPEC;
-  hints.ai_socktype = SOCK_STREAM;
-  hints.ai_flags = AI_PASSIVE | AI_NUMERICHOST;
-
-  snprintf(portname, sizeof(portname), "%d", port);
-
-  /*
-   * Next, if we have been given an IP address, get the address and skip the
-   * DNS check (and head direct to comm_connect_tryconnect()).
-   */
-  if (getaddrinfo(host, portname, &hints, &res))
-  {
-    /* Send the DNS request, for the next level */
-    if (aftype == AF_INET6)
-      gethost_byname_type(comm_connect_dns_callback, F, host, T_AAAA);
-    else
-      gethost_byname_type(comm_connect_dns_callback, F, host, T_A);
-  }
-  else
-  {
-    /* We have a valid IP, so we just call tryconnect */
-    /* Make sure we actually set the timeout here .. */
-    assert(res);
-
-    memcpy(&F->connect.hostaddr, res->ai_addr, res->ai_addrlen);
-    F->connect.hostaddr.ss_len = res->ai_addrlen;
-    F->connect.hostaddr.ss.ss_family = res->ai_family;
-
-    freeaddrinfo(res);
-
-    comm_settimeout(F, timeout * 1000, comm_connect_timeout, NULL);
-    comm_connect_tryconnect(F, NULL);
-  }
+  comm_settimeout(F, timeout, comm_connect_timeout, NULL);
+  comm_connect_tryconnect(F, NULL);
 }
 
 /*
@@ -461,42 +426,6 @@ comm_connect_timeout(fde_t *F, void *unused)
   comm_connect_callback(F, COMM_ERR_TIMEOUT);
 }
 
-/*
- * comm_connect_dns_callback() - called at the completion of the DNS request
- *
- * The DNS request has completed, so if we've got an error, return it,
- * otherwise we initiate the connect()
- */
-static void
-comm_connect_dns_callback(void *vptr, const struct irc_ssaddr *addr, const char *name, size_t namelength)
-{
-  fde_t *const F = vptr;
-
-  if (!addr)
-  {
-    comm_connect_callback(F, COMM_ERR_DNS);
-    return;
-  }
-
-  /* No error, set a 30 second timeout */
-  comm_settimeout(F, 30 * 1000, comm_connect_timeout, NULL);
-
-  /* Copy over the DNS reply info so we can use it in the connect() */
-  /*
-   * Note we don't fudge the refcount here, because we aren't keeping
-   * the DNS record around, and the DNS cache is gone anyway..
-   *     -- adrian
-   */
-  memcpy(&F->connect.hostaddr, addr, addr->ss_len);
-
-  /* The cast is hacky, but safe - port offset is same on v4 and v6 */
-  ((struct sockaddr_in *)&F->connect.hostaddr)->sin_port = F->connect.hostaddr.ss_port;
-  F->connect.hostaddr.ss_len = addr->ss_len;
-
-  /* Now, call the tryconnect() routine to try a connect() */
-  comm_connect_tryconnect(F, NULL);
-}
-
 /* static void comm_connect_tryconnect(fde_t *fd, void *unused)
  * Input: The fd, the handler data(unused).
  * Output: None.
@@ -588,7 +517,7 @@ comm_socket(int family, int sock_type, int proto)
  * fd_open (this function no longer does it).
  */
 int
-comm_accept(int fd, struct irc_ssaddr *addr)
+comm_accept(fde_t *F, struct irc_ssaddr *addr)
 {
   socklen_t addrlen = sizeof(struct irc_ssaddr);
 
@@ -605,16 +534,16 @@ comm_accept(int fd, struct irc_ssaddr *addr)
    * reserved fd limit, but we can deal with that when comm_open()
    * also does it. XXX -- adrian
    */
-  int new_fd = accept(fd, (struct sockaddr *)addr, &addrlen);
-  if (new_fd < 0)
+  int fd = accept(F->fd, (struct sockaddr *)addr, &addrlen);
+  if (fd < 0)
     return -1;
 
   remove_ipv6_mapping(addr);
 
-  setup_socket(new_fd);
+  setup_socket(fd);
 
   /* .. and return */
-  return new_fd;
+  return fd;
 }
 
 /*
