@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_kqueue.c
  * \brief kqueue() compatible network routines.
- * \version $Id: s_bsd_kqueue.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: s_bsd_kqueue.c 8940 2019-04-27 23:45:33Z michael $
  */
 
 #include "stdinc.h"
@@ -55,7 +55,7 @@ comm_select_init(void)
     exit(EXIT_FAILURE); /* Whee! */
   }
 
-  fd_open(kqueue_fd, 0, "kqueue() file descriptor");
+  fd_open(kqueue_fd, false, "kqueue() file descriptor");
 }
 
 /*
@@ -91,6 +91,9 @@ comm_setselect(fde_t *F, unsigned int type, void (*handler)(fde_t *, void *),
 {
   int new_events, diff;
 
+  assert(F);
+  assert(F->flags.open == true);
+
   if ((type & COMM_SELECT_READ))
   {
     F->read_handler = handler;
@@ -108,7 +111,7 @@ comm_setselect(fde_t *F, unsigned int type, void (*handler)(fde_t *, void *),
 
   if (timeout)
   {
-    F->timeout = CurrentTime + (timeout / 1000);
+    F->timeout = event_base->time.sec_monotonic + timeout;
     F->timeout_handler = handler;
     F->timeout_data = client_data;
   }
@@ -149,7 +152,7 @@ comm_select(void)
   num = kevent(kqueue_fd, kq_fdlist, kqoff, ke, KE_LENGTH, &poll_time);
   kqoff = 0;
 
-  set_time();
+  event_time_set();
 
   if (num < 0)
   {
@@ -162,7 +165,7 @@ comm_select(void)
   {
     fde_t *F = ke[i].udata;
 
-    if (F->flags.open == 0 || (ke[i].flags & EV_ERROR))
+    if (F->flags.open == false || (ke[i].flags & EV_ERROR))
       continue;
 
     if (ke[i].filter == EVFILT_READ)
@@ -172,7 +175,7 @@ comm_select(void)
         F->read_handler = NULL;
         hdl(F, F->read_data);
 
-        if (F->flags.open == 0)
+        if (F->flags.open == false)
           continue;
       }
     }
@@ -184,7 +187,7 @@ comm_select(void)
         F->write_handler = NULL;
         hdl(F, F->write_data);
 
-        if (F->flags.open == 0)
+        if (F->flags.open == false)
           continue;
       }
     }
