@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2018 ircd-hybrid development team
+ *  Copyright (c) 2000-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_bsd_poll.c
  * \brief POSIX poll() compatible network routines.
- * \version $Id: s_bsd_poll.c 8430 2018-03-27 18:48:40Z michael $
+ * \version $Id: s_bsd_poll.c 8940 2019-04-27 23:45:33Z michael $
  */
 
 #include "stdinc.h"
@@ -72,6 +72,9 @@ comm_setselect(fde_t *F, unsigned int type, void (*handler)(fde_t *, void *),
 {
   int new_events;
 
+  assert(F);
+  assert(F->flags.open == true);
+
   if ((type & COMM_SELECT_READ))
   {
     F->read_handler = handler;
@@ -89,7 +92,7 @@ comm_setselect(fde_t *F, unsigned int type, void (*handler)(fde_t *, void *),
 
   if (timeout)
   {
-    F->timeout = CurrentTime + (timeout / 1000);
+    F->timeout = event_base->time.sec_monotonic + timeout;
     F->timeout_handler = handler;
     F->timeout_data = client_data;
   }
@@ -151,7 +154,7 @@ comm_select(void)
 
   num = poll(pollfds, pollnum, SELECT_DELAY);
 
-  set_time();
+  event_time_set();
 
   if (num < 0)
   {
@@ -170,7 +173,7 @@ comm_select(void)
 
     fde_t *F = &fd_table[pollfds[ci].fd];
 
-    if (F->flags.open == 0)
+    if (F->flags.open == false)
       continue;
 
     if (revents & (POLLRDNORM | POLLIN | POLLHUP | POLLERR))
@@ -180,7 +183,7 @@ comm_select(void)
         F->read_handler = NULL;
         hdl(F, F->read_data);
 
-        if (F->flags.open == 0)
+        if (F->flags.open == false)
           continue;
       }
     }
@@ -192,7 +195,7 @@ comm_select(void)
         F->write_handler = NULL;
         hdl(F, F->write_data);
 
-        if (F->flags.open == 0)
+        if (F->flags.open == false)
           continue;
       }
     }
