@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.c
  * \brief Functions for sending messages.
- * \version $Id: send.c 8413 2018-03-22 18:09:06Z michael $
+ * \version $Id: send.c 9001 2019-05-25 23:13:18Z michael $
  */
 
 #include "stdinc.h"
@@ -134,14 +134,10 @@ send_message_remote(struct Client *to, const struct Client *from, struct dbuf_bl
   assert(to->from == to);
 
   if (to == from->from)
-  {
-    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
-                         "Send message to %s dropped from %s (Fake Dir)",
+    sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE, "Send message to %s dropped from %s (Fake Dir)",
                          to->name, from->name);
-    return;
-  }
-
-  send_message(to, buf);
+  else
+    send_message(to, buf);
 }
 
 /*
@@ -171,8 +167,7 @@ sendq_unblocked(fde_t *F, void *data)
 void
 send_queued_write(struct Client *to)
 {
-  int retlen = 0;
-  int want_read = 0;
+  ssize_t retlen = 0;
 
   /*
    ** Once socket is marked dead, we cannot start writing to it,
@@ -182,80 +177,44 @@ send_queued_write(struct Client *to)
     return;  /* no use calling send() now */
 
   /* Next, lets try to write some data */
-  if (dbuf_length(&to->connection->buf_sendq))
+  while (dbuf_length(&to->connection->buf_sendq))
   {
-    do
+    bool want_read = false;
+    const struct dbuf_block *first = to->connection->buf_sendq.blocks.head->data;
+
+    if (tls_isusing(&to->connection->fd->ssl))
     {
-      const struct dbuf_block *first = to->connection->buf_sendq.blocks.head->data;
+      retlen = tls_write(&to->connection->fd->ssl, first->data + to->connection->buf_sendq.pos,
+                                                   first->size - to->connection->buf_sendq.pos, &want_read);
 
-      if (tls_isusing(&to->connection->fd->ssl))
+      if (want_read == true)
+        return;  /* Retry later, don't register for write events */
+    }
+    else
+      retlen = send(to->connection->fd->fd, first->data + to->connection->buf_sendq.pos,
+                                            first->size - to->connection->buf_sendq.pos, 0);
+
+    if (retlen <= 0)
+    {
+      if (retlen < 0 && comm_ignore_errno(errno) == true)
       {
-        retlen = tls_write(&to->connection->fd->ssl, first->data + to->connection->buf_sendq.pos,
-                                                     first->size - to->connection->buf_sendq.pos, &want_read);
-
-        if (want_read)
-          return;  /* Retry later, don't register for write events */
+        AddFlag(to, FLAGS_BLOCKED);
+        /* We have a non-fatal error, reschedule a write */
+        comm_setselect(to->connection->fd, COMM_SELECT_WRITE, sendq_unblocked, to, 0);
       }
       else
-        retlen = send(to->connection->fd->fd, first->data + to->connection->buf_sendq.pos,
-                                              first->size - to->connection->buf_sendq.pos, 0);
-
-      if (retlen <= 0)
-        break;
-
-      dbuf_delete(&to->connection->buf_sendq, retlen);
-
-      /* We have some data written .. update counters */
-      to->connection->send.bytes += retlen;
-      me.connection->send.bytes += retlen;
-    } while (dbuf_length(&to->connection->buf_sendq));
-
-    if (retlen < 0 && comm_ignore_errno(errno))
-    {
-      AddFlag(to, FLAGS_BLOCKED);
-
-      /* we have a non-fatal error, reschedule a write */
-      comm_setselect(to->connection->fd, COMM_SELECT_WRITE, sendq_unblocked, to, 0);
-    }
-    else if (retlen <= 0)
-    {
-      dead_link_on_write(to, errno);
+        dead_link_on_write(to, errno);
       return;
     }
+
+    dbuf_delete(&to->connection->buf_sendq, retlen);
+
+    /* We have some data written .. update counters */
+    to->connection->send.bytes += retlen;
+    me.connection->send.bytes += retlen;
   }
 }
 
-/* send_queued_all()
- *
- * input        - NONE
- * output       - NONE
- * side effects - try to flush sendq of each client
- */
-void
-send_queued_all(void)
-{
-  dlink_node *node;
-
-  /* Servers are processed first, mainly because this can generate
-   * a notice to opers, which is to be delivered by this function.
-   */
-  DLINK_FOREACH(node, local_server_list.head)
-    send_queued_write(node->data);
-
-  DLINK_FOREACH(node, unknown_list.head)
-    send_queued_write(node->data);
-
-  DLINK_FOREACH(node, local_client_list.head)
-    send_queued_write(node->data);
-
-  /* NOTE: This can still put clients on aborted_list; unfortunately,
-   * exit_aborted_clients takes precedence over send_queued_all,
-   * because exiting clients can generate server/oper traffic.
-   * The easiest approach is dealing with aborted clients in the next I/O lap.
-   * -adx
-   */
-}
-
 /* sendto_one()
  *
  * inputs	- pointer to destination client
@@ -290,7 +249,7 @@ sendto_one_numeric(struct Client *to, const struct Client *from, enum irc_numeri
   const char *numstr = NULL;
 
   if (IsDead(to->from))
-    return;
+    return;  /* This socket has already been marked as dead */
 
   const char *dest = ID_or_name(to, to);
   if (EmptyString(dest))
@@ -320,7 +279,7 @@ sendto_one_notice(struct Client *to, const struct Client *from, const char *patt
   va_list args;
 
   if (IsDead(to->from))
-    return;
+    return;  /* This socket has already been marked as dead */
 
   const char *dest = ID_or_name(to, to);
   if (EmptyString(dest))
@@ -384,7 +343,7 @@ sendto_channel_butone(struct Client *one, const struct Client *from,
 
     assert(IsClient(target_p));
 
-    if (IsDefunct(target_p->from))
+    if (IsDead(target_p->from))
       continue;
 
     if (one && (target_p->from == one->from))
@@ -478,7 +437,7 @@ sendto_server(const struct Client *one,
  *		  used by m_nick.c and exit_one_client.
  */
 void
-sendto_common_channels_local(struct Client *user, int touser, unsigned int poscap,
+sendto_common_channels_local(struct Client *user, bool touser, unsigned int poscap,
                              unsigned int negcap, const char *pattern, ...)
 {
   va_list args;
@@ -499,13 +458,18 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int posca
   {
     chptr = ((struct Membership *)cptr->data)->chptr;
 
-    DLINK_FOREACH(uptr, chptr->locmembers.head)
+    DLINK_FOREACH(uptr, chptr->members_local.head)
     {
       member = uptr->data;
       target_p = member->client_p;
 
-      if (target_p == user || IsDefunct(target_p) ||
-          target_p->connection->serial == current_serial)
+      if (IsDead(target_p))
+        continue;
+
+      if (target_p == user)
+        continue;
+
+      if (target_p->connection->serial == current_serial)
         continue;
 
       if (poscap && HasCap(target_p, poscap) != poscap)
@@ -519,8 +483,7 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int posca
     }
   }
 
-  if (touser && MyConnect(user) && !IsDead(user) &&
-      user->connection->serial != current_serial)
+  if (touser == true && MyConnect(user) && !IsDead(user))
     if (HasCap(user, poscap) == poscap)
       send_message(user, buffer);
 
@@ -547,15 +510,15 @@ sendto_channel_local(const struct Client *one, struct Channel *chptr, unsigned i
   send_format(buffer, pattern, args);
   va_end(args);
 
-  DLINK_FOREACH(node, chptr->locmembers.head)
+  DLINK_FOREACH(node, chptr->members_local.head)
   {
     struct Membership *member = node->data;
     struct Client *target_p = member->client_p;
 
-    if (IsDefunct(target_p))
+    if (IsDead(target_p))
       continue;
 
-    if (one && target_p == one->from)
+    if (one && (target_p == one->from))
       continue;
 
     if (status && (member->flags & status) == 0)
@@ -590,13 +553,13 @@ sendto_channel_local(const struct Client *one, struct Channel *chptr, unsigned i
  * output	- 1 or 0 if match or not
  * side effects	- NONE
  */
-static int
+static bool
 match_it(const struct Client *one, const char *mask, unsigned int what)
 {
   if (what == MATCH_HOST)
-    return !match(mask, one->host);
+    return match(mask, one->host) == 0;
 
-  return !match(mask, one->servptr->name);
+  return match(mask, one->servptr->name) == 0;
 }
 
 /* sendto_match_butone()
@@ -631,9 +594,16 @@ sendto_match_butone(const struct Client *one, const struct Client *from,
   {
     struct Client *client_p = node->data;
 
-    if ((!one || client_p != one->from) && !IsDefunct(client_p) &&
-        match_it(client_p, mask, what))
-      send_message(client_p, local_buf);
+    if (IsDead(client_p))
+      continue;
+
+    if (one && (client_p == one->from))
+      continue;
+
+    if (match_it(client_p, mask, what) == false)
+      continue;
+
+    send_message(client_p, local_buf);
   }
 
   /* Now scan servers */
@@ -665,8 +635,13 @@ sendto_match_butone(const struct Client *one, const struct Client *from,
      * server deal with it.
      * -wnder
      */
-    if ((!one || client_p != one->from) && !IsDefunct(client_p))
-      send_message_remote(client_p, from, remote_buf);
+    if (IsDead(client_p))
+      continue;
+
+    if (one && (client_p == one->from))
+      continue;
+
+    send_message_remote(client_p, from, remote_buf);
   }
 
   dbuf_ref_free(local_buf);
@@ -701,8 +676,15 @@ sendto_match_servs(const struct Client *source_p, const char *mask, unsigned int
   {
     struct Client *target_p = node->data;
 
-    /* Do not attempt to send to ourselves, or the source */
-    if (IsMe(target_p) || target_p->from == source_p->from)
+    if (IsDead(target_p->from))
+      continue;
+
+    /* Do not attempt to send to ourselves ... */
+    if (IsMe(target_p))
+      continue;
+
+    /* ... or the source */
+    if (target_p->from == source_p->from)
       continue;
 
     if (target_p->from->connection->serial == current_serial)
@@ -802,6 +784,9 @@ sendto_realops_flags(unsigned int flags, int level, int type, const char *patter
     struct Client *client_p = node->data;
     assert(HasUMode(client_p, UMODE_OPER));
 
+    if (IsDead(client_p))
+      continue;
+
     /*
      * If we're sending it to opers and they're an admin, skip.
      * If we're sending it to admins, and they're not, skip.
@@ -810,8 +795,10 @@ sendto_realops_flags(unsigned int flags, int level, int type, const char *patter
         ((level == L_OPER) && HasUMode(client_p, UMODE_ADMIN)))
       continue;
 
-    if (HasUMode(client_p, flags) && !IsDead(client_p))
-      send_message(client_p, buffer);
+    if (!HasUMode(client_p, flags))
+      continue;
+
+    send_message(client_p, buffer);
   }
 
   dbuf_ref_free(buffer);
@@ -830,10 +817,10 @@ sendto_realops_flags_ratelimited(uintmax_t *rate, const char *pattern, ...)
   va_list args;
   char buffer[IRCD_BUFSIZE] = "";
 
-  if ((CurrentTime - *rate) < 20)
+  if ((event_base->time.sec_monotonic - *rate) < 20)
     return;
 
-  *rate = CurrentTime;
+  *rate = event_base->time.sec_monotonic;
 
   va_start(args, pattern);
   vsnprintf(buffer, sizeof(buffer), pattern, args);
@@ -873,8 +860,13 @@ sendto_wallops_flags(unsigned int flags, const struct Client *source_p,
     struct Client *client_p = node->data;
     assert(client_p->umodes & UMODE_OPER);
 
-    if (HasUMode(client_p, flags) && !IsDead(client_p))
-      send_message(client_p, buffer);
+    if (IsDead(client_p))
+      continue;
+
+    if (!HasUMode(client_p, flags))
+      continue;
+
+    send_message(client_p, buffer);
   }
 
   dbuf_ref_free(buffer);
