@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file server.c
  * \brief Server related functions.
- * \version $Id: server.c 8436 2018-03-29 09:04:53Z michael $
+ * \version $Id: server.c 9004 2019-05-26 00:01:08Z michael $
  */
 
 #include "stdinc.h"
@@ -186,14 +186,14 @@ server_hunt(struct Client *source_p, const char *command,
     if (h->target_p->from == source_p->from && !MyConnect(h->target_p))
       h->target_p = NULL;
 
-  if (!h->target_p && has_wildcards(parv[server]))
+  if (h->target_p == NULL && has_wildcards(parv[server]))
   {
     DLINK_FOREACH(node, global_server_list.head)
     {
       struct Client *tmp = node->data;
 
       assert(IsMe(tmp) || IsServer(tmp));
-      if (!match(parv[server], tmp->name))
+      if (match(parv[server], tmp->name) == 0)
       {
         if (tmp->from == source_p->from && !MyConnect(tmp))
           continue;
@@ -203,14 +203,14 @@ server_hunt(struct Client *source_p, const char *command,
       }
     }
 
-    if (!h->target_p)
+    if (h->target_p == NULL)
     {
       DLINK_FOREACH(node, global_client_list.head)
       {
         struct Client *tmp = node->data;
 
         assert(IsClient(tmp));
-        if (!match(parv[server], tmp->name))
+        if (match(parv[server], tmp->name) == 0)
         {
           if (tmp->from == source_p->from && !MyConnect(tmp))
             continue;
@@ -259,7 +259,7 @@ try_connections(void *unused)
 {
   dlink_node *node;
 
-  if (GlobalSetOptions.autoconn == 0)
+  if (GlobalSetOptions.autoconn == false)
     return;
 
   DLINK_FOREACH(node, connect_items.head)
@@ -280,10 +280,10 @@ try_connections(void *unused)
      * made one successfull connection... [this algorithm is
      * a bit fuzzy... -- msa >;) ]
      */
-    if (conf->until > CurrentTime)
+    if (conf->until > event_base->time.sec_monotonic)
       continue;
 
-    conf->until = CurrentTime + conf->class->con_freq;
+    conf->until = event_base->time.sec_monotonic + conf->class->con_freq;
 
     /*
      * Found a CONNECT config with port specified, scan clients
@@ -329,7 +329,7 @@ try_connections(void *unused)
   }
 }
 
-int
+bool
 server_valid_name(const char *name)
 {
   unsigned int dots = 0;
@@ -338,7 +338,7 @@ server_valid_name(const char *name)
   for (; *p; ++p)
   {
     if (!IsServChar(*p))
-      return 0;
+      return false;
 
     if (*p == '.')
       ++dots;
@@ -379,47 +379,44 @@ server_make(struct Client *client_p)
  * We return 1 if the connection is attempted, since we don't know whether
  * it suceeded or not, and 0 if it fails in here somewhere.
  */
-int
+bool
 server_connect(struct MaskItem *conf, struct Client *by)
 {
   char buf[HOSTIPLEN + 1] = "";
 
-  /* conversion structs */
-  struct sockaddr_in *v4;
-
   /* Make sure conf is useful */
   assert(conf);
   assert(conf->type == CONF_SERVER);
   assert(hash_find_server(conf->name) == NULL);  /* This should have been checked by the caller */
 
-  getnameinfo((const struct sockaddr *)&conf->addr, conf->addr.ss_len,
-              buf, sizeof(buf), NULL, 0, NI_NUMERICHOST);
-  ilog(LOG_TYPE_IRCD, "Connect to %s[%s] @%s", conf->name, conf->host, buf);
-
   /* Still processing a DNS lookup? -> exit */
-  if (conf->dns_pending)
+  if (conf->dns_pending == true)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error connecting to %s: DNS lookup for connect{} in progress.",
                          conf->name);
-    return 0;
+    return false;
   }
 
-  if (conf->dns_failed)
+  if (conf->dns_failed == true)
   {
     sendto_realops_flags(UMODE_SERVNOTICE, L_ALL, SEND_NOTICE,
                          "Error connecting to %s: DNS lookup for connect{} failed.",
                          conf->name);
-    return 0;
+    return false;
   }
 
+  getnameinfo((const struct sockaddr *)conf->addr, conf->addr->ss_len,
+              buf, sizeof(buf), NULL, 0, NI_NUMERICHOST);
+  ilog(LOG_TYPE_IRCD, "Connect to %s[%s] @%s", conf->name, conf->host, buf);
+
   /* Create a socket for the server connection */
-  int fd = comm_socket(conf->addr.ss.ss_family, SOCK_STREAM, 0);
+  int fd = comm_socket(conf->addr->ss.ss_family, SOCK_STREAM, 0);
   if (fd == -1)
   {
     /* Eek, failure to create the socket */
     report_error(L_ALL, "opening stream socket to %s: %s", conf->name, errno);
-    return 0;
+    return false;
   }
 
   /* Create a local client */
@@ -432,7 +429,8 @@ server_connect(struct MaskItem *conf, struct Client *by)
   /* We already converted the ip once, so lets use it - stu */
   strlcpy(client_p->sockhost, buf, sizeof(client_p->sockhost));
 
-  client_p->connection->fd = fd_open(fd, 1, NULL);
+  client_p->ip = *conf->addr;
+  client_p->connection->fd = fd_open(fd, true, NULL);
 
   /* Server names are always guaranteed under HOSTLEN chars */
   fd_note(client_p->connection->fd, "Server: %s", client_p->name);
@@ -451,91 +449,10 @@ server_connect(struct MaskItem *conf, struct Client *by)
     strlcpy(client_p->serv->by, "AutoConn.", sizeof(client_p->serv->by));
 
   SetConnecting(client_p);
-  client_p->connection->aftype = conf->aftype;
 
   /* Now, initiate the connection */
-  /* XXX assume that a non 0 type means a specific bind address
-   * for this connect.
-   */
-  switch (conf->aftype)
-  {
-    case AF_INET:
-      v4 = (struct sockaddr_in*)&conf->bind;
-
-      if (v4->sin_addr.s_addr)
-      {
-        struct irc_ssaddr ipn;
-
-        memset(&ipn, 0, sizeof(ipn));
-        ipn.ss.ss_family = AF_INET;
-        ipn.ss_port = 0;
-        memcpy(&ipn, &conf->bind, sizeof(ipn));
-
-        comm_connect_tcp(client_p->connection->fd, conf->host, conf->port,
-                         (struct sockaddr *)&ipn, ipn.ss_len,
-                         server_connect_callback, client_p, conf->aftype,
-                         CONNECTTIMEOUT);
-      }
-      else if (ConfigServerInfo.specific_ipv4_vhost)
-      {
-        struct irc_ssaddr ipn;
-
-        memset(&ipn, 0, sizeof(ipn));
-        ipn.ss.ss_family = AF_INET;
-        ipn.ss_port = 0;
-        memcpy(&ipn, &ConfigServerInfo.ip, sizeof(ipn));
-
-        comm_connect_tcp(client_p->connection->fd, conf->host, conf->port,
-                         (struct sockaddr *)&ipn, ipn.ss_len,
-                         server_connect_callback, client_p, conf->aftype,
-                         CONNECTTIMEOUT);
-      }
-      else
-        comm_connect_tcp(client_p->connection->fd, conf->host, conf->port,
-                         NULL, 0, server_connect_callback, client_p, conf->aftype,
-                         CONNECTTIMEOUT);
-      break;
-    case AF_INET6:
-      {
-        struct irc_ssaddr ipn;
-        struct sockaddr_in6 *v6;
-        struct sockaddr_in6 *v6conf;
-
-        memset(&ipn, 0, sizeof(ipn));
-        v6conf = (struct sockaddr_in6 *)&conf->bind;
-        v6 = (struct sockaddr_in6 *)&ipn;
-
-        if (memcmp(&v6conf->sin6_addr, &v6->sin6_addr, sizeof(struct in6_addr)))
-        {
-          memcpy(&ipn, &conf->bind, sizeof(ipn));
-          ipn.ss.ss_family = AF_INET6;
-          ipn.ss_port = 0;
-
-          comm_connect_tcp(client_p->connection->fd,
-                           conf->host, conf->port,
-                           (struct sockaddr *)&ipn, ipn.ss_len,
-                           server_connect_callback, client_p,
-                           conf->aftype, CONNECTTIMEOUT);
-        }
-        else if (ConfigServerInfo.specific_ipv6_vhost)
-        {
-          memcpy(&ipn, &ConfigServerInfo.ip6, sizeof(ipn));
-          ipn.ss.ss_family = AF_INET6;
-          ipn.ss_port = 0;
-
-          comm_connect_tcp(client_p->connection->fd,
-                           conf->host, conf->port,
-                           (struct sockaddr *)&ipn, ipn.ss_len,
-                           server_connect_callback, client_p,
-                           conf->aftype, CONNECTTIMEOUT);
-        }
-        else
-          comm_connect_tcp(client_p->connection->fd,
-                           conf->host, conf->port,
-                           NULL, 0, server_connect_callback, client_p,
-                           conf->aftype, CONNECTTIMEOUT);
-      }
-  }
+  comm_connect_tcp(client_p->connection->fd, conf->addr, conf->port, conf->bind,
+                   server_connect_callback, client_p, CONNECTTIMEOUT);
 
   /*
    * At this point we have a connection in progress and a connect {} block
@@ -544,7 +461,7 @@ server_connect(struct MaskItem *conf, struct Client *by)
    *
    * The socket has been connected or connect is in progress.
    */
-  return 1;
+  return true;
 }
 
 static void
@@ -563,6 +480,9 @@ server_finish_tls_handshake(struct Client *client_p)
     return;
   }
 
+  /* Next, send the initial handshake */
+  SetHandshake(client_p);
+
   sendto_one(client_p, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
 
   sendto_one(client_p, "CAPAB :%s", capab_get(NULL));
@@ -589,7 +509,7 @@ server_tls_handshake(fde_t *F, void *data)
   tls_handshake_status_t ret = tls_handshake(&F->ssl, TLS_ROLE_CLIENT, &sslerr);
   if (ret != TLS_HANDSHAKE_DONE)
   {
-    if ((CurrentTime - client_p->connection->firsttime) > CONNECTTIMEOUT)
+    if ((event_base->time.sec_monotonic - client_p->connection->created_monotonic) > TLS_HANDSHAKE_TIMEOUT)
     {
       exit_client(client_p, "Timeout during TLS handshake");
       return;
@@ -599,11 +519,11 @@ server_tls_handshake(fde_t *F, void *data)
     {
       case TLS_HANDSHAKE_WANT_WRITE:
         comm_setselect(F, COMM_SELECT_WRITE,
-                       server_tls_handshake, client_p, CONNECTTIMEOUT);
+                       server_tls_handshake, client_p, TLS_HANDSHAKE_TIMEOUT);
         return;
       case TLS_HANDSHAKE_WANT_READ:
         comm_setselect(F, COMM_SELECT_READ,
-                       server_tls_handshake, client_p, CONNECTTIMEOUT);
+                       server_tls_handshake, client_p, TLS_HANDSHAKE_TIMEOUT);
         return;
       default:
       {
@@ -618,7 +538,7 @@ server_tls_handshake(fde_t *F, void *data)
 
   comm_settimeout(F, 0, NULL, NULL);
 
-  if (!tls_verify_cert(&F->ssl, ConfigServerInfo.message_digest_algorithm, &client_p->certfp))
+  if (tls_verify_cert(&F->ssl, ConfigServerInfo.message_digest_algorithm, &client_p->certfp) == false)
     ilog(LOG_TYPE_IRCD, "Server %s!%s@%s gave bad TLS client certificate",
          client_p->name, client_p->username, client_p->host);
 
@@ -633,7 +553,7 @@ server_tls_connect_init(struct Client *client_p, const struct MaskItem *conf, fd
   assert(client_p->connection->fd);
   assert(client_p->connection->fd == F);
 
-  if (!tls_new(&F->ssl, F->fd, TLS_ROLE_CLIENT))
+  if (tls_new(&F->ssl, F->fd, TLS_ROLE_CLIENT) == false)
   {
     SetDead(client_p);
     exit_client(client_p, "TLS context initialization failed");
@@ -665,9 +585,6 @@ server_connect_callback(fde_t *F, int status, void *data)
   assert(client_p->connection->fd);
   assert(client_p->connection->fd == F);
 
-  /* Next, for backward purposes, record the ip of the server */
-  memcpy(&client_p->connection->ip, &F->connect.hostaddr, sizeof(client_p->connection->ip));
-
   /* Check the status */
   if (status != COMM_OK)
   {
@@ -702,15 +619,15 @@ server_connect_callback(fde_t *F, int status, void *data)
     return;
   }
 
-  /* Next, send the initial handshake */
-  SetHandshake(client_p);
-
   if (IsConfSSL(conf))
   {
     server_tls_connect_init(client_p, conf, F);
     return;
   }
 
+  /* Next, send the initial handshake */
+  SetHandshake(client_p);
+
   sendto_one(client_p, "PASS %s TS %u %s", conf->spasswd, TS_CURRENT, me.id);
 
   sendto_one(client_p, "CAPAB :%s", capab_get(NULL));
