@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2015-2018 ircd-hybrid development team
+ *  Copyright (c) 2015-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls_gnutls.c
  * \brief Includes all GnuTLS-specific TLS functions
- * \version $Id: tls_gnutls.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: tls_gnutls.c 8960 2019-05-11 08:50:02Z michael $
  */
 
 #include "stdinc.h"
@@ -35,9 +35,16 @@
 
 #ifdef HAVE_TLS_GNUTLS
 
-static int TLS_initialized;
+static bool TLS_initialized;
+static const char tls_default_priority_string[] =
+  "NORMAL:"
+  "%SERVER_PRECEDENCE:"
+  "!VERS-TLS1.1:"
+  "!VERS-TLS1.0:"
+  "!VERS-SSL3.0";
 
-int
+
+bool
 tls_is_initialized(void)
 {
   return TLS_initialized;
@@ -60,16 +67,16 @@ tls_free_cred(tls_context_t cred)
   xfree(cred);
 }
 
-int
+bool
 tls_new_cred(void)
 {
   int ret;
   struct gnutls_context *context;
 
-  TLS_initialized = 0;
+  TLS_initialized = false;
 
   if (!ConfigServerInfo.ssl_certificate_file || !ConfigServerInfo.rsa_private_key_file)
-    return 1;
+    return true;
 
   context = xcalloc(sizeof(*context));
 
@@ -80,12 +87,12 @@ tls_new_cred(void)
   {
     ilog(LOG_TYPE_IRCD, "ERROR: Could not initialize the TLS credentials -- %s", gnutls_strerror(ret));
     xfree(context);
-    return 0;
+    return false;
   }
 
   /* TBD: set ciphers based on serverinfo::ssl_cipher_list */
 
-  gnutls_priority_init(&context->priorities, "NORMAL:%SERVER_PRECEDENCE:!VERS-SSL3.0", NULL);
+  gnutls_priority_init(&context->priorities, tls_default_priority_string, NULL);
 
   ret = gnutls_certificate_set_x509_key_file(context->x509_cred, ConfigServerInfo.ssl_certificate_file, ConfigServerInfo.rsa_private_key_file, GNUTLS_X509_FMT_PEM);
   if (ret != GNUTLS_E_SUCCESS)
@@ -95,7 +102,7 @@ tls_new_cred(void)
     gnutls_certificate_free_credentials(context->x509_cred);
     gnutls_priority_deinit(context->priorities);
     xfree(context);
-    return 0;
+    return false;
   }
 
   gnutls_dh_params_init(&context->dh_params);
@@ -140,8 +147,8 @@ tls_new_cred(void)
   ConfigServerInfo.tls_ctx = context;
   ++context->refs;
 
-  TLS_initialized = 1;
-  return 1;
+  TLS_initialized = true;
+  return true;
 }
 
 const char *
@@ -168,7 +175,7 @@ tls_get_version(void)
   return buf;
 }
 
-int
+bool
 tls_isusing(tls_data_t *tls_data)
 {
   return tls_data->session != NULL;
@@ -180,10 +187,10 @@ tls_free(tls_data_t *tls_data)
   gnutls_deinit(tls_data->session);
 }
 
-int
-tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, int *want_write)
+ssize_t
+tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, bool *want_write)
 {
-  int length = gnutls_record_recv(tls_data->session, buf, bufsize);
+  ssize_t length = gnutls_record_recv(tls_data->session, buf, bufsize);
 
   if (length <= 0)
   {
@@ -203,10 +210,10 @@ tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, int *want_write)
   return length;
 }
 
-int
-tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, int *want_read)
+ssize_t
+tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, bool *want_read)
 {
-  int length = gnutls_record_send(tls_data->session, buf, bufsize);
+  ssize_t length = gnutls_record_send(tls_data->session, buf, bufsize);
 
   if (length <= 0)
   {
@@ -234,11 +241,11 @@ tls_shutdown(tls_data_t *tls_data)
     tls_free_cred(tls_data->context);
 }
 
-int
+bool
 tls_new(tls_data_t *tls_data, int fd, tls_role_t role)
 {
-  if (!TLS_initialized)
-    return 0;
+  if (TLS_initialized == false)
+    return false;
 
   gnutls_init(&tls_data->session, role == TLS_ROLE_SERVER ? GNUTLS_SERVER : GNUTLS_CLIENT);
 
@@ -254,10 +261,10 @@ tls_new(tls_data_t *tls_data, int fd, tls_role_t role)
     /* Request client certificate if any. */
     gnutls_certificate_server_set_request(tls_data->session, GNUTLS_CERT_REQUEST);
 
-  return 1;
+  return true;
 }
 
-int
+bool
 tls_set_ciphers(tls_data_t *tls_data, const char *cipher_list)
 {
   int ret;
@@ -269,13 +276,13 @@ tls_set_ciphers(tls_data_t *tls_data, const char *cipher_list)
   if (ret != GNUTLS_E_SUCCESS)
   {
     /* GnuTLS did not understand the user supplied string, log and fall back to the default priorities */
-    ilog(LOG_TYPE_IRCD, "Failed to set GnuTLS priorities to \"%s\": %s Syntax error at position %u, falling back to default (NORMAL:%%SERVER_PRECEDENCE:!VERS-SSL3.0)",
-         cipher_list, gnutls_strerror(ret), (unsigned int)(prioerror - cipher_list));
-    gnutls_priority_init(&tls_data->context->priorities, "NORMAL:%SERVER_PRECEDENCE:!VERS-SSL3.0", NULL);
-    return 0;
+    ilog(LOG_TYPE_IRCD, "Failed to set GnuTLS priorities to \"%s\": %s Syntax error at position %u, falling back to default %",
+         cipher_list, gnutls_strerror(ret), (unsigned int)(prioerror - cipher_list), tls_default_priority_string);
+    gnutls_priority_init(&tls_data->context->priorities, tls_default_priority_string, NULL);
+    return false;
   }
 
-  return 1;
+  return true;
 }
 
 tls_handshake_status_t
@@ -312,7 +319,7 @@ tls_handshake(tls_data_t *tls_data, tls_role_t role, const char **errstr)
   }
 }
 
-int
+bool
 tls_verify_cert(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
 {
   int ret;
@@ -324,12 +331,12 @@ tls_verify_cert(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
   char buf[TLS_GNUTLS_MAX_HASH_SIZE * 2 + 1];
 
   cert_list = gnutls_certificate_get_peers(tls_data->session, &cert_list_size);
-  if (!cert_list)
-    return 1;  /* No certificate */
+  if (cert_list == NULL)
+    return true;  /* No certificate */
 
   ret = gnutls_x509_crt_init(&cert);
   if (ret != GNUTLS_E_SUCCESS)
-    return 1;
+    return true;
 
   ret = gnutls_x509_crt_import(cert, &cert_list[0], GNUTLS_X509_FMT_DER);
   if (ret != GNUTLS_E_SUCCESS)
@@ -343,10 +350,10 @@ tls_verify_cert(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
   *fingerprint = xstrdup(buf);
 
   gnutls_x509_crt_deinit(cert);
-  return 1;
+  return true;
 
 info_done_dealloc:
   gnutls_x509_crt_deinit(cert);
-  return 0;
+  return false;
 }
 #endif  /* HAVE_TLS_GNUTLS */
