@@ -3,7 +3,7 @@
  *
  *  Copyright (c) 2015 Attila Molnar <attilamolnar@hush.com>
  *  Copyright (c) 2015 Adam <Adam@anope.org>
- *  Copyright (c) 2005-2018 ircd-hybrid development team
+ *  Copyright (c) 2005-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 /*! \file tls_openssl.c
  * \brief Includes all OpenSSL-specific TLS functions
- * \version $Id: tls_openssl.c 8280 2018-02-20 19:30:33Z michael $
+ * \version $Id: tls_openssl.c 8960 2019-05-11 08:50:02Z michael $
  */
 
 #include "stdinc.h"
@@ -35,7 +35,7 @@
 
 #ifdef HAVE_TLS_OPENSSL
 
-static int TLS_initialized;
+static bool TLS_initialized;
 
 /*
  * report_crypto_errors - Dump crypto error list to log
@@ -55,7 +55,7 @@ always_accept_verify_cb(int preverify_ok, X509_STORE_CTX *x509_ctx)
   return 1;
 }
 
-int
+bool
 tls_is_initialized(void)
 {
   return TLS_initialized;
@@ -73,7 +73,7 @@ tls_init(void)
   SSL_load_error_strings();
   SSLeay_add_ssl_algorithms();
 
-  if (!(ConfigServerInfo.tls_ctx.server_ctx = SSL_CTX_new(SSLv23_server_method())))
+  if ((ConfigServerInfo.tls_ctx.server_ctx = SSL_CTX_new(SSLv23_server_method())) == NULL)
   {
     const char *s = ERR_lib_error_string(ERR_get_error());
 
@@ -82,7 +82,7 @@ tls_init(void)
     return;  /* Not reached */
   }
 
-  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TICKET);
+  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TLSv1|SSL_OP_NO_TLSv1_1|SSL_OP_NO_TICKET);
   SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_SINGLE_DH_USE|SSL_OP_CIPHER_SERVER_PREFERENCE);
   SSL_CTX_set_verify(ConfigServerInfo.tls_ctx.server_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE,
                      always_accept_verify_cb);
@@ -101,7 +101,7 @@ tls_init(void)
   SSL_CTX_set_options(ConfigServerInfo.tls_ctx.server_ctx, SSL_OP_SINGLE_ECDH_USE);
 #endif
 
-  if (!(ConfigServerInfo.tls_ctx.client_ctx = SSL_CTX_new(SSLv23_client_method())))
+  if ((ConfigServerInfo.tls_ctx.client_ctx = SSL_CTX_new(SSLv23_client_method())) == NULL)
   {
     const char *s = ERR_lib_error_string(ERR_get_error());
 
@@ -110,40 +110,40 @@ tls_init(void)
     return;  /* Not reached */
   }
 
-  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.client_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TICKET);
+  SSL_CTX_set_options(ConfigServerInfo.tls_ctx.client_ctx, SSL_OP_NO_SSLv2|SSL_OP_NO_SSLv3|SSL_OP_NO_TLSv1|SSL_OP_NO_TLSv1_1|SSL_OP_NO_TICKET);
   SSL_CTX_set_options(ConfigServerInfo.tls_ctx.client_ctx, SSL_OP_SINGLE_DH_USE);
   SSL_CTX_set_verify(ConfigServerInfo.tls_ctx.client_ctx, SSL_VERIFY_PEER|SSL_VERIFY_CLIENT_ONCE,
                      always_accept_verify_cb);
   SSL_CTX_set_session_cache_mode(ConfigServerInfo.tls_ctx.client_ctx, SSL_SESS_CACHE_OFF);
 }
 
-int
+bool
 tls_new_cred(void)
 {
-  TLS_initialized = 0;
+  TLS_initialized = false;
 
   if (!ConfigServerInfo.ssl_certificate_file || !ConfigServerInfo.rsa_private_key_file)
-    return 1;
+    return true;
 
   if (SSL_CTX_use_certificate_chain_file(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.ssl_certificate_file) <= 0 ||
       SSL_CTX_use_certificate_chain_file(ConfigServerInfo.tls_ctx.client_ctx, ConfigServerInfo.ssl_certificate_file) <= 0)
   {
     report_crypto_errors();
-    return 0;
+    return false;
   }
 
   if (SSL_CTX_use_PrivateKey_file(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) <= 0 ||
       SSL_CTX_use_PrivateKey_file(ConfigServerInfo.tls_ctx.client_ctx, ConfigServerInfo.rsa_private_key_file, SSL_FILETYPE_PEM) <= 0)
   {
     report_crypto_errors();
-    return 0;
+    return false;
   }
 
   if (!SSL_CTX_check_private_key(ConfigServerInfo.tls_ctx.server_ctx) ||
       !SSL_CTX_check_private_key(ConfigServerInfo.tls_ctx.client_ctx))
   {
     report_crypto_errors();
-    return 0;
+    return false;
   }
 
   if (ConfigServerInfo.ssl_dh_param_file)
@@ -213,8 +213,8 @@ set_default_curve:
   if (ConfigServerInfo.ssl_cipher_list)
     SSL_CTX_set_cipher_list(ConfigServerInfo.tls_ctx.server_ctx, ConfigServerInfo.ssl_cipher_list);
 
-  TLS_initialized = 1;
-  return 1;
+  TLS_initialized = true;
+  return true;
 }
 
 const char *
@@ -241,7 +241,7 @@ tls_get_version(void)
   return buf;
 }
 
-int
+bool
 tls_isusing(tls_data_t *tls_data)
 {
   SSL *ssl = *tls_data;
@@ -255,11 +255,11 @@ tls_free(tls_data_t *tls_data)
   *tls_data = NULL;
 }
 
-int
-tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, int *want_write)
+ssize_t
+tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, bool *want_write)
 {
   SSL *ssl = *tls_data;
-  int length = SSL_read(ssl, buf, bufsize);
+  ssize_t length = SSL_read(ssl, buf, bufsize);
 
   /* Translate openssl error codes, sigh */
   if (length < 0)
@@ -269,7 +269,7 @@ tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, int *want_write)
       case SSL_ERROR_WANT_WRITE:
       {
         /* OpenSSL wants to write, we signal this to the caller and do nothing about that here */
-        *want_write = 1;
+        *want_write = true;
         break;
       }
       case SSL_ERROR_WANT_READ:
@@ -288,11 +288,11 @@ tls_read(tls_data_t *tls_data, char *buf, size_t bufsize, int *want_write)
   return length;
 }
 
-int
-tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, int *want_read)
+ssize_t
+tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, bool *want_read)
 {
   SSL *ssl = *tls_data;
-  int retlen = SSL_write(ssl, buf, bufsize);
+  ssize_t retlen = SSL_write(ssl, buf, bufsize);
 
   /* Translate openssl error codes, sigh */
   if (retlen < 0)
@@ -300,7 +300,7 @@ tls_write(tls_data_t *tls_data, const char *buf, size_t bufsize, int *want_read)
     switch (SSL_get_error(ssl, retlen))
     {
       case SSL_ERROR_WANT_READ:
-        *want_read = 1;
+        *want_read = true;
         break;  /* Retry later, don't register for write events */
       case SSL_ERROR_WANT_WRITE:
         errno = EWOULDBLOCK;
@@ -330,13 +330,13 @@ tls_shutdown(tls_data_t *tls_data)
     SSL_shutdown(ssl);
 }
 
-int
+bool
 tls_new(tls_data_t *tls_data, int fd, tls_role_t role)
 {
   SSL *ssl;
 
-  if (!TLS_initialized)
-    return 0;
+  if (TLS_initialized == false)
+    return false;
 
   if (role == TLS_ROLE_SERVER)
     ssl = SSL_new(ConfigServerInfo.tls_ctx.server_ctx);
@@ -347,19 +347,19 @@ tls_new(tls_data_t *tls_data, int fd, tls_role_t role)
   {
     ilog(LOG_TYPE_IRCD, "SSL_new() ERROR! -- %s",
          ERR_error_string(ERR_get_error(), NULL));
-    return 0;
+    return false;
   }
 
   *tls_data = ssl;
   SSL_set_fd(ssl, fd);
-  return 1;
+  return true;
 }
 
-int
+bool
 tls_set_ciphers(tls_data_t *tls_data, const char *cipher_list)
 {
   SSL_set_cipher_list(*tls_data, cipher_list);
-  return 1;
+  return true;
 }
 
 tls_handshake_status_t
@@ -394,32 +394,35 @@ tls_handshake(tls_data_t *tls_data, tls_role_t role, const char **errstr)
   }
 }
 
-int
+bool
 tls_verify_cert(tls_data_t *tls_data, tls_md_t digest, char **fingerprint)
 {
   SSL *ssl = *tls_data;
-  X509 *cert = SSL_get_peer_certificate(ssl);
   unsigned int n;
   char buf[EVP_MAX_MD_SIZE * 2 + 1];
   unsigned char md[EVP_MAX_MD_SIZE];
-  int ret = 0;
+  bool ret = false;
 
   /* Accept NULL return from SSL_get_peer_certificate */
-  if (!cert)
-    return 1;
+  X509 *cert = SSL_get_peer_certificate(ssl);
+  if (cert == NULL)
+    return true;
 
-  int res = SSL_get_verify_result(ssl);
-  if (res == X509_V_OK || res == X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN ||
-      res == X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE ||
-      res == X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT)
+  switch (SSL_get_verify_result(ssl))
   {
-    ret = 1;
+    case X509_V_OK:
+    case X509_V_ERR_SELF_SIGNED_CERT_IN_CHAIN:
+    case X509_V_ERR_UNABLE_TO_VERIFY_LEAF_SIGNATURE:
+    case X509_V_ERR_DEPTH_ZERO_SELF_SIGNED_CERT:
+      ret = true;
 
-    if (X509_digest(cert, digest, md, &n))
-    {
-      binary_to_hex(md, buf, n);
-      *fingerprint = xstrdup(buf);
-    }
+      if (X509_digest(cert, digest, md, &n))
+      {
+        binary_to_hex(md, buf, n);
+        *fingerprint = xstrdup(buf);
+      }
+    default:
+      break;
   }
 
   X509_free(cert);
