@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file user.c
  * \brief User related functions.
- * \version $Id: user.c 8438 2018-03-29 13:05:42Z michael $
+ * \version $Id: user.c 8962 2019-05-11 21:04:34Z michael $
  */
 
 #include "stdinc.h"
@@ -46,12 +46,12 @@
 #include "memory.h"
 #include "packet.h"
 #include "rng_mt.h"
-#include "userhost.h"
 #include "misc.h"
 #include "parse.h"
 #include "watch.h"
 #include "isupport.h"
 #include "tls.h"
+#include "patchlevel.h"
 
 static char umode_buffer[UMODE_MAX_STR];
 
@@ -62,6 +62,7 @@ const struct user_modes  umode_tab[] =
   { 'F', UMODE_FARCONNECT   },
   { 'G', UMODE_SOFTCALLERID },
   { 'H', UMODE_HIDDEN       },
+  { 'X', UMODE_EXPIRATION   },
   { 'R', UMODE_REGONLY      },
   { 'S', UMODE_SSL          },
   { 'W', UMODE_WEBIRC       },
@@ -111,7 +112,7 @@ user_modes_init(void)
 void
 show_lusers(struct Client *client_p)
 {
-  if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
+  if (ConfigServerHide.hide_servers == 0 || HasUMode(client_p, UMODE_OPER))
     sendto_one_numeric(client_p, &me, RPL_LUSERCLIENT, (dlink_list_length(&global_client_list) - Count.invisi),
                        Count.invisi, dlink_list_length(&global_server_list));
   else
@@ -127,7 +128,7 @@ show_lusers(struct Client *client_p)
   if (dlink_list_length(channel_get_list()))
     sendto_one_numeric(client_p, &me, RPL_LUSERCHANNELS, dlink_list_length(channel_get_list()));
 
-  if (!ConfigServerHide.hide_servers || HasUMode(client_p, UMODE_OPER))
+  if (ConfigServerHide.hide_servers == 0 || HasUMode(client_p, UMODE_OPER))
   {
     sendto_one_numeric(client_p, &me, RPL_LUSERME, dlink_list_length(&local_client_list), dlink_list_length(&local_server_list));
     sendto_one_numeric(client_p, &me, RPL_LOCALUSERS, dlink_list_length(&local_client_list), Count.max_loc);
@@ -266,9 +267,9 @@ user_welcome(struct Client *client_p)
   sendto_one_numeric(client_p, &me, RPL_WELCOME, ConfigServerInfo.network_name,
                      client_p->name, client_p->username, client_p->realhost);
   sendto_one_numeric(client_p, &me, RPL_YOURHOST,
-                     listener_get_name(client_p->connection->listener), ircd_version);
+                     listener_get_name(client_p->connection->listener), PATCHLEVEL);
   sendto_one_numeric(client_p, &me, RPL_CREATED, built_date);
-  sendto_one_numeric(client_p, &me, RPL_MYINFO, me.name, ircd_version, umode_buffer);
+  sendto_one_numeric(client_p, &me, RPL_MYINFO, me.name, PATCHLEVEL, umode_buffer);
 
   isupport_show(client_p);
   show_lusers(client_p);
@@ -281,13 +282,13 @@ user_welcome(struct Client *client_p)
  * outupt       - 1 if exiting 0 if ok
  * side effects -
  */
-static int
+static bool
 check_xline(struct Client *client_p)
 {
   const struct GecosItem *gecos = NULL;
 
   if (HasFlag(client_p, FLAGS_EXEMPTXLINE))
-    return 0;
+    return false;
 
   if ((gecos = gecos_find(client_p->info, match)))
   {
@@ -299,10 +300,10 @@ check_xline(struct Client *client_p)
 
     ++ServerStats.is_ref;
     exit_client(client_p, "Bad user info");
-    return 1;
+    return true;
   }
 
-  return 0;
+  return false;
 }
 
 /*! \brief This function is called when both NICK and USER messages
@@ -316,13 +317,13 @@ register_local_user(struct Client *client_p)
   const struct MaskItem *conf = NULL;
 
   assert(client_p == client_p->from);
+  assert(client_p->connection->registration == 0);
   assert(MyConnect(client_p));
   assert(IsUnknown(client_p));
-  assert(!client_p->connection->registration);
 
   if (ConfigGeneral.ping_cookie)
   {
-    if (!HasFlag(client_p, FLAGS_PINGSENT) && !client_p->connection->random_ping)
+    if (!HasFlag(client_p, FLAGS_PINGSENT) && client_p->connection->random_ping == 0)
     {
       do
         client_p->connection->random_ping = genrand_int32();
@@ -337,11 +338,7 @@ register_local_user(struct Client *client_p)
       return;
   }
 
-  client_p->connection->last_privmsg = CurrentTime;
-  /* Straight up the maximum rate of flooding... */
-  client_p->connection->allow_read = MAX_FLOOD_BURST;
-
-  if (!check_client(client_p))
+  if (check_client(client_p) == 0)
     return;
 
   conf = client_p->connection->confs.head->data;
@@ -374,7 +371,7 @@ register_local_user(struct Client *client_p)
   /* Password check */
   if (!EmptyString(conf->passwd))
   {
-    if (!match_conf_password(client_p->connection->password, conf))
+    if (match_conf_password(client_p->connection->password, conf) == false)
     {
       ++ServerStats.is_ref;
 
@@ -417,7 +414,7 @@ register_local_user(struct Client *client_p)
     return;
   }
 
-  if (!valid_username(client_p->username, 1))
+  if (valid_username(client_p->username, true) == false)
   {
     char buf[IRCD_BUFSIZE] = "";
 
@@ -454,7 +451,10 @@ register_local_user(struct Client *client_p)
   }
 
   assert(client_p->servptr == &me);
+
   SetClient(client_p);
+  client_p->connection->last_privmsg = event_base->time.sec_monotonic;
+
   dlinkAdd(client_p, &client_p->lnode, &client_p->servptr->serv->client_list);
   dlinkAdd(client_p, &client_p->node, &global_client_list);
 
@@ -483,8 +483,6 @@ register_local_user(struct Client *client_p)
   ++Count.totalrestartcount;
 
   user_welcome(client_p);
-  userhost_add(client_p->sockhost, 0);
-  AddFlag(client_p, FLAGS_USERHOST);
 
   introduce_client(client_p);
 }
@@ -518,9 +516,6 @@ register_remote_user(struct Client *client_p)
   if (dlink_list_length(&global_client_list) > Count.max_tot)
     Count.max_tot = dlink_list_length(&global_client_list);
 
-  userhost_add(client_p->sockhost, 1);
-  AddFlag(client_p, FLAGS_USERHOST);
-
   if (HasFlag(client_p->servptr, FLAGS_EOB))
     sendto_realops_flags(UMODE_FARCONNECT, L_ALL, SEND_NOTICE,
                          "Client connecting at %s: %s (%s@%s) [%s] [%s] <%s>",
@@ -540,7 +535,7 @@ register_remote_user(struct Client *client_p)
  * NOTE: this doesn't allow a hostname to begin with a dot and
  * will not allow more dots than chars.
  */
-int
+bool
 valid_hostname(const char *hostname)
 {
   const char *p = hostname;
@@ -548,11 +543,11 @@ valid_hostname(const char *hostname)
   assert(p);
 
   if (EmptyString(p) || *p == '.' || *p == ':')
-    return 0;
+    return false;
 
   for (; *p; ++p)
     if (!IsHostChar(*p))
-      return 0;
+      return false;
 
   return p - hostname <= HOSTLEN;
 }
@@ -568,8 +563,8 @@ valid_hostname(const char *hostname)
  * Allow '.' in username to allow for "first.last"
  * style of username
  */
-int
-valid_username(const char *username, const int local)
+bool
+valid_username(const char *username, bool local)
 {
   const char *p = username;
 
@@ -584,7 +579,7 @@ valid_username(const char *username, const int local)
    * or "-hi-@somehost", "h-----@somehost" would still be accepted.
    */
   if (!IsAlNum(*p))
-    return 0;
+    return false;
 
   if (local)
   {
@@ -595,19 +590,19 @@ valid_username(const char *username, const int local)
       if (*p == '.' && ConfigGeneral.dots_in_ident)
       {
         if (++dots > ConfigGeneral.dots_in_ident)
-          return 0;
+          return false;
         if (!IsUserChar(*(p + 1)))
-          return 0;
+          return false;
       }
       else if (!IsUserChar(*p))
-        return 0;
+        return false;
     }
   }
   else
   {
     while (*++p)
       if (!IsUserChar(*p))
-        return 0;
+        return false;
   }
 
   return p - username <= USERLEN;
@@ -620,8 +615,8 @@ valid_username(const char *username, const int local)
  * output       - none
  * side effects - walks through the nickname, returning 0 if erroneous
  */
-int
-valid_nickname(const char *nickname, const int local)
+bool
+valid_nickname(const char *nickname, bool local)
 {
   const char *p = nickname;
 
@@ -631,11 +626,11 @@ valid_nickname(const char *nickname, const int local)
    * Nicks can't start with a digit or - or be 0 length.
    */
   if (EmptyString(p) || *p == '-' || (IsDigit(*p) && local))
-    return 0;
+    return false;
 
   for (; *p; ++p)
     if (!IsNickChar(*p))
-      return 0;
+      return false;
 
   return p - nickname <= NICKLEN;
 }
@@ -647,8 +642,7 @@ valid_nickname(const char *nickname, const int local)
  * \param buf       Pointer to buffer to build string in
  */
 void
-send_umode(struct Client *client_p, unsigned int dispatch,
-           unsigned int old, char *buf)
+send_umode(struct Client *client_p, bool dispatch, unsigned int old, char *buf)
 {
   char *m = buf;
   int what = 0;
@@ -685,7 +679,7 @@ send_umode(struct Client *client_p, unsigned int dispatch,
 
   *m = '\0';
 
-  if (dispatch && *buf)
+  if (dispatch == true && *buf)
     sendto_one(client_p, ":%s!%s@%s MODE %s :%s",
                client_p->name, client_p->username,
                client_p->host, client_p->name, buf);
@@ -714,14 +708,14 @@ user_set_hostmask(struct Client *client_p, const char *hostname)
 {
   dlink_node *node;
 
-  if (!strcmp(client_p->host, hostname))
+  if (strcmp(client_p->host, hostname) == 0)
     return;
 
   if (ConfigGeneral.cycle_on_host_change)
-    sendto_common_channels_local(client_p, 0, 0, CAP_CHGHOST, ":%s!%s@%s QUIT :Changing hostname",
+    sendto_common_channels_local(client_p, false, 0, CAP_CHGHOST, ":%s!%s@%s QUIT :Changing hostname",
                                  client_p->name, client_p->username, client_p->host);
 
-  sendto_common_channels_local(client_p, 0, CAP_CHGHOST, 0, ":%s!%s@%s CHGHOST %s %s",
+  sendto_common_channels_local(client_p, true, CAP_CHGHOST, 0, ":%s!%s@%s CHGHOST %s %s",
                                client_p->name, client_p->username,
                                client_p->host, client_p->username, hostname);
 
@@ -733,7 +727,7 @@ user_set_hostmask(struct Client *client_p, const char *hostname)
     clear_ban_cache_list(&client_p->channel);
   }
 
-  if (!ConfigGeneral.cycle_on_host_change)
+  if (ConfigGeneral.cycle_on_host_change == 0)
     return;
 
   DLINK_FOREACH(node, client_p->channel.head)
@@ -779,7 +773,7 @@ user_set_hostmask(struct Client *client_p, const char *hostname)
   }
 
   if (client_p->away[0])
-    sendto_common_channels_local(client_p, 0, CAP_AWAY_NOTIFY, CAP_CHGHOST,
+    sendto_common_channels_local(client_p, false, CAP_AWAY_NOTIFY, CAP_CHGHOST,
                                  ":%s!%s@%s AWAY :%s",
                                  client_p->name, client_p->username,
                                  client_p->host, client_p->away);
