@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1997 Jukka Santala (Donwulff)
- *  Copyright (c) 2005-2018 ircd-hybrid development team
+ *  Copyright (c) 2005-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file watch.c
  * \brief File including functions for WATCH support
- * \version $Id: watch.c 8384 2018-03-16 20:06:38Z michael $
+ * \version $Id: watch.c 8927 2019-04-22 11:08:47Z michael $
  */
 
 #include "stdinc.h"
@@ -81,7 +81,7 @@ watch_check_hash(const struct Client *client_p, const enum irc_numerics reply)
     return;  /* This name isn't on watch */
 
   /* Update the time of last change to item */
-  watch->lasttime = CurrentTime;
+  watch->lasttime = event_base->time.sec_real;
 
   /* Send notifies out to everybody on the list in header */
   DLINK_FOREACH(node, watch->watched_by.head)
@@ -102,7 +102,7 @@ watch_find_hash(const char *name)
   {
     struct Watch *watch = node->data;
 
-    if (!irccmp(watch->name, name))
+    if (irccmp(watch->name, name) == 0)
       return watch;
   }
 
@@ -124,10 +124,11 @@ watch_add_to_hash_table(const char *name, struct Client *client_p)
   {
     watch = xcalloc(sizeof(*watch));
 
-    watch->lasttime = CurrentTime;
     strlcpy(watch->name, name, sizeof(watch->name));
+    watch->hash_value = strhash(watch->name);
+    watch->lasttime = event_base->time.sec_real;
 
-    dlinkAdd(watch, &watch->node, &watchTable[strhash(watch->name)]);
+    dlinkAdd(watch, &watch->node, &watchTable[watch->hash_value]);
   }
   else
   {
@@ -168,8 +169,8 @@ watch_del_from_hash_table(const char *name, struct Client *client_p)
   /* In case this header is now empty of notices, remove it */
   if (watch->watched_by.head == NULL)
   {
-    assert(dlinkFind(&watchTable[strhash(watch->name)], watch));
-    dlinkDelete(&watch->node, &watchTable[strhash(watch->name)]);
+    assert(dlinkFind(&watchTable[watch->hash_value], watch));
+    dlinkDelete(&watch->node, &watchTable[watch->hash_value]);
     xfree(watch);
   }
 }
@@ -196,8 +197,8 @@ watch_del_watch_list(struct Client *client_p)
     /* If this leaves a header without notifies, remove it. */
     if (watch->watched_by.head == NULL)
     {
-      assert(dlinkFind(&watchTable[strhash(watch->name)], watch));
-      dlinkDelete(&watch->node, &watchTable[strhash(watch->name)]);
+      assert(dlinkFind(&watchTable[watch->hash_value], watch));
+      dlinkDelete(&watch->node, &watchTable[watch->hash_value]);
 
       xfree(watch);
     }
