@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2018 ircd-hybrid development team
+ *  Copyright (c) 1997-2019 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file whowas.c
  * \brief WHOWAS user cache.
- * \version $Id: whowas.c 8384 2018-03-16 20:06:38Z michael $
+ * \version $Id: whowas.c 8948 2019-04-30 22:37:37Z michael $
  */
 
 #include "stdinc.h"
@@ -40,15 +40,15 @@ static dlink_list whowas_hash[HASHSIZE];
 
 
 /*! \brief Returns a slot of the whowas_hash by the hash value associated with it.
- * \param hashv Hash value.
+ * \param hash_value Hash value.
  */
 const dlink_list *
-whowas_get_hash(unsigned int hashv)
+whowas_get_hash(unsigned int hash_value)
 {
-  if (hashv >= HASHSIZE)
+  if (hash_value >= HASHSIZE)
     return NULL;
 
-  return &whowas_hash[hashv];
+  return &whowas_hash[hash_value];
 }
 
 /*! \brief Unlinks a Whowas struct from its associated lists.
@@ -60,7 +60,7 @@ whowas_unlink(struct Whowas *whowas)
   if (whowas->online)
     dlinkDelete(&whowas->cnode, &whowas->online->whowas_list);
 
-  dlinkDelete(&whowas->hnode, &whowas_hash[whowas->hashv]);
+  dlinkDelete(&whowas->hnode, &whowas_hash[whowas->hash_value]);
   dlinkDelete(&whowas->lnode, &whowas_list);
 
   return whowas;
@@ -114,15 +114,15 @@ whowas_trim(void)
  * \param online   Either 1 if it's a nick change or 0 on client exit
  */
 void
-whowas_add_history(struct Client *client_p, const int online)
+whowas_add_history(struct Client *client_p, bool online)
 {
   struct Whowas *whowas = whowas_make();
 
   assert(IsClient(client_p));
 
-  whowas->hashv = strhash(client_p->name);
-  whowas->shide = IsHidden(client_p->servptr) != 0;
-  whowas->logoff = CurrentTime;
+  whowas->hash_value = strhash(client_p->name);
+  whowas->logoff = event_base->time.sec_real;
+  whowas->server_hidden = IsHidden(client_p->servptr) != 0;
 
   strlcpy(whowas->account, client_p->account, sizeof(whowas->account));
   strlcpy(whowas->name, client_p->name, sizeof(whowas->name));
@@ -133,7 +133,7 @@ whowas_add_history(struct Client *client_p, const int online)
   strlcpy(whowas->realname, client_p->info, sizeof(whowas->realname));
   strlcpy(whowas->servername, client_p->servptr->name, sizeof(whowas->servername));
 
-  if (online)
+  if (online == true)
   {
     whowas->online = client_p;
     dlinkAdd(whowas, &whowas->cnode, &client_p->whowas_list);
@@ -141,7 +141,7 @@ whowas_add_history(struct Client *client_p, const int online)
   else
     whowas->online = NULL;
 
-  dlinkAdd(whowas, &whowas->hnode, &whowas_hash[whowas->hashv]);
+  dlinkAdd(whowas, &whowas->hnode, &whowas_hash[whowas->hash_value]);
   dlinkAdd(whowas, &whowas->lnode, &whowas_list);
 }
 
@@ -173,7 +173,7 @@ whowas_get_history(const char *name, uintmax_t timelimit)
 {
   dlink_node *node;
 
-  timelimit = CurrentTime - timelimit;
+  timelimit = event_base->time.sec_real - timelimit;
 
   DLINK_FOREACH(node, whowas_hash[strhash(name)].head)
   {
